// Copyright (c) 2013-2016 CoolGames

(function() {
/******************************************************************************
 * Spine Runtimes Software License
 * Version 2.3
 * 
 * Copyright (c) 2013-2015, Esoteric Software
 * All rights reserved.
 * 
 * You are granted a perpetual, non-exclusive, non-sublicensable and
 * non-transferable license to use, install, execute and perform the Spine
 * Runtimes Software (the "Software") and derivative works solely for personal
 * or internal use. Without the written permission of Esoteric Software (see
 * Section 2 of the Spine Software License Agreement), you may not (a) modify,
 * translate, adapt or otherwise create derivative works, improvements of the
 * Software or develop new applications using the Software or (b) remove,
 * delete, alter or obscure any trademarks or any copyright, trademark, patent
 * or other intellectual property or proprietary rights notices on or in the
 * Software, including any copy thereof. Redistributions in binary or source
 * form must include this license and terms.
 * 
 * THIS SOFTWARE IS PROVIDED BY ESOTERIC SOFTWARE "AS IS" AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO
 * EVENT SHALL ESOTERIC SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *****************************************************************************/

var spine = {
	radDeg: 180 / Math.PI,
	degRad: Math.PI / 180,
	temp: [],
    Float32Array: (typeof(Float32Array) === 'undefined') ? Array : Float32Array,
    Uint16Array: (typeof(Uint16Array) === 'undefined') ? Array : Uint16Array
};

spine.BoneData = function (name, parent) {
	this.name = name;
	this.parent = parent;
};
spine.BoneData.prototype = {
	length: 0,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	inheritScale: true,
	inheritRotation: true,
	flipX: false, flipY: false
};

spine.BlendMode = {
	normal: 0,
	additive: 1,
	multiply: 2,
	screen: 3
};

spine.SlotData = function (name, boneData) {
	this.name = name;
	this.boneData = boneData;
};
spine.SlotData.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	attachmentName: null,
	blendMode: spine.BlendMode.normal
};

spine.IkConstraintData = function (name) {
	this.name = name;
	this.bones = [];
};
spine.IkConstraintData.prototype = {
	target: null,
	bendDirection: 1,
	mix: 1
};

spine.Bone = function (boneData, skeleton, parent) {
	this.data = boneData;
	this.skeleton = skeleton;
	this.parent = parent;
	this.setToSetupPose();
};
spine.Bone.yDown = false;
spine.Bone.prototype = {
	x: 0, y: 0,
	rotation: 0, rotationIK: 0,
	scaleX: 1, scaleY: 1,
	flipX: false, flipY: false,
	m00: 0, m01: 0, worldX: 0, // a b x
	m10: 0, m11: 0, worldY: 0, // c d y
	worldRotation: 0,
	worldScaleX: 1, worldScaleY: 1,
	worldFlipX: false, worldFlipY: false,
	updateWorldTransform: function () {
		var parent = this.parent;
		if (parent) {
			this.worldX = this.x * parent.m00 + this.y * parent.m01 + parent.worldX;
			this.worldY = this.x * parent.m10 + this.y * parent.m11 + parent.worldY;
			if (this.data.inheritScale) {
				this.worldScaleX = parent.worldScaleX * this.scaleX;
				this.worldScaleY = parent.worldScaleY * this.scaleY;
			} else {
				this.worldScaleX = this.scaleX;
				this.worldScaleY = this.scaleY;
			}
			this.worldRotation = this.data.inheritRotation ? (parent.worldRotation + this.rotationIK) : this.rotationIK;
			this.worldFlipX = parent.worldFlipX != this.flipX;
			this.worldFlipY = parent.worldFlipY != this.flipY;
		} else {
			var skeletonFlipX = this.skeleton.flipX, skeletonFlipY = this.skeleton.flipY;
			this.worldX = skeletonFlipX ? -this.x : this.x;
			this.worldY = (skeletonFlipY != spine.Bone.yDown) ? -this.y : this.y;
			this.worldScaleX = this.scaleX;
			this.worldScaleY = this.scaleY;
			this.worldRotation = this.rotationIK;
			this.worldFlipX = skeletonFlipX != this.flipX;
			this.worldFlipY = skeletonFlipY != this.flipY;
		}
		var radians = this.worldRotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		if (this.worldFlipX) {
			this.m00 = -cos * this.worldScaleX;
			this.m01 = sin * this.worldScaleY;
		} else {
			this.m00 = cos * this.worldScaleX;
			this.m01 = -sin * this.worldScaleY;
		}
		if (this.worldFlipY != spine.Bone.yDown) {
			this.m10 = -sin * this.worldScaleX;
			this.m11 = -cos * this.worldScaleY;
		} else {
			this.m10 = sin * this.worldScaleX;
			this.m11 = cos * this.worldScaleY;
		}
	},
	setToSetupPose: function () {
		var data = this.data;
		this.x = data.x;
		this.y = data.y;
		this.rotation = data.rotation;
		this.rotationIK = this.rotation;
		this.scaleX = data.scaleX;
		this.scaleY = data.scaleY;
		this.flipX = data.flipX;
		this.flipY = data.flipY;
	},
	worldToLocal: function (world) {
		var dx = world[0] - this.worldX, dy = world[1] - this.worldY;
		var m00 = this.m00, m10 = this.m10, m01 = this.m01, m11 = this.m11;
		if (this.worldFlipX != (this.worldFlipY != spine.Bone.yDown)) {
			m00 = -m00;
			m11 = -m11;
		}
		var invDet = 1 / (m00 * m11 - m01 * m10);
		world[0] = dx * m00 * invDet - dy * m01 * invDet;
		world[1] = dy * m11 * invDet - dx * m10 * invDet;
	},
	localToWorld: function (local) {
		var localX = local[0], localY = local[1];
		local[0] = localX * this.m00 + localY * this.m01 + this.worldX;
		local[1] = localX * this.m10 + localY * this.m11 + this.worldY;
	}
};

spine.Slot = function (slotData, bone) {
	this.data = slotData;
	this.bone = bone;
	this.setToSetupPose();
};
spine.Slot.prototype = {
	r: 1, g: 1, b: 1, a: 1,
	_attachmentTime: 0,
	attachment: null,
	attachmentVertices: [],
	setAttachment: function (attachment) {
		if (this.attachment == attachment) return;
		this.attachment = attachment;
		this._attachmentTime = this.bone.skeleton.time;
		this.attachmentVertices.length = 0;
	},
	setAttachmentTime: function (time) {
		this._attachmentTime = this.bone.skeleton.time - time;
	},
	getAttachmentTime: function () {
		return this.bone.skeleton.time - this._attachmentTime;
	},
	setToSetupPose: function () {
		var data = this.data;
		this.r = data.r;
		this.g = data.g;
		this.b = data.b;
		this.a = data.a;

		if (!data.attachmentName)
			this.setAttachment(null);
		else {
			var slotDatas = this.bone.skeleton.data.slots;
			for (var i = 0, n = slotDatas.length; i < n; i++) {
				if (slotDatas[i] == data) {
					this.attachment = null;
					this.setAttachment(this.bone.skeleton.getAttachmentBySlotIndex(i, data.attachmentName));
					break;
				}
			}
		}
	}
};

spine.IkConstraint = function (data, skeleton) {
	this.data = data;
	this.mix = data.mix;
	this.bendDirection = data.bendDirection;

	this.bones = [];
	for (var i = 0, n = data.bones.length; i < n; i++)
		this.bones.push(skeleton.findBone(data.bones[i].name));
	this.target = skeleton.findBone(data.target.name);
};
spine.IkConstraint.prototype = {
	apply: function () {
		var target = this.target;
		var bones = this.bones;
		switch (bones.length) {
		case 1:
			spine.IkConstraint.apply1(bones[0], target.worldX, target.worldY, this.mix);
			break;
		case 2:
			spine.IkConstraint.apply2(bones[0], bones[1], target.worldX, target.worldY, this.bendDirection, this.mix);
			break;
		}
	}
};
/** Adjusts the bone rotation so the tip is as close to the target position as possible. The target is specified in the world
 * coordinate system. */
spine.IkConstraint.apply1 = function (bone, targetX, targetY, alpha) {
	var parentRotation = (!bone.data.inheritRotation || !bone.parent) ? 0 : bone.parent.worldRotation;
	var rotation = bone.rotation;
	var rotationIK = Math.atan2(targetY - bone.worldY, targetX - bone.worldX) * spine.radDeg;
	if (bone.worldFlipX != (bone.worldFlipY != spine.Bone.yDown)) rotationIK = -rotationIK;
	rotationIK -= parentRotation;
	bone.rotationIK = rotation + (rotationIK - rotation) * alpha;
};
/** Adjusts the parent and child bone rotations so the tip of the child is as close to the target position as possible. The
 * target is specified in the world coordinate system.
 * @param child Any descendant bone of the parent. */
spine.IkConstraint.apply2 = function (parent, child, targetX, targetY, bendDirection, alpha) {
	var childRotation = child.rotation, parentRotation = parent.rotation;
	if (!alpha) {
		child.rotationIK = childRotation;
		parent.rotationIK = parentRotation;
		return;
	}
	var positionX, positionY, tempPosition = spine.temp;
	var parentParent = parent.parent;
	if (parentParent) {
		tempPosition[0] = targetX;
		tempPosition[1] = targetY;
		parentParent.worldToLocal(tempPosition);
		targetX = (tempPosition[0] - parent.x) * parentParent.worldScaleX;
		targetY = (tempPosition[1] - parent.y) * parentParent.worldScaleY;
	} else {
		targetX -= parent.x;
		targetY -= parent.y;
	}
	if (child.parent == parent) {
		positionX = child.x;
		positionY = child.y;
	} else {
		tempPosition[0] = child.x;
		tempPosition[1] = child.y;
		child.parent.localToWorld(tempPosition);
		parent.worldToLocal(tempPosition);
		positionX = tempPosition[0];
		positionY = tempPosition[1];
	}
	var childX = positionX * parent.worldScaleX, childY = positionY * parent.worldScaleY;
	var offset = Math.atan2(childY, childX);
	var len1 = Math.sqrt(childX * childX + childY * childY), len2 = child.data.length * child.worldScaleX;
	// Based on code by Ryan Juckett with permission: Copyright (c) 2008-2009 Ryan Juckett, http://www.ryanjuckett.com/
	var cosDenom = 2 * len1 * len2;
	if (cosDenom < 0.0001) {
		child.rotationIK = childRotation + (Math.atan2(targetY, targetX) * spine.radDeg - parentRotation - childRotation) * alpha;
		return;
	}
	var cos = (targetX * targetX + targetY * targetY - len1 * len1 - len2 * len2) / cosDenom;
	if (cos < -1)
		cos = -1;
	else if (cos > 1)
		cos = 1;
	var childAngle = Math.acos(cos) * bendDirection;
	var adjacent = len1 + len2 * cos, opposite = len2 * Math.sin(childAngle);
	var parentAngle = Math.atan2(targetY * adjacent - targetX * opposite, targetX * adjacent + targetY * opposite);
	var rotation = (parentAngle - offset) * spine.radDeg - parentRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	parent.rotationIK = parentRotation + rotation * alpha;
	rotation = (childAngle + offset) * spine.radDeg - childRotation;
	if (rotation > 180)
		rotation -= 360;
	else if (rotation < -180) //
		rotation += 360;
	child.rotationIK = childRotation + (rotation + parent.worldRotation - child.parent.worldRotation) * alpha;
};

spine.Skin = function (name) {
	this.name = name;
	this.attachments = {};
};
spine.Skin.prototype = {
	addAttachment: function (slotIndex, name, attachment) {
		this.attachments[slotIndex + ":" + name] = attachment;
	},
	getAttachment: function (slotIndex, name) {
		return this.attachments[slotIndex + ":" + name];
	},
	_attachAll: function (skeleton, oldSkin) {
		for (var key in oldSkin.attachments) {
			var colon = key.indexOf(":");
			var slotIndex = parseInt(key.substring(0, colon));
			var name = key.substring(colon + 1);
			var slot = skeleton.slots[slotIndex];
			if (slot.attachment && slot.attachment.name == name) {
				var attachment = this.getAttachment(slotIndex, name);
				if (attachment) slot.setAttachment(attachment);
			}
		}
	}
};

spine.Animation = function (name, timelines, duration) {
	this.name = name;
	this.timelines = timelines;
	this.duration = duration;
};
spine.Animation.prototype = {
	apply: function (skeleton, lastTime, time, loop, events) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, 1);
	},
	mix: function (skeleton, lastTime, time, loop, events, alpha) {
		if (loop && this.duration != 0) {
			time %= this.duration;
			lastTime %= this.duration;
		}
		var timelines = this.timelines;
		for (var i = 0, n = timelines.length; i < n; i++)
			timelines[i].apply(skeleton, lastTime, time, events, alpha);
	}
};
spine.Animation.binarySearch = function (values, target, step) {
	var low = 0;
	var high = Math.floor(values.length / step) - 2;
	if (!high) return step;
	var current = high >>> 1;
	while (true) {
		if (values[(current + 1) * step] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return (low + 1) * step;
		current = (low + high) >>> 1;
	}
};
spine.Animation.binarySearch1 = function (values, target) {
	var low = 0;
	var high = values.length - 2;
	if (!high) return 1;
	var current = high >>> 1;
	while (true) {
		if (values[current + 1] <= target)
			low = current + 1;
		else
			high = current;
		if (low == high) return low + 1;
		current = (low + high) >>> 1;
	}
};
spine.Animation.linearSearch = function (values, target, step) {
	for (var i = 0, last = values.length - step; i <= last; i += step)
		if (values[i] > target) return i;
	return -1;
};

spine.Curves = function (frameCount) {
	this.curves = []; // type, x, y, ...
	//this.curves.length = (frameCount - 1) * 19/*BEZIER_SIZE*/;
};
spine.Curves.prototype = {
	setLinear: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 0/*LINEAR*/;
	},
	setStepped: function (frameIndex) {
		this.curves[frameIndex * 19/*BEZIER_SIZE*/] = 1/*STEPPED*/;
	},
	/** Sets the control handle positions for an interpolation bezier curve used to transition from this keyframe to the next.
	 * cx1 and cx2 are from 0 to 1, representing the percent of time between the two keyframes. cy1 and cy2 are the percent of
	 * the difference between the keyframe's values. */
	setCurve: function (frameIndex, cx1, cy1, cx2, cy2) {
		var subdiv1 = 1 / 10/*BEZIER_SEGMENTS*/, subdiv2 = subdiv1 * subdiv1, subdiv3 = subdiv2 * subdiv1;
		var pre1 = 3 * subdiv1, pre2 = 3 * subdiv2, pre4 = 6 * subdiv2, pre5 = 6 * subdiv3;
		var tmp1x = -cx1 * 2 + cx2, tmp1y = -cy1 * 2 + cy2, tmp2x = (cx1 - cx2) * 3 + 1, tmp2y = (cy1 - cy2) * 3 + 1;
		var dfx = cx1 * pre1 + tmp1x * pre2 + tmp2x * subdiv3, dfy = cy1 * pre1 + tmp1y * pre2 + tmp2y * subdiv3;
		var ddfx = tmp1x * pre4 + tmp2x * pre5, ddfy = tmp1y * pre4 + tmp2y * pre5;
		var dddfx = tmp2x * pre5, dddfy = tmp2y * pre5;

		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var curves = this.curves;
		curves[i++] = 2/*BEZIER*/;
		
		var x = dfx, y = dfy;
		for (var n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			curves[i] = x;
			curves[i + 1] = y;
			dfx += ddfx;
			dfy += ddfy;
			ddfx += dddfx;
			ddfy += dddfy;
			x += dfx;
			y += dfy;
		}
	},
	getCurvePercent: function (frameIndex, percent) {
		percent = percent < 0 ? 0 : (percent > 1 ? 1 : percent);
		var curves = this.curves;
		var i = frameIndex * 19/*BEZIER_SIZE*/;
		var type = curves[i];
		if (type === 0/*LINEAR*/) return percent;
		if (type == 1/*STEPPED*/) return 0;
		i++;
		var x = 0;
		for (var start = i, n = i + 19/*BEZIER_SIZE*/ - 1; i < n; i += 2) {
			x = curves[i];
			if (x >= percent) {
				var prevX, prevY;
				if (i == start) {
					prevX = 0;
					prevY = 0;
				} else {
					prevX = curves[i - 2];
					prevY = curves[i - 1];
				}
				return prevY + (curves[i + 1] - prevY) * (percent - prevX) / (x - prevX);
			}
		}
		var y = curves[i - 1];
		return y + (1 - y) * (percent - x) / (1 - x); // Last point is 1,1.
	}
};

spine.RotateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, angle, ...
	this.frames.length = frameCount * 2;
};
spine.RotateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, angle) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = angle;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 2]) { // Time is after last frame.
			var amount = bone.data.rotation + frames[frames.length - 1] - bone.rotation;
			while (amount > 180)
				amount -= 360;
			while (amount < -180)
				amount += 360;
			bone.rotation += amount * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 2);
		var prevFrameValue = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 2/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 2 - 1, percent);

		var amount = frames[frameIndex + 1/*FRAME_VALUE*/] - prevFrameValue;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		amount = bone.data.rotation + (prevFrameValue + amount * percent) - bone.rotation;
		while (amount > 180)
			amount -= 360;
		while (amount < -180)
			amount += 360;
		bone.rotation += amount * alpha;
	}
};

spine.TranslateTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.TranslateTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.x += (bone.data.x + frames[frames.length - 2] - bone.x) * alpha;
			bone.y += (bone.data.y + frames[frames.length - 1] - bone.y) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.x += (bone.data.x + prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent - bone.x) * alpha;
		bone.y += (bone.data.y + prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent - bone.y) * alpha;
	}
};

spine.ScaleTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, x, y, ...
	this.frames.length = frameCount * 3;
};
spine.ScaleTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, x, y) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = x;
		this.frames[frameIndex + 2] = y;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var bone = skeleton.bones[this.boneIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			bone.scaleX += (bone.data.scaleX * frames[frames.length - 2] - bone.scaleX) * alpha;
			bone.scaleY += (bone.data.scaleY * frames[frames.length - 1] - bone.scaleY) * alpha;
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameX = frames[frameIndex - 2];
		var prevFrameY = frames[frameIndex - 1];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		bone.scaleX += (bone.data.scaleX * (prevFrameX + (frames[frameIndex + 1/*FRAME_X*/] - prevFrameX) * percent) - bone.scaleX) * alpha;
		bone.scaleY += (bone.data.scaleY * (prevFrameY + (frames[frameIndex + 2/*FRAME_Y*/] - prevFrameY) * percent) - bone.scaleY) * alpha;
	}
};

spine.ColorTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, r, g, b, a, ...
	this.frames.length = frameCount * 5;
};
spine.ColorTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 5;
	},
	setFrame: function (frameIndex, time, r, g, b, a) {
		frameIndex *= 5;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = r;
		this.frames[frameIndex + 2] = g;
		this.frames[frameIndex + 3] = b;
		this.frames[frameIndex + 4] = a;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var r, g, b, a;
		if (time >= frames[frames.length - 5]) {
			// Time is after last frame.
			var i = frames.length - 1;
			r = frames[i - 3];
			g = frames[i - 2];
			b = frames[i - 1];
			a = frames[i];
		} else {
			// Interpolate between the previous frame and the current frame.
			var frameIndex = spine.Animation.binarySearch(frames, time, 5);
			var prevFrameR = frames[frameIndex - 4];
			var prevFrameG = frames[frameIndex - 3];
			var prevFrameB = frames[frameIndex - 2];
			var prevFrameA = frames[frameIndex - 1];
			var frameTime = frames[frameIndex];
			var percent = 1 - (time - frameTime) / (frames[frameIndex - 5/*PREV_FRAME_TIME*/] - frameTime);
			percent = this.curves.getCurvePercent(frameIndex / 5 - 1, percent);

			r = prevFrameR + (frames[frameIndex + 1/*FRAME_R*/] - prevFrameR) * percent;
			g = prevFrameG + (frames[frameIndex + 2/*FRAME_G*/] - prevFrameG) * percent;
			b = prevFrameB + (frames[frameIndex + 3/*FRAME_B*/] - prevFrameB) * percent;
			a = prevFrameA + (frames[frameIndex + 4/*FRAME_A*/] - prevFrameA) * percent;
		}
		var slot = skeleton.slots[this.slotIndex];
		if (alpha < 1) {
			slot.r += (r - slot.r) * alpha;
			slot.g += (g - slot.g) * alpha;
			slot.b += (b - slot.b) * alpha;
			slot.a += (a - slot.a) * alpha;
		} else {
			slot.r = r;
			slot.g = g;
			slot.b = b;
			slot.a = a;
		}
	}
};

spine.AttachmentTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.attachmentNames = [];
	this.attachmentNames.length = frameCount;
};
spine.AttachmentTimeline.prototype = {
	slotIndex: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, attachmentName) {
		this.frames[frameIndex] = time;
		this.attachmentNames[frameIndex] = attachmentName;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;

		var frameIndex = time >= frames[frames.length - 1] ? frames.length - 1 : spine.Animation.binarySearch1(frames, time) - 1;
		if (frames[frameIndex] < lastTime) return;

		var attachmentName = this.attachmentNames[frameIndex];
		skeleton.slots[this.slotIndex].setAttachment(
			!attachmentName ? null : skeleton.getAttachmentBySlotIndex(this.slotIndex, attachmentName));
	}
};

spine.EventTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.events = [];
	this.events.length = frameCount;
};
spine.EventTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, event) {
		this.frames[frameIndex] = time;
		this.events[frameIndex] = event;
	},
	/** Fires events for frames > lastTime and <= time. */
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		if (!firedEvents) return;

		var frames = this.frames;
		var frameCount = frames.length;

		if (lastTime > time) { // Fire events after last time for looped animations.
			this.apply(skeleton, lastTime, Number.MAX_VALUE, firedEvents, alpha);
			lastTime = -1;
		} else if (lastTime >= frames[frameCount - 1]) // Last time is after last frame.
			return;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (lastTime < frames[0])
			frameIndex = 0;
		else {
			frameIndex = spine.Animation.binarySearch1(frames, lastTime);
			var frame = frames[frameIndex];
			while (frameIndex > 0) { // Fire multiple events with the same frame.
				if (frames[frameIndex - 1] != frame) break;
				frameIndex--;
			}
		}
		var events = this.events;
		for (; frameIndex < frameCount && time >= frames[frameIndex]; frameIndex++)
			firedEvents.push(events[frameIndex]);
	}
};

spine.DrawOrderTimeline = function (frameCount) {
	this.frames = []; // time, ...
	this.frames.length = frameCount;
	this.drawOrders = [];
	this.drawOrders.length = frameCount;
};
spine.DrawOrderTimeline.prototype = {
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, drawOrder) {
		this.frames[frameIndex] = time;
		this.drawOrders[frameIndex] = drawOrder;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameIndex;
		if (time >= frames[frames.length - 1]) // Time is after last frame.
			frameIndex = frames.length - 1;
		else
			frameIndex = spine.Animation.binarySearch1(frames, time) - 1;

		var drawOrder = skeleton.drawOrder;
		var slots = skeleton.slots;
		var drawOrderToSetupIndex = this.drawOrders[frameIndex];
		if (!drawOrderToSetupIndex) {
			for (var i = 0, n = slots.length; i < n; i++)
				drawOrder[i] = slots[i];
		} else {
			for (var i = 0, n = drawOrderToSetupIndex.length; i < n; i++)
				drawOrder[i] = skeleton.slots[drawOrderToSetupIndex[i]];
		}

	}
};

spine.FfdTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = [];
	this.frames.length = frameCount;
	this.frameVertices = [];
	this.frameVertices.length = frameCount;
};
spine.FfdTimeline.prototype = {
	slotIndex: 0,
	attachment: 0,
	getFrameCount: function () {
		return this.frames.length;
	},
	setFrame: function (frameIndex, time, vertices) {
		this.frames[frameIndex] = time;
		this.frameVertices[frameIndex] = vertices;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var slot = skeleton.slots[this.slotIndex];
		if (slot.attachment != this.attachment) return;

		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var frameVertices = this.frameVertices;
		var vertexCount = frameVertices[0].length;

		var vertices = slot.attachmentVertices;
		if (vertices.length != vertexCount) alpha = 1;
		vertices.length = vertexCount;

		if (time >= frames[frames.length - 1]) { // Time is after last frame.
			var lastVertices = frameVertices[frames.length - 1];
			if (alpha < 1) {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] += (lastVertices[i] - vertices[i]) * alpha;
			} else {
				for (var i = 0; i < vertexCount; i++)
					vertices[i] = lastVertices[i];
			}
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch1(frames, time);
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex - 1] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex - 1, percent < 0 ? 0 : (percent > 1 ? 1 : percent));

		var prevVertices = frameVertices[frameIndex - 1];
		var nextVertices = frameVertices[frameIndex];

		if (alpha < 1) {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] += (prev + (nextVertices[i] - prev) * percent - vertices[i]) * alpha;
			}
		} else {
			for (var i = 0; i < vertexCount; i++) {
				var prev = prevVertices[i];
				vertices[i] = prev + (nextVertices[i] - prev) * percent;
			}
		}
	}
};

spine.IkConstraintTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, mix, bendDirection, ...
	this.frames.length = frameCount * 3;
};
spine.IkConstraintTimeline.prototype = {
	ikConstraintIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 3;
	},
	setFrame: function (frameIndex, time, mix, bendDirection) {
		frameIndex *= 3;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = mix;
		this.frames[frameIndex + 2] = bendDirection;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) return; // Time is before first frame.

		var ikConstraint = skeleton.ikConstraints[this.ikConstraintIndex];

		if (time >= frames[frames.length - 3]) { // Time is after last frame.
			ikConstraint.mix += (frames[frames.length - 2] - ikConstraint.mix) * alpha;
			ikConstraint.bendDirection = frames[frames.length - 1];
			return;
		}

		// Interpolate between the previous frame and the current frame.
		var frameIndex = spine.Animation.binarySearch(frames, time, 3);
		var prevFrameMix = frames[frameIndex + -2/*PREV_FRAME_MIX*/];
		var frameTime = frames[frameIndex];
		var percent = 1 - (time - frameTime) / (frames[frameIndex + -3/*PREV_FRAME_TIME*/] - frameTime);
		percent = this.curves.getCurvePercent(frameIndex / 3 - 1, percent);

		var mix = prevFrameMix + (frames[frameIndex + 1/*FRAME_MIX*/] - prevFrameMix) * percent;
		ikConstraint.mix += (mix - ikConstraint.mix) * alpha;
		ikConstraint.bendDirection = frames[frameIndex + -1/*PREV_FRAME_BEND_DIRECTION*/];
	}
};

spine.FlipXTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipXTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipX = frames[frameIndex + 1] != 0;
	}
};

spine.FlipYTimeline = function (frameCount) {
	this.curves = new spine.Curves(frameCount);
	this.frames = []; // time, flip, ...
	this.frames.length = frameCount * 2;
};
spine.FlipYTimeline.prototype = {
	boneIndex: 0,
	getFrameCount: function () {
		return this.frames.length / 2;
	},
	setFrame: function (frameIndex, time, flip) {
		frameIndex *= 2;
		this.frames[frameIndex] = time;
		this.frames[frameIndex + 1] = flip ? 1 : 0;
	},
	apply: function (skeleton, lastTime, time, firedEvents, alpha) {
		var frames = this.frames;
		if (time < frames[0]) {
			if (lastTime > time) this.apply(skeleton, lastTime, Number.MAX_VALUE, null, 0);
			return;
		} else if (lastTime > time) //
			lastTime = -1;
		var frameIndex = (time >= frames[frames.length - 2] ? frames.length : spine.Animation.binarySearch(frames, time, 2)) - 2;
		if (frames[frameIndex] < lastTime) return;
		skeleton.bones[this.boneIndex].flipY = frames[frameIndex + 1] != 0;
	}
};

spine.SkeletonData = function () {
	this.bones = [];
	this.slots = [];
	this.skins = [];
	this.events = [];
	this.animations = [];
	this.ikConstraints = [];
};
spine.SkeletonData.prototype = {
	name: null,
	defaultSkin: null,
	width: 0, height: 0,
	version: null, hash: null,
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			if (slots[i].name == slotName) return slot[i];
		}
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].name == slotName) return i;
		return -1;
	},
	/** @return May be null. */
	findSkin: function (skinName) {
		var skins = this.skins;
		for (var i = 0, n = skins.length; i < n; i++)
			if (skins[i].name == skinName) return skins[i];
		return null;
	},
	/** @return May be null. */
	findEvent: function (eventName) {
		var events = this.events;
		for (var i = 0, n = events.length; i < n; i++)
			if (events[i].name == eventName) return events[i];
		return null;
	},
	/** @return May be null. */
	findAnimation: function (animationName) {
		var animations = this.animations;
		for (var i = 0, n = animations.length; i < n; i++)
			if (animations[i].name == animationName) return animations[i];
		return null;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].name == ikConstraintName) return ikConstraints[i];
		return null;
	}
};

spine.Skeleton = function (skeletonData) {
	this.data = skeletonData;

	this.bones = [];
	for (var i = 0, n = skeletonData.bones.length; i < n; i++) {
		var boneData = skeletonData.bones[i];
		var parent = !boneData.parent ? null : this.bones[skeletonData.bones.indexOf(boneData.parent)];
		this.bones.push(new spine.Bone(boneData, this, parent));
	}

	this.slots = [];
	this.drawOrder = [];
	for (var i = 0, n = skeletonData.slots.length; i < n; i++) {
		var slotData = skeletonData.slots[i];
		var bone = this.bones[skeletonData.bones.indexOf(slotData.boneData)];
		var slot = new spine.Slot(slotData, bone);
		this.slots.push(slot);
		this.drawOrder.push(slot);
	}
	
	this.ikConstraints = [];
	for (var i = 0, n = skeletonData.ikConstraints.length; i < n; i++)
		this.ikConstraints.push(new spine.IkConstraint(skeletonData.ikConstraints[i], this));

	this.boneCache = [];
	this.updateCache();
};
spine.Skeleton.prototype = {
	x: 0, y: 0,
	skin: null,
	r: 1, g: 1, b: 1, a: 1,
	time: 0,
	flipX: false, flipY: false,
	/** Caches information about bones and IK constraints. Must be called if bones or IK constraints are added or removed. */
	updateCache: function () {
		var ikConstraints = this.ikConstraints;
		var ikConstraintsCount = ikConstraints.length;

		var arrayCount = ikConstraintsCount + 1;
		var boneCache = this.boneCache;
		if (boneCache.length > arrayCount) boneCache.length = arrayCount;
		for (var i = 0, n = boneCache.length; i < n; i++)
			boneCache[i].length = 0;
		while (boneCache.length < arrayCount)
			boneCache[boneCache.length] = [];

		var nonIkBones = boneCache[0];
		var bones = this.bones;

		outer:
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			var current = bone;
			do {
				for (var ii = 0; ii < ikConstraintsCount; ii++) {
					var ikConstraint = ikConstraints[ii];
					var parent = ikConstraint.bones[0];
					var child= ikConstraint.bones[ikConstraint.bones.length - 1];
					while (true) {
						if (current == child) {
							boneCache[ii].push(bone);
							boneCache[ii + 1].push(bone);
							continue outer;
						}
						if (child == parent) break;
						child = child.parent;
					}
				}
				current = current.parent;
			} while (current);
			nonIkBones[nonIkBones.length] = bone;
		}
	},
	/** Updates the world transform for each bone. */
	updateWorldTransform: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++) {
			var bone = bones[i];
			bone.rotationIK = bone.rotation;
		}
		var i = 0, last = this.boneCache.length - 1;
		while (true) {
			var cacheBones = this.boneCache[i];
			for (var ii = 0, nn = cacheBones.length; ii < nn; ii++)
				cacheBones[ii].updateWorldTransform();
			if (i == last) break;
			this.ikConstraints[i].apply();
			i++;
		}
	},
	/** Sets the bones and slots to their setup pose values. */
	setToSetupPose: function () {
		this.setBonesToSetupPose();
		this.setSlotsToSetupPose();
	},
	setBonesToSetupPose: function () {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			bones[i].setToSetupPose();

		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++) {
			var ikConstraint = ikConstraints[i];
			ikConstraint.bendDirection = ikConstraint.data.bendDirection;
			ikConstraint.mix = ikConstraint.data.mix;
		}
	},
	setSlotsToSetupPose: function () {
		var slots = this.slots;
		var drawOrder = this.drawOrder;
		for (var i = 0, n = slots.length; i < n; i++) {
			drawOrder[i] = slots[i];
			slots[i].setToSetupPose(i);
		}
	},
	/** @return May return null. */
	getRootBone: function () {
		return this.bones.length ? this.bones[0] : null;
	},
	/** @return May be null. */
	findBone: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return bones[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findBoneIndex: function (boneName) {
		var bones = this.bones;
		for (var i = 0, n = bones.length; i < n; i++)
			if (bones[i].data.name == boneName) return i;
		return -1;
	},
	/** @return May be null. */
	findSlot: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return slots[i];
		return null;
	},
	/** @return -1 if the bone was not found. */
	findSlotIndex: function (slotName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++)
			if (slots[i].data.name == slotName) return i;
		return -1;
	},
	setSkinByName: function (skinName) {
		var skin = this.data.findSkin(skinName);
		if (!skin) throw "Skin not found: " + skinName;
		this.setSkin(skin);
	},
	/** Sets the skin used to look up attachments before looking in the {@link SkeletonData#getDefaultSkin() default skin}. 
	 * Attachments from the new skin are attached if the corresponding attachment from the old skin was attached. If there was 
	 * no old skin, each slot's setup mode attachment is attached from the new skin.
	 * @param newSkin May be null. */
	setSkin: function (newSkin) {
		if (newSkin) {
			if (this.skin)
				newSkin._attachAll(this, this.skin);
			else {
				var slots = this.slots;
				for (var i = 0, n = slots.length; i < n; i++) {
					var slot = slots[i];
					var name = slot.data.attachmentName;
					if (name) {
						var attachment = newSkin.getAttachment(i, name);
						if (attachment) slot.setAttachment(attachment);
					}
				}
			}
		}
		this.skin = newSkin;
	},
	/** @return May be null. */
	getAttachmentBySlotName: function (slotName, attachmentName) {
		return this.getAttachmentBySlotIndex(this.data.findSlotIndex(slotName), attachmentName);
	},
	/** @return May be null. */
	getAttachmentBySlotIndex: function (slotIndex, attachmentName) {
		if (this.skin) {
			var attachment = this.skin.getAttachment(slotIndex, attachmentName);
			if (attachment) return attachment;
		}
		if (this.data.defaultSkin) return this.data.defaultSkin.getAttachment(slotIndex, attachmentName);
		return null;
	},
	/** @param attachmentName May be null. */
	setAttachment: function (slotName, attachmentName) {
		var slots = this.slots;
		for (var i = 0, n = slots.length; i < n; i++) {
			var slot = slots[i];
			if (slot.data.name == slotName) {
				var attachment = null;
				if (attachmentName) {
					attachment = this.getAttachmentBySlotIndex(i, attachmentName);
					if (!attachment) throw "Attachment not found: " + attachmentName + ", for slot: " + slotName;
				}
				slot.setAttachment(attachment);
				return;
			}
		}
		throw "Slot not found: " + slotName;
	},
	/** @return May be null. */
	findIkConstraint: function (ikConstraintName) {
		var ikConstraints = this.ikConstraints;
		for (var i = 0, n = ikConstraints.length; i < n; i++)
			if (ikConstraints[i].data.name == ikConstraintName) return ikConstraints[i];
		return null;
	},
	update: function (delta) {
		this.time += delta;
	}
};

spine.EventData = function (name) {
	this.name = name;
};
spine.EventData.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.Event = function (data) {
	this.data = data;
};
spine.Event.prototype = {
	intValue: 0,
	floatValue: 0,
	stringValue: null
};

spine.AttachmentType = {
	region: 0,
	boundingbox: 1,
	mesh: 2,
	skinnedmesh: 3
};

spine.RegionAttachment = function (name) {
	this.name = name;
	this.offset = [];
	this.offset.length = 8;
	this.uvs = [];
	this.uvs.length = 8;
};
spine.RegionAttachment.prototype = {
	type: spine.AttachmentType.region,
	x: 0, y: 0,
	rotation: 0,
	scaleX: 1, scaleY: 1,
	width: 0, height: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	setUVs: function (u, v, u2, v2, rotate) {
		var uvs = this.uvs;
		if (rotate) {
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v2;
			uvs[4/*X3*/] = u;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v;
			uvs[0/*X1*/] = u2;
			uvs[1/*Y1*/] = v2;
		} else {
			uvs[0/*X1*/] = u;
			uvs[1/*Y1*/] = v2;
			uvs[2/*X2*/] = u;
			uvs[3/*Y2*/] = v;
			uvs[4/*X3*/] = u2;
			uvs[5/*Y3*/] = v;
			uvs[6/*X4*/] = u2;
			uvs[7/*Y4*/] = v2;
		}
	},
	updateOffset: function () {
		var regionScaleX = this.width / this.regionOriginalWidth * this.scaleX;
		var regionScaleY = this.height / this.regionOriginalHeight * this.scaleY;
		var localX = -this.width / 2 * this.scaleX + this.regionOffsetX * regionScaleX;
		var localY = -this.height / 2 * this.scaleY + this.regionOffsetY * regionScaleY;
		var localX2 = localX + this.regionWidth * regionScaleX;
		var localY2 = localY + this.regionHeight * regionScaleY;
		var radians = this.rotation * spine.degRad;
		var cos = Math.cos(radians);
		var sin = Math.sin(radians);
		var localXCos = localX * cos + this.x;
		var localXSin = localX * sin;
		var localYCos = localY * cos + this.y;
		var localYSin = localY * sin;
		var localX2Cos = localX2 * cos + this.x;
		var localX2Sin = localX2 * sin;
		var localY2Cos = localY2 * cos + this.y;
		var localY2Sin = localY2 * sin;
		var offset = this.offset;
		offset[0/*X1*/] = localXCos - localYSin;
		offset[1/*Y1*/] = localYCos + localXSin;
		offset[2/*X2*/] = localXCos - localY2Sin;
		offset[3/*Y2*/] = localY2Cos + localXSin;
		offset[4/*X3*/] = localX2Cos - localY2Sin;
		offset[5/*Y3*/] = localY2Cos + localX2Sin;
		offset[6/*X4*/] = localX2Cos - localYSin;
		offset[7/*Y4*/] = localYCos + localX2Sin;
	},
	computeVertices: function (x, y, bone, vertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var offset = this.offset;
		vertices[0/*X1*/] = offset[0/*X1*/] * m00 + offset[1/*Y1*/] * m01 + x;
		vertices[1/*Y1*/] = offset[0/*X1*/] * m10 + offset[1/*Y1*/] * m11 + y;
		vertices[2/*X2*/] = offset[2/*X2*/] * m00 + offset[3/*Y2*/] * m01 + x;
		vertices[3/*Y2*/] = offset[2/*X2*/] * m10 + offset[3/*Y2*/] * m11 + y;
		vertices[4/*X3*/] = offset[4/*X3*/] * m00 + offset[5/*X3*/] * m01 + x;
		vertices[5/*X3*/] = offset[4/*X3*/] * m10 + offset[5/*X3*/] * m11 + y;
		vertices[6/*X4*/] = offset[6/*X4*/] * m00 + offset[7/*Y4*/] * m01 + x;
		vertices[7/*Y4*/] = offset[6/*X4*/] * m10 + offset[7/*Y4*/] * m11 + y;
	}
};

spine.MeshAttachment = function (name) {
	this.name = name;
};
spine.MeshAttachment.prototype = {
	type: spine.AttachmentType.mesh,
	vertices: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function () {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var bone = slot.bone;
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		var verticesCount = vertices.length;
		if (slot.attachmentVertices.length == verticesCount) vertices = slot.attachmentVertices;
		for (var i = 0; i < verticesCount; i += 2) {
			var vx = vertices[i];
			var vy = vertices[i + 1];
			worldVertices[i] = vx * m00 + vy * m01 + x;
			worldVertices[i + 1] = vx * m10 + vy * m11 + y;
		}
	}
};

spine.SkinnedMeshAttachment = function (name) {
	this.name = name;
};
spine.SkinnedMeshAttachment.prototype = {
	type: spine.AttachmentType.skinnedmesh,
	bones: null,
	weights: null,
	uvs: null,
	regionUVs: null,
	triangles: null,
	hullLength: 0,
	r: 1, g: 1, b: 1, a: 1,
	path: null,
	rendererObject: null,
	regionU: 0, regionV: 0, regionU2: 0, regionV2: 0, regionRotate: false,
	regionOffsetX: 0, regionOffsetY: 0,
	regionWidth: 0, regionHeight: 0,
	regionOriginalWidth: 0, regionOriginalHeight: 0,
	edges: null,
	width: 0, height: 0,
	updateUVs: function (u, v, u2, v2, rotate) {
		var width = this.regionU2 - this.regionU, height = this.regionV2 - this.regionV;
		var n = this.regionUVs.length;
		if (!this.uvs || this.uvs.length != n) {
            this.uvs = new spine.Float32Array(n);
		}
		if (this.regionRotate) {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i + 1] * width;
                this.uvs[i + 1] = this.regionV + height - this.regionUVs[i] * height;
			}
		} else {
			for (var i = 0; i < n; i += 2) {
                this.uvs[i] = this.regionU + this.regionUVs[i] * width;
                this.uvs[i + 1] = this.regionV + this.regionUVs[i + 1] * height;
			}
		}
	},
	computeWorldVertices: function (x, y, slot, worldVertices) {
		var skeletonBones = slot.bone.skeleton.bones;
		var weights = this.weights;
		var bones = this.bones;

		var w = 0, v = 0, b = 0, f = 0, n = bones.length, nn;
		var wx, wy, bone, vx, vy, weight;
		if (!slot.attachmentVertices.length) {
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3) {
					bone = skeletonBones[bones[v]];
					vx = weights[b];
					vy = weights[b + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		} else {
			var ffd = slot.attachmentVertices;
			for (; v < n; w += 2) {
				wx = 0;
				wy = 0;
				nn = bones[v++] + v;
				for (; v < nn; v++, b += 3, f += 2) {
					bone = skeletonBones[bones[v]];
					vx = weights[b] + ffd[f];
					vy = weights[b + 1] + ffd[f + 1];
					weight = weights[b + 2];
					wx += (vx * bone.m00 + vy * bone.m01 + bone.worldX) * weight;
					wy += (vx * bone.m10 + vy * bone.m11 + bone.worldY) * weight;
				}
				worldVertices[w] = wx + x;
				worldVertices[w + 1] = wy + y;
			}
		}
	}
};

spine.BoundingBoxAttachment = function (name) {
	this.name = name;
	this.vertices = [];
};
spine.BoundingBoxAttachment.prototype = {
	type: spine.AttachmentType.boundingbox,
	computeWorldVertices: function (x, y, bone, worldVertices) {
		x += bone.worldX;
		y += bone.worldY;
		var m00 = bone.m00, m01 = bone.m01, m10 = bone.m10, m11 = bone.m11;
		var vertices = this.vertices;
		for (var i = 0, n = vertices.length; i < n; i += 2) {
			var px = vertices[i];
			var py = vertices[i + 1];
			worldVertices[i] = px * m00 + py * m01 + x;
			worldVertices[i + 1] = px * m10 + py * m11 + y;
		}
	}
};

spine.AnimationStateData = function (skeletonData) {
	this.skeletonData = skeletonData;
	this.animationToMixTime = {};
};
spine.AnimationStateData.prototype = {
	defaultMix: 0,
	setMixByName: function (fromName, toName, duration) {
		var from = this.skeletonData.findAnimation(fromName);
		if (!from) throw "Animation not found: " + fromName;
		var to = this.skeletonData.findAnimation(toName);
		if (!to) throw "Animation not found: " + toName;
		this.setMix(from, to, duration);
	},
	setMix: function (from, to, duration) {
		this.animationToMixTime[from.name + ":" + to.name] = duration;
	},
	getMix: function (from, to) {
		var key = from.name + ":" + to.name;
		return this.animationToMixTime.hasOwnProperty(key) ? this.animationToMixTime[key] : this.defaultMix;
	}
};

spine.TrackEntry = function () {};
spine.TrackEntry.prototype = {
	next: null, previous: null,
	animation: null,
	loop: false,
	delay: 0, time: 0, lastTime: -1, endTime: 0,
	timeScale: 1,
	mixTime: 0, mixDuration: 0, mix: 1,
	onStart: null, onEnd: null, onComplete: null, onEvent: null
};

spine.AnimationState = function (stateData) {
	this.data = stateData;
	this.tracks = [];
	this.events = [];
};
spine.AnimationState.prototype = {
	onStart: null,
	onEnd: null,
	onComplete: null,
	onEvent: null,
	timeScale: 1,
	update: function (delta) {
		delta *= this.timeScale;
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			current.time += delta * current.timeScale;
			if (current.previous) {
				var previousDelta = delta * current.previous.timeScale;
				current.previous.time += previousDelta;
				current.mixTime += previousDelta;
			}

			var next = current.next;
			if (next) {
				next.time = current.lastTime - next.delay;
				if (next.time >= 0) this.setCurrent(i, next);
			} else {
				// End non-looping animation when it reaches its end time and there is no next entry.
				if (!current.loop && current.lastTime >= current.endTime) this.clearTrack(i);
			}
		}
	},
	apply: function (skeleton) {
		for (var i = 0; i < this.tracks.length; i++) {
			var current = this.tracks[i];
			if (!current) continue;

			this.events.length = 0;

			var time = current.time;
			var lastTime = current.lastTime;
			var endTime = current.endTime;
			var loop = current.loop;
			if (!loop && time > endTime) time = endTime;

			var previous = current.previous;
			if (!previous) {
				if (current.mix == 1)
					current.animation.apply(skeleton, current.lastTime, time, loop, this.events);
				else
					current.animation.mix(skeleton, current.lastTime, time, loop, this.events, current.mix);
			} else {
				var previousTime = previous.time;
				if (!previous.loop && previousTime > previous.endTime) previousTime = previous.endTime;
				previous.animation.apply(skeleton, previousTime, previousTime, previous.loop, null);

				var alpha = current.mixTime / current.mixDuration * current.mix;
				if (alpha >= 1) {
					alpha = 1;
					current.previous = null;
				}
				current.animation.mix(skeleton, current.lastTime, time, loop, this.events, alpha);
			}

			for (var ii = 0, nn = this.events.length; ii < nn; ii++) {
				var event = this.events[ii];
				if (current.onEvent) current.onEvent(i, event);
				if (this.onEvent) this.onEvent(i, event);
			}

			// Check if completed the animation or a loop iteration.
			if (loop ? (lastTime % endTime > time % endTime) : (lastTime < endTime && time >= endTime)) {
				var count = Math.floor(time / endTime);
				if (current.onComplete) current.onComplete(i, count);
				if (this.onComplete) this.onComplete(i, count);
			}

			current.lastTime = current.time;
		}
	},
	clearTracks: function () {
		for (var i = 0, n = this.tracks.length; i < n; i++)
			this.clearTrack(i);
		this.tracks.length = 0; 
	},
	clearTrack: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return;
		var current = this.tracks[trackIndex];
		if (!current) return;

		if (current.onEnd) current.onEnd(trackIndex);
		if (this.onEnd) this.onEnd(trackIndex);

		this.tracks[trackIndex] = null;
	},
	_expandToIndex: function (index) {
		if (index < this.tracks.length) return this.tracks[index];
		while (index >= this.tracks.length)
			this.tracks.push(null);
		return null;
	},
	setCurrent: function (index, entry) {
		var current = this._expandToIndex(index);
		if (current) {
			var previous = current.previous;
			current.previous = null;

			if (current.onEnd) current.onEnd(index);
			if (this.onEnd) this.onEnd(index);

			entry.mixDuration = this.data.getMix(current.animation, entry.animation);
			if (entry.mixDuration > 0) {
				entry.mixTime = 0;
				// If a mix is in progress, mix from the closest animation.
				if (previous && current.mixTime / current.mixDuration < 0.5)
					entry.previous = previous;
				else
					entry.previous = current;
			}
		}

		this.tracks[index] = entry;

		if (entry.onStart) entry.onStart(index);
		if (this.onStart) this.onStart(index);
	},
	setAnimationByName: function (trackIndex, animationName, loop) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.setAnimation(trackIndex, animation, loop);
	},
	/** Set the current animation. Any queued animations are cleared. */
	setAnimation: function (trackIndex, animation, loop) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;
		this.setCurrent(trackIndex, entry);
		return entry;
	},
	addAnimationByName: function (trackIndex, animationName, loop, delay) {
		var animation = this.data.skeletonData.findAnimation(animationName);
		if (!animation) throw "Animation not found: " + animationName;
		return this.addAnimation(trackIndex, animation, loop, delay);
	},
	/** Adds an animation to be played delay seconds after the current or last queued animation.
	 * @param delay May be <= 0 to use duration of previous animation minus any mix duration plus the negative delay. */
	addAnimation: function (trackIndex, animation, loop, delay) {
		var entry = new spine.TrackEntry();
		entry.animation = animation;
		entry.loop = loop;
		entry.endTime = animation.duration;

		var last = this._expandToIndex(trackIndex);
		if (last) {
			while (last.next)
				last = last.next;
			last.next = entry;
		} else
			this.tracks[trackIndex] = entry;

		if (delay <= 0) {
			if (last)
				delay += last.endTime - this.data.getMix(last.animation, animation);
			else
				delay = 0;
		}
		entry.delay = delay;

		return entry;
	},
	/** May be null. */
	getCurrent: function (trackIndex) {
		if (trackIndex >= this.tracks.length) return null;
		return this.tracks[trackIndex];
	}
};

spine.SkeletonJson = function (attachmentLoader) {
	this.attachmentLoader = attachmentLoader;
};
spine.SkeletonJson.prototype = {
	scale: 1,
	readSkeletonData: function (root, name) {
		var skeletonData = new spine.SkeletonData();
		skeletonData.name = name;

		// Skeleton.
		var skeletonMap = root["skeleton"];
		if (skeletonMap) {
			skeletonData.hash = skeletonMap["hash"];
			skeletonData.version = skeletonMap["spine"];
			skeletonData.width = skeletonMap["width"] || 0;
			skeletonData.height = skeletonMap["height"] || 0;
		}

		// Bones.
		var bones = root["bones"];
		for (var i = 0, n = bones.length; i < n; i++) {
			var boneMap = bones[i];
			var parent = null;
			if (boneMap["parent"]) {
				parent = skeletonData.findBone(boneMap["parent"]);
				if (!parent) throw "Parent bone not found: " + boneMap["parent"];
			}
			var boneData = new spine.BoneData(boneMap["name"], parent);
			boneData.length = (boneMap["length"] || 0) * this.scale;
			boneData.x = (boneMap["x"] || 0) * this.scale;
			boneData.y = (boneMap["y"] || 0) * this.scale;
			boneData.rotation = (boneMap["rotation"] || 0);
			boneData.scaleX = boneMap.hasOwnProperty("scaleX") ? boneMap["scaleX"] : 1;
			boneData.scaleY = boneMap.hasOwnProperty("scaleY") ? boneMap["scaleY"] : 1;
			boneData.inheritScale = boneMap.hasOwnProperty("inheritScale") ? boneMap["inheritScale"] : true;
			boneData.inheritRotation = boneMap.hasOwnProperty("inheritRotation") ? boneMap["inheritRotation"] : true;
			skeletonData.bones.push(boneData);
		}

		// IK constraints.
		var ik = root["ik"];
		if (ik) {
			for (var i = 0, n = ik.length; i < n; i++) {
				var ikMap = ik[i];
				var ikConstraintData = new spine.IkConstraintData(ikMap["name"]);

				var bones = ikMap["bones"];
				for (var ii = 0, nn = bones.length; ii < nn; ii++) {
					var bone = skeletonData.findBone(bones[ii]);
					if (!bone) throw "IK bone not found: " + bones[ii];
					ikConstraintData.bones.push(bone);
				}

				ikConstraintData.target = skeletonData.findBone(ikMap["target"]);
				if (!ikConstraintData.target) throw "Target bone not found: " + ikMap["target"];

				ikConstraintData.bendDirection = (!ikMap.hasOwnProperty("bendPositive") || ikMap["bendPositive"]) ? 1 : -1;
				ikConstraintData.mix = ikMap.hasOwnProperty("mix") ? ikMap["mix"] : 1;

				skeletonData.ikConstraints.push(ikConstraintData);
			}
		}

		// Slots.
		var slots = root["slots"];
		for (var i = 0, n = slots.length; i < n; i++) {
			var slotMap = slots[i];
			var boneData = skeletonData.findBone(slotMap["bone"]);
			if (!boneData) throw "Slot bone not found: " + slotMap["bone"];
			var slotData = new spine.SlotData(slotMap["name"], boneData);

			var color = slotMap["color"];
			if (color) {
				slotData.r = this.toColor(color, 0);
				slotData.g = this.toColor(color, 1);
				slotData.b = this.toColor(color, 2);
				slotData.a = this.toColor(color, 3);
			}

			slotData.attachmentName = slotMap["attachment"];
			slotData.blendMode = spine.BlendMode[slotMap["blend"] || "normal"];

			skeletonData.slots.push(slotData);
		}

		// Skins.
		var skins = root["skins"];
		for (var skinName in skins) {
			if (!skins.hasOwnProperty(skinName)) continue;
			var skinMap = skins[skinName];
			var skin = new spine.Skin(skinName);
			for (var slotName in skinMap) {
				if (!skinMap.hasOwnProperty(slotName)) continue;
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var slotEntry = skinMap[slotName];
				for (var attachmentName in slotEntry) {
					if (!slotEntry.hasOwnProperty(attachmentName)) continue;
					var attachment = this.readAttachment(skin, attachmentName, slotEntry[attachmentName]);
					if (attachment) skin.addAttachment(slotIndex, attachmentName, attachment);
				}
			}
			skeletonData.skins.push(skin);
			if (skin.name == "default") skeletonData.defaultSkin = skin;
		}

		// Events.
		var events = root["events"];
		for (var eventName in events) {
			if (!events.hasOwnProperty(eventName)) continue;
			var eventMap = events[eventName];
			var eventData = new spine.EventData(eventName);
			eventData.intValue = eventMap["int"] || 0;
			eventData.floatValue = eventMap["float"] || 0;
			eventData.stringValue = eventMap["string"] || null;
			skeletonData.events.push(eventData);
		}

		// Animations.
		var animations = root["animations"];
		for (var animationName in animations) {
			if (!animations.hasOwnProperty(animationName)) continue;
			this.readAnimation(animationName, animations[animationName], skeletonData);
		}

		return skeletonData;
	},
	readAttachment: function (skin, name, map) {
		name = map["name"] || name;

		var type = spine.AttachmentType[map["type"] || "region"];
		var path = map["path"] || name;
		
		var scale = this.scale;
		if (type == spine.AttachmentType.region) {
			var region = this.attachmentLoader.newRegionAttachment(skin, name, path);
			if (!region) return null;
			region.path = path;
			region.x = (map["x"] || 0) * scale;
			region.y = (map["y"] || 0) * scale;
			region.scaleX = map.hasOwnProperty("scaleX") ? map["scaleX"] : 1;
			region.scaleY = map.hasOwnProperty("scaleY") ? map["scaleY"] : 1;
			region.rotation = map["rotation"] || 0;
			region.width = (map["width"] || 0) * scale;
			region.height = (map["height"] || 0) * scale;

			var color = map["color"];
			if (color) {
				region.r = this.toColor(color, 0);
				region.g = this.toColor(color, 1);
				region.b = this.toColor(color, 2);
				region.a = this.toColor(color, 3);
			}

			region.updateOffset();
			return region;
		} else if (type == spine.AttachmentType.mesh) {
			var mesh = this.attachmentLoader.newMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path; 
			mesh.vertices = this.getFloatArray(map, "vertices", scale);
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = this.getFloatArray(map, "uvs", 1);
			mesh.updateUVs();

			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}

			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.skinnedmesh) {
			var mesh = this.attachmentLoader.newSkinnedMeshAttachment(skin, name, path);
			if (!mesh) return null;
			mesh.path = path;

			var uvs = this.getFloatArray(map, "uvs", 1);
			var vertices = this.getFloatArray(map, "vertices", 1);
			var weights = [];
			var bones = [];
			for (var i = 0, n = vertices.length; i < n; ) {
				var boneCount = vertices[i++] | 0;
				bones[bones.length] = boneCount;
				for (var nn = i + boneCount * 4; i < nn; ) {
					bones[bones.length] = vertices[i];
					weights[weights.length] = vertices[i + 1] * scale;
					weights[weights.length] = vertices[i + 2] * scale;
					weights[weights.length] = vertices[i + 3];
					i += 4;
				}
			}
			mesh.bones = bones;
			mesh.weights = weights;
			mesh.triangles = this.getIntArray(map, "triangles");
			mesh.regionUVs = uvs;
			mesh.updateUVs();
			
			color = map["color"];
			if (color) {
				mesh.r = this.toColor(color, 0);
				mesh.g = this.toColor(color, 1);
				mesh.b = this.toColor(color, 2);
				mesh.a = this.toColor(color, 3);
			}
			
			mesh.hullLength = (map["hull"] || 0) * 2;
			if (map["edges"]) mesh.edges = this.getIntArray(map, "edges");
			mesh.width = (map["width"] || 0) * scale;
			mesh.height = (map["height"] || 0) * scale;
			return mesh;
		} else if (type == spine.AttachmentType.boundingbox) {
			var attachment = this.attachmentLoader.newBoundingBoxAttachment(skin, name);
			var vertices = map["vertices"];
			for (var i = 0, n = vertices.length; i < n; i++)
				attachment.vertices.push(vertices[i] * scale);
			return attachment;
		}
		throw "Unknown attachment type: " + type;
	},
	readAnimation: function (name, map, skeletonData) {
		var timelines = [];
		var duration = 0;

		var slots = map["slots"];
		for (var slotName in slots) {
			if (!slots.hasOwnProperty(slotName)) continue;
			var slotMap = slots[slotName];
			var slotIndex = skeletonData.findSlotIndex(slotName);

			for (var timelineName in slotMap) {
				if (!slotMap.hasOwnProperty(timelineName)) continue;
				var values = slotMap[timelineName];
				if (timelineName == "color") {
					var timeline = new spine.ColorTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var color = valueMap["color"];
						var r = this.toColor(color, 0);
						var g = this.toColor(color, 1);
						var b = this.toColor(color, 2);
						var a = this.toColor(color, 3);
						timeline.setFrame(frameIndex, valueMap["time"], r, g, b, a);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 5 - 5]);

				} else if (timelineName == "attachment") {
					var timeline = new spine.AttachmentTimeline(values.length);
					timeline.slotIndex = slotIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex++, valueMap["time"], valueMap["name"]);
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);

				} else
					throw "Invalid timeline type for a slot: " + timelineName + " (" + slotName + ")";
			}
		}

		var bones = map["bones"];
		for (var boneName in bones) {
			if (!bones.hasOwnProperty(boneName)) continue;
			var boneIndex = skeletonData.findBoneIndex(boneName);
			if (boneIndex == -1) throw "Bone not found: " + boneName;
			var boneMap = bones[boneName];

			for (var timelineName in boneMap) {
				if (!boneMap.hasOwnProperty(timelineName)) continue;
				var values = boneMap[timelineName];
				if (timelineName == "rotate") {
					var timeline = new spine.RotateTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap["angle"]);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);

				} else if (timelineName == "translate" || timelineName == "scale") {
					var timeline;
					var timelineScale = 1;
					if (timelineName == "scale")
						timeline = new spine.ScaleTimeline(values.length);
					else {
						timeline = new spine.TranslateTimeline(values.length);
						timelineScale = this.scale;
					}
					timeline.boneIndex = boneIndex;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var x = (valueMap["x"] || 0) * timelineScale;
						var y = (valueMap["y"] || 0) * timelineScale;
						timeline.setFrame(frameIndex, valueMap["time"], x, y);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 3 - 3]);

				} else if (timelineName == "flipX" || timelineName == "flipY") {
					var x = timelineName == "flipX";
					var timeline = x ? new spine.FlipXTimeline(values.length) : new spine.FlipYTimeline(values.length);
					timeline.boneIndex = boneIndex;

					var field = x ? "x" : "y";
					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						timeline.setFrame(frameIndex, valueMap["time"], valueMap[field] || false);
						frameIndex++;
					}
					timelines.push(timeline);
					duration = Math.max(duration, timeline.frames[timeline.getFrameCount() * 2 - 2]);
				} else
					throw "Invalid timeline type for a bone: " + timelineName + " (" + boneName + ")";
			}
		}

		var ikMap = map["ik"];
		for (var ikConstraintName in ikMap) {
			if (!ikMap.hasOwnProperty(ikConstraintName)) continue;
			var ikConstraint = skeletonData.findIkConstraint(ikConstraintName);
			var values = ikMap[ikConstraintName];
			var timeline = new spine.IkConstraintTimeline(values.length);
			timeline.ikConstraintIndex = skeletonData.ikConstraints.indexOf(ikConstraint);
			var frameIndex = 0;
			for (var i = 0, n = values.length; i < n; i++) {
				var valueMap = values[i];
				var mix = valueMap.hasOwnProperty("mix") ? valueMap["mix"] : 1;
				var bendDirection = (!valueMap.hasOwnProperty("bendPositive") || valueMap["bendPositive"]) ? 1 : -1;
				timeline.setFrame(frameIndex, valueMap["time"], mix, bendDirection);
				this.readCurve(timeline, frameIndex, valueMap);
				frameIndex++;
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.frameCount * 3 - 3]);
		}

		var ffd = map["ffd"];
		for (var skinName in ffd) {
			var skin = skeletonData.findSkin(skinName);
			var slotMap = ffd[skinName];
			for (slotName in slotMap) {
				var slotIndex = skeletonData.findSlotIndex(slotName);
				var meshMap = slotMap[slotName];
				for (var meshName in meshMap) {
					var values = meshMap[meshName];
					var timeline = new spine.FfdTimeline(values.length);
					var attachment = skin.getAttachment(slotIndex, meshName);
					if (!attachment) throw "FFD attachment not found: " + meshName;
					timeline.slotIndex = slotIndex;
					timeline.attachment = attachment;
					
					var isMesh = attachment.type == spine.AttachmentType.mesh;
					var vertexCount;
					if (isMesh)
						vertexCount = attachment.vertices.length;
					else
						vertexCount = attachment.weights.length / 3 * 2;

					var frameIndex = 0;
					for (var i = 0, n = values.length; i < n; i++) {
						var valueMap = values[i];
						var vertices;
						if (!valueMap["vertices"]) {
							if (isMesh)
								vertices = attachment.vertices;
							else {
								vertices = [];
								vertices.length = vertexCount;
							}
						} else {
							var verticesValue = valueMap["vertices"];
							var vertices = [];
							vertices.length = vertexCount;
							var start = valueMap["offset"] || 0;
							var nn = verticesValue.length;
							if (this.scale == 1) {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii];
							} else {
								for (var ii = 0; ii < nn; ii++)
									vertices[ii + start] = verticesValue[ii] * this.scale;
							}
							if (isMesh) {
								var meshVertices = attachment.vertices;
								for (var ii = 0, nn = vertices.length; ii < nn; ii++)
									vertices[ii] += meshVertices[ii];
							}
						}
						
						timeline.setFrame(frameIndex, valueMap["time"], vertices);
						this.readCurve(timeline, frameIndex, valueMap);
						frameIndex++;
					}
					timelines[timelines.length] = timeline;
					duration = Math.max(duration, timeline.frames[timeline.frameCount - 1]);
				}
			}
		}

		var drawOrderValues = map["drawOrder"];
		if (!drawOrderValues) drawOrderValues = map["draworder"];
		if (drawOrderValues) {
			var timeline = new spine.DrawOrderTimeline(drawOrderValues.length);
			var slotCount = skeletonData.slots.length;
			var frameIndex = 0;
			for (var i = 0, n = drawOrderValues.length; i < n; i++) {
				var drawOrderMap = drawOrderValues[i];
				var drawOrder = null;
				if (drawOrderMap["offsets"]) {
					drawOrder = [];
					drawOrder.length = slotCount;
					for (var ii = slotCount - 1; ii >= 0; ii--)
						drawOrder[ii] = -1;
					var offsets = drawOrderMap["offsets"];
					var unchanged = [];
					unchanged.length = slotCount - offsets.length;
					var originalIndex = 0, unchangedIndex = 0;
					for (var ii = 0, nn = offsets.length; ii < nn; ii++) {
						var offsetMap = offsets[ii];
						var slotIndex = skeletonData.findSlotIndex(offsetMap["slot"]);
						if (slotIndex == -1) throw "Slot not found: " + offsetMap["slot"];
						// Collect unchanged items.
						while (originalIndex != slotIndex)
							unchanged[unchangedIndex++] = originalIndex++;
						// Set changed items.
						drawOrder[originalIndex + offsetMap["offset"]] = originalIndex++;
					}
					// Collect remaining unchanged items.
					while (originalIndex < slotCount)
						unchanged[unchangedIndex++] = originalIndex++;
					// Fill in unchanged items.
					for (var ii = slotCount - 1; ii >= 0; ii--)
						if (drawOrder[ii] == -1) drawOrder[ii] = unchanged[--unchangedIndex];
				}
				timeline.setFrame(frameIndex++, drawOrderMap["time"], drawOrder);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		var events = map["events"];
		if (events) {
			var timeline = new spine.EventTimeline(events.length);
			var frameIndex = 0;
			for (var i = 0, n = events.length; i < n; i++) {
				var eventMap = events[i];
				var eventData = skeletonData.findEvent(eventMap["name"]);
				if (!eventData) throw "Event not found: " + eventMap["name"];
				var event = new spine.Event(eventData);
				event.intValue = eventMap.hasOwnProperty("int") ? eventMap["int"] : eventData.intValue;
				event.floatValue = eventMap.hasOwnProperty("float") ? eventMap["float"] : eventData.floatValue;
				event.stringValue = eventMap.hasOwnProperty("string") ? eventMap["string"] : eventData.stringValue;
				timeline.setFrame(frameIndex++, eventMap["time"], event);
			}
			timelines.push(timeline);
			duration = Math.max(duration, timeline.frames[timeline.getFrameCount() - 1]);
		}

		skeletonData.animations.push(new spine.Animation(name, timelines, duration));
	},
	readCurve: function (timeline, frameIndex, valueMap) {
		var curve = valueMap["curve"];
		if (!curve) 
			timeline.curves.setLinear(frameIndex);
		else if (curve == "stepped")
			timeline.curves.setStepped(frameIndex);
		else if (curve instanceof Array)
			timeline.curves.setCurve(frameIndex, curve[0], curve[1], curve[2], curve[3]);
	},
	toColor: function (hexString, colorIndex) {
		if (hexString.length != 8) throw "Color hexidecimal length must be 8, recieved: " + hexString;
		return parseInt(hexString.substring(colorIndex * 2, (colorIndex * 2) + 2), 16) / 255;
	},
	getFloatArray: function (map, name, scale) {
		var list = map[name];
		var values = new spine.Float32Array(list.length);
		var i = 0, n = list.length;
		if (scale == 1) {
			for (; i < n; i++)
				values[i] = list[i];
		} else {
			for (; i < n; i++)
				values[i] = list[i] * scale;
		}
		return values;
	},
	getIntArray: function (map, name) {
		var list = map[name];
		var values = new spine.Uint16Array(list.length);
		for (var i = 0, n = list.length; i < n; i++)
			values[i] = list[i] | 0;
		return values;
	}
};

spine.Atlas = function (atlasText, textureLoader) {
	this.textureLoader = textureLoader;
	this.pages = [];
	this.regions = [];

	var reader = new spine.AtlasReader(atlasText);
	var tuple = [];
	tuple.length = 4;
	var page = null;
	while (true) {
		var line = reader.readLine();
		if (line === null) break;
		line = reader.trim(line);
		if (!line.length)
			page = null;
		else if (!page) {
			page = new spine.AtlasPage();
			page.name = line;

			if (reader.readTuple(tuple) == 2) { // size is only optional for an atlas packed with an old TexturePacker.
				page.width = parseInt(tuple[0]);
				page.height = parseInt(tuple[1]);
				reader.readTuple(tuple);
			}
			page.format = spine.Atlas.Format[tuple[0]];

			reader.readTuple(tuple);
			page.minFilter = spine.Atlas.TextureFilter[tuple[0]];
			page.magFilter = spine.Atlas.TextureFilter[tuple[1]];

			var direction = reader.readValue();
			page.uWrap = spine.Atlas.TextureWrap.clampToEdge;
			page.vWrap = spine.Atlas.TextureWrap.clampToEdge;
			if (direction == "x")
				page.uWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "y")
				page.vWrap = spine.Atlas.TextureWrap.repeat;
			else if (direction == "xy")
				page.uWrap = page.vWrap = spine.Atlas.TextureWrap.repeat;

			textureLoader.load(page, line, this);

			this.pages.push(page);

		} else {
			var region = new spine.AtlasRegion();
			region.name = line;
			region.page = page;

			region.rotate = reader.readValue() == "true";

			reader.readTuple(tuple);
			var x = parseInt(tuple[0]);
			var y = parseInt(tuple[1]);

			reader.readTuple(tuple);
			var width = parseInt(tuple[0]);
			var height = parseInt(tuple[1]);

			region.u = x / page.width;
			region.v = y / page.height;
			if (region.rotate) {
				region.u2 = (x + height) / page.width;
				region.v2 = (y + width) / page.height;
			} else {
				region.u2 = (x + width) / page.width;
				region.v2 = (y + height) / page.height;
			}
			region.x = x;
			region.y = y;
			region.width = Math.abs(width);
			region.height = Math.abs(height);

			if (reader.readTuple(tuple) == 4) { // split is optional
				region.splits = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

				if (reader.readTuple(tuple) == 4) { // pad is optional, but only present with splits
					region.pads = [parseInt(tuple[0]), parseInt(tuple[1]), parseInt(tuple[2]), parseInt(tuple[3])];

					reader.readTuple(tuple);
				}
			}

			region.originalWidth = parseInt(tuple[0]);
			region.originalHeight = parseInt(tuple[1]);

			reader.readTuple(tuple);
			region.offsetX = parseInt(tuple[0]);
			region.offsetY = parseInt(tuple[1]);

			region.index = parseInt(reader.readValue());

			this.regions.push(region);
		}
	}
};
spine.Atlas.prototype = {
	findRegion: function (name) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++)
			if (regions[i].name == name) return regions[i];
		return null;
	},
	dispose: function () {
		var pages = this.pages;
		for (var i = 0, n = pages.length; i < n; i++)
			this.textureLoader.unload(pages[i].rendererObject);
	},
	updateUVs: function (page) {
		var regions = this.regions;
		for (var i = 0, n = regions.length; i < n; i++) {
			var region = regions[i];
			if (region.page != page) continue;
			region.u = region.x / page.width;
			region.v = region.y / page.height;
			if (region.rotate) {
				region.u2 = (region.x + region.height) / page.width;
				region.v2 = (region.y + region.width) / page.height;
			} else {
				region.u2 = (region.x + region.width) / page.width;
				region.v2 = (region.y + region.height) / page.height;
			}
		}
	}
};

spine.Atlas.Format = {
	alpha: 0,
	intensity: 1,
	luminanceAlpha: 2,
	rgb565: 3,
	rgba4444: 4,
	rgb888: 5,
	rgba8888: 6
};

spine.Atlas.TextureFilter = {
	nearest: 0,
	linear: 1,
	mipMap: 2,
	mipMapNearestNearest: 3,
	mipMapLinearNearest: 4,
	mipMapNearestLinear: 5,
	mipMapLinearLinear: 6
};

spine.Atlas.TextureWrap = {
	mirroredRepeat: 0,
	clampToEdge: 1,
	repeat: 2
};

spine.AtlasPage = function () {};
spine.AtlasPage.prototype = {
	name: null,
	format: null,
	minFilter: null,
	magFilter: null,
	uWrap: null,
	vWrap: null,
	rendererObject: null,
	width: 0,
	height: 0
};

spine.AtlasRegion = function () {};
spine.AtlasRegion.prototype = {
	page: null,
	name: null,
	x: 0, y: 0,
	width: 0, height: 0,
	u: 0, v: 0, u2: 0, v2: 0,
	offsetX: 0, offsetY: 0,
	originalWidth: 0, originalHeight: 0,
	index: 0,
	rotate: false,
	splits: null,
	pads: null
};

spine.AtlasReader = function (text) {
	this.lines = text.split(/\r\n|\r|\n/);
};
spine.AtlasReader.prototype = {
	index: 0,
	trim: function (value) {
		return value.replace(/^\s+|\s+$/g, "");
	},
	readLine: function () {
		if (this.index >= this.lines.length) return null;
		return this.lines[this.index++];
	},
	readValue: function () {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		return this.trim(line.substring(colon + 1));
	},
	/** Returns the number of tuple values read (1, 2 or 4). */
	readTuple: function (tuple) {
		var line = this.readLine();
		var colon = line.indexOf(":");
		if (colon == -1) throw "Invalid line: " + line;
		var i = 0, lastMatch = colon + 1;
		for (; i < 3; i++) {
			var comma = line.indexOf(",", lastMatch);
			if (comma == -1) break;
			tuple[i] = this.trim(line.substr(lastMatch, comma - lastMatch));
			lastMatch = comma + 1;
		}
		tuple[i] = this.trim(line.substring(lastMatch));
		return i + 1;
	}
};

spine.AtlasAttachmentLoader = function (atlas) {
	this.atlas = atlas;
};
spine.AtlasAttachmentLoader.prototype = {
	newRegionAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (region attachment: " + name + ")";
		var attachment = new spine.RegionAttachment(name);
		attachment.rendererObject = region;
		attachment.setUVs(region.u, region.v, region.u2, region.v2, region.rotate);
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (mesh attachment: " + name + ")";
		var attachment = new spine.MeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newSkinnedMeshAttachment: function (skin, name, path) {
		var region = this.atlas.findRegion(path);
		if (!region) throw "Region not found in atlas: " + path + " (skinned mesh attachment: " + name + ")";
		var attachment = new spine.SkinnedMeshAttachment(name);
		attachment.rendererObject = region;
		attachment.regionU = region.u;
		attachment.regionV = region.v;
		attachment.regionU2 = region.u2;
		attachment.regionV2 = region.v2;
		attachment.regionRotate = region.rotate;
		attachment.regionOffsetX = region.offsetX;
		attachment.regionOffsetY = region.offsetY;
		attachment.regionWidth = region.width;
		attachment.regionHeight = region.height;
		attachment.regionOriginalWidth = region.originalWidth;
		attachment.regionOriginalHeight = region.originalHeight;
		return attachment;
	},
	newBoundingBoxAttachment: function (skin, name) {
		return new spine.BoundingBoxAttachment(name);
	}
};

spine.SkeletonBounds = function () {
	this.polygonPool = [];
	this.polygons = [];
	this.boundingBoxes = [];
};
spine.SkeletonBounds.prototype = {
	minX: 0, minY: 0, maxX: 0, maxY: 0,
	update: function (skeleton, updateAabb) {
		var slots = skeleton.slots;
		var slotCount = slots.length;
		var x = skeleton.x, y = skeleton.y;
		var boundingBoxes = this.boundingBoxes;
		var polygonPool = this.polygonPool;
		var polygons = this.polygons;

		boundingBoxes.length = 0;
		for (var i = 0, n = polygons.length; i < n; i++)
			polygonPool.push(polygons[i]);
		polygons.length = 0;

		for (var i = 0; i < slotCount; i++) {
			var slot = slots[i];
			var boundingBox = slot.attachment;
			if (boundingBox.type != spine.AttachmentType.boundingbox) continue;
			boundingBoxes.push(boundingBox);

			var poolCount = polygonPool.length, polygon;
			if (poolCount > 0) {
				polygon = polygonPool[poolCount - 1];
				polygonPool.splice(poolCount - 1, 1);
			} else
				polygon = [];
			polygons.push(polygon);

			polygon.length = boundingBox.vertices.length;
			boundingBox.computeWorldVertices(x, y, slot.bone, polygon);
		}

		if (updateAabb) this.aabbCompute();
	},
	aabbCompute: function () {
		var polygons = this.polygons;
		var minX = Number.MAX_VALUE, minY = Number.MAX_VALUE, maxX = Number.MIN_VALUE, maxY = Number.MIN_VALUE;
		for (var i = 0, n = polygons.length; i < n; i++) {
			var vertices = polygons[i];
			for (var ii = 0, nn = vertices.length; ii < nn; ii += 2) {
				var x = vertices[ii];
				var y = vertices[ii + 1];
				minX = Math.min(minX, x);
				minY = Math.min(minY, y);
				maxX = Math.max(maxX, x);
				maxY = Math.max(maxY, y);
			}
		}
		this.minX = minX;
		this.minY = minY;
		this.maxX = maxX;
		this.maxY = maxY;
	},
	/** Returns true if the axis aligned bounding box contains the point. */
	aabbContainsPoint: function (x, y) {
		return x >= this.minX && x <= this.maxX && y >= this.minY && y <= this.maxY;
	},
	/** Returns true if the axis aligned bounding box intersects the line segment. */
	aabbIntersectsSegment: function (x1, y1, x2, y2) {
		var minX = this.minX, minY = this.minY, maxX = this.maxX, maxY = this.maxY;
		if ((x1 <= minX && x2 <= minX) || (y1 <= minY && y2 <= minY) || (x1 >= maxX && x2 >= maxX) || (y1 >= maxY && y2 >= maxY))
			return false;
		var m = (y2 - y1) / (x2 - x1);
		var y = m * (minX - x1) + y1;
		if (y > minY && y < maxY) return true;
		y = m * (maxX - x1) + y1;
		if (y > minY && y < maxY) return true;
		var x = (minY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		x = (maxY - y1) / m + x1;
		if (x > minX && x < maxX) return true;
		return false;
	},
	/** Returns true if the axis aligned bounding box intersects the axis aligned bounding box of the specified bounds. */
	aabbIntersectsSkeleton: function (bounds) {
		return this.minX < bounds.maxX && this.maxX > bounds.minX && this.minY < bounds.maxY && this.maxY > bounds.minY;
	},
	/** Returns the first bounding box attachment that contains the point, or null. When doing many checks, it is usually more
	 * efficient to only call this method if {@link #aabbContainsPoint(float, float)} returns true. */
	containsPoint: function (x, y) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (this.polygonContainsPoint(polygons[i], x, y)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns the first bounding box attachment that contains the line segment, or null. When doing many checks, it is usually
	 * more efficient to only call this method if {@link #aabbIntersectsSegment(float, float, float, float)} returns true. */
	intersectsSegment: function (x1, y1, x2, y2) {
		var polygons = this.polygons;
		for (var i = 0, n = polygons.length; i < n; i++)
			if (polygons[i].intersectsSegment(x1, y1, x2, y2)) return this.boundingBoxes[i];
		return null;
	},
	/** Returns true if the polygon contains the point. */
	polygonContainsPoint: function (polygon, x, y) {
		var nn = polygon.length;
		var prevIndex = nn - 2;
		var inside = false;
		for (var ii = 0; ii < nn; ii += 2) {
			var vertexY = polygon[ii + 1];
			var prevY = polygon[prevIndex + 1];
			if ((vertexY < y && prevY >= y) || (prevY < y && vertexY >= y)) {
				var vertexX = polygon[ii];
				if (vertexX + (y - vertexY) / (prevY - vertexY) * (polygon[prevIndex] - vertexX) < x) inside = !inside;
			}
			prevIndex = ii;
		}
		return inside;
	},
	/** Returns true if the polygon contains the line segment. */
	polygonIntersectsSegment: function (polygon, x1, y1, x2, y2) {
		var nn = polygon.length;
		var width12 = x1 - x2, height12 = y1 - y2;
		var det1 = x1 * y2 - y1 * x2;
		var x3 = polygon[nn - 2], y3 = polygon[nn - 1];
		for (var ii = 0; ii < nn; ii += 2) {
			var x4 = polygon[ii], y4 = polygon[ii + 1];
			var det2 = x3 * y4 - y3 * x4;
			var width34 = x3 - x4, height34 = y3 - y4;
			var det3 = width12 * height34 - height12 * width34;
			var x = (det1 * width34 - width12 * det2) / det3;
			if (((x >= x3 && x <= x4) || (x >= x4 && x <= x3)) && ((x >= x1 && x <= x2) || (x >= x2 && x <= x1))) {
				var y = (det1 * height34 - height12 * det2) / det3;
				if (((y >= y3 && y <= y4) || (y >= y4 && y <= y3)) && ((y >= y1 && y <= y2) || (y >= y2 && y <= y1))) return true;
			}
			x3 = x4;
			y3 = y4;
		}
		return false;
	},
	getPolygon: function (attachment) {
		var index = this.boundingBoxes.indexOf(attachment);
		return index == -1 ? null : this.polygons[index];
	},
	getWidth: function () {
		return this.maxX - this.minX;
	},
	getHeight: function () {
		return this.maxY - this.minY;
	}
};
// *********************************
// CoolGames Builder JavaScript file
// *********************************

/*
 CryptoJS v3.1.2
 code.google.com/p/crypto-js
 (c) 2009-2013 by Jeff Mott. All rights reserved.
 code.google.com/p/crypto-js/wiki/License
 */
/**
 * CryptoJS core components.
 */
var CryptoJS = CryptoJS || (function (Math, undefined) {
        /**
         * CryptoJS namespace.
         */
        var C = {};

        /**
         * Library namespace.
         */
        var C_lib = C.lib = {};

        /**
         * Base object for prototypal inheritance.
         */
        var Base = C_lib.Base = (function () {
            function F() {}

            return {
                /**
                 * Creates a new object that inherits from this object.
                 *
                 * @param {Object} overrides Properties to copy into the new object.
                 *
                 * @return {Object} The new object.
                 *
                 * @static
                 *
                 * @example
                 *
                 *     var MyType = CryptoJS.lib.Base.extend({
             *         field: 'value',
             *
             *         method: function () {
             *         }
             *     });
                 */
                extend: function (overrides) {
                    // Spawn
                    F.prototype = this;
                    var subtype = new F();

                    // Augment
                    if (overrides) {
                        subtype.mixIn(overrides);
                    }

                    // Create default initializer
                    if (!subtype.hasOwnProperty('init')) {
                        subtype.init = function () {
                            subtype.$super.init.apply(this, arguments);
                        };
                    }

                    // Initializer's prototype is the subtype object
                    subtype.init.prototype = subtype;

                    // Reference supertype
                    subtype.$super = this;

                    return subtype;
                },

                /**
                 * Extends this object and runs the init method.
                 * Arguments to create() will be passed to init().
                 *
                 * @return {Object} The new object.
                 *
                 * @static
                 *
                 * @example
                 *
                 *     var instance = MyType.create();
                 */
                create: function () {
                    var instance = this.extend();
                    instance.init.apply(instance, arguments);

                    return instance;
                },

                /**
                 * Initializes a newly created object.
                 * Override this method to add some logic when your objects are created.
                 *
                 * @example
                 *
                 *     var MyType = CryptoJS.lib.Base.extend({
             *         init: function () {
             *             // ...
             *         }
             *     });
                 */
                init: function () {
                },

                /**
                 * Copies properties into this object.
                 *
                 * @param {Object} properties The properties to mix in.
                 *
                 * @example
                 *
                 *     MyType.mixIn({
             *         field: 'value'
             *     });
                 */
                mixIn: function (properties) {
                    for (var propertyName in properties) {
                        if (properties.hasOwnProperty(propertyName)) {
                            this[propertyName] = properties[propertyName];
                        }
                    }

                    // IE won't copy toString using the loop above
                    if (properties.hasOwnProperty('toString')) {
                        this.toString = properties.toString;
                    }
                },

                /**
                 * Creates a copy of this object.
                 *
                 * @return {Object} The clone.
                 *
                 * @example
                 *
                 *     var clone = instance.clone();
                 */
                clone: function () {
                    return this.init.prototype.extend(this);
                }
            };
        }());

        /**
         * An array of 32-bit words.
         *
         * @property {Array} words The array of 32-bit words.
         * @property {number} sigBytes The number of significant bytes in this word array.
         */
        var WordArray = C_lib.WordArray = Base.extend({
            /**
             * Initializes a newly created word array.
             *
             * @param {Array} words (Optional) An array of 32-bit words.
             * @param {number} sigBytes (Optional) The number of significant bytes in the words.
             *
             * @example
             *
             *     var wordArray = CryptoJS.lib.WordArray.create();
             *     var wordArray = CryptoJS.lib.WordArray.create([0x00010203, 0x04050607]);
             *     var wordArray = CryptoJS.lib.WordArray.create([0x00010203, 0x04050607], 6);
             */
            init: function (words, sigBytes) {
                words = this.words = words || [];

                if (sigBytes != undefined) {
                    this.sigBytes = sigBytes;
                } else {
                    this.sigBytes = words.length * 4;
                }
            },

            /**
             * Converts this word array to a string.
             *
             * @param {Encoder} encoder (Optional) The encoding strategy to use. Default: CryptoJS.enc.Hex
             *
             * @return {string} The stringified word array.
             *
             * @example
             *
             *     var string = wordArray + '';
             *     var string = wordArray.toString();
             *     var string = wordArray.toString(CryptoJS.enc.Utf8);
             */
            toString: function (encoder) {
                return (encoder || Hex).stringify(this);
            },

            /**
             * Concatenates a word array to this word array.
             *
             * @param {WordArray} wordArray The word array to append.
             *
             * @return {WordArray} This word array.
             *
             * @example
             *
             *     wordArray1.concat(wordArray2);
             */
            concat: function (wordArray) {
                // Shortcuts
                var thisWords = this.words;
                var thatWords = wordArray.words;
                var thisSigBytes = this.sigBytes;
                var thatSigBytes = wordArray.sigBytes;

                // Clamp excess bits
                this.clamp();

                // Concat
                if (thisSigBytes % 4) {
                    // Copy one byte at a time
                    for (var i = 0; i < thatSigBytes; i++) {
                        var thatByte = (thatWords[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
                        thisWords[(thisSigBytes + i) >>> 2] |= thatByte << (24 - ((thisSigBytes + i) % 4) * 8);
                    }
                } else if (thatWords.length > 0xffff) {
                    // Copy one word at a time
                    for (var i = 0; i < thatSigBytes; i += 4) {
                        thisWords[(thisSigBytes + i) >>> 2] = thatWords[i >>> 2];
                    }
                } else {
                    // Copy all words at once
                    thisWords.push.apply(thisWords, thatWords);
                }
                this.sigBytes += thatSigBytes;

                // Chainable
                return this;
            },

            /**
             * Removes insignificant bits.
             *
             * @example
             *
             *     wordArray.clamp();
             */
            clamp: function () {
                // Shortcuts
                var words = this.words;
                var sigBytes = this.sigBytes;

                // Clamp
                words[sigBytes >>> 2] &= 0xffffffff << (32 - (sigBytes % 4) * 8);
                words.length = Math.ceil(sigBytes / 4);
            },

            /**
             * Creates a copy of this word array.
             *
             * @return {WordArray} The clone.
             *
             * @example
             *
             *     var clone = wordArray.clone();
             */
            clone: function () {
                var clone = Base.clone.call(this);
                clone.words = this.words.slice(0);

                return clone;
            },

            /**
             * Creates a word array filled with random bytes.
             *
             * @param {number} nBytes The number of random bytes to generate.
             *
             * @return {WordArray} The random word array.
             *
             * @static
             *
             * @example
             *
             *     var wordArray = CryptoJS.lib.WordArray.random(16);
             */
            random: function (nBytes) {
                var words = [];
                for (var i = 0; i < nBytes; i += 4) {
                    words.push((Math.random() * 0x100000000) | 0);
                }

                return new WordArray.init(words, nBytes);
            }
        });

        /**
         * Encoder namespace.
         */
        var C_enc = C.enc = {};

        /**
         * Hex encoding strategy.
         */
        var Hex = C_enc.Hex = {
            /**
             * Converts a word array to a hex string.
             *
             * @param {WordArray} wordArray The word array.
             *
             * @return {string} The hex string.
             *
             * @static
             *
             * @example
             *
             *     var hexString = CryptoJS.enc.Hex.stringify(wordArray);
             */
            stringify: function (wordArray) {
                // Shortcuts
                var words = wordArray.words;
                var sigBytes = wordArray.sigBytes;

                // Convert
                var hexChars = [];
                for (var i = 0; i < sigBytes; i++) {
                    var bite = (words[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
                    hexChars.push((bite >>> 4).toString(16));
                    hexChars.push((bite & 0x0f).toString(16));
                }

                return hexChars.join('');
            },

            /**
             * Converts a hex string to a word array.
             *
             * @param {string} hexStr The hex string.
             *
             * @return {WordArray} The word array.
             *
             * @static
             *
             * @example
             *
             *     var wordArray = CryptoJS.enc.Hex.parse(hexString);
             */
            parse: function (hexStr) {
                // Shortcut
                var hexStrLength = hexStr.length;

                // Convert
                var words = [];
                for (var i = 0; i < hexStrLength; i += 2) {
                    words[i >>> 3] |= parseInt(hexStr.substr(i, 2), 16) << (24 - (i % 8) * 4);
                }

                return new WordArray.init(words, hexStrLength / 2);
            }
        };

        /**
         * Latin1 encoding strategy.
         */
        var Latin1 = C_enc.Latin1 = {
            /**
             * Converts a word array to a Latin1 string.
             *
             * @param {WordArray} wordArray The word array.
             *
             * @return {string} The Latin1 string.
             *
             * @static
             *
             * @example
             *
             *     var latin1String = CryptoJS.enc.Latin1.stringify(wordArray);
             */
            stringify: function (wordArray) {
                // Shortcuts
                var words = wordArray.words;
                var sigBytes = wordArray.sigBytes;

                // Convert
                var latin1Chars = [];
                for (var i = 0; i < sigBytes; i++) {
                    var bite = (words[i >>> 2] >>> (24 - (i % 4) * 8)) & 0xff;
                    latin1Chars.push(String.fromCharCode(bite));
                }

                return latin1Chars.join('');
            },

            /**
             * Converts a Latin1 string to a word array.
             *
             * @param {string} latin1Str The Latin1 string.
             *
             * @return {WordArray} The word array.
             *
             * @static
             *
             * @example
             *
             *     var wordArray = CryptoJS.enc.Latin1.parse(latin1String);
             */
            parse: function (latin1Str) {
                // Shortcut
                var latin1StrLength = latin1Str.length;

                // Convert
                var words = [];
                for (var i = 0; i < latin1StrLength; i++) {
                    words[i >>> 2] |= (latin1Str.charCodeAt(i) & 0xff) << (24 - (i % 4) * 8);
                }

                return new WordArray.init(words, latin1StrLength);
            }
        };

        /**
         * UTF-8 encoding strategy.
         */
        var Utf8 = C_enc.Utf8 = {
            /**
             * Converts a word array to a UTF-8 string.
             *
             * @param {WordArray} wordArray The word array.
             *
             * @return {string} The UTF-8 string.
             *
             * @static
             *
             * @example
             *
             *     var utf8String = CryptoJS.enc.Utf8.stringify(wordArray);
             */
            stringify: function (wordArray) {
                try {
                    return decodeURIComponent(escape(Latin1.stringify(wordArray)));
                } catch (e) {
                    throw new Error('Malformed UTF-8 data');
                }
            },

            /**
             * Converts a UTF-8 string to a word array.
             *
             * @param {string} utf8Str The UTF-8 string.
             *
             * @return {WordArray} The word array.
             *
             * @static
             *
             * @example
             *
             *     var wordArray = CryptoJS.enc.Utf8.parse(utf8String);
             */
            parse: function (utf8Str) {
                return Latin1.parse(unescape(encodeURIComponent(utf8Str)));
            }
        };

        /**
         * Abstract buffered block algorithm template.
         *
         * The property blockSize must be implemented in a concrete subtype.
         *
         * @property {number} _minBufferSize The number of blocks that should be kept unprocessed in the buffer. Default: 0
         */
        var BufferedBlockAlgorithm = C_lib.BufferedBlockAlgorithm = Base.extend({
            /**
             * Resets this block algorithm's data buffer to its initial state.
             *
             * @example
             *
             *     bufferedBlockAlgorithm.reset();
             */
            reset: function () {
                // Initial values
                this._data = new WordArray.init();
                this._nDataBytes = 0;
            },

            /**
             * Adds new data to this block algorithm's buffer.
             *
             * @param {WordArray|string} data The data to append. Strings are converted to a WordArray using UTF-8.
             *
             * @example
             *
             *     bufferedBlockAlgorithm._append('data');
             *     bufferedBlockAlgorithm._append(wordArray);
             */
            _append: function (data) {
                // Convert string to WordArray, else assume WordArray already
                if (typeof data == 'string') {
                    data = Utf8.parse(data);
                }

                // Append
                this._data.concat(data);
                this._nDataBytes += data.sigBytes;
            },

            /**
             * Processes available data blocks.
             *
             * This method invokes _doProcessBlock(offset), which must be implemented by a concrete subtype.
             *
             * @param {boolean} doFlush Whether all blocks and partial blocks should be processed.
             *
             * @return {WordArray} The processed data.
             *
             * @example
             *
             *     var processedData = bufferedBlockAlgorithm._process();
             *     var processedData = bufferedBlockAlgorithm._process(!!'flush');
             */
            _process: function (doFlush) {
                // Shortcuts
                var data = this._data;
                var dataWords = data.words;
                var dataSigBytes = data.sigBytes;
                var blockSize = this.blockSize;
                var blockSizeBytes = blockSize * 4;

                // Count blocks ready
                var nBlocksReady = dataSigBytes / blockSizeBytes;
                if (doFlush) {
                    // Round up to include partial blocks
                    nBlocksReady = Math.ceil(nBlocksReady);
                } else {
                    // Round down to include only full blocks,
                    // less the number of blocks that must remain in the buffer
                    nBlocksReady = Math.max((nBlocksReady | 0) - this._minBufferSize, 0);
                }

                // Count words ready
                var nWordsReady = nBlocksReady * blockSize;

                // Count bytes ready
                var nBytesReady = Math.min(nWordsReady * 4, dataSigBytes);

                // Process blocks
                if (nWordsReady) {
                    for (var offset = 0; offset < nWordsReady; offset += blockSize) {
                        // Perform concrete-algorithm logic
                        this._doProcessBlock(dataWords, offset);
                    }

                    // Remove processed words
                    var processedWords = dataWords.splice(0, nWordsReady);
                    data.sigBytes -= nBytesReady;
                }

                // Return processed words
                return new WordArray.init(processedWords, nBytesReady);
            },

            /**
             * Creates a copy of this object.
             *
             * @return {Object} The clone.
             *
             * @example
             *
             *     var clone = bufferedBlockAlgorithm.clone();
             */
            clone: function () {
                var clone = Base.clone.call(this);
                clone._data = this._data.clone();

                return clone;
            },

            _minBufferSize: 0
        });

        /**
         * Abstract hasher template.
         *
         * @property {number} blockSize The number of 32-bit words this hasher operates on. Default: 16 (512 bits)
         */
        var Hasher = C_lib.Hasher = BufferedBlockAlgorithm.extend({
            /**
             * Configuration options.
             */
            cfg: Base.extend(),

            /**
             * Initializes a newly created hasher.
             *
             * @param {Object} cfg (Optional) The configuration options to use for this hash computation.
             *
             * @example
             *
             *     var hasher = CryptoJS.algo.SHA256.create();
             */
            init: function (cfg) {
                // Apply config defaults
                this.cfg = this.cfg.extend(cfg);

                // Set initial values
                this.reset();
            },

            /**
             * Resets this hasher to its initial state.
             *
             * @example
             *
             *     hasher.reset();
             */
            reset: function () {
                // Reset data buffer
                BufferedBlockAlgorithm.reset.call(this);

                // Perform concrete-hasher logic
                this._doReset();
            },

            /**
             * Updates this hasher with a message.
             *
             * @param {WordArray|string} messageUpdate The message to append.
             *
             * @return {Hasher} This hasher.
             *
             * @example
             *
             *     hasher.update('message');
             *     hasher.update(wordArray);
             */
            update: function (messageUpdate) {
                // Append
                this._append(messageUpdate);

                // Update the hash
                this._process();

                // Chainable
                return this;
            },

            /**
             * Finalizes the hash computation.
             * Note that the finalize operation is effectively a destructive, read-once operation.
             *
             * @param {WordArray|string} messageUpdate (Optional) A final message update.
             *
             * @return {WordArray} The hash.
             *
             * @example
             *
             *     var hash = hasher.finalize();
             *     var hash = hasher.finalize('message');
             *     var hash = hasher.finalize(wordArray);
             */
            finalize: function (messageUpdate) {
                // Final message update
                if (messageUpdate) {
                    this._append(messageUpdate);
                }

                // Perform concrete-hasher logic
                var hash = this._doFinalize();

                return hash;
            },

            blockSize: 512/32,

            /**
             * Creates a shortcut function to a hasher's object interface.
             *
             * @param {Hasher} hasher The hasher to create a helper for.
             *
             * @return {Function} The shortcut function.
             *
             * @static
             *
             * @example
             *
             *     var SHA256 = CryptoJS.lib.Hasher._createHelper(CryptoJS.algo.SHA256);
             */
            _createHelper: function (hasher) {
                return function (message, cfg) {
                    return new hasher.init(cfg).finalize(message);
                };
            },

            /**
             * Creates a shortcut function to the HMAC's object interface.
             *
             * @param {Hasher} hasher The hasher to use in this HMAC helper.
             *
             * @return {Function} The shortcut function.
             *
             * @static
             *
             * @example
             *
             *     var HmacSHA256 = CryptoJS.lib.Hasher._createHmacHelper(CryptoJS.algo.SHA256);
             */
            _createHmacHelper: function (hasher) {
                return function (message, key) {
                    return new C_algo.HMAC.init(hasher, key).finalize(message);
                };
            }
        });

        /**
         * Algorithm namespace.
         */
        var C_algo = C.algo = {};

        return C;
}(Math));

window["Crypto"] = CryptoJS;

/*
 CryptoJS v3.1.2
 code.google.com/p/crypto-js
 (c) 2009-2013 by Jeff Mott. All rights reserved.
 code.google.com/p/crypto-js/wiki/License
 */
(function () {
    // Shortcuts
    var C = CryptoJS;
    var C_lib = C.lib;
    var Base = C_lib.Base;
    var C_enc = C.enc;
    var Utf8 = C_enc.Utf8;
    var C_algo = C.algo;

    /**
     * HMAC algorithm.
     */
    var HMAC = C_algo.HMAC = Base.extend({
        /**
         * Initializes a newly created HMAC.
         *
         * @param {Hasher} hasher The hash algorithm to use.
         * @param {WordArray|string} key The secret key.
         *
         * @example
         *
         *     var hmacHasher = CryptoJS.algo.HMAC.create(CryptoJS.algo.SHA256, key);
         */
        init: function (hasher, key) {
            // Init hasher
            hasher = this._hasher = new hasher.init();

            // Convert string to WordArray, else assume WordArray already
            if (typeof key == 'string') {
                key = Utf8.parse(key);
            }

            // Shortcuts
            var hasherBlockSize = hasher.blockSize;
            var hasherBlockSizeBytes = hasherBlockSize * 4;

            // Allow arbitrary length keys
            if (key.sigBytes > hasherBlockSizeBytes) {
                key = hasher.finalize(key);
            }

            // Clamp excess bits
            key.clamp();

            // Clone key for inner and outer pads
            var oKey = this._oKey = key.clone();
            var iKey = this._iKey = key.clone();

            // Shortcuts
            var oKeyWords = oKey.words;
            var iKeyWords = iKey.words;

            // XOR keys with pad constants
            for (var i = 0; i < hasherBlockSize; i++) {
                oKeyWords[i] ^= 0x5c5c5c5c;
                iKeyWords[i] ^= 0x36363636;
            }
            oKey.sigBytes = iKey.sigBytes = hasherBlockSizeBytes;

            // Set initial values
            this.reset();
        },

        /**
         * Resets this HMAC to its initial state.
         *
         * @example
         *
         *     hmacHasher.reset();
         */
        reset: function () {
            // Shortcut
            var hasher = this._hasher;

            // Reset
            hasher.reset();
            hasher.update(this._iKey);
        },

        /**
         * Updates this HMAC with a message.
         *
         * @param {WordArray|string} messageUpdate The message to append.
         *
         * @return {HMAC} This HMAC instance.
         *
         * @example
         *
         *     hmacHasher.update('message');
         *     hmacHasher.update(wordArray);
         */
        update: function (messageUpdate) {
            this._hasher.update(messageUpdate);

            // Chainable
            return this;
        },

        /**
         * Finalizes the HMAC computation.
         * Note that the finalize operation is effectively a destructive, read-once operation.
         *
         * @param {WordArray|string} messageUpdate (Optional) A final message update.
         *
         * @return {WordArray} The HMAC.
         *
         * @example
         *
         *     var hmac = hmacHasher.finalize();
         *     var hmac = hmacHasher.finalize('message');
         *     var hmac = hmacHasher.finalize(wordArray);
         */
        finalize: function (messageUpdate) {
            // Shortcut
            var hasher = this._hasher;

            // Compute HMAC
            var innerHash = hasher.finalize(messageUpdate);
            hasher.reset();
            var hmac = hasher.finalize(this._oKey.clone().concat(innerHash));

            return hmac;
        }
    });
}());

/*
 CryptoJS v3.1.2
 code.google.com/p/crypto-js
 (c) 2009-2013 by Jeff Mott. All rights reserved.
 code.google.com/p/crypto-js/wiki/License
 */
(function (Math) {
    // Shortcuts
    var C = CryptoJS;
    var C_lib = C.lib;
    var WordArray = C_lib.WordArray;
    var Hasher = C_lib.Hasher;
    var C_algo = C.algo;

    // Initialization and round constants tables
    var H = [];
    var K = [];

    // Compute constants
    (function () {
        function isPrime(n) {
            var sqrtN = Math.sqrt(n);
            for (var factor = 2; factor <= sqrtN; factor++) {
                if (!(n % factor)) {
                    return false;
                }
            }

            return true;
        }

        function getFractionalBits(n) {
            return ((n - (n | 0)) * 0x100000000) | 0;
        }

        var n = 2;
        var nPrime = 0;
        while (nPrime < 64) {
            if (isPrime(n)) {
                if (nPrime < 8) {
                    H[nPrime] = getFractionalBits(Math.pow(n, 1 / 2));
                }
                K[nPrime] = getFractionalBits(Math.pow(n, 1 / 3));

                nPrime++;
            }

            n++;
        }
    }());

    // Reusable object
    var W = [];

    /**
     * SHA-256 hash algorithm.
     */
    var SHA256 = C_algo.SHA256 = Hasher.extend({
        _doReset: function () {
            this._hash = new WordArray.init(H.slice(0));
        },

        _doProcessBlock: function (M, offset) {
            // Shortcut
            var H = this._hash.words;

            // Working variables
            var a = H[0];
            var b = H[1];
            var c = H[2];
            var d = H[3];
            var e = H[4];
            var f = H[5];
            var g = H[6];
            var h = H[7];

            // Computation
            for (var i = 0; i < 64; i++) {
                if (i < 16) {
                    W[i] = M[offset + i] | 0;
                } else {
                    var gamma0x = W[i - 15];
                    var gamma0  = ((gamma0x << 25) | (gamma0x >>> 7))  ^
                        ((gamma0x << 14) | (gamma0x >>> 18)) ^
                        (gamma0x >>> 3);

                    var gamma1x = W[i - 2];
                    var gamma1  = ((gamma1x << 15) | (gamma1x >>> 17)) ^
                        ((gamma1x << 13) | (gamma1x >>> 19)) ^
                        (gamma1x >>> 10);

                    W[i] = gamma0 + W[i - 7] + gamma1 + W[i - 16];
                }

                var ch  = (e & f) ^ (~e & g);
                var maj = (a & b) ^ (a & c) ^ (b & c);

                var sigma0 = ((a << 30) | (a >>> 2)) ^ ((a << 19) | (a >>> 13)) ^ ((a << 10) | (a >>> 22));
                var sigma1 = ((e << 26) | (e >>> 6)) ^ ((e << 21) | (e >>> 11)) ^ ((e << 7)  | (e >>> 25));

                var t1 = h + sigma1 + ch + K[i] + W[i];
                var t2 = sigma0 + maj;

                h = g;
                g = f;
                f = e;
                e = (d + t1) | 0;
                d = c;
                c = b;
                b = a;
                a = (t1 + t2) | 0;
            }

            // Intermediate hash value
            H[0] = (H[0] + a) | 0;
            H[1] = (H[1] + b) | 0;
            H[2] = (H[2] + c) | 0;
            H[3] = (H[3] + d) | 0;
            H[4] = (H[4] + e) | 0;
            H[5] = (H[5] + f) | 0;
            H[6] = (H[6] + g) | 0;
            H[7] = (H[7] + h) | 0;
        },

        _doFinalize: function () {
            // Shortcuts
            var data = this._data;
            var dataWords = data.words;

            var nBitsTotal = this._nDataBytes * 8;
            var nBitsLeft = data.sigBytes * 8;

            // Add padding
            dataWords[nBitsLeft >>> 5] |= 0x80 << (24 - nBitsLeft % 32);
            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 14] = Math.floor(nBitsTotal / 0x100000000);
            dataWords[(((nBitsLeft + 64) >>> 9) << 4) + 15] = nBitsTotal;
            data.sigBytes = dataWords.length * 4;

            // Hash final blocks
            this._process();

            // Return final computed hash
            return this._hash;
        },

        clone: function () {
            var clone = Hasher.clone.call(this);
            clone._hash = this._hash.clone();

            return clone;
        }
    });

    /**
     * Shortcut function to the hasher's object interface.
     *
     * @param {WordArray|string} message The message to hash.
     *
     * @return {WordArray} The hash.
     *
     * @static
     *
     * @example
     *
     *     var hash = CryptoJS.SHA256('message');
     *     var hash = CryptoJS.SHA256(wordArray);
     */
    C.SHA256 = Hasher._createHelper(SHA256);

    /**
     * Shortcut function to the HMAC's object interface.
     *
     * @param {WordArray|string} message The message to hash.
     * @param {WordArray|string} key The secret key.
     *
     * @return {WordArray} The HMAC.
     *
     * @static
     *
     * @example
     *
     *     var hmac = CryptoJS.HmacSHA256(message, key);
     */
    C.HmacSHA256 = Hasher._createHmacHelper(SHA256);
}(Math));

/*
 CryptoJS v3.1.2
 code.google.com/p/crypto-js
 (c) 2009-2013 by Jeff Mott. All rights reserved.
 code.google.com/p/crypto-js/wiki/License
 */
(function () {
    // Shortcuts
    var C = CryptoJS;
    var C_lib = C.lib;
    var WordArray = C_lib.WordArray;
    var C_enc = C.enc;

    /**
     * Base64 encoding strategy.
     */
    var Base64 = C_enc.Base64 = {
        /**
         * Converts a word array to a Base64 string.
         *
         * @param {WordArray} wordArray The word array.
         *
         * @return {string} The Base64 string.
         *
         * @static
         *
         * @example
         *
         *     var base64String = CryptoJS.enc.Base64.stringify(wordArray);
         */
        stringify: function (wordArray) {
            // Shortcuts
            var words = wordArray.words;
            var sigBytes = wordArray.sigBytes;
            var map = this._map;

            // Clamp excess bits
            wordArray.clamp();

            // Convert
            var base64Chars = [];
            for (var i = 0; i < sigBytes; i += 3) {
                var byte1 = (words[i >>> 2]       >>> (24 - (i % 4) * 8))       & 0xff;
                var byte2 = (words[(i + 1) >>> 2] >>> (24 - ((i + 1) % 4) * 8)) & 0xff;
                var byte3 = (words[(i + 2) >>> 2] >>> (24 - ((i + 2) % 4) * 8)) & 0xff;

                var triplet = (byte1 << 16) | (byte2 << 8) | byte3;

                for (var j = 0; (j < 4) && (i + j * 0.75 < sigBytes); j++) {
                    base64Chars.push(map.charAt((triplet >>> (6 * (3 - j))) & 0x3f));
                }
            }

            // Add padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                while (base64Chars.length % 4) {
                    base64Chars.push(paddingChar);
                }
            }

            return base64Chars.join('');
        },

        /**
         * Converts a Base64 string to a word array.
         *
         * @param {string} base64Str The Base64 string.
         *
         * @return {WordArray} The word array.
         *
         * @static
         *
         * @example
         *
         *     var wordArray = CryptoJS.enc.Base64.parse(base64String);
         */
        parse: function (base64Str) {
            // Shortcuts
            var base64StrLength = base64Str.length;
            var map = this._map;

            // Ignore padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                var paddingIndex = base64Str.indexOf(paddingChar);
                if (paddingIndex != -1) {
                    base64StrLength = paddingIndex;
                }
            }

            // Convert
            var words = [];
            var nBytes = 0;
            for (var i = 0; i < base64StrLength; i++) {
                if (i % 4) {
                    var bits1 = map.indexOf(base64Str.charAt(i - 1)) << ((i % 4) * 2);
                    var bits2 = map.indexOf(base64Str.charAt(i)) >>> (6 - (i % 4) * 2);
                    words[nBytes >>> 2] |= (bits1 | bits2) << (24 - (nBytes % 4) * 8);
                    nBytes++;
                }
            }

            return WordArray.create(words, nBytes);
        },

        _map: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='
    };
}());
var e,aa=document.getElementById("canvasBackground"),ba="big game_bubbleshooter theme_druid_christmas gameui_endless endscreen_endless boostermedia2 final".split(" ");function ca(a,b){var c=a.userAgent.match(b);return c&&1<c.length&&c[1]||""}
var g=new function(){this.userAgent=void 0;void 0===this.userAgent&&(this.userAgent=void 0!==navigator?navigator.userAgent:"");var a=ca(this,/(ipod|iphone|ipad)/i).toLowerCase(),b=!/like android/i.test(this.userAgent)&&/android/i.test(this.userAgent),c=ca(this,/version\/(\d+(\.\d+)?)/i),d=/tablet/i.test(this.userAgent),f=!d&&/[^-]mobi/i.test(this.userAgent);this.t={};this.ab={};this.ce={};/opera|opr/i.test(this.userAgent)?(this.name="Opera",this.t.opera=!0,this.t.version=c||ca(this,/(?:opera|opr)[\s\/](\d+(\.\d+)?)/i)):
/windows phone/i.test(this.userAgent)?(this.name="Windows Phone",this.ab.gq=!0,this.t.Cl=!0,this.t.version=ca(this,/iemobile\/(\d+(\.\d+)?)/i)):/msie|trident|Edge/i.test(this.userAgent)?(this.name="Internet Explorer",this.t.Cl=!0,this.t.version=ca(this,/(?:msie |rv:)(\d+(\.\d+)?)/i)):/chrome|crios|crmo/i.test(this.userAgent)?(this.name="Chrome",this.t.chrome=!0,this.t.version=ca(this,/(?:chrome|crios|crmo)\/(\d+(\.\d+)?)/i)):a?(this.name="iphone"==a?"iPhone":"ipad"==a?"iPad":"iPod",c&&(this.t.version=
c)):/sailfish/i.test(this.userAgent)?(this.name="Sailfish",this.t.EC=!0,this.t.version=ca(this,/sailfish\s?browser\/(\d+(\.\d+)?)/i)):/seamonkey\//i.test(this.userAgent)?(this.name="SeaMonkey",this.t.TC=!0,this.t.version=ca(this,/seamonkey\/(\d+(\.\d+)?)/i)):/firefox|iceweasel/i.test(this.userAgent)?(this.name="Firefox",this.t.Lr=!0,this.t.version=ca(this,/(?:firefox|iceweasel)[ \/](\d+(\.\d+)?)/i),/\((mobile|tablet);[^\)]*rv:[\d\.]+\)/i.test(this.userAgent)&&(this.ab.TA=!0)):/silk/i.test(this.userAgent)?
(this.name="Amazon Silk",this.t.Dt=!0,this.t.version=ca(this,/silk\/(\d+(\.\d+)?)/i)):b?(this.name="Android",this.t.Yh=!0,this.t.version=c):/phantom/i.test(this.userAgent)?(this.name="PhantomJS",this.t.aC=!0,this.t.version=ca(this,/phantomjs\/(\d+(\.\d+)?)/i)):/blackberry|\bbb\d+/i.test(this.userAgent)||/rim\stablet/i.test(this.userAgent)?(this.name="BlackBerry",this.t.Tq=!0,this.t.version=c||ca(this,/blackberry[\d]+\/(\d+(\.\d+)?)/i)):/(web|hpw)os/i.test(this.userAgent)?(this.name="WebOS",this.t.Lu=
!0,this.t.version=c||ca(this,/w(?:eb)?osbrowser\/(\d+(\.\d+)?)/i),/touchpad\//i.test(this.userAgent)&&(this.ce.Jz=!0)):/bada/i.test(this.userAgent)?(this.name="Bada",this.t.Sq=!0,this.t.version=ca(this,/dolfin\/(\d+(\.\d+)?)/i)):/tizen/i.test(this.userAgent)?(this.name="Tizen",this.t.Hz=!0,this.t.version=ca(this,/(?:tizen\s?)?browser\/(\d+(\.\d+)?)/i)||c):/safari/i.test(this.userAgent)&&(this.name="Safari",this.t.zp=!0,this.t.version=c);/(apple)?webkit/i.test(this.userAgent)?(this.name=this.name||
"Webkit",this.t.vD=!0,!this.t.version&&c&&(this.t.version=c)):!this.opera&&/gecko\//i.test(this.userAgent)&&(this.name=this.name||"Gecko",this.t.bB=!0,this.t.version=this.t.version||ca(this,/gecko\/(\d+(\.\d+)?)/i));b||this.Dt?this.ab.bA=!0:a&&(this.ab.ol=!0);c="";a?(c=ca(this,/os (\d+([_\s]\d+)*) like mac os x/i),c=c.replace(/[_\s]/g,".")):b?c=ca(this,/android[ \/-](\d+(\.\d+)*)/i):this.gq?c=ca(this,/windows phone (?:os)?\s?(\d+(\.\d+)*)/i):this.Lu?c=ca(this,/(?:web|hpw)os\/(\d+(\.\d+)*)/i):this.Tq?
c=ca(this,/rim\stablet\sos\s(\d+(\.\d+)*)/i):this.Sq?c=ca(this,/bada\/(\d+(\.\d+)*)/i):this.Hz&&(c=ca(this,/tizen[\/\s](\d+(\.\d+)*)/i));c&&(this.ab.version=c);c=c.split(".")[0];if(d||"ipad"==a||b&&(3==c||4==c&&!f)||this.Dt)this.ce.Sp=!0;else if(f||"iphone"==a||"ipod"==a||b||this.Tq||this.Lu||this.Sq)this.ce.cp=!0;this.sf={Zc:!1,Mi:!1,x:!1};this.Cl&&10<=this.t.version||this.chrome&&20<=this.t.version||this.Lr&&20<=this.t.version||this.zp&&6<=this.t.version||this.opera&&10<=this.t.version||this.ol&&
this.ab.version&&6<=this.ab.version.split(".")[0]?this.sf.Zc=!0:this.Cl&&10>this.t.version||this.chrome&&20>this.t.version||this.Lr&&20>this.t.version||this.zp&&6>this.t.version||this.opera&&10>this.t.version||this.ol&&this.ab.version&&6>this.ab.version.split(".")[0]?this.sf.Mi=!0:this.sf.x=!0;try{this.t.ef=this.t.version?parseFloat(this.t.version.match(/\d+(\.\d+)?/)[0],10):0}catch(h){this.t.ef=0}try{this.ab.ef=this.ab.version?parseFloat(this.ab.version.match(/\d+(\.\d+)?/)[0],10):0}catch(k){this.ab.ef=
0}};function m(a,b){this.x=a;this.y=b}function da(a,b){return new m(b*Math.cos(Math.PI*a/180),-b*Math.sin(Math.PI*a/180))}e=m.prototype;e.length=function(){return Math.sqrt(this.x*this.x+this.y*this.y)};e.direction=function(){return 180*Math.atan2(-this.y,this.x)/Math.PI};e.P=function(){return new m(this.x,this.y)};e.add=function(a){return new m(this.x+a.x,this.y+a.y)};e.ic=function(a){return new m(this.x-a.x,this.y-a.y)};e.scale=function(a){return new m(a*this.x,a*this.y)};
e.rotate=function(a){var b=Math.sin(a*Math.PI/180);a=Math.cos(a*Math.PI/180);return new m(a*this.x+b*this.y,-b*this.x+a*this.y)};e.ng=function(a){return this.x*a.x+this.y*a.y};e.normalize=function(){var a=Math.sqrt(this.x*this.x+this.y*this.y);return 0===a?new m(0,0):new m(this.x/a,this.y/a)};function ea(a){return(new m(a.y,-a.x)).normalize()}
e.tc=function(a,b,c){var d=Math.min(8,this.length()/4),f=this.ic(this.normalize().scale(2*d)),h=f.add(ea(this).scale(d)),d=f.add(ea(this).scale(-d)),k=p.context;k.strokeStyle=c;k.beginPath();k.moveTo(a,b);k.lineTo(a+f.x,b+f.y);k.lineTo(a+h.x,b+h.y);k.lineTo(a+this.x,b+this.y);k.lineTo(a+d.x,b+d.y);k.lineTo(a+f.x,b+f.y);k.stroke()};function fa(a){this.uj=4294967296;this.Zc=1664525;this.Mi=1013904223;this.state=void 0===a?Math.floor(Math.random()*(this.uj-1)):a}
fa.prototype.P=function(){var a=new fa;a.uj=this.uj;a.Zc=this.Zc;a.Mi=this.Mi;a.state=this.state;return a};fa.prototype.random=function(a){var b=1;void 0!==a&&(b=a);this.state=(this.Zc*this.state+this.Mi)%this.uj;return this.state/this.uj*b};function ha(a,b){var c=1;void 0!==b&&(c=b);return Math.floor(a.random(c+1))}new fa;function ia(){this.hf="";this.Om=[];this.zi=[];this.Vf=[];this.bh=[];this.Xc=[];this.V("start");this.V("load");this.V("game")}
function ja(a){var b=ka;b.hf=a;""!==b.hf&&"/"!==b.hf[b.hf.length-1]&&(b.hf+="/")}e=ia.prototype;e.V=function(a){this.Xc[a]||(this.zi[a]=0,this.Vf[a]=0,this.bh[a]=0,this.Xc[a]=[],this.Om[a]=!1)};e.loaded=function(a){return this.Xc[a]?this.Vf[a]:0};e.Cd=function(a){return this.Xc[a]?this.bh[a]:0};e.complete=function(a){return this.Xc[a]?this.Vf[a]+this.bh[a]===this.zi[a]:!0};function la(a){var b=ka;return b.Xc[a]?100*(b.Vf[a]+b.bh[a])/b.zi[a]:100}
function ma(a){var b=ka;b.Vf[a]+=1;b.complete(a)&&na("Load Complete",{pb:a})}function oa(a){var b=ka;b.bh[a]+=1;na("Load Failed",{pb:a})}function pa(a,b,c){var d=ka;d.Xc[b]||d.V(b);d.Xc[b].push(a);d.zi[b]+=c}e.je=function(a){var b;if(!this.Om[a])if(this.Om[a]=!0,this.Xc[a]&&0!==this.Xc[a].length)for(b=0;b<this.Xc[a].length;b+=1)this.Xc[a][b].je(a,this.hf);else na("Load Complete",{pb:a})};var ka=new ia;function qa(a){this.context=this.canvas=void 0;this.height=this.width=0;a&&this.ja(a)}
qa.prototype.ja=function(a){this.canvas=a;this.context=a.getContext("2d");this.width=a.width;this.height=a.height};qa.prototype.clear=function(){this.context.clearRect(0,0,this.width,this.height);this.context.beginPath();this.context.moveTo(0,0);this.context.lineTo(-1,-1);this.context.closePath();this.context.stroke()};
function sa(a,b,c,d,f,h){var k=p;k.context.save();!1===h?(k.context.fillStyle=f,k.context.fillRect(a,b,c,d)):!0===h?(k.context.strokeStyle=f,k.context.strokeRect(a,b,c,d)):(void 0!==f&&(k.context.fillStyle=f,k.context.fillRect(a,b,c,d)),void 0!==h&&(k.context.strokeStyle=h,k.context.strokeRect(a,b,c,d)));k.context.restore()}
function ta(a,b,c,d){var f=p;f.context.save();f.context.beginPath();f.context.moveTo(a,b);f.context.lineTo(c,d);f.context.lineWidth=1;f.context.strokeStyle="green";f.context.stroke();f.context.restore()}
qa.prototype.Mc=function(a,b,c,d,f,h,k){this.context.save();this.context.font=f;!1===h?(this.context.fillStyle=d,this.context.fillText(a,b,c)):!0===h?(this.context.strokeStyle=d,this.context.strokeText(a,b,c)):(void 0!==d&&(this.context.fillStyle=d,this.context.fillText(a,b,c)),void 0!==h&&(k&&(this.context.lineWidth=k),this.context.strokeStyle=h,this.context.strokeText(a,b,c)));this.context.restore()};qa.prototype.aa=function(a,b){this.context.font=b;return this.context.measureText(a).width};
var p=new qa(aa);function ua(a,b,c){this.name=a;this.D=b;this.Uw=c;this.ad=[];this.Nn=[];pa(this,this.Uw,this.D)}ua.prototype.je=function(a,b){function c(){oa(a)}function d(){ma(a)}var f,h;for(f=0;f<this.ad.length;f+=1)h=this.Nn[f],0!==h.toLowerCase().indexOf("http:")&&0!==h.toLowerCase().indexOf("https:")&&(h=b+h),this.ad[f].src=h,this.ad[f].addEventListener("load",d,!1),this.ad[f].addEventListener("error",c,!1)};
ua.prototype.complete=function(){var a;for(a=0;a<this.ad.length;a+=1)if(!this.ad[a].complete||0===this.ad[a].width)return!1;return!0};function va(a,b,c){0<=b&&b<a.D&&(a.ad[b]=new Image,a.Nn[b]=c)}ua.prototype.c=function(a,b){0<=a&&a<this.D&&(this.ad[a]=b,this.Nn[a]="")};ua.prototype.Da=function(a,b,c,d,f,h,k,l,n){this.ad[a]&&this.ad[a].complete&&(void 0===l&&(l=d),void 0===n&&(n=f),0>=d||0>=f||0!==Math.round(l)&&0!==Math.round(n)&&p.context.drawImage(this.ad[a],b,c,d,f,h,k,l,n))};
function r(a,b,c,d,f,h,k,l,n,q){this.name=a;this.cf=b;this.D=c;this.width=d;this.height=f;this.eb=h;this.Za=k;this.Qi=l;this.ph=n;this.Jh=q;this.Hf=[];this.If=[];this.Jf=[];this.$e=[];this.Ze=[];this.af=[];this.bf=[]}e=r.prototype;e.c=function(a,b,c,d,f,h,k,l){0<=a&&a<this.D&&(this.Hf[a]=b,this.If[a]=c,this.Jf[a]=d,this.$e[a]=f,this.Ze[a]=h,this.af[a]=k,this.bf[a]=l)};e.complete=function(){return this.cf.complete()};
e.o=function(a,b,c){a=(Math.round(a)%this.D+this.D)%this.D;this.cf.Da(this.Hf[a],this.If[a],this.Jf[a],this.$e[a],this.Ze[a],b-this.eb+this.af[a],c-this.Za+this.bf[a])};e.fd=function(a,b,c,d){var f=p.context,h=f.globalAlpha;f.globalAlpha=d;a=(Math.round(a)%this.D+this.D)%this.D;this.cf.Da(this.Hf[a],this.If[a],this.Jf[a],this.$e[a],this.Ze[a],b-this.eb+this.af[a],c-this.Za+this.bf[a]);f.globalAlpha=h};
e.S=function(a,b,c,d,f,h,k){var l=p.context;1E-4>Math.abs(d)||1E-4>Math.abs(f)||(a=(Math.round(a)%this.D+this.D)%this.D,l.save(),l.translate(b,c),l.rotate(-h*Math.PI/180),l.scale(d,f),l.globalAlpha=k,this.cf.Da(this.Hf[a],this.If[a],this.Jf[a],this.$e[a],this.Ze[a],this.af[a]-this.eb,this.bf[a]-this.Za),l.restore())};
e.Da=function(a,b,c,d,f,h,k,l){var n=p.context,q=n.globalAlpha,u,B,C,t;a=(Math.round(a)%this.D+this.D)%this.D;u=this.af[a];B=this.bf[a];C=this.$e[a];t=this.Ze[a];b-=u;c-=B;0>=b+d||0>=c+f||b>=C||c>=t||(0>b&&(d+=b,h-=b,b=0),0>c&&(f+=c,k-=c,c=0),b+d>C&&(d=C-b),c+f>t&&(f=t-c),n.globalAlpha=l,this.cf.Da(this.Hf[a],this.If[a]+b,this.Jf[a]+c,d,f,h,k),n.globalAlpha=q)};
e.En=function(a,b,c,d,f,h,k,l,n,q,u,B){var C,t,s,v,w,U,ra,Z,ga,Oa;if(!(0>=h||0>=k))for(b=Math.round(b)%h,0<b&&(b-=h),c=Math.round(c)%k,0<c&&(c-=k),C=Math.ceil((q-b)/h),t=Math.ceil((u-c)/k),b+=l,c+=n,ga=0;ga<C;ga+=1)for(Oa=0;Oa<t;Oa+=1)w=d,U=f,ra=h,Z=k,s=b+ga*h,v=c+Oa*k,s<l&&(w+=l-s,ra-=l-s,s=l),s+ra>=l+q&&(ra=l+q-s),v<n&&(U+=n-v,Z-=n-v,v=n),v+Z>=n+u&&(Z=n+u-v),0<ra&&0<Z&&this.Da(a,w,U,ra,Z,s,v,B)};e.Kk=function(a,b,c,d,f,h,k,l,n,q){this.En(a,0,0,b,c,d,f,h,k,l,n,q)};
e.Jk=function(a,b,c,d,f,h,k,l,n,q){var u=p.context,B=u.globalAlpha,C,t,s,v,w,U;a=(Math.round(a)%this.D+this.D)%this.D;C=l/d;t=n/f;s=this.af[a];v=this.bf[a];w=this.$e[a];U=this.Ze[a];b-=s;c-=v;0>=b+d||0>=c+f||b>=w||c>=U||(0>b&&(d+=b,l+=C*b,h-=C*b,b=0),0>c&&(f+=c,n+=t*c,k-=t*c,c=0),b+d>w&&(l-=C*(d-w+b),d=w-b),c+f>U&&(n-=t*(f-U+c),f=U-c),u.globalAlpha=q,this.cf.Da(this.Hf[a],this.If[a]+b,this.Jf[a]+c,d,f,h,k,l,n),u.globalAlpha=B)};
function wa(a,b,c){var d,f,h;for(d=0;d<a.D;d+=1)f=b+d%a.Jh*a.width,h=c+a.height*Math.floor(d/a.Jh),a.cf.Da(a.Hf[d],a.If[d],a.Jf[d],a.$e[d],a.Ze[d],f-a.eb+a.af[d],h-a.Za+a.bf[d])}function x(a,b){this.canvas=document.createElement("canvas");this.context=this.canvas.getContext("2d");this.width=a;this.height=b;this.Za=this.eb=0;this.canvas.width=a;this.canvas.height=b;this.clear();this.Fl=void 0}e=x.prototype;
e.P=function(){var a=new x(this.width,this.height);a.eb=this.eb;a.Za=this.Za;y(a);this.o(0,0);z(a);return a};function y(a){a.Fl=p.canvas;p.ja(a.canvas)}function z(a){p.canvas===a.canvas&&void 0!==a.Fl&&(p.ja(a.Fl),a.Fl=void 0)}e.clear=function(){this.context.clearRect(0,0,this.canvas.width,this.canvas.height)};e.o=function(a,b){p.context.drawImage(this.canvas,a-this.eb,b-this.Za)};
e.fd=function(a,b,c){var d=p.context,f=d.globalAlpha;d.globalAlpha=c;p.context.drawImage(this.canvas,a-this.eb,b-this.Za);d.globalAlpha=f};e.S=function(a,b,c,d,f,h){var k=p.context;1E-4>Math.abs(c)||1E-4>Math.abs(d)||(k.save(),k.translate(a,b),k.rotate(-f*Math.PI/180),k.scale(c,d),k.globalAlpha=h,p.context.drawImage(this.canvas,-this.eb,-this.Za),k.restore())};
e.Da=function(a,b,c,d,f,h,k){var l=p.context,n=l.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),l.globalAlpha=k,p.context.drawImage(this.canvas,a,b,c,d,f,h,c,d),l.globalAlpha=n)};
e.En=function(a,b,c,d,f,h,k,l,n,q,u){var B,C,t,s,v,w,U,ra,Z,ga;if(!(0>=f||0>=h))for(c+f>this.width&&(f=this.width-c),d+h>this.height&&(h=this.height-d),a=Math.round(a)%f,0<a&&(a-=f),b=Math.round(b)%h,0<b&&(b-=h),B=Math.ceil((n-a)/f),C=Math.ceil((q-b)/h),a+=k,b+=l,Z=0;Z<B;Z+=1)for(ga=0;ga<C;ga+=1)v=c,w=d,U=f,ra=h,t=a+Z*f,s=b+ga*h,t<k&&(v+=k-t,U-=k-t,t=k),t+U>=k+n&&(U=k+n-t),s<l&&(w+=l-s,ra-=l-s,s=l),s+ra>=l+q&&(ra=l+q-s),0<U&&0<ra&&this.Da(v,w,U,ra,t,s,u)};
e.Kk=function(a,b,c,d,f,h,k,l,n){this.En(0,0,a,b,c,d,f,h,k,l,n)};e.Jk=function(a,b,c,d,f,h,k,l,n){var q=p.context,u=q.globalAlpha;0>=c||0>=d||(a+c>this.width&&(c=this.width-a),b+d>this.height&&(d=this.height-b),0!==Math.round(k)&&0!==Math.round(l)&&(q.globalAlpha=n,p.context.drawImage(this.canvas,a,b,c,d,f,h,k,l),q.globalAlpha=u))};function xa(a){this.name=a;this.align="left";this.i="base";this.xm=this.ka=0}e=xa.prototype;e.complete=function(){return this.b.cf.complete()};
function ya(a,b,c){var d=[],f,h,k;if(void 0===c)return d=b.split("\n");0>c&&(c=0);h=f=0;for(d[0]="";f<b.length;)if("\n"===b[f])d.push(""),h=0,f+=1;else if(k=d.length-1,h+=a.width[b.charCodeAt(f)],h>c&&0<d[k].length){for(h=d[k].length-1;0<=h&&" "!==d[k][h];)h-=1;0<=h&&(f=f-d[k].length+h+1,d[k]=d[k].substr(0,h));d.push("");h=0}else d[k]+=b[f],h+=a.xm,f+=1;return d}e.Xf=function(a){var b=0,c;for(c=a.length-1;0<=c;c-=1)b+=this.width[a.charCodeAt(c)]+this.xm;return b-this.xm};
e.aa=function(a,b){var c=ya(this,a,b),d=0,f;for(f=c.length-1;0<=f;f-=1)d=Math.max(d,this.Xf(c[f]));return d};e.T=function(a,b){var c=ya(this,a,b);return c.length*this.height+(c.length-1)*this.ka};
e.o=function(a,b,c,d){a=ya(this,a,d);d=a.length*this.height+(a.length-1)*this.ka;var f,h,k,l;switch(this.i){case "top":c-=this.top;break;case "middle":c-=this.top+Math.round(d/2);break;case "base":c-=this.ih;break;case "bottom":c-=this.top+d}d=c;for(h=0;h<a.length;h+=1){c=b;switch(this.align){case "left":c=b;break;case "center":c=b-Math.round(this.Xf(a[h])/2);break;case "right":c=b-this.Xf(a[h])}for(f=0;f<a[h].length;f+=1)k=a[h].charCodeAt(f),l=this.index[k],0<=l&&this.b.o(l,c-this.left[k],d),c+=
this.width[k]+this.xm;d+=this.height+this.ka}};e.fd=function(a,b,c,d,f){var h=p.context;h.save();h.globalAlpha=d;this.o(a,b,c,f);h.restore()};e.S=function(a,b,c,d,f,h,k,l){var n=p.context;1E-4>Math.abs(d)||1E-4>Math.abs(f)||(n.save(),n.translate(b,c),n.rotate(-h*Math.PI/180),n.scale(d,f),n.globalAlpha=k,this.o(a,0,0,l/d),n.restore())};
function za(a,b,c,d){this.H=a;this.Sz=b;this.Lz=c;this.ck=[{text:"MiHhX!@v&Qq",width:-1,font:"sans-serif"},{text:"MiHhX!@v&Qq",width:-1,font:"serif"},{text:"AaMm#@!Xx67",width:-1,font:"sans-serif"},{text:"AaMm#@!Xx67",width:-1,font:"serif"}];this.Yt=!1;pa(this,d,1)}function Aa(a,b,c){p.context.save();p.context.font="250pt "+a+", "+b;a=p.context.measureText(c).width;p.context.restore();return a}
function Ba(a){var b,c,d;for(b=0;b<a.ck.length;b+=1)if(c=a.ck[b],d=Aa(a.H,c.font,c.text),c.width!==d){ma(a.Tw);document.body.removeChild(a.ff);a.Yt=!0;return}window.setTimeout(function(){Ba(a)},33)}
za.prototype.je=function(a,b){var c="@font-face {font-family: "+this.H+";src: url('"+b+this.Sz+"') format('woff'), url('"+b+this.Lz+"') format('truetype');}",d=document.createElement("style");d.id=this.H+"_fontface";d.type="text/css";d.styleSheet?d.styleSheet.cssText=c:d.appendChild(document.createTextNode(c));document.getElementsByTagName("head")[0].appendChild(d);this.ff=document.createElement("span");this.ff.style.position="absolute";this.ff.style.left="-9999px";this.ff.style.top="-9999px";this.ff.style.visibility=
"hidden";this.ff.style.fontSize="250pt";this.ff.id=this.H+"_loader";document.body.appendChild(this.ff);for(c=0;c<this.ck.length;c+=1)d=this.ck[c],d.width=Aa(d.font,d.font,d.text);this.Tw=a;Ba(this)};za.prototype.complete=function(){return this.Yt};
function Ca(a,b){this.H=a;this.Yi=b;this.fontWeight=this.fontStyle="";this.uh="normal";this.fontSize=12;this.fill=!0;this.Ta=1;this.hd=0;this.fillColor="black";this.Dd={b:void 0,hc:0,wp:!0,xp:!0};this.mb={Vj:!0,D:3,Ak:["red","white","blue"],size:.6,offset:0};this.fillStyle=void 0;this.stroke=!1;this.Wa=1;this.Zh=0;this.strokeColor="black";this.strokeStyle=void 0;this.Uc=1;this.ke=!1;this.Og="miter";this.I={h:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1};this.align="left";this.i="top";
this.ka=this.Qa=0}e=Ca.prototype;
e.P=function(){var a=new Ca(this.H,this.Yi);a.fontStyle=this.fontStyle;a.fontWeight=this.fontWeight;a.uh=this.uh;a.fontSize=this.fontSize;a.fill=this.fill;a.Ta=this.Ta;a.hd=this.hd;a.fillColor=this.fillColor;a.Dd={b:this.Dd.b,wp:this.Dd.wp,xp:this.Dd.xp};a.mb={Vj:this.mb.Vj,D:this.mb.D,Ak:this.mb.Ak.slice(0),size:this.mb.size,offset:this.mb.offset};a.fillStyle=this.fillStyle;a.stroke=this.stroke;a.Wa=this.Wa;a.Zh=this.Zh;a.strokeColor=this.strokeColor;a.strokeStyle=this.strokeStyle;a.Uc=this.Uc;a.ke=
this.ke;a.Og=this.Og;a.I={h:this.I.h,color:this.I.color,offsetX:this.I.offsetX,offsetY:this.I.offsetY,blur:this.I.blur};a.align=this.align;a.i=this.i;a.Qa=this.Qa;a.ka=this.ka;return a};
function A(a,b){void 0!==b.H&&(a.H=b.H);void 0!==b.Yi&&(a.Yi=b.Yi);void 0!==b.fontStyle&&(a.fontStyle=b.fontStyle);void 0!==b.fontWeight&&(a.fontWeight=b.fontWeight);void 0!==b.uh&&(a.uh=b.uh);void 0!==b.fontSize&&(a.fontSize=b.fontSize);void 0!==b.fill&&(a.fill=b.fill);void 0!==b.Ta&&(a.Ta=b.Ta);void 0!==b.fillColor&&(a.hd=0,a.fillColor=b.fillColor);void 0!==b.Dd&&(a.hd=1,a.Dd=b.Dd);void 0!==b.mb&&(a.hd=2,a.mb=b.mb);void 0!==b.fillStyle&&(a.hd=3,a.fillStyle=b.fillStyle);void 0!==b.stroke&&(a.stroke=
b.stroke);void 0!==b.Wa&&(a.Wa=b.Wa);void 0!==b.strokeColor&&(a.Zh=0,a.strokeColor=b.strokeColor);void 0!==b.strokeStyle&&(a.Zh=3,a.strokeStyle=b.strokeStyle);void 0!==b.Uc&&(a.Uc=b.Uc);void 0!==b.ke&&(a.ke=b.ke);void 0!==b.Og&&(a.Og=b.Og);void 0!==b.I&&(a.I=b.I);void 0!==b.align&&(a.align=b.align);void 0!==b.i&&(a.i=b.i);void 0!==b.Qa&&(a.Qa=b.Qa);void 0!==b.ka&&(a.ka=b.ka)}function Da(a){a.fontWeight="normal"}function D(a,b){a.fontSize=void 0===b?12:b}
e.setFillColor=function(a){this.hd=0;this.fillColor=void 0===a?"black":a};function Ea(a,b,c,d,f){a.hd=2;a.mb.Vj=!0;a.mb.D=b;a.mb.Ak=c.slice(0);a.mb.size=void 0===d?.6:d;a.mb.offset=void 0===f?0:f}function Fa(a,b){a.stroke=void 0===b?!1:b}e.setStrokeColor=function(a){this.Zh=0;this.strokeColor=void 0===a?"black":a};function Ga(a,b){a.Uc=void 0===b?1:b}function Ha(a,b){a.ke=void 0===b?!1:b}function Ia(a,b){a.Og=void 0===b?"miter":b}
function Ja(a,b,c,d,f,h){void 0===b?a.I={h:!1,color:"rgba(10, 10, 10, 0.3)",offsetX:3,offsetY:3,blur:1}:b instanceof Object?a.I={h:b.h,color:b.color,offsetX:b.offsetX,offsetY:b.offsetY,blur:b.blur}:void 0===c?a.I.h=b:a.I={h:b,color:c,offsetX:d,offsetY:f,blur:h}}function Ka(a){return{h:a.I.h,color:a.I.color,offsetX:a.I.offsetX,offsetY:a.I.offsetY,blur:a.I.blur}}function La(a,b){a.align=void 0===b?"left":b}function Ma(a,b){a.i=void 0===b?"top":b}
function Na(a){return a.fontStyle+" "+a.fontWeight+" "+a.fontSize+"px "+a.H+", "+a.Yi}e.Xf=function(a){var b=0,c;for(c=0;c<a.length;c+=1)b=Math.max(b,a[c].width);return b};function Pa(a,b){return a.fontSize*b.length+a.ka*(b.length-1)}
function Qa(a,b,c){var d,f,h,k,l,n,q=[],u=p.context;u.font=Na(a);switch(a.uh){case "upper":b=b.toUpperCase();break;case "lower":b=b.toLowerCase()}if(void 0===c){n=b.split("\n");for(a=0;a<n.length;a+=1)q.push({text:n[a],width:u.measureText(n[a]).width});return q}n=b.split("\n");h=u.measureText(" ").width;for(a=0;a<n.length;a+=1){f=n[a].split(" ");d=f[0];l=u.measureText(f[0]).width;for(b=1;b<f.length;b+=1)k=u.measureText(f[b]).width,l+h+k<c?(d+=" "+f[b],l+=h+k):(q.push({text:d,width:l}),d=f[b],l=k);
q.push({text:d,width:l})}return q}e.aa=function(a,b){var c;p.context.save();c=this.Xf(Qa(this,a,b));p.context.restore();return c};e.T=function(a,b){var c;p.context.save();c=Pa(this,Qa(this,a,b));p.context.restore();return c};function Ra(a,b,c,d,f,h){var k=a.fontSize;a.fontSize=b;b=h?Qa(a,c,d):Qa(a,c);d=a.Xf(b)<=d&&Pa(a,b)<=f;a.fontSize=k;return d}
function Sa(a,b,c,d,f){var h=0,k=32;void 0===f&&(f=!1);for(p.context.save();Ra(a,h+k,b,c,d,f);)h+=k;for(;2<=k;)k/=2,Ra(a,h+k,b,c,d,f)&&(h+=k);p.context.restore();return Math.max(4,h)}function Ta(a,b,c,d,f){var h=Math.max(.01,a.mb.size),k=a.mb.offset;a.mb.Vj?(k=f/2+k*f,h=.5*h*f,b=p.context.createLinearGradient(b,c+k-h,b,c+k+h)):(k=d/2+k*d,h=.5*h*d,b=p.context.createLinearGradient(b+k-h,c,b+k+h,c));c=1/(a.mb.D-1);for(d=0;d<a.mb.D;d+=1)b.addColorStop(d*c,a.mb.Ak[d]);return b}
function Ua(a,b,c,d,f,h,k){var l,n;!a.fill&&a.I.h?(b.shadowColor=a.I.color,b.shadowOffsetX=a.I.offsetX,b.shadowOffsetY=a.I.offsetY,b.shadowBlur=a.I.blur):(b.shadowColor=void 0,b.shadowOffsetX=0,b.shadowOffsetY=0,b.shadowBlur=0);b.globalAlpha=k*a.Wa;switch(a.Zh){case 0:b.strokeStyle=a.strokeColor;break;case 3:b.strokeStyle=a.strokeStyle}b.lineWidth=a.Uc;b.lineJoin=a.Og;for(k=0;k<c.length;k+=1){l=0;switch(a.align){case "right":l=h-c[k].width;break;case "center":l=(h-c[k].width)/2}n=a.fontSize*(k+1)+
a.ka*k;b.strokeText(c[k].text,d+l,f+n)}}
function Va(a,b,c,d,f,h,k){c=Qa(a,c,k);k=a.Xf(c);var l=Pa(a,c);b.textAlign="left";b.textBaseline="bottom";switch(a.align){case "right":d+=-k;break;case "center":d+=-k/2}switch(a.i){case "base":case "bottom":f+=-l+Math.round(a.Qa*a.fontSize);break;case "middle":f+=-l/2+Math.round(a.Qa*a.fontSize/2)}b.font=Na(a);a.stroke&&a.ke&&Ua(a,b,c,d,f,k,h);if(a.fill){var n=d,q=f,u,B;a.I.h?(b.shadowColor=a.I.color,b.shadowOffsetX=a.I.offsetX,b.shadowOffsetY=a.I.offsetY,b.shadowBlur=a.I.blur):(b.shadowColor=void 0,
b.shadowOffsetX=0,b.shadowOffsetY=0,b.shadowBlur=0);b.globalAlpha=h*a.Ta;switch(a.hd){case 0:b.fillStyle=a.fillColor;break;case 1:l=a.Dd.b;B=new x(l.width,l.height);var C=a.Dd.wp,t=a.Dd.xp;C&&t?u="repeat":C&&!t?u="repeat-x":!C&&t?u="repeat-y":C||t||(u="no-repeat");y(B);l.o(a.Dd.hc,0,0);z(B);u=p.context.createPattern(B.canvas,u);b.fillStyle=u;break;case 2:b.fillStyle=Ta(a,n,q,k,l);break;case 3:b.fillStyle=a.fillStyle;break;default:b.fillStyle=a.fillColor}for(u=0;u<c.length;u+=1){l=0;switch(a.align){case "right":l=
k-c[u].width;break;case "center":l=(k-c[u].width)/2}B=a.fontSize*(u+1)+a.ka*u;2===a.hd&&a.mb.Vj&&(b.fillStyle=Ta(a,n,q+B-a.fontSize,k,a.fontSize));b.fillText(c[u].text,n+l,q+B)}}a.stroke&&!a.ke&&Ua(a,b,c,d,f,k,h)}e.o=function(a,b,c,d){var f=p.context;this.fill&&1===this.hd?this.S(a,b,c,1,1,0,1,d):(f.save(),Va(this,f,a,b,c,1,d),f.restore())};e.fd=function(a,b,c,d,f){var h=p.context;this.fill&&1===this.hd?this.S(a,b,c,1,1,0,d,f):(h.save(),Va(this,h,a,b,c,d,f),h.restore())};
e.S=function(a,b,c,d,f,h,k,l){var n=p.context;n.save();n.translate(b,c);n.rotate(-h*Math.PI/180);n.scale(d,f);try{Va(this,n,a,0,0,k,l)}catch(q){}n.restore()};
function Wa(){this.kx=10;this.hk=-1;this.av="stop_lowest_prio";this.Oq=this.hb=this.Hb=!1;var a,b=this,c="undefined"!==typeof AudioContext?AudioContext:"undefined"!==typeof webkitAudioContext?webkitAudioContext:void 0;if(c)this.Hb=!0;else if("undefined"!==typeof Audio)try{"undefined"!==typeof(new Audio).canPlayType&&(this.hb=!0)}catch(d){}this.Oq=this.Hb||this.hb;this.hb&&g.t.Yh&&(this.hk=1);if(this.Oq)try{a=new Audio,this.sq={ogg:!!a.canPlayType('audio/ogg; codecs="vorbis"').replace(/^no$/,""),mp3:!!a.canPlayType("audio/mpeg;").replace(/^no$/,
""),opus:!!a.canPlayType('audio/ogg; codecs="opus"').replace(/^no$/,""),wav:!!a.canPlayType('audio/wav; codecs="1"').replace(/^no$/,""),m4a:!!(a.canPlayType("audio/x-m4a;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),mp4:!!(a.canPlayType("audio/x-mp4;")||a.canPlayType("audio/aac;")).replace(/^no$/,""),weba:!!a.canPlayType('audio/webm; codecs="vorbis"').replace(/^no$/,"")}}catch(f){this.sq={ogg:!1,mp3:!0,opus:!1,wav:!1,m4a:!1,mp4:!1,weba:!1}}this.Ac=[];this.Uf={};this.yb={};this.xd={};this.oe=
[];this.Kc=0;this.Hb?(this.ne=new c,this.tq="function"===typeof this.ne.createGain?function(){return b.ne.createGain()}:"function"===typeof this.ne.createGainNode?function(){return b.ne.createGainNode()}:function(){},this.Sf={},this.gk=this.tq(),void 0===this.gk?(this.hb=!0,this.li=Wa.prototype.Nm):(this.gk.connect(this.ne.destination),this.Sf.master=this.gk,this.li=Wa.prototype.$u)):this.li=this.hb?Wa.prototype.Nm:function(){}}
function Xa(a){var b=E,c,d,f,h,k;for(c=0;c<b.Ac.length;c+=1)if((d=b.Ac[c])&&0===d.Jn)if(d.paused)d.xq&&(d.Pm+=a,d.Pm>=d.xq&&b.Gj(d.id));else if(d.Qm+=a,d.ah&&d.Qm>=d.Ot)d.ah=!1,Za(b,d,d.qe);else if(d.qb&&b.hb&&b.po(d.id)>=d.duration)if(d.Vo)try{d.F.pause(),d.F.currentTime=d.qe/1E3,4===d.F.readyState?d.F.play():(f=function(){var a=d;return{ready:function(){a.F.play();a.F.removeEventListener("canplaythrough",f.ready,!1)}}}(),d.F.addEventListener("canplaythrough",f.ready,!1))}catch(l){}else d.F.pause(),
$a(d);for(c=b.oe.length-1;0<=c;c-=1)h=b.oe[c],b.Go(h.id)||0!==h.Jn||(h.l+=a,h.l>=h.duration?(ab(E,h.id,h.Mj),void 0!==b.xd[h.id]&&(b.xd[h.id]=h.Mj),h.zb&&h.zb(),b.oe.splice(c,1)):(k=h.lb(h.l,h.start,h.Mj-h.start,h.duration),ab(E,h.id,k),void 0!==b.xd[h.id]&&(b.xd[h.id]=k)))}function bb(a,b){a.Uf[b.Xb.r.name]?a.Uf[b.Xb.r.name].length<a.kx&&a.Uf[b.Xb.r.name].push(b.F):a.Uf[b.Xb.r.name]=[b.F]}
function cb(a,b){var c,d,f;f=[];for(c=0;c<a.Ac.length;c+=1)(d=a.Ac[c])&&0<=d.La.indexOf(b)&&f.push(d);return f}function db(a,b){if(0<a.hk&&a.Kc>=a.hk)switch(a.av){case "cancel_new":return!1;case "stop_lowest_prio":var c,d,f;for(c=0;c<a.Ac.length;c+=1)(d=a.Ac[c])&&d.qb&&!d.paused&&(void 0===f||f.Tl<d.Tl)&&(f=d);if(f.Tl>b.vi){a.stop(f.id);break}return!1}return!0}
function eb(a,b){var c,d=1;for(c=0;c<b.La.length;c+=1)void 0!==E.yb[b.La[c]]&&(d*=E.yb[b.La[c]]);c=a.tq();c.gain.value=d;c.connect(a.gk);a.Sf[b.id]=c;b.F.connect(c)}function fb(a,b){b.F.disconnect(0);a.Sf[b.id]&&(a.Sf[b.id].disconnect(0),delete a.Sf[b.id])}function gb(a,b){var c;if(b.r&&b.r.qc){if(a.Hb)return c=a.ne.createBufferSource(),c.buffer=b.r.qc,c.loopStart=b.startOffset/1E3,c.loopEnd=(b.startOffset+b.duration)/1E3,c;if(a.hb)return c=b.r.qc.cloneNode(!0),c.volume=0,c}}
function hb(a,b){var c,d;if(a.Hb)(c=gb(a,b))&&(d=new ib(b,c));else if(a.hb){c=a.Uf[b.r.name];if(!c)return;0<c.length?d=new ib(b,c.pop()):(c=gb(a,b))&&(d=new ib(b,c))}if(d){a.Hb&&eb(a,d);for(c=0;c<a.Ac.length;c+=1)if(void 0===a.Ac[c])return a.Ac[c]=d;a.Ac.push(d)}return d}function jb(a){var b=E,c,d;for(c=0;c<a.length;c+=1)if(d=a[c].split(".").pop(),b.sq[d])return a[c];return!1}e=Wa.prototype;
e.Nm=function(a,b,c){function d(){var b;a.loaded=!0;ma(c);a.duration=Math.ceil(1E3*a.qc.duration);a.qc.removeEventListener("canplaythrough",d,!1);a.qc.removeEventListener("error",f,!1);b=a.qc.cloneNode(!0);E.Uf[a.name].push(b)}function f(){oa(c)}(b=jb(b))?(a.qc=new Audio,a.qc.src=b,a.qc.autoplay=!1,a.qc.dC="auto",a.qc.addEventListener("canplaythrough",d,!1),a.qc.addEventListener("error",f,!1),a.qc.load()):f()};
e.$u=function(a,b,c){var d=jb(b),f=new XMLHttpRequest;f.open("GET",d,!0);f.responseType="arraybuffer";f.onload=function(){E.ne.decodeAudioData(f.response,function(b){b&&(a.qc=b,a.duration=1E3*b.duration,a.loaded=!0,ma(c))},function(){oa(c)})};f.onerror=function(){"undefined"!==typeof Audio&&(E.Hb=!1,E.hb=!0,E.li=Wa.prototype.Nm,E.li(a,b,c))};try{f.send()}catch(h){}};
e.play=function(a,b,c,d){if(a instanceof F){if(db(this,a)){a=hb(this,a);if(!a)return-1;a.Ot=b||0;a.ah=0<b;a.$b=c||0;a.Me=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};a.ah||Za(this,a,a.qe);return a.id}return-1}};
function Za(a,b,c){var d;"number"!==typeof c&&(c=0);kb(a,b.id);0<b.$b&&(d=lb(a,b.id),ab(a,b.id,0),mb(a,b.id,d,b.$b,b.Me),b.$b=0,b.Me=void 0);if(a.Hb){d=c-b.qe;b.bv=1E3*a.ne.currentTime-d;b.F.onended=function(){$a(b)};try{b.F.start?b.F.start(0,c/1E3,(b.duration-d)/1E3):b.F.noteGrainOn&&b.F.noteGrainOn(0,c/1E3,(b.duration-d)/1E3),b.Vd=!0,b.qb=!0,a.Kc+=1,b.F.loop=b.Vo}catch(f){}}else if(a.hb){if(4!==b.F.readyState){var h=function(){return{ready:function(){b.F.currentTime=c/1E3;b.F.play();b.Vd=!0;b.F.removeEventListener("canplaythrough",
h.ready,!1)}}}();b.F.addEventListener("canplaythrough",h.ready,!1)}else b.F.currentTime=c/1E3,b.F.play(),b.Vd=!0;b.qb=!0;a.Kc+=1}}
e.Gj=function(a,b,c,d){var f,h,k,l,n=cb(this,a);for(f=0;f<n.length;f+=1)if(h=n[f],(h.paused||!h.qb)&&!d||!h.paused&&d){if(!d){for(f=this.oe.length-1;0<=f;f-=1)if(a=this.oe[f],a.id===h.id){l=a;b=0;c=void 0;break}h.paused=!1;h.$b=b||0;h.Me=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b};h.ji&&(void 0===b&&(h.$b=h.ji.duration),void 0===c&&(h.Me=h.ji.lb),k=h.ji.gain,h.ji=void 0)}this.Hb&&(a=gb(this,h.Xb))&&(h.F=a,eb(this,h));void 0!==k&&ab(E,h.id,k);Za(this,h,h.qe+(h.ik||0));void 0!==l&&
(ab(E,h.id,l.lb(l.l,l.start,l.Mj-l.start,l.duration)),mb(E,h.id,l.Mj,l.duration-l.l,l.lb,l.zb))}};
e.pause=function(a,b,c,d,f){var h,k,l=cb(this,a);for(a=0;a<l.length;a+=1)if(h=l[a],!h.paused)if(h.$b=c||0,0<h.$b)h.Me=d||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},h.ji={gain:nb(h.id),duration:h.$b,lb:h.Me},mb(E,h.id,0,h.$b,h.Me,function(){E.pause(h.id,b)});else if(k=this.po(h.id),h.ik=k,f||(h.paused=!0,h.Pm=0,h.xq=b,this.Kc-=1),this.Hb){h.F.onended=function(){};if(h.qb&&h.Vd){try{h.F.stop?h.F.stop(0):h.F.noteOff&&h.F.noteOff(0)}catch(n){}h.Vd=!1}fb(this,h)}else this.hb&&h.F.pause()};
function $a(a){var b=E;b.yb[a.id]&&delete b.yb[a.id];a.paused||(b.Kc-=1);b.Hb?(a.Vd=!1,a.qb=!1,fb(b,a)):b.hb&&bb(b,a);b.Ac[b.Ac.indexOf(a)]=void 0}
e.stop=function(a,b,c){var d,f=cb(this,a);for(a=0;a<f.length;a+=1)if(d=f[a],d.$b=b||0,0<d.$b)d.Me=c||function(a,b,c,d){return 0==a?b:c*Math.pow(2,10*(a/d-1))+b},mb(E,d.id,0,d.$b,d.Me,function(){E.stop(d.id)});else{this.yb[d.id]&&delete this.yb[d.id];d.qb&&!d.paused&&(this.Kc-=1);if(this.Hb){if(d.qb&&!d.paused&&!d.ah){if(d.Vd){try{d.F.stop?d.F.stop(0):d.F.noteOff&&d.F.noteOff(0)}catch(h){}d.Vd=!1}fb(this,d)}}else this.hb&&(d.ah||d.F.pause(),bb(this,d));this.Ac[this.Ac.indexOf(d)]=void 0;d.qb=!1}};
function mb(a,b,c,d,f,h){var k;for(k=0;k<a.oe.length;k+=1)if(a.oe[k].id===b){a.oe.splice(k,1);break}a.oe.push({id:b,Mj:c,lb:f||function(a,b,c,d){return a==d?b+c:c*(-Math.pow(2,-10*a/d)+1)+b},duration:d,l:0,start:lb(a,b),zb:h,Jn:0})}function ob(a){var b=E,c;void 0===b.xd[a]&&(c=void 0!==b.yb[a]?b.yb[a]:1,ab(b,a,0),b.xd[a]=c)}function pb(a){var b=E;void 0!==b.xd[a]&&(ab(b,a,b.xd[a]),delete b.xd[a])}
e.position=function(a,b){var c,d,f,h,k=cb(this,a);if(!isNaN(b)&&0<=b)for(c=0;c<k.length;c++)if(d=k[c],b%=d.duration,this.Hb)if(d.paused)d.ik=b;else{d.F.onended=function(){};if(d.Vd){try{d.F.stop?d.F.stop(0):d.F.noteOff&&d.F.noteOff(0)}catch(l){}d.Vd=!1}fb(this,d);this.Kc-=1;if(f=gb(this,d.Xb))d.F=f,eb(this,d),Za(this,d,d.qe+b)}else this.hb&&(4===d.F.readyState?d.F.currentTime=(d.qe+b)/1E3:(h=function(){var a=d,c=b;return{$r:function(){a.F.currentTime=(a.qe+c)/1E3;a.F.removeEventListener("canplaythrough",
h.$r,!1)}}}(),d.F.addEventListener("canplaythrough",h.$r,!1)))};e.yp=function(a){E.position(a,0)};e.wt=function(a,b){var c,d=cb(this,a);for(c=0;c<d.length;c+=1)d[c].Vo=b,this.Hb&&(d[c].F.loop=b)};function lb(a,b){return void 0!==a.yb[b]?a.yb[b]:1}function nb(a){var b=E,c=1,d=cb(b,a)[0];if(d)for(a=0;a<d.La.length;a+=1)void 0!==b.yb[d.La[a]]&&(c*=b.yb[d.La[a]]);return Math.round(100*c)/100}
function ab(a,b,c){var d,f,h=1,k=cb(a,b);a.yb[b]=c;a.xd[b]&&delete a.xd[b];for(c=0;c<k.length;c+=1)if(d=k[c],0<=d.La.indexOf(b)){for(f=0;f<d.La.length;f+=1)void 0!==a.yb[d.La[f]]&&(h*=a.yb[d.La[f]]);h=Math.round(100*h)/100;a.Hb?a.Sf[d.id].gain.value=h:a.hb&&(d.F.volume=h)}}function kb(a,b){var c,d,f,h=1,k=cb(a,b);for(c=0;c<k.length;c+=1){d=k[c];for(f=0;f<d.La.length;f+=1)void 0!==a.yb[d.La[f]]&&(h*=a.yb[d.La[f]]);h=Math.round(100*h)/100;a.Hb?a.Sf[d.id].gain.value=h:a.hb&&(d.F.volume=h)}}
e.Iq=function(a,b){var c,d,f,h=cb(this,a);for(c=0;c<h.length;c+=1)for(d=h[c],b=[].concat(b),f=0;f<b.length;f+=1)0>d.La.indexOf(b[f])&&d.La.push(b[f]);kb(this,a)};e.Go=function(a){if(a=cb(this,a)[0])return a.paused};e.Fo=function(a){return cb(this,a)[0]?!0:!1};e.po=function(a){if(a=cb(this,a)[0]){if(this.Hb)return a.paused?a.ik:(1E3*E.ne.currentTime-a.bv)%a.duration;if(E.hb)return Math.ceil(1E3*a.F.currentTime-a.qe)}};var E=new Wa;
function qb(a,b,c,d){this.name=a;this.Mx=b;this.Qx=c;this.Rc=d;this.loaded=!1;this.qc=null;pa(this,this.Rc,1)}qb.prototype.je=function(a,b){var c,d;c=this.Mx;0!==c.toLowerCase().indexOf("http:")&&0!==c.toLowerCase().indexOf("https:")&&(c=b+c);d=this.Qx;0!==d.toLowerCase().indexOf("http:")&&0!==d.toLowerCase().indexOf("https:")&&(d=b+d);E.Uf[this.name]=[];E.li(this,[d,c],a)};qb.prototype.complete=function(){return this.loaded};
function F(a,b,c,d,f,h,k){this.name=a;this.r=b;this.startOffset=c;this.duration=d;ab(E,this.name,void 0!==f?f:1);this.vi=void 0!==h?h:10;this.La=[];k&&(this.La=this.La.concat(k));0>this.La.indexOf(this.name)&&this.La.push(this.name)}F.prototype.complete=function(){return this.r.complete()};F.prototype.Tl=function(a){void 0!==a&&(this.vi=a);return this.vi};F.prototype.Iq=function(a){var b;a=[].concat(a);for(b=0;b<a.length;b+=1)0>this.La.indexOf(a[b])&&this.La.push(a[b])};
function ib(a,b){this.Xb=a;this.qe=this.Xb.startOffset;this.F=b;this.duration=this.Xb.duration;this.gf()}ib.prototype.gf=function(){this.id=Math.round(Date.now()*Math.random())+"";this.La=["master",this.id].concat(this.Xb.La);this.Tl=void 0!==this.Xb.vi?this.Xb.vi:10;this.paused=this.qb=this.Vo=!1;this.Qm=this.Jn=0;this.Vd=this.ah=!1;this.Ot=this.ik=0;var a,b=1;for(a=0;a<this.La.length;a+=1)void 0!==E.yb[this.La[a]]&&(b*=E.yb[this.La[a]]);!E.Hb&&E.hb&&(this.F.volume=b)};
function rb(a,b){this.name=a;this.fileName=b;this.info=void 0}function sb(a){this.name=a;this.text="";this.Cd=this.complete=!1}sb.prototype.Vf=function(a){4===a.readyState&&(this.complete=!0,(this.Cd=200!==a.status)?na("Get Failed",{name:this.name}):(this.text=a.responseText,na("Get Complete",{name:this.name})))};
function tb(a,b){var c=new XMLHttpRequest;a.complete=!1;c.open("POST",b);c.setRequestHeader("Content-Type","text/plain;charset=UTF-8");c.onreadystatechange=function(){4===c.readyState&&(a.complete=!0,a.Cd=200!==c.status,a.Cd?na("Post Failed",{name:a.name}):na("Post Complete",{name:a.name}))};c.send(a.text)}function ub(a,b){var c=new XMLHttpRequest;c.open("GET",b,!1);try{c.send()}catch(d){return!1}a.complete=!0;a.Cd=200!==c.status;if(a.Cd)return!1;a.text=c.responseText;return!0}
function vb(a){a&&(this.he=a);this.clear();this.si=this.fh=this.vd=this.ri=this.qi=this.ui=this.ni=this.ti=this.pe=this.pi=this.oi=0;wb(this,this);xb(this,this);yb(this,this);this.jc=[];this.fi=[];this.xi=[];this.L=0;this.yq=!1;this.ql=this.startTime=Date.now();this.Ng=this.zh=0;this.lx=200;this.Rc="";window.Zj(window.pq)}vb.prototype.clear=function(){this.C=[];this.yi=!1;this.pc=[];this.Km=!1};
function wb(a,b){window.addEventListener("click",function(a){var d,f,h;if(void 0!==b.he&&!(0<b.L)&&(d=b.he,f=d.getBoundingClientRect(),h=d.width/f.width*(a.clientX-f.left),d=d.height/f.height*(a.clientY-f.top),a.preventDefault(),b.$g.x=h,b.$g.y=d,b.hi.push({x:b.$g.x,y:b.$g.y}),0<b.ri))for(a=b.C.length-1;0<=a&&!((h=b.C[a])&&h.h&&0>=h.L&&h.vo&&(h=h.vo(b.$g.x,b.$g.y),!0===h));a-=1);},!1);zb(a)}function zb(a){a.$g={x:0,y:0};a.hi=[]}
function xb(a,b){window.addEventListener("mousedown",function(a){0<b.L||(a.preventDefault(),window.focus(),b.wq>=Date.now()-1E3||(Ab(b,0,a.clientX,a.clientY),Bb(b,0)))},!1);window.addEventListener("mouseup",function(a){0<b.L||(a.preventDefault(),b.fk>=Date.now()-1E3||(Ab(b,0,a.clientX,a.clientY),Cb(b,0)))},!1);window.addEventListener("mousemove",function(a){0<b.L||(a.preventDefault(),Ab(b,0,a.clientX,a.clientY))},!1);window.addEventListener("touchstart",function(a){var d=a.changedTouches;b.wq=Date.now();
if(!(0<b.L))for(a.preventDefault(),window.focus(),a=0;a<d.length;a+=1)Ab(b,d[a].identifier,d[a].clientX,d[a].clientY),Bb(b,d[a].identifier)},!1);window.addEventListener("touchend",function(a){var d=a.changedTouches;b.fk=Date.now();if(!(0<b.L))for(a.preventDefault(),a=0;a<d.length;a+=1)Ab(b,d[a].identifier,d[a].clientX,d[a].clientY),Cb(b,d[a].identifier)},!1);window.addEventListener("touchmove",function(a){var d=a.changedTouches;if(!(0<b.L))for(a.preventDefault(),a=0;a<d.length;a+=1)Ab(b,d[a].identifier,
d[a].clientX,d[a].clientY)},!1);window.addEventListener("touchleave",function(a){var d=a.changedTouches;b.fk=Date.now();if(!(0<b.L))for(a.preventDefault(),a=0;a<d.length;a+=1)Ab(b,d[a].identifier,d[a].clientX,d[a].clientY),Cb(b,d[a].identifier)},!1);window.addEventListener("touchcancel",function(a){var d=a.changedTouches;b.fk=Date.now();if(!(0<b.L))for(a.preventDefault(),a=0;a<d.length;a+=1)Ab(b,d[a].identifier,d[a].clientX,d[a].clientY),Cb(b,d[a].identifier)},!1);window.addEventListener("mousewheel",
function(a){Db(b,a)},!1);window.addEventListener("DOMMouseScroll",function(a){Db(b,a)},!1);Eb(a);a.wq=0;a.fk=0}function Eb(a){var b;a.ia=[];for(b=0;16>b;b+=1)a.ia[b]={id:-1,Bb:!1,x:0,y:0};a.Yf=[]}function Fb(a,b){var c=-1,d;for(d=0;16>d;d+=1)if(a.ia[d].id===b){c=d;break}if(-1===c)for(d=0;16>d;d+=1)if(!a.ia[d].Bb){c=d;a.ia[d].id=b;break}return c}
function Ab(a,b,c,d){var f,h;void 0!==a.he&&(b=Fb(a,b),-1!==b&&(f=a.he,h=f.getBoundingClientRect(),a.ia[b].x=f.width/h.width*(c-h.left),a.ia[b].y=f.height/h.height*(d-h.top)))}function Bb(a,b){var c=Fb(a,b),d,f;if(-1!==c&&!a.ia[c].Bb&&(a.Yf.push({og:c,x:a.ia[c].x,y:a.ia[c].y,Bb:!0}),a.ia[c].Bb=!0,0<a.vd))for(d=a.C.length-1;0<=d&&!((f=a.C[d])&&f.h&&0>=f.L&&f.Bh&&(f=f.Bh(c,a.ia[c].x,a.ia[c].y),!0===f));d-=1);}
function Cb(a,b){var c=Fb(a,b),d,f;if(-1!==c&&a.ia[c].Bb&&(a.Yf.push({og:c,x:a.ia[c].x,y:a.ia[c].y,Bb:!1}),a.ia[c].Bb=!1,0<a.vd))for(d=a.C.length-1;0<=d&&!((f=a.C[d])&&f.h&&0>=f.L&&f.Ch&&(f=f.Ch(c,a.ia[c].x,a.ia[c].y),!0===f));d-=1);}
function Db(a,b){var c;if(!(0<a.L)){b.preventDefault();window.focus();c=Math.max(-1,Math.min(1,b.wheelDelta||-b.detail));var d,f;a.Yf.push({og:0,x:a.ia[0].x,y:a.ia[0].y,wheelDelta:c});if(0<a.vd)for(d=a.C.length-1;0<=d&&!((f=a.C[d])&&f.h&&0>=f.L&&f.yo&&(f=f.yo(c,a.ia[0].x,a.ia[0].y),!0===f));d-=1);}}
function yb(a,b){window.addEventListener("keydown",function(a){0<b.L||(-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault(),Gb(b,a.keyCode))},!1);window.addEventListener("keyup",function(a){0<b.L||(-1<[32,37,38,39,40].indexOf(a.keyCode)&&a.preventDefault(),Hb(b,a.keyCode))},!1);Ib(a)}function Ib(a){var b;a.ki=[];for(b=0;256>b;b+=1)a.ki[b]=!1;a.eh=[]}
function Gb(a,b){var c,d;if(!a.ki[b]&&(a.eh.push({key:b,Bb:!0}),a.ki[b]=!0,0<a.fh))for(c=0;c<a.C.length&&!((d=a.C[c])&&d.h&&0>=d.L&&d.wo&&(d=d.wo(b),!0===d));c+=1);}function Hb(a,b){var c,d;if(a.ki[b]&&(a.eh.push({key:b,Bb:!1}),a.ki[b]=!1,0<a.fh))for(c=0;c<a.C.length&&!((d=a.C[c])&&d.h&&0>=d.L&&d.xo&&(d=d.xo(b),!0===d));c+=1);}function Jb(){var a=G,b;for(b=0;b<a.jc.length;b+=1)a.jc[b].paused+=1}
function na(a,b){var c,d=G,f,h;void 0===c&&(c=null);d.xi.push({id:a,jv:b,Nf:c});if(0<d.si)for(f=0;f<d.C.length&&(!((h=d.C[f])&&h.h&&0>=h.L&&h.zo)||null!==c&&c!==h||(h=h.zo(a,b),!0!==h));f+=1);}
function Kb(a,b){var c=a.pc[b];c.visible&&(void 0!==c.canvas&&c.canvas!==p.canvas&&p.ja(c.canvas),!1!==p.canvas.Y||!0===c.kd)&&(0===c.vq&&(0>=c.L&&(c.hc+=c.iv*a.Ng/1E3),1===c.Em&&1===c.Fm&&0===c.pa?1===c.alpha?c.b.o(c.hc,c.x,c.y):c.b.fd(c.hc,c.x,c.y,c.alpha):c.b.S(c.hc,c.x,c.y,c.Em,c.Fm,c.pa,c.alpha)),1===c.vq&&(1===c.Em&&1===c.Fm&&0===c.pa?1===c.alpha?c.font.o(c.text,c.x,c.y):c.font.fd(c.text,c.x,c.y,c.alpha):c.font.S(c.text,c.x,c.y,c.Em,c.Fm,c.pa,c.alpha)))}
function Lb(a,b){var c=a.C[b];if(c.visible&&(void 0!==c.canvas&&c.canvas!==p.canvas&&p.ja(c.canvas),(!1!==p.canvas.Y||!0===c.kd)&&c.za))return c.za()}function Mb(a){for(var b=0,c=0;b<a.C.length||c<a.pc.length;)if(c===a.pc.length){if(!0===Lb(a,b))break;b+=1}else if(b===a.C.length)Kb(a,c),c+=1;else if(a.pc[c].Ua>a.C[b].Ua||a.pc[c].Ua===a.C[b].Ua&&a.pc[c].depth>a.C[b].depth)Kb(a,c),c+=1;else{if(!0===Lb(a,b))break;b+=1}}vb.prototype.pause=function(a){this.L+=1;void 0===a&&(a=!1);this.yq=a};
vb.prototype.Gj=function(){0!==this.L&&(this.ql=Date.now(),this.L-=1)};vb.prototype.Go=function(){return 0<this.L};window.Im=0;window.Hm=0;window.qq=0;window.Su=0;window.rq=0;window.Uu=60;window.Vu=0;window.Tu=!1;
window.pq=function(){window.Im=Date.now();window.Su=window.Im-window.Hm;var a=G,b;if(0<a.L)a.yq&&(Nb(a),Mb(a));else{b=Date.now();"number"!==typeof b&&(b=a.ql);a.Ng=Math.min(a.lx,b-a.ql);a.zh+=a.Ng;""===a.Rc&&(a.Rc="start",ka.je(a.Rc));"start"===a.Rc&&ka.complete(a.Rc)&&(a.Rc="load",ka.je(a.Rc));"load"===a.Rc&&ka.complete(a.Rc)&&(a.Rc="game",ka.je(a.Rc));"undefined"!==typeof E&&Xa(a.Ng);var c,d;if(0<a.oi)for(c=0;c<a.C.length&&!((d=a.C[c])&&d.Z&&d.h&&0>=d.L&&!0===d.Z(a.Ng));c+=1);var f,h;if(0!==a.hi.length){if(0<
a.pi)for(d=a.C.length-1;0<=d;d-=1)if((f=a.C[d])&&f.h&&0>=f.L&&f.to)for(c=0;c<a.hi.length;c+=1)h=a.hi[c],!0!==h.md&&(h.md=f.to(h.x,h.y));a.hi=[]}if(0!==a.Yf.length){if(0<a.pe)for(d=a.C.length-1;0<=d;d-=1)if((f=a.C[d])&&f.h&&0>=f.L&&(f.Ub||f.Vb||f.hl))for(c=0;c<a.Yf.length;c+=1)h=a.Yf[c],!0!==h.md&&(void 0!==h.wheelDelta&&f.hl?h.md=f.hl(h.wheelDelta,h.x,h.y):h.Bb&&f.Ub?h.md=f.Ub(h.og,h.x,h.y):void 0!==h.Bb&&!h.Bb&&f.Vb&&(h.md=f.Vb(h.og,h.x,h.y)));a.Yf=[]}if(0!==a.eh.length){if(0<a.ti)for(d=0;d<a.C.length;d+=
1)if((f=a.C[d])&&f.h&&0>=f.L&&(f.vg||f.wg))for(c=0;c<a.eh.length;c+=1)h=a.eh[c],!0!==h.md&&(h.Bb&&f.vg?h.md=f.vg(h.key):!h.Bb&&f.wg&&(h.md=f.wg(h.key)));a.eh=[]}c=a.Ng;for(d=a.fi.length=0;d<a.jc.length;d+=1)f=a.jc[d],void 0!==f.id&&0===f.paused&&(0<f.Sg||0<f.Yl)&&(f.Sg-=c,0>=f.Sg&&(a.fi.push({id:f.id,Nf:f.Nf}),0<f.Yl?(f.Yl-=1,f.Sg+=f.time):f.Sg=0));if(0<a.ni&&0<a.fi.length)for(c=0;c<a.C.length;c+=1)if((d=a.C[c])&&d.cl&&d.h)for(f=0;f<a.fi.length;f+=1)h=a.fi[f],!0===h.md||null!==h.Nf&&h.Nf!==d||(h.md=
d.cl(h.id));if(0<a.ui&&0<a.xi.length)for(c=0;c<a.C.length;c+=1)if((f=a.C[c])&&f.Oc&&f.h&&0>=f.L)for(d=0;d<a.xi.length;d+=1)h=a.xi[d],!0===h.md||null!==h.Nf&&h.Nf!==f||(h.md=f.Oc(h.id,h.jv));a.xi.length=0;if(0<a.qi)for(c=0;c<a.C.length&&!((d=a.C[c])&&d.Pe&&d.h&&0>=d.L&&!0===d.Pe(a.Ng));c+=1);Nb(a);Mb(a);a.ql=b}window.Hm=Date.now();window.qq=window.Hm-window.Im;window.rq=Math.max(window.Vu,1E3/window.Uu-window.qq);window.Zj(window.pq)};window.Zj=function(a){window.setTimeout(a,window.rq)};
window.Tu||(window.Zj=window.requestAnimationFrame||window.webkitRequestAnimationFrame||window.mozRequestAnimationFrame||window.msRequestAnimationFrame||window.oRequestAnimationFrame||window.Zj);
function Nb(a){function b(a,b){return a.Ua===b.Ua?b.depth-a.depth:a.Ua>b.Ua?-1:1}var c,d;for(c=d=0;c<a.C.length;c+=1)a.C[c]&&(a.C[c].Jm&&(a.C[c].Jm=!1,a.C[c].h=!0),a.C[d]=a.C[c],d+=1);a.C.length=d;a.yi&&a.C.sort(b);a.yi=!1;for(c=d=0;c<a.pc.length;c+=1)a.pc[c]&&(a.pc[d]=a.pc[c],d+=1);a.pc.length=d;a.Km&&a.pc.sort(b);a.Km=!1}
function H(a,b){var c=G;void 0===a.group&&(a.group=0);void 0===a.visible&&(a.visible=!0);void 0===a.h&&(a.h=!0);void 0===a.depth&&(a.depth=0);void 0===a.Ua&&(a.Ua=0);void 0===a.L&&(a.L=0);void 0===a.re&&(a.re=[]);a.Jm=!1;void 0!==b&&!1===b&&(a.Jm=!0,a.h=!1);c.C.push(a);c.yi=!0;a.Z&&(c.oi+=1);a.to&&(c.pi+=1);if(a.Ub||a.Vb)c.pe+=1;a.hl&&(c.pe+=1);if(a.vg||a.wg)c.ti+=1;a.cl&&(c.ni+=1);a.Oc&&(c.ui+=1);a.Pe&&(c.qi+=1);a.vo&&(c.ri+=1);if(a.Bh||a.Ch)c.vd+=1;a.yo&&(c.vd+=1);if(a.wo||a.xo)c.fh+=1;a.zo&&(c.si+=
1);a.ac&&a.ac()}function Ob(a,b){var c=G;a.depth!==b&&(c.yi=!0);a.depth=b}function Pb(a,b){var c;b=[].concat(b);void 0===a.re&&(a.re=[]);for(c=b.length-1;0<=c;c-=1)0>a.re.indexOf(b[c])&&a.re.push(b[c])}
function Qb(a,b){var c=[],d,f;if(void 0===b||"all"===b||"master"===b)for(d=0;d<a.C.length;d+=1)f=a.C[d],void 0!==f&&c.push(f);else if("function"===typeof b)for(d=0;d<a.C.length;d+=1)f=a.C[d],void 0!==f&&b(f)&&c.push(f);else for(d=0;d<a.C.length;d+=1)f=a.C[d],void 0!==f&&0<=f.re.indexOf(b)&&c.push(f);return c}function Rb(a){var b=Qb(G,a);for(a=0;a<b.length;a+=1){var c=b[a];c.L+=1}}function Sb(a){var b=Qb(G,a);for(a=0;a<b.length;a+=1){var c=b[a];c.L=Math.max(0,c.L-1)}}
function I(a,b){var c=a.C.indexOf(b);if(!(0>c)){a.C[c].nb&&a.C[c].nb();var d=a.C[c];d.Z&&(a.oi-=1);d.to&&(a.pi-=1);if(d.Ub||d.Vb)a.pe-=1;d.hl&&(a.pe-=1);if(d.vg||d.wg)a.ti-=1;d.cl&&(a.ni-=1);d.Oc&&(a.ui-=1);d.Pe&&(a.qi-=1);d.vo&&(a.ri-=1);if(d.Bh||d.Ch)a.vd-=1;d.yo&&(a.vd-=1);if(d.wo||d.xo)a.fh-=1;d.zo&&(a.si-=1);a.C[c]=void 0}}function Tb(a){var b=G,c=Qb(b,a);for(a=0;a<c.length;a+=1)I(b,c[a])}
vb.prototype.c=function(a,b,c,d,f,h,k){void 0===k&&(k=0);this.pc.push({vq:0,b:a,hc:b,iv:c,visible:!0,x:d,y:f,Em:1,Fm:1,pa:0,alpha:1,depth:h,Ua:k,L:0,re:[]});this.Km=!0;return this.pc[this.pc.length-1]};var G=new vb(aa);
function Ub(a,b){var c;this.kind=a;this.u=null;switch(this.kind){case 0:this.u={x:[b.x],y:[b.y]};this.ba=b.x;this.ua=b.y;this.Oa=b.x;this.tb=b.y;break;case 2:this.u={x:[b.x,b.x+b.zc-1,b.x+b.zc-1,b.x,b.x],y:[b.y,b.y,b.y+b.Ic-1,b.y+b.Ic-1,b.y]};this.ba=b.x;this.ua=b.y;this.Oa=b.x+b.zc-1;this.tb=b.y+b.Ic-1;break;case 3:this.u={x:[],y:[]};this.ba=b.x-b.Wl;this.ua=b.y-b.Wl;this.Oa=b.x+b.Wl;this.tb=b.y+b.Wl;break;case 1:this.u={x:[b.jq,b.kq],y:[b.lq,b.mq]};this.ba=Math.min(b.jq,b.kq);this.ua=Math.min(b.lq,
b.mq);this.Oa=Math.max(b.jq,b.kq);this.tb=Math.max(b.lq,b.mq);break;case 4:this.u={x:[],y:[]};this.ba=b.x[0];this.ua=b.y[0];this.Oa=b.x[0];this.tb=b.y[0];for(c=0;c<b.x.length;c+=1)this.u.x.push(b.x[c]),this.u.y.push(b.y[c]),this.ba=Math.min(this.ba,b.x[c]),this.ua=Math.min(this.ua,b.y[c]),this.Oa=Math.max(this.Oa,b.x[c]),this.tb=Math.max(this.tb,b.y[c]);this.u.x.push(b.x[0]);this.u.y.push(b.y[0]);break;default:this.ua=this.ba=0,this.tb=this.Oa=-1}}
function Vb(a,b,c,d){return new Ub(2,{x:a,y:b,zc:c,Ic:d})}function Wb(a,b,c){return new Ub(3,{x:a,y:b,Wl:c})}function Xb(a){var b=1E6,c=-1E6,d=1E6,f=-1E6,h,k,l,n,q;for(h=0;h<a.D;h+=1)k=a.af[h]-a.eb,l=k+a.$e[h]-1,n=a.bf[h]-a.Za,q=n+a.Ze[h]-1,k<b&&(b=k),l>c&&(c=l),n<d&&(d=n),q>f&&(f=q);return new Ub(2,{x:b,y:d,zc:c-b+1,Ic:f-d+1})}e=Ub.prototype;
e.P=function(){var a=new Ub(-1,{}),b;a.kind=this.kind;a.ba=this.ba;a.Oa=this.Oa;a.ua=this.ua;a.tb=this.tb;a.u={x:[],y:[]};for(b=0;b<this.u.x.length;b+=1)a.u.x[b]=this.u.x[b];for(b=0;b<this.u.y.length;b+=1)a.u.y[b]=this.u.y[b];return a};e.translate=function(a,b){var c=this.P(),d;c.ba+=a;c.Oa+=a;c.ua+=b;c.tb+=b;for(d=0;d<c.u.x.length;d+=1)c.u.x[d]+=a;for(d=0;d<c.u.y.length;d+=1)c.u.y[d]+=b;return c};
e.scale=function(a){var b=this.P(),c;b.ba*=a;b.Oa*=a;b.ua*=a;b.tb*=a;for(c=0;c<b.u.x.length;c+=1)b.u.x[c]*=a;for(c=0;c<b.u.y.length;c+=1)b.u.y[c]*=a;return b};
e.rotate=function(a){var b,c,d,f;switch(this.kind){case 0:return b=new m(this.u.x[0],this.u.y[0]),b=b.rotate(a),new Ub(0,{x:b.x,y:b.y});case 1:return b=new m(this.u.x[0],this.u.y[0]),b=b.rotate(a),c=new m(this.u.x[1],this.u.y[1]),c=c.rotate(a),new Ub(1,{jq:b.x,lq:b.y,kq:c.x,mq:c.y});case 3:return b=(this.Oa-this.ba)/2,c=new m(this.ba+b,this.ua+b),c=c.rotate(a),Wb(c.x,c.y,b);default:c=[];d=[];for(f=0;f<this.u.x.length-1;f+=1)b=new m(this.u.x[f],this.u.y[f]),b=b.rotate(a),c.push(b.x),d.push(b.y);return new Ub(4,
{x:c,y:d})}};function Yb(a,b,c,d){var f=new m(0,0),h,k=1E9,l=-1E10,n;for(n=0;n<a.u.x.length;n+=1)f.x=b+a.u.x[n],f.y=c+a.u.y[n],h=f.ng(d),k=Math.min(k,h),l=Math.max(l,h);return{min:k,max:l}}function Zb(a){var b=new m(0,0),c=new m(0,0),d=[],f;for(f=0;f<a.u.x.length-1;f+=1)b.x=a.u.x[f],b.y=a.u.y[f],c.x=a.u.x[f+1],c.y=a.u.y[f+1],d.push(ea(b.ic(c)));return d}
function $b(a,b,c,d,f,h){var k,l,n,q;if(f+d.Oa<b+a.ba||f+d.ba>b+a.Oa||h+d.tb<c+a.ua||h+d.ua>c+a.tb)return!1;if(2===a.kind&&2===d.kind)return!0;if(3===d.kind)return k=(d.Oa-d.ba)/2,bc(a,b,c,f+d.ba+k,h+d.ua+k,k);if(3===a.kind)return k=(a.Oa-a.ba)/2,bc(d,f,h,b+a.ba+k,c+a.ua+k,k);if(0===d.kind)return cc(a,b,c,f+d.ba,h+d.ua);if(0===a.kind)return cc(d,f,h,b+a.ba,c+a.ua);k=Zb(a).concat(Zb(d));for(q=0;q<k.length;q+=1)if(l=Yb(a,b,c,k[q]),n=Yb(d,f,h,k[q]),l.max<n.min||n.max<l.min)return!1;return!0}
function bc(a,b,c,d,f,h){var k,l,n,q,u,B,C;if(d+h<b+a.ba||d-h>b+a.Oa||f+h<c+a.ua||f-h>c+a.tb)return!1;switch(a.kind){case 0:return l=d-(b+a.ba),n=f-(c+a.ua),l*l+n*n<=h*h;case 3:return q=(a.Oa-a.ba)/2,l=d-(b+a.ba+q),n=f-(c+a.ua+q),l*l+n*n<=(q+h)*(q+h);default:q=Zb(a);u=k=0;B=1E9;for(C=0;C<a.u.x.length;C+=1)l=b+a.u.x[C]-d,n=c+a.u.y[C]-f,l=l*l+n*n,l<=B&&(k=b+a.u.x[C],u=c+a.u.y[C],B=l);d=new m(d,f);q.push(d.ic(new m(k,u)).normalize());for(C=0;C<q.length;C+=1)if(k=d.ng(q[C]),f=k-h,k+=h,u=Yb(a,b,c,q[C]),
k<u.min||u.max<f)return!1;return!0}}function cc(a,b,c,d,f){var h,k,l,n;if(d<b+a.ba||d>b+a.Oa||f<c+a.ua||f>c+a.tb)return!1;switch(a.kind){case 0:case 2:return!0;case 3:return h=(a.Oa-a.ba)/2,d-=b+a.ba+h,f-=c+a.ua+h,d*d+f*f<=h*h;case 1:return h=b+a.u.x[0],k=c+a.u.y[0],b+=a.u.x[1],a=c+a.u.y[1],d===h?f===k:d===b?f===a:1>Math.abs(k+(d-h)*(a-k)/(b-h)-f);case 4:h=Zb(a);for(k=0;k<h.length;k+=1)if(l=new m(d,f),l=l.ng(h[k]),n=Yb(a,b,c,h[k]),l<n.min||n.max<l)return!1;return!0;default:return!1}}
e.tc=function(a,b,c){var d=p.context;d.fillStyle=c;d.strokeStyle=c;switch(this.kind){case 0:d.fillRect(a+this.ba-1,b+this.ua-1,3,3);break;case 2:d.fillRect(a+this.ba,b+this.ua,this.Oa-this.ba+1,this.tb-this.ua+1);break;case 3:c=(this.Oa-this.ba)/2;d.beginPath();d.arc(a+this.ba+c,b+this.ua+c,c,0,2*Math.PI,!1);d.closePath();d.fill();break;case 1:d.beginPath();d.moveTo(a+this.u.x[0],b+this.u.y[0]);d.lineTo(a+this.u.x[1],b+this.u.y[1]);d.stroke();break;case 4:d.beginPath();d.moveTo(a+this.u.x[0],b+this.u.y[0]);
for(c=1;c<this.u.x.length-1;c+=1)d.lineTo(a+this.u.x[c],b+this.u.y[c]);d.closePath();d.fill()}};function dc(){this.depth=1E7;this.visible=!1;this.h=!0;this.group="Engine";this.ta=[];this.mi=this.L=this.wi=!1;this.Ud=1;this.Yc=-1;this.ya=-1E6}e=dc.prototype;e.P=function(){var a=new dc,b;for(b=0;b<this.ta.length;b+=1)a.ta.push({pb:this.ta[b].pb,action:this.ta[b].action});a.mi=this.mi;return a};
e.V=function(a,b){var c,d;if(0===this.ta.length||this.ta[this.ta.length-1].pb<=a)this.ta.push({pb:a,action:b});else{for(c=0;this.ta[c].pb<=a;)c+=1;for(d=this.ta.length;d>c;d-=1)this.ta[d]=this.ta[d-1];this.ta[c]={pb:a,action:b}}this.ya=-1E6};e.start=function(){this.wi=!0;this.L=!1;this.Yc=0>this.Ud&&0<this.ta.length?this.ta[this.ta.length-1].pb+1:-1;this.ya=-1E6;I(G,this);H(this)};
e.yp=function(){if(0>this.Ud&&0<this.ta.length){var a=this.ta[this.ta.length-1].pb;this.Yc=0>this.Ud?a+1:a-1}else this.Yc=0>this.Ud?1:-1;this.ya=-1E6};e.stop=function(){this.wi=!1;I(G,this)};e.Ve=function(){return this.wi};e.pause=function(){this.L=!0;I(G,this)};e.Gj=function(){this.L=!1;I(G,this);H(this)};e.paused=function(){return this.wi&&this.L};e.wt=function(a){this.mi=a};
e.Z=function(a){if(this.wi&&!this.L&&0!==this.Ud)if(0<this.Ud){0>this.ya&&(this.ya=0);for(;this.ya<this.ta.length&&this.ta[this.ya].pb<=this.Yc;)this.ya+=1;for(this.Yc+=this.Ud*a;0<=this.ya&&this.ya<this.ta.length&&this.ta[this.ya].pb<=this.Yc;)this.ta[this.ya].action(this.ta[this.ya].pb,this),this.ya+=1;this.ya>=this.ta.length&&(this.mi?this.yp():this.stop())}else{0>this.ya&&(this.ya=this.ta.length-1);for(;0<=this.ya&&this.ta[this.ya].pb>=this.Yc;)this.ya-=1;for(this.Yc+=this.Ud*a;0<=this.ya&&this.ta[this.ya].pb>=
this.Yc;)this.ta[this.ya].action(this.ta[this.ya].pb,this),this.ya-=1;0>this.ya&&0>=this.Yc&&(this.mi?this.yp():this.stop())}};function ec(){this.depth=1E7;this.visible=!1;this.h=!0;this.group="Engine";this.oc=[];this.Rf=[];this.clear();this.Py=!1;H(this)}e=ec.prototype;e.Z=function(){var a,b,c,d,f;if(this.Py)for(a=0;16>a;a+=1)G.ia[a].Bb&&(b=G.ia[a].x,c=G.ia[a].y,d=this.Rf[a],f=this.oc[d],!(0<=d&&f&&f.selected)||f&&cc(f.ob,0,0,b,c)||(Hb(G,f.keyCode),f.selected=!1,this.Rf[a]=-1),this.Ub(a,b,c))};
e.Ub=function(a,b,c){var d;if(!(0<=this.Rf[a]))for(d=0;d<this.oc.length;d+=1){var f;if(f=this.oc[d])f=(f=this.oc[d])?cc(f.ob,0,0,b,c):!1;if(f&&!this.oc[d].selected){Gb(G,this.oc[d].keyCode);this.oc[d].selected=!0;this.Rf[a]=d;break}}};e.Vb=function(a){var b=this.Rf[a];0<=b&&this.oc[b]&&this.oc[b].selected&&(Hb(G,this.oc[b].keyCode),this.oc[b].selected=!1);this.Rf[a]=-1};function fc(a,b,c,d,f,h,k){c=Vb(c,d,f,h);a.oc.push({keyCode:k,ob:c,id:b,selected:!1})}
e.clear=function(){var a;for(a=this.oc.length=0;16>a;a+=1)this.Rf[a]=-1};e.tc=function(a,b,c){var d,f,h,k;for(d=0;d<this.oc.length;d+=1)if(f=this.oc[d])f.selected?f.ob.tc(0,0,b):f.ob.tc(0,0,a),h=(f.ob.ba+f.ob.Oa)/2,k=(f.ob.ua+f.ob.tb)/2,p.Mc("id: "+f.id,h-20,k-10,c,"16px Arial"),p.Mc("key: "+f.keyCode,h-20,k+10,c,"16px Arial")};new fa;function gc(a,b){return b}function J(a,b,c,d){return b+a/d*c}function hc(a,b,c,d,f){void 0===f&&(f=3);return b+c*Math.pow(a/d,f)}
function ic(a,b,c,d){return hc(a,b,c,d,2)}function jc(a,b,c,d){return hc(a,b,c,d,3)}function kc(a,b,c,d){return b+c*hc(d-a,1,-1,d,3)}function lc(a,b,c,d){return b+c*(a<d/2?hc(a,0,.5,d/2,3):hc(d-a,1,-.5,d/2,3))}function mc(a,b,c,d){return b+c*hc(d-a,1,-1,d,4)}function oc(a,b,c,d){return b+c*(a<d/2?0+.5*(1-Math.cos(a/(d/2)*Math.PI/2)):1+-.5*(1-Math.cos((d-a)/(d/2)*Math.PI/2)))}function pc(a,b,c,d){return b+c*(1+-1*(1-Math.sqrt(1-Math.pow((d-a)/d,2))))}
function qc(a,b,c,d,f,h){a=d-a;var k=h;void 0===f&&(f=3);void 0===k&&(k=8);h=Math.sin(2*(1-a/d)*Math.PI*f+Math.PI/2);f=k;void 0===f&&(f=8);k=Math.pow(2,-f);h*=0+(Math.pow(2,f*a/d-f)-k)/(1-k)*1;return b+c*(1+-1*h)}function rc(a,b,c,d,f){void 0===f&&(f=1.70158);return b+c*((1+f)*Math.pow(a/d,3)-f*Math.pow(a/d,2))}function sc(a,b,c,d,f){return b+c*rc(d-a,1,-1,d,f)}
function tc(a){switch(1){case 0:return function(b,c,d,f,h,k,l){return 0>b?c:b>f?c+d:a(b,c,d,f,h,k,l)};case 1:return function(b,c,d,f,h,k,l){return a(b-Math.floor(b/f)*f,c,d,f,h,k,l)};case 2:return function(b,c,d,f,h,k,l){b=0===Math.floor(b/f)%2?a(b-Math.floor(b/f)*f,0,1,f,h,k,l):a(f-b+Math.floor(b/f)*f,0,1,f,h,k,l);return c+d*b};case 3:return function(b,c,d,f,h,k,l){h=a(b-Math.floor(b/f)*f,0,1,f,h,k,l);0!==Math.floor(b/f)%2&&(h=1-h);return c+d*h};case 4:return function(b,c,d,f,h,k,l){var n=Math.floor(b/
f);b=a(b-Math.floor(b/f)*f,0,1,f,h,k,l);return c+d*(n+b)};case 5:return function(b,c,d,f,h,k,l){var n=Math.floor(b/f);b=0===Math.floor(b/f)%2?a(b-Math.floor(b/f)*f,0,1,f,h,k,l):a(f-b+Math.floor(b/f)*f,1,-1,f,h,k,l);return c+d*(n+b)};default:return function(b,c,d,f,h,k,l){return a(b,c,d,f,h,k,l)}}}
function uc(a,b,c){var d,f=0,h=1,k=[0],l=[0];for(void 0===b&&(b=[]);b.length<a.length;)b.push(!1);for(void 0===c&&(c=[]);c.length<a.length;)c.push(1/a.length);for(d=0;d<a.length;d+=1)f+=c[d];for(d=0;d<a.length;d+=1)c[d]/=f;for(d=0;d<a.length;d+=1)l.push(l[d]+c[d]),f=a[d]===gc?0:b[d]?-1:1,k.push(k[d]+f),h=Math.max(h,k[d+1]);return function(d,f,u,B,C,t,s){var v,w;v=a.length-1;for(w=0;w<a.length;w+=1)if(d/B<=l[w+1]){v=w;break}d=a[v](d/B-l[v],0,1,c[v],C,t,s);b[v]&&(d=-d);return f+(k[v]+d)*u/h}}
var K=window.TG_InitSettings||{};K.size=void 0!==K.size?K.size:"big";K.Du=K.usesFullScreen;K.Ap="big"===K.size?1:.5;K.qg=20;K.rg=10;K.qf=0;K.al=-10;K.xh=-20;K.Hc=-30;K.Oe=-40;
function L(a,b){var c;if("number"===typeof a){a:switch(b){case "floor":c=Math.floor(K.Ap*a);break a;case "round":c=Math.round(K.Ap*a);break a;default:c=K.Ap*a}return c}if("[object Array]"===Object.prototype.toString.call(a)){for(c=0;c<a.length;c++)a[c]=L(a[c],b);return a}if("object"===typeof a){for(c in a)a.hasOwnProperty(c)&&(a[c]=L(a[c],b));return a}}function M(a){return"big"===K.size?void 0!==a.big?a.big:a:void 0!==a.small?a.small:a}var N=N||{};N["nl-nl"]=N["nl-nl"]||{};N["nl-nl"].bs_stage="Level";
N["nl-nl"].bs_start="Doel";N["nl-nl"].bs_gameover="Helaas";N["nl-nl"].bs_shootallbubbles="Kun jij het hoogste level behalen?";N["nl-nl"].bs_switch="Wisselen";N["nl-nl"].bs_tap_to_switch_bubbles="#touch{Klik om bubbles te wisselen}{Tik om bubbles te wisselen}";N["nl-nl"].bs_nice="Mooi!";N["nl-nl"].bs_great="Geweldig!";N["nl-nl"].bs_awesome="Fantastisch!";N["nl-nl"].TutorialTitle_1="Speluitleg";N["nl-nl"].TutorialText_0="Schiet met bubbels en vorm groepen van drie of meer bubbels van dezelfde kleur.";
N["nl-nl"].TutorialText_1="Door groepen te vormen verwijder je bubbels.";N["nl-nl"].TutorialTitle_2="Voortgang";N["nl-nl"].TutorialText_2="Elke bubbel is punten waard. Hoe groter de groep, hoe meer punten.";N["nl-nl"].TutorialTitle_3="Levels voltooien";N["nl-nl"].TutorialText_3="Verdien 500 punten om naar het volgende level te gaan.";N["nl-nl"].TutorialTitle_6="Bonussen";N["nl-nl"].TutorialText_6="Dit is een bom. De bom verwijdert omliggende bubbels als hij geraakt wordt.";
N["nl-nl"].TutorialTitle_5="Bonussen";N["nl-nl"].TutorialText_5="Dit zijn kleurenbommen. Ze geven hun kleur aan alle omliggende bubbels.";N["nl-nl"].TutorialTitle_7="Bonussen";N["nl-nl"].TutorialText_7="Dit is een vuurbal. Hij vernietigt alle bubbels op zijn pad.";N["nl-nl"].TutorialTitle_0="Speluitleg";N["nl-nl"].TutorialText_4="Dit zijn blokkers. Een blok kan je alleen wegspelen door de omringende bubbels te verwijderen.";N["nl-nl"].TutorialTitle_4="Blokkers";N["en-us"]=N["en-us"]||{};
N["en-us"].bs_stage="Stage";N["en-us"].bs_start="Goal";N["en-us"].bs_gameover="Game over";N["en-us"].bs_shootallbubbles="Can you reach the highest level?";N["en-us"].bs_switch="Switch";N["en-us"].bs_tap_to_switch_bubbles="#touch{Click to switch bubbles}{Tap to switch bubbles}";N["en-us"].bs_nice="Nice!";N["en-us"].bs_great="Great!";N["en-us"].bs_awesome="Awesome!";N["en-us"].TutorialTitle_1="How to play";N["en-us"].TutorialText_0="Shoot bubbles to form groups of 3 or more of the same color.";
N["en-us"].TutorialText_1="Creating groups will destroy bubbles.";N["en-us"].TutorialTitle_2="Progress";N["en-us"].TutorialText_2="Each bubble is worth points. Bigger groups earn you more points.";N["en-us"].TutorialTitle_3="Completing levels";N["en-us"].TutorialText_3="Earn 500 points to gain a level.";N["en-us"].TutorialTitle_6="Boosters";N["en-us"].TutorialText_6="This is a bomb. It will remove all surrounding bubbles when hit.";N["en-us"].TutorialTitle_5="Boosters";N["en-us"].TutorialText_5="These are color bombs. They will color all surrounding bubbles with their color.";
N["en-us"].TutorialTitle_7="Boosters";N["en-us"].TutorialText_7="This is a fireball. It will destroy all bubbles in its path.";N["en-us"].TutorialTitle_0="How to play";N["en-us"].TutorialText_4="These are blockers. You can get rid of them by removing their surrounding bubbles.";N["en-us"].TutorialTitle_4="Blockers";N["en-gb"]=N["en-gb"]||{};N["en-gb"].bs_stage="Stage";N["en-gb"].bs_start="Goal";N["en-gb"].bs_gameover="Game over";N["en-gb"].bs_shootallbubbles="Can you reach the highest level?";
N["en-gb"].bs_switch="Switch";N["en-gb"].bs_tap_to_switch_bubbles="#touch{Click to switch bubbles}{Tap to switch bubbles}";N["en-gb"].bs_nice="Nice!";N["en-gb"].bs_great="Great!";N["en-gb"].bs_awesome="Awesome!";N["en-gb"].TutorialTitle_1="How to play";N["en-gb"].TutorialText_0="Shoot bubbles to form groups of 3 or more of the same color.";N["en-gb"].TutorialText_1="Creating groups will destroy bubbles.";N["en-gb"].TutorialTitle_2="Progress";N["en-gb"].TutorialText_2="Each bubble is worth points. Bigger groups earn you more points.";
N["en-gb"].TutorialTitle_3="Completing levels";N["en-gb"].TutorialText_3="Earn 500 points to gain a level.";N["en-gb"].TutorialTitle_6="Boosters";N["en-gb"].TutorialText_6="This is a bomb. It will remove all surrounding bubbles when hit.";N["en-gb"].TutorialTitle_5="Boosters";N["en-gb"].TutorialText_5="These are colour bombs. They will colour all surrounding bubbles with their colour.";N["en-gb"].TutorialTitle_7="Boosters";N["en-gb"].TutorialText_7="This is a fireball. It will destroy all bubbles in its path.";
N["en-gb"].TutorialTitle_0="How to play";N["en-gb"].TutorialText_4="These are blockers. You can get rid of them by removing their surrounding bubbles.";N["en-gb"].TutorialTitle_4="Blockers";N["de-de"]=N["de-de"]||{};N["de-de"].bs_stage="Stufe";N["de-de"].bs_start="Ziel";N["de-de"].bs_gameover="ENDE!";N["de-de"].bs_shootallbubbles="Kannst du das h\u00f6chste Level erreichen?";N["de-de"].bs_switch="Schalter";N["de-de"].bs_tap_to_switch_bubbles="#touch{Blasen wechseln: Klicken}{Blasen wechseln: Tippen}";
N["de-de"].bs_nice="Toll!";N["de-de"].bs_great="Super!";N["de-de"].bs_awesome="Fantastisch!";N["de-de"].TutorialTitle_1="So wird gespielt";N["de-de"].TutorialText_0="Schie\u00dfe Blasen nach oben, um Gruppen aus mindestens drei gleichfarbigen Blasen zu bilden.";N["de-de"].TutorialText_1="Wird eine Gruppe gebildet, zerst\u00f6rt das die Blasen.";N["de-de"].TutorialTitle_2="Fortschritt";N["de-de"].TutorialText_2="Jede Blase bringt dir Punkte ein. Gr\u00f6\u00dfere Gruppen sind mehr Punkte wert.";
N["de-de"].TutorialTitle_3="Levels abschlie\u00dfen";N["de-de"].TutorialText_3="Verdiene dir 500 Punkte, um ein Level aufzusteigen.";N["de-de"].TutorialTitle_6="Extras";N["de-de"].TutorialText_6="Das ist eine Bombe. Sie entfernt bei einem Treffer alle Blasen, von denen sie umgeben ist.";N["de-de"].TutorialTitle_5="Extras";N["de-de"].TutorialText_5="Das sind Farbbomben. Sie f\u00e4rben alle sie umgebenden Blasen in ihre Farbe um.";N["de-de"].TutorialTitle_7="Extras";N["de-de"].TutorialText_7="Das ist ein Feuerball. Er zerst\u00f6rt alle Blasen in seiner Flugbahn.";
N["de-de"].TutorialTitle_0="So wird gespielt";N["de-de"].TutorialText_4="Das sind Blocker. Blocker wirst du los, indem du die Blasen entfernst, von denen sie umgeben sind.";N["de-de"].TutorialTitle_4="Blocker";N["fr-fr"]=N["fr-fr"]||{};N["fr-fr"].bs_stage="Sc\u00e8ne";N["fr-fr"].bs_start="Objectif";N["fr-fr"].bs_gameover="Partie termin\u00e9e";N["fr-fr"].bs_shootallbubbles="Atteindrez-vous le dernier niveau ?";N["fr-fr"].bs_switch="\u00c9changer";N["fr-fr"].bs_tap_to_switch_bubbles="#touch{Cliquez pour \u00e9changer les bulles}{Touchez pour \u00e9changer les bulles}";
N["fr-fr"].bs_nice="Joli !";N["fr-fr"].bs_great="G\u00e9nial !";N["fr-fr"].bs_awesome="Excellent !";N["fr-fr"].TutorialTitle_1="Comment jouer";N["fr-fr"].TutorialText_0="Tirez vos bulles pour former des groupes de 3 (ou plus) de la m\u00eame couleur.";N["fr-fr"].TutorialText_1="Cr\u00e9er des groupes de bulles les fait dispara\u00eetre.";N["fr-fr"].TutorialTitle_2="Progression";N["fr-fr"].TutorialText_2="Chaque bulle rapporte des points. Plus le groupe est grand, plus vous gagnez de points.";
N["fr-fr"].TutorialTitle_3="Terminer les niveaux";N["fr-fr"].TutorialText_3="Atteignez 500 points pour passer au niveau suivant.";N["fr-fr"].TutorialTitle_6="Bonus";N["fr-fr"].TutorialText_6="Ceci est une bombe. Elle fait dispara\u00eetre toutes les bulles proches.";N["fr-fr"].TutorialTitle_5="Bonus";N["fr-fr"].TutorialText_5="Voici des bombes de couleur. Elles changent la couleur de toutes les bulles avoisinantes.";N["fr-fr"].TutorialTitle_7="Bonus";N["fr-fr"].TutorialText_7="Ceci est une boule de feu. Elle d\u00e9truit toutes les bulles sur son chemin.";
N["fr-fr"].TutorialTitle_0="Comment jouer";N["fr-fr"].TutorialText_4="Voici des cailloux. Vous pouvez vous en d\u00e9barrasser en \u00e9clatant les bulles situ\u00e9es autour.";N["fr-fr"].TutorialTitle_4="Cailloux";N["pt-br"]=N["pt-br"]||{};N["pt-br"].bs_stage="Fase";N["pt-br"].bs_start="Objetivo";N["pt-br"].bs_gameover="Fim do jogo";N["pt-br"].bs_shootallbubbles="Tente chegar ao n\u00edvel m\u00e1ximo!";N["pt-br"].bs_switch="Trocar";N["pt-br"].bs_tap_to_switch_bubbles="#touch{Clique para trocar as bolhas.}{Toque para trocar as bolhas.}";
N["pt-br"].bs_nice="Legal!";N["pt-br"].bs_great="\u00d3timo!";N["pt-br"].bs_awesome="Incr\u00edvel!";N["pt-br"].TutorialTitle_1="Como jogar";N["pt-br"].TutorialText_0="Atire nas bolhas para formar grupos de 3 ou mais da mesma cor.";N["pt-br"].TutorialText_1="Forme grupos para destruir as bolhas.";N["pt-br"].TutorialTitle_2="Progresso";N["pt-br"].TutorialText_2="Cada bolha vale pontos. Grupos maiores valem mais pontos.";N["pt-br"].TutorialTitle_3="Passar de n\u00edvel";N["pt-br"].TutorialText_3="Fa\u00e7a 500 pontos para passar de fase.";
N["pt-br"].TutorialTitle_6="Refor\u00e7os";N["pt-br"].TutorialText_6="Esta \u00e9 a bomba. Quando \u00e9 atingida, remove todas as bolhas ao redor.";N["pt-br"].TutorialTitle_5="Refor\u00e7os";N["pt-br"].TutorialText_5="Estas s\u00e3o bombas de cor. Elas deixam as bolhas ao redor com a mesma cor delas.";N["pt-br"].TutorialTitle_7="Refor\u00e7os";N["pt-br"].TutorialText_7="Esta \u00e9 a bola de fogo. Ela destr\u00f3i todas as bolhas em seu caminho.";N["pt-br"].TutorialTitle_0="Como jogar";
N["pt-br"].TutorialText_4="Estes s\u00e3o os bloqueadores. Remova as bolhas ao redor, para se livrar deles.";N["pt-br"].TutorialTitle_4="Bloqueadores";N["es-es"]=N["es-es"]||{};N["es-es"].bs_stage="Fase";N["es-es"].bs_start="Objetivo";N["es-es"].bs_gameover="Fin del juego";N["es-es"].bs_shootallbubbles="\u00bfPuedes llegar al \u00faltimo nivel?";N["es-es"].bs_switch="Cambiar";N["es-es"].bs_tap_to_switch_bubbles="#touch{Haz clic para cambiar de burbuja.}{Toca para cambiar de burbuja.}";
N["es-es"].bs_nice="\u00a1Guay!";N["es-es"].bs_great="\u00a1Genial!";N["es-es"].bs_awesome="\u00a1Estupendo!";N["es-es"].TutorialTitle_1="C\u00f3mo jugar";N["es-es"].TutorialText_0="Dispara burbujas para crear grupos de 3 o m\u00e1s del mismo color.";N["es-es"].TutorialText_1="Al crear grupos, eliminas las burbujas.";N["es-es"].TutorialTitle_2="Progreso";N["es-es"].TutorialText_2="Cada burbuja te da puntos. Cuanto mayor sea el grupo, m\u00e1s puntos dan.";N["es-es"].TutorialTitle_3="Completar niveles";
N["es-es"].TutorialText_3="Gana 500 puntos para subir de nivel.";N["es-es"].TutorialTitle_6="Potenciadores";N["es-es"].TutorialText_6="Esto es una bomba. Eliminar\u00e1 las burbujas a su alrededor si le das.";N["es-es"].TutorialTitle_5="Potenciadores";N["es-es"].TutorialText_5="Estas son bombas de color. Hacen que las burbujas cercanas sean de su color.";N["es-es"].TutorialTitle_7="Potenciadores";N["es-es"].TutorialText_7="Esto es una bola de fuego. Destruye las burbujas en su camino.";
N["es-es"].TutorialTitle_0="C\u00f3mo jugar";N["es-es"].TutorialText_4="Esto es un bloqueo. Para librarte de \u00e9l, elimina las burbujas de alrededor.";N["es-es"].TutorialTitle_4="Bloqueos";N["tr-tr"]=N["tr-tr"]||{};N["tr-tr"].bs_stage="B\u00f6l\u00fcm";N["tr-tr"].bs_start="Hedef";N["tr-tr"].bs_gameover="Oyun bitti";N["tr-tr"].bs_shootallbubbles="En y\u00fcksek seviyeye ula\u015fabilir misin?";N["tr-tr"].bs_switch="De\u011fi\u015ftir";N["tr-tr"].bs_tap_to_switch_bubbles="#touch{Balonlar\u0131 de\u011fi\u015ftirmek i\u00e7in t\u0131kla}{Balonlar\u0131 de\u011fi\u015ftirmek i\u00e7in dokun}";
N["tr-tr"].bs_nice="G\u00fczel!";N["tr-tr"].bs_great="Harika!";N["tr-tr"].bs_awesome="Muhte\u015fem!";N["tr-tr"].TutorialTitle_1="Nas\u0131l oynan\u0131r";N["tr-tr"].TutorialText_0="3'l\u00fc ya da daha fazla ayn\u0131 renkten gruplar olu\u015fturmak i\u00e7in balonlar\u0131 vur.";N["tr-tr"].TutorialText_1="Gruplar olu\u015fturmak balonlar\u0131 yok eder.";N["tr-tr"].TutorialTitle_2="\u0130lerleme";N["tr-tr"].TutorialText_2="Her balonun puan de\u011feri vard\u0131r. Daha b\u00fcy\u00fck gruplar daha fazla puan kazand\u0131r\u0131r.";
N["tr-tr"].TutorialTitle_3="Seviyeleri tamamlama";N["tr-tr"].TutorialText_3="Seviye atlamak i\u00e7in 500 puan kazan.";N["tr-tr"].TutorialTitle_6="Destekler";N["tr-tr"].TutorialText_6="Bu bir bombad\u0131r. Vuruldu\u011funda etraflar\u0131ndaki balonlar\u0131 kald\u0131r\u0131r.";N["tr-tr"].TutorialTitle_5="Destekler";N["tr-tr"].TutorialText_5="Bunlar renkli bombalard\u0131r. Etraflar\u0131ndaki balonlar\u0131 kendi renklerine boyarlar.";N["tr-tr"].TutorialTitle_7="Destekler";
N["tr-tr"].TutorialText_7="Bu bir alev topu. Yolundaki t\u00fcm balonlar\u0131 yok eder.";N["tr-tr"].TutorialTitle_0="Nas\u0131l oynan\u0131r";N["tr-tr"].TutorialText_4="Bunlar engelleyenler! Bunlardan kurtulmak i\u00e7in etraflar\u0131ndaki balonlar\u0131 kald\u0131r.";N["tr-tr"].TutorialTitle_4="Engelleyenler";N["ru-ru"]=N["ru-ru"]||{};N["ru-ru"].bs_stage="\u042d\u0442\u0430\u043f";N["ru-ru"].bs_start="\u0426\u0435\u043b\u044c";N["ru-ru"].bs_gameover="\u041a\u043e\u043d\u0435\u0446 \u0438\u0433\u0440\u044b";
N["ru-ru"].bs_shootallbubbles="\u0414\u043e\u0431\u0435\u0440\u0435\u0442\u0435\u0441\u044c \u043b\u0438 \u0432\u044b \u0434\u043e \u0441\u0430\u043c\u043e\u0433\u043e \u0432\u044b\u0441\u043e\u043a\u043e\u0433\u043e \u0443\u0440\u043e\u0432\u043d\u044f?";N["ru-ru"].bs_switch="\u0421\u043c\u0435\u043d\u0430 \u0446\u0432\u0435\u0442\u0430";N["ru-ru"].bs_tap_to_switch_bubbles="#touch{\u0429\u0435\u043b\u043a\u043d\u0438\u0442\u0435, \u0447\u0442\u043e\u0431\u044b \u043f\u043e\u043c\u0435\u043d\u044f\u0442\u044c \u043f\u0443\u0437\u044b\u0440\u0438 \u043c\u0435\u0441\u0442\u0430\u043c\u0438}{\u041a\u043e\u0441\u043d\u0438\u0442\u0435\u0441\u044c, \u0447\u0442\u043e\u0431\u044b \u043f\u043e\u043c\u0435\u043d\u044f\u0442\u044c \u043f\u0443\u0437\u044b\u0440\u0438 \u043c\u0435\u0441\u0442\u0430\u043c\u0438}";
N["ru-ru"].bs_nice="\u0417\u0434\u043e\u0440\u043e\u0432\u043e!";N["ru-ru"].bs_great="\u041e\u0442\u043b\u0438\u0447\u043d\u043e!";N["ru-ru"].bs_awesome="\u041a\u0440\u0443\u0442\u043e!";N["ru-ru"].TutorialTitle_1="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";N["ru-ru"].TutorialText_0="\u0421\u0442\u0440\u0435\u043b\u044f\u0439\u0442\u0435 \u043f\u0443\u0437\u044b\u0440\u044f\u043c\u0438, \u0447\u0442\u043e\u0431\u044b \u0441\u043e\u0435\u0434\u0438\u043d\u0438\u0442\u044c 3 \u0438 \u0431\u043e\u043b\u044c\u0448\u0435 \u043f\u0443\u0437\u044b\u0440\u0435\u0439 \u043e\u0434\u043d\u043e\u0433\u043e \u0446\u0432\u0435\u0442\u0430.";
N["ru-ru"].TutorialText_1="\u0421\u043e\u0435\u0434\u0438\u043d\u0435\u043d\u043d\u044b\u0435 \u043f\u0443\u0437\u044b\u0440\u0438 \u043b\u043e\u043f\u0430\u044e\u0442\u0441\u044f.";N["ru-ru"].TutorialTitle_2="\u0425\u043e\u0434 \u0438\u0433\u0440\u044b";N["ru-ru"].TutorialText_2="\u0417\u0430 \u043a\u0430\u0436\u0434\u044b\u0439 \u043f\u0443\u0437\u044b\u0440\u044c \u0432\u044b \u043f\u043e\u043b\u0443\u0447\u0430\u0435\u0442\u0435 \u043e\u0447\u043a\u0438. \u0427\u0435\u043c \u0431\u043e\u043b\u044c\u0448\u0435 \u0433\u0440\u0443\u043f\u043f\u0430, \u0442\u0435\u043c \u0431\u043e\u043b\u044c\u0448\u0435 \u043e\u0447\u043a\u043e\u0432 \u0432\u044b \u0437\u0430\u0440\u0430\u0431\u043e\u0442\u0430\u0435\u0442\u0435.";
N["ru-ru"].TutorialTitle_3="\u041f\u0440\u043e\u0445\u043e\u0436\u0434\u0435\u043d\u0438\u0435 \u0443\u0440\u043e\u0432\u043d\u0435\u0439";N["ru-ru"].TutorialText_3="\u0417\u0430\u0440\u0430\u0431\u043e\u0442\u0430\u0439\u0442\u0435 500 \u043e\u0447\u043a\u043e\u0432, \u0447\u0442\u043e\u0431\u044b \u043f\u043e\u043b\u0443\u0447\u0438\u0442\u044c \u043d\u043e\u0432\u044b\u0439 \u0443\u0440\u043e\u0432\u0435\u043d\u044c.";N["ru-ru"].TutorialTitle_6="\u0411\u043e\u043d\u0443\u0441\u044b";
N["ru-ru"].TutorialText_6="\u042d\u0442\u043e \u0431\u043e\u043c\u0431\u0430. \u041f\u0440\u0438 \u0432\u0437\u0440\u044b\u0432\u0435 \u043e\u043d\u0430 \u0443\u043d\u0438\u0447\u0442\u043e\u0436\u0430\u0435\u0442 \u0432\u0441\u0435 \u043e\u043a\u0440\u0443\u0436\u0430\u044e\u0449\u0438\u0435 \u043f\u0443\u0437\u044b\u0440\u0438.";N["ru-ru"].TutorialTitle_5="\u0411\u043e\u043d\u0443\u0441\u044b";N["ru-ru"].TutorialText_5="\u042d\u0442\u043e \u0446\u0432\u0435\u0442\u043d\u044b\u0435 \u0431\u043e\u043c\u0431\u044b. \u041e\u043d\u0438 \u043f\u0435\u0440\u0435\u043a\u0440\u0430\u0448\u0438\u0432\u0430\u044e\u0442 \u0432\u0441\u0435 \u043f\u0443\u0437\u044b\u0440\u0438 \u0440\u044f\u0434\u043e\u043c \u0432 \u0441\u0432\u043e\u0439 \u0446\u0432\u0435\u0442.";
N["ru-ru"].TutorialTitle_7="\u0411\u043e\u043d\u0443\u0441\u044b";N["ru-ru"].TutorialText_7="\u042d\u0442\u043e \u043e\u0433\u043d\u0435\u043d\u043d\u044b\u0439 \u0448\u0430\u0440. \u041e\u043d \u0443\u043d\u0438\u0447\u0442\u043e\u0436\u0430\u0435\u0442 \u0432\u0441\u0435 \u043f\u0443\u0437\u044b\u0440\u0438 \u043d\u0430 \u0441\u0432\u043e\u0435\u043c \u043f\u0443\u0442\u0438.";N["ru-ru"].TutorialTitle_0="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";N["ru-ru"].TutorialText_4="\u042d\u0442\u043e \u0431\u043b\u043e\u043a\u0430\u0442\u043e\u0440\u044b. \u0418\u0437\u0431\u0430\u0432\u0438\u0442\u044c\u0441\u044f \u043e\u0442 \u043d\u0438\u0445 \u043c\u043e\u0436\u043d\u043e, \u0443\u0431\u0440\u0430\u0432 \u043e\u043a\u0440\u0443\u0436\u0430\u044e\u0449\u0438\u0435 \u043f\u0443\u0437\u044b\u0440\u0438.";
N["ru-ru"].TutorialTitle_4="\u0411\u043b\u043e\u043a\u0430\u0442\u043e\u0440\u044b";N["ar-eg"]=N["ar-eg"]||{};N["ar-eg"].bs_stage="\u0627\u0644\u0645\u0631\u062d\u0644\u0629";N["ar-eg"].bs_start="\u0627\u0644\u0647\u062f\u0641";N["ar-eg"].bs_gameover="\u0627\u0646\u062a\u0647\u062a \u0627\u0644\u0644\u0639\u0628\u0629";N["ar-eg"].bs_shootallbubbles="\u0647\u0644 \u064a\u0645\u0643\u0646\u0643 \u0627\u0644\u0648\u0635\u0648\u0644 \u0625\u0644\u0649 \u0623\u0639\u0644\u0649 \u0645\u0633\u062a\u0648\u0649\u061f";
N["ar-eg"].bs_switch="\u062a\u0628\u062f\u064a\u0644";N["ar-eg"].bs_tap_to_switch_bubbles="#touch{\u0627\u0646\u0642\u0631 \u0644\u062a\u0628\u062f\u064a\u0644 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a}{\u0627\u0644\u0645\u0633 \u0644\u062a\u0628\u062f\u064a\u0644 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a}";N["ar-eg"].bs_nice="\u062c\u064a\u062f!";N["ar-eg"].bs_great="\u0639\u0638\u064a\u0645!";N["ar-eg"].bs_awesome="\u0631\u0627\u0626\u0639!";N["ar-eg"].TutorialTitle_1="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";
N["ar-eg"].TutorialText_0="\u0642\u0645 \u0628\u0642\u0630\u0641 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0644\u062a\u0643\u0648\u064a\u0646 \u0645\u062c\u0645\u0648\u0639\u0627\u062a \u0645\u0646 \u062b\u0644\u0627\u062b \u0641\u0642\u0627\u0639\u0627\u062a \u0623\u0648 \u0643\u062b\u0631 \u0645\u0646 \u0646\u0641\u0633 \u0627\u0644\u0644\u0648\u0646.";N["ar-eg"].TutorialText_1="\u064a\u0624\u062f\u064a \u062a\u0643\u0648\u064a\u0646 \u0645\u062c\u0645\u0648\u0639\u0627\u062a \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0625\u0644\u0649 \u062a\u062f\u0645\u064a\u0631\u0647\u0627.";
N["ar-eg"].TutorialTitle_2="\u0627\u0644\u062a\u0642\u062f\u0645";N["ar-eg"].TutorialText_2="\u062a\u0633\u0627\u0648\u064a \u0643\u0644 \u0641\u0642\u0627\u0639\u0629 \u0639\u062f\u062f\u064b\u0627 \u0645\u0646 \u0627\u0644\u0646\u0642\u0627\u0637. \u0648\u0643\u0644\u0645\u0627 \u0632\u0627\u062f \u0639\u062f\u062f \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0641\u064a \u0627\u0644\u0645\u062c\u0645\u0648\u0639\u0629\u060c \u0632\u0627\u062f \u0639\u062f\u062f \u0627\u0644\u0646\u0642\u0627\u0637 \u0627\u0644\u062a\u0628 \u062a\u062c\u0645\u0639\u0647\u0627.";
N["ar-eg"].TutorialTitle_3="\u0625\u0643\u0645\u0627\u0644 \u0627\u0644\u0645\u0633\u062a\u0648\u064a\u0627\u062a";N["ar-eg"].TutorialText_3="\u0627\u062c\u0645\u0639 500 \u0646\u0642\u0637\u0629 \u0644\u0644\u0641\u0648\u0632 \u0628\u0645\u0633\u062a\u0648\u0649.";N["ar-eg"].TutorialTitle_6="\u0645\u064a\u0632\u0627\u062a";N["ar-eg"].TutorialText_6="\u0647\u0630\u0647 \u0642\u0646\u0628\u0644\u0629. \u0633\u062a\u0642\u0648\u0645 \u0628\u0625\u0632\u0627\u0644\u0629 \u0643\u0644 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0627\u0644\u0645\u062d\u064a\u0637\u0629 \u0628\u0647\u0627 \u0639\u0646\u062f \u0636\u0631\u0628\u0647\u0627.";
N["ar-eg"].TutorialTitle_5="\u0645\u064a\u0632\u0627\u062a";N["ar-eg"].TutorialText_5="\u0647\u0630\u0647 \u0642\u0646\u0627\u0628\u0644 \u0627\u0644\u0644\u0648\u0646. \u0633\u062a\u0642\u0648\u0645 \u0627\u0644\u0642\u0646\u0627\u0628\u0644 \u0628\u062a\u0644\u0648\u064a\u0646 \u0643\u0644 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0627\u0644\u0645\u062d\u064a\u0637\u0629 \u0628\u0647\u0627 \u0628\u0644\u0648\u0646\u0647\u0627.";N["ar-eg"].TutorialTitle_7="\u0645\u064a\u0632\u0627\u062a";
N["ar-eg"].TutorialText_7="\u0647\u0630\u0647 \u0643\u0631\u0629 \u0646\u0627\u0631\u064a\u0629. \u0633\u062a\u0642\u0648\u0645 \u0628\u062a\u062f\u0645\u064a\u0631 \u0643\u0644 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0627\u0644\u0645\u0648\u062c\u0648\u062f\u0629 \u0641\u064a \u0645\u0633\u0627\u0631\u0647\u0627.";N["ar-eg"].TutorialTitle_0="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";N["ar-eg"].TutorialText_4="\u0647\u0630\u0647 \u0635\u062e\u0648\u0631. \u064a\u0645\u0643\u0646\u0643 \u0627\u0644\u062a\u062e\u0644\u0635 \u0645\u0646\u0647\u0627 \u0639\u0646 \u0637\u0631\u064a\u0642 \u0625\u0632\u0627\u0644\u0629 \u0627\u0644\u0641\u0642\u0627\u0639\u0627\u062a \u0627\u0644\u0645\u062d\u064a\u0637\u0629 \u0628\u0647\u0627.";
N["ar-eg"].TutorialTitle_4="\u0635\u062e\u0648\u0631";N["ko-kr"]=N["ko-kr"]||{};N["ko-kr"].bs_stage="Stage";N["ko-kr"].bs_start="\ubaa9\ud45c";N["ko-kr"].bs_gameover="Game over";N["ko-kr"].bs_shootallbubbles="\ucd5c\uace0 \ub808\ubca8\uc5d0 \ub3c4\ub2ec\ud560 \uc218 \uc788\ub098\uc694?";N["ko-kr"].bs_switch="\uc804\ud658";N["ko-kr"].bs_tap_to_switch_bubbles="#touch{\ubc84\ube14\uc744 \ubc14\uafb8\ub824\uba74 \uc804\ud658\uc744 \ud074\ub9ad\ud558\uc138\uc694}{\ubc84\ube14\uc744 \ubc14\uafb8\ub824\uba74 \uc804\ud658\uc744 \ub204\ub974\uc138\uc694}";
N["ko-kr"].bs_nice="\uc88b\uc544\uc694!";N["ko-kr"].bs_great="\ud6cc\ub96d\ud574!";N["ko-kr"].bs_awesome="\uba4b\uc9c0\uad70\uc694!";N["ko-kr"].TutorialTitle_1="\uac8c\uc784 \ubc29\ubc95";N["ko-kr"].TutorialText_0="3\uac1c \uc774\uc0c1\uc758 \uac19\uc740 \uc0c9 \uadf8\ub8f9\uc744 \ud5a5\ud574 \uc3d8\uc138\uc694.";N["ko-kr"].TutorialText_1="\uadf8\ub8f9\uc774 \ub9cc\ub4e4\uba74 \ubc84\ube14\uc744 \ud30c\uad34\ud569\ub2c8\ub2e4.";N["ko-kr"].TutorialTitle_2="\uc9c4\ud589";N["ko-kr"].TutorialText_2="\uac01 \ubc84\ube14\uc774 \uc810\uc218\uac00 \ub429\ub2c8\ub2e4. \ub354 \ud070 \uadf8\ub8f9\uc740 \ub354 \ub9ce\uc740 \uc810\uc218\ub97c \ud68d\ub4dd\ud569\ub2c8\ub2e4.";
N["ko-kr"].TutorialTitle_3="\ub808\ubca8 \uc644\ub8cc\ud558\uae30";N["ko-kr"].TutorialText_3="\ub808\ubca8\uc744 \ud655\ubcf4\ud558\ub824\uba74 500\uc810\uc744 \ud68d\ub4dd\ud558\uc138\uc694.";N["ko-kr"].TutorialTitle_6="\ubd80\uc2a4\ud130";N["ko-kr"].TutorialText_6="\ud3ed\ud0c4\uc785\ub2c8\ub2e4. \ub9de\ucd94\uba74 \uc8fc\uc704 \ubaa8\ub4e0 \ubc84\ube14\uc744 \uc81c\uac70\ud569\ub2c8\ub2e4.";N["ko-kr"].TutorialTitle_5="\ubd80\uc2a4\ud130";N["ko-kr"].TutorialText_5="\uc0c9\uae54 \ud3ed\ud0c4\uc785\ub2c8\ub2e4. \uc8fc\ubcc0\uc758 \ubc84\ube14\uc744 \uac19\uc740 \uc0c9\uc73c\ub85c \ubc14\uafc9\ub2c8\ub2e4.";
N["ko-kr"].TutorialTitle_7="\ubd80\uc2a4\ud130";N["ko-kr"].TutorialText_7="\ubd88 \ub369\uc5b4\ub9ac\uc785\ub2c8\ub2e4. \uc9c0\ub098\uac04 \uc790\ub9ac\uc758 \ubaa8\ub4e0 \ubc84\ube14\uc744 \ud30c\uad34\ud569\ub2c8\ub2e4.";N["ko-kr"].TutorialTitle_0="\uac8c\uc784 \ubc29\ubc95";N["ko-kr"].TutorialText_4="\ucc28\ub2e8\uc81c\uc785\ub2c8\ub2e4. \uc8fc\ubcc0 \ubc84\ube14\uc744 \uc81c\uac70\ud574 \ud30c\uad34\ud560 \uc218 \uc788\uc2b5\ub2c8\ub2e4.";N["ko-kr"].TutorialTitle_4="\ucc28\ub2e8\uc81c";
N["jp-jp"]=N["jp-jp"]||{};N["jp-jp"].bs_stage="\u30ec\u30d9\u30eb";N["jp-jp"].bs_start="\u30b4\u30fc\u30eb";N["jp-jp"].bs_gameover="\u30b2\u30fc\u30e0\u30aa\u30fc\u30d0\u30fc";N["jp-jp"].bs_shootallbubbles="\u30cf\u30a4\u30b9\u30b3\u30a2\u3092\u76ee\u6307\u3057\u3066\u306d\uff01";N["jp-jp"].bs_switch="\u4ea4\u63db";N["jp-jp"].bs_tap_to_switch_bubbles="#touch{\u30bf\u30c3\u30d7\u3057\u3066\u30d0\u30d6\u30eb\u3092\u4ea4\u63db\u3057\u3066\u304f\u3060\u3055\u3044\u3002}{\u30bf\u30c3\u30d7\u3067\u30d0\u30d6\u30eb\u3092\u4ea4\u63db}";
N["jp-jp"].bs_nice="Nice!";N["jp-jp"].bs_great="Great!";N["jp-jp"].bs_awesome="Awesome!";N["jp-jp"].TutorialTitle_1="\u3042\u305d\u3073\u65b9";N["jp-jp"].TutorialText_0="\u540c\u3058\u8272\u306e\u30d0\u30d6\u30eb\u304c\uff13\u3064\u4ee5\u4e0a\u30de\u30c3\u30c1\u3059\u308b\u5834\u6240\u306b\u3001\u30d0\u30d6\u30eb\u3092\u6483\u3063\u3066\u304f\u3060\u3055\u3044\u3002";N["jp-jp"].TutorialText_1="\u30de\u30c3\u30c1\u3059\u308b\u3068\u30d0\u30d6\u30eb\u304c\u6d88\u3048\u307e\u3059\u3002";
N["jp-jp"].TutorialTitle_2="\u30dd\u30a4\u30f3\u30c8";N["jp-jp"].TutorialText_2="\u30d0\u30d6\u30eb\u3092\u6d88\u3059\u3068\u30dd\u30a4\u30f3\u30c8\u304c\u5f97\u3089\u308c\u307e\u3059\u3002\u591a\u304f\u306e\u30d0\u30d6\u30eb\u3092\u4e00\u5ea6\u306b\u6d88\u3059\u3068\u3001\u3088\u308a\u591a\u304f\u306e\u30dd\u30a4\u30f3\u30c8\u3092\u7372\u5f97\u3067\u304d\u307e\u3059\u3002";N["jp-jp"].TutorialTitle_3="\u30ec\u30d9\u30eb\u30af\u30ea\u30a2";N["jp-jp"].TutorialText_3="500\u30dd\u30a4\u30f3\u30c8\u3092\u7372\u5f97\u3059\u308b\u3068\u6b21\u306e\u30ec\u30d9\u30eb\u3078\u9032\u3081\u307e\u3059\u3002";
N["jp-jp"].TutorialTitle_6="\u304a\u52a9\u3051\u30a2\u30a4\u30c6\u30e0";N["jp-jp"].TutorialText_6="\u7206\u5f3e\u3092\u6483\u3064\u3068\u3001\u307e\u308f\u308a\u306e\u30d0\u30eb\u30fc\u30f3\u3092\u4e00\u5ea6\u306b\u6d88\u3059\u3053\u3068\u304c\u3067\u304d\u307e\u3059\u3002";N["jp-jp"].TutorialTitle_5="\u304a\u52a9\u3051\u30a2\u30a4\u30c6\u30e0";N["jp-jp"].TutorialText_5="\u30ab\u30e9\u30fc\u7206\u5f3e\u3092\u6483\u3064\u3068\u3001\u307e\u308f\u308a\u306e\u30d0\u30eb\u30fc\u30f3\u304c\u7206\u5f3e\u3068\u540c\u3058\u8272\u306b\u5909\u308f\u308a\u307e\u3059\u3002";
N["jp-jp"].TutorialTitle_7="\u304a\u52a9\u3051\u30a2\u30a4\u30c6\u30e0";N["jp-jp"].TutorialText_7="\u30d5\u30a1\u30a4\u30e4\u30fc\u30dc\u30fc\u30eb\u3092\u6483\u3064\u3068\u3001<br>\u4e00\u5217\u3059\u3079\u3066\u306e\u30d0\u30d6\u30eb\u3092\u6d88\u3059\u3053\u3068\u304c\u3067\u304d\u307e\u3059\u3002";N["jp-jp"].TutorialTitle_0="\u3042\u305d\u3073\u65b9";N["jp-jp"].TutorialText_4="\u307e\u308f\u308a\u306e\u30d0\u30eb\u30fc\u30f3\u3092\u6d88\u3057\u3066\u3001\u77f3\u3092\u53d6\u308a\u9664\u3044\u3066\u304f\u3060\u3055\u3044\u3002";
N["jp-jp"].TutorialTitle_4="\u304a\u90aa\u9b54\u30a2\u30a4\u30c6\u30e0";
var vc=function(){function a(a,c,d,f,h,k){this.orientation=c;this.Zx=d;this.Oz=f;this.Ry=h;this.qn=k;this.fv=a.adChannel;this.ew=a.gameCode;this.Ur=a.gameName;this.lw=a.gameVersion;this.dw=a.gameCategory;this.Kv=a.developerId;this.cw=a.gameAnalyticsId;this.wz=a.tabIcon;var l=setInterval(function(){this.ready()&&(this.Ey(),clearInterval(l))}.bind(this),100)}a.prototype.ready=function(){return window.Booster.ready&&window.Booster.Ad};a.prototype.Ey=function(){new Booster.Init({orientation:this.orientation,
splash:!0,minimalUI:!0,rotationOnHide:function(){window.setTimeout(function(){K.e.Tb()},400)},rotationOnShow:function(){G.Go()||K.e.Hd()}});adSense=new Booster.Ad({type:"adsense",size:"300x250",channelID:this.fv});community=new Booster.Community({position:1,gameCode:this.ew,tabIcon:this.wz});analytics=new Booster.Analytics({gameName:this.Ur,gameId:this.lw,gameCategory:this.dw,developer:this.Kv,gameAnalyticsId:this.cw});moregames=new Booster.Moregames;try{freemium=new Booster.Freemium}catch(a){}var c=
this;Booster.onSplashFinishedEvent=function(){c.Ry.call(c.qn)};Booster.onOpenTab=function(){c.Zx.call(c.qn)};Booster.onCloseTab=function(){c.Oz.call(c.qn)}};return a}();window.throbber=new rb("throbber","media/throbber.png");window.favicon=new rb("favicon","favicon.ico");window.AppIcon60x60=new rb("AppIcon60x60","AppIcon60x60.png");window.AppIcon76x76=new rb("AppIcon76x76","AppIcon76x76.png");window.lvl_test=" 0 0 0 0 0   D   0 0 0 0 0 ;0 1 5 3 4 4     4 3 5 5 5  ; 1 5 5 1 1 1 | 5 3 3 5 2   ;2 5 2 5 2 1  |2 5 2 5 2 1  ;   5 5 5 0 1 | 5 5 5 5 5   ;R   2 3 5 5  |4 4 5 5 4    ;   1 1 1 1 1 | 3 3 3 3 2   ;2 2 2 2 2 2  |2 1 2 2 2 1  ;                             ;B B B B B r     e B B B B B".split(";");
var wc=new ua("StartTexture",1,"start");window.StartTexture=wc;va(wc,0,"media/StartTexture0.png");var xc=new ua("StartScreenTexture",1,"load");window.StartScreenTexture=xc;va(xc,0,"media/StartScreenTexture0.png");var yc=new ua("LevelMapScreenTexture",1,"load");window.LevelMapScreenTexture=yc;va(yc,0,"media/LevelMapScreenTexture0.png");var zc=new ua("LevelEndTexture",2,"load");window.LevelEndTexture=zc;va(zc,0,"media/LevelEndTexture0.png");va(zc,1,"media/LevelEndTexture1.png");
var O=new ua("MenuTexture",2,"load");window.MenuTexture=O;va(O,0,"media/MenuTexture0.png");va(O,1,"media/MenuTexture1.png");var P=new ua("GameTexture",2,"load");window.GameTexture=P;va(P,0,"media/GameTexture0.png");va(P,1,"media/GameTexture1.png");var Ac=new ua("GameStaticTexture",2,"load");window.GameStaticTexture=Ac;va(Ac,0,"media/GameStaticTexture0.png");va(Ac,1,"media/GameStaticTexture1.png");var Bc=new ua("TutorialTexture",1,"load");window.TutorialTexture=Bc;va(Bc,0,"media/TutorialTexture0.png");
var Cc=new ua("texture",1,"load");window.texture=Cc;va(Cc,0,"media/texture0.png");var Dc=new ua("FloaterTexture",1,"load");window.FloaterTexture=Dc;va(Dc,0,"media/FloaterTexture0.png");var Ec=new r("s_loadingbar_background",xc,1,42,32,0,0,42,32,1);window.s_loadingbar_background=Ec;Ec.c(0,0,673,161,42,32,0,0);var Fc=new r("s_loadingbar_fill",xc,1,20,12,0,0,20,12,1);window.s_loadingbar_fill=Fc;Fc.c(0,0,1001,1,20,12,0,0);var Gc=new r("s_level_0",yc,1,125,140,0,0,125,140,1);window.s_level_0=Gc;
Gc.c(0,0,129,1,125,140,0,0);var Hc=new r("s_level_1",yc,1,125,140,0,0,125,140,1);window.s_level_1=Hc;Hc.c(0,0,257,1,125,140,0,0);var Ic=new r("s_level_2",yc,1,125,140,0,0,125,140,1);window.s_level_2=Ic;Ic.c(0,0,1,1,125,140,0,0);var Jc=new r("s_level_3",yc,1,125,140,0,0,125,140,1);window.s_level_3=Jc;Jc.c(0,0,385,1,125,140,0,0);var Kc=new r("s_level_lock",yc,1,48,70,0,0,48,70,1);window.s_level_lock=Kc;Kc.c(0,0,777,113,48,69,0,1);var Lc=new r("s_level_stars",yc,1,126,46,0,0,126,46,1);
window.s_level_stars=Lc;Lc.c(0,0,513,1,126,45,0,1);var Mc=new r("s_level2_0",yc,1,84,87,0,0,84,87,1);window.s_level2_0=Mc;Mc.c(0,0,897,97,84,87,0,0);var Nc=new r("s_level2_1",yc,1,84,87,0,0,84,87,1);window.s_level2_1=Nc;Nc.c(0,0,897,1,84,87,0,0);var Oc=new r("s_level2_2",yc,1,84,87,0,0,84,87,1);window.s_level2_2=Oc;Oc.c(0,0,601,113,84,87,0,0);var Pc=new r("s_level2_3",yc,1,84,87,0,0,84,87,1);window.s_level2_3=Pc;Pc.c(0,0,513,49,84,87,0,0);
var Qc=new r("s_level2_arrow_right",yc,2,60,108,0,0,60,216,1);window.s_level2_arrow_right=Qc;Qc.c(0,0,833,1,60,108,0,0);Qc.c(1,0,641,1,60,108,0,0);var Rc=new r("s_level2_arrow_left",yc,2,60,108,0,0,60,216,1);window.s_level2_arrow_left=Rc;Rc.c(0,0,705,1,60,108,0,0);Rc.c(1,0,769,1,60,108,0,0);var Sc=new r("s_level2_lock",yc,1,84,87,0,0,84,87,1);window.s_level2_lock=Sc;Sc.c(0,0,689,113,84,87,0,0);var Tc=new r("s_pop_medal",zc,8,378,378,189,189,3024,378,8);window.s_pop_medal=Tc;
Tc.c(0,0,633,1,349,241,3,69);Tc.c(1,0,633,529,346,267,5,54);Tc.c(2,0,633,249,348,276,20,56);Tc.c(3,1,353,1,342,288,26,50);Tc.c(4,1,697,1,319,292,22,46);Tc.c(5,1,1,313,337,304,14,41);Tc.c(6,1,1,1,343,305,12,41);Tc.c(7,1,353,297,341,304,13,41);var Uc=new r("s_medal_shadow",zc,1,195,208,0,0,195,208,1);window.s_medal_shadow=Uc;Uc.c(0,1,697,513,189,204,3,1);var Vc=new r("s_medal_shine",zc,6,195,208,0,0,1170,208,6);window.s_medal_shine=Vc;Vc.c(0,1,697,297,193,207,1,1);Vc.c(1,0,801,801,193,207,1,1);
Vc.c(2,0,1,737,193,207,1,1);Vc.c(3,0,601,801,193,207,1,1);Vc.c(4,0,201,737,193,207,1,1);Vc.c(5,0,401,737,193,207,1,1);var Wc=new r("s_icon_toggle_hard",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_hard=Wc;Wc.c(0,0,945,193,67,67,0,0);var Xc=new r("s_icon_toggle_medium",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_medium=Xc;Xc.c(0,0,945,337,67,67,0,0);var Yc=new r("s_icon_toggle_easy",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_easy=Yc;Yc.c(0,0,945,265,67,67,0,0);
var Zc=new r("s_flagIcon_us",O,1,48,48,0,0,48,48,1);window.s_flagIcon_us=Zc;Zc.c(0,0,825,769,48,36,0,6);var $c=new r("s_flagIcon_gb",O,1,48,48,0,0,48,48,1);window.s_flagIcon_gb=$c;$c.c(0,0,929,753,48,36,0,6);var ad=new r("s_flagIcon_nl",O,1,48,48,0,0,48,48,1);window.s_flagIcon_nl=ad;ad.c(0,0,521,737,48,36,0,6);var bd=new r("s_flagIcon_tr",O,1,48,48,0,0,48,48,1);window.s_flagIcon_tr=bd;bd.c(0,0,1,833,48,36,0,6);var cd=new r("s_flagIcon_de",O,1,48,48,0,0,48,48,1);window.s_flagIcon_de=cd;
cd.c(0,0,57,833,48,36,0,6);var dd=new r("s_flagIcon_fr",O,1,48,48,0,0,48,48,1);window.s_flagIcon_fr=dd;dd.c(0,0,281,833,48,36,0,6);var ed=new r("s_flagIcon_br",O,1,48,48,0,0,48,48,1);window.s_flagIcon_br=ed;ed.c(0,0,225,833,48,36,0,6);var fd=new r("s_flagIcon_es",O,1,48,48,0,0,48,48,1);window.s_flagIcon_es=fd;fd.c(0,0,337,833,48,36,0,6);var gd=new r("s_flagIcon_jp",O,1,48,48,0,0,48,48,1);window.s_flagIcon_jp=gd;gd.c(0,0,113,833,48,36,0,6);var hd=new r("s_flagIcon_ru",O,1,48,48,0,0,48,48,1);
window.s_flagIcon_ru=hd;hd.c(0,0,465,737,48,36,0,6);var id=new r("s_flagIcon_ar",O,1,48,48,0,0,48,48,1);window.s_flagIcon_ar=id;id.c(0,0,169,833,48,36,0,6);var jd=new r("s_flagIcon_kr",O,1,48,48,0,0,48,48,1);window.s_flagIcon_kr=jd;jd.c(0,0,929,793,48,36,0,6);var kd=new r("s_tutorialButton_close",O,1,66,65,0,0,66,65,1);window.s_tutorialButton_close=kd;kd.c(0,0,929,553,65,65,0,0);var ld=new r("s_tutorialButton_next",O,1,66,65,0,0,66,65,1);window.s_tutorialButton_next=ld;ld.c(0,0,929,481,66,65,0,0);
var md=new r("s_tutorialButton_previous",O,1,66,65,0,0,66,65,1);window.s_tutorialButton_previous=md;md.c(0,0,945,409,66,65,0,0);var nd=new r("s_logo_tinglygames",O,1,240,240,0,0,240,240,1);window.s_logo_tinglygames=nd;nd.c(0,0,593,177,240,240,0,0);var od=new r("s_logo_coolgames",O,1,240,240,0,0,240,240,1);window.s_logo_coolgames=od;od.c(0,0,593,1,240,167,0,36);var pd=new r("s_logo_tinglygames_start",xc,1,156,54,0,0,156,54,1);window.s_logo_tinglygames_start=pd;pd.c(0,0,521,1,156,53,0,0);
var qd=new r("s_logo_coolgames_start",xc,1,300,104,0,0,300,104,1);window.s_logo_coolgames_start=qd;qd.c(0,0,521,57,150,104,75,0);var rd=new r("s_ui_cup_highscore",P,1,32,28,0,0,32,28,1);window.s_ui_cup_highscore=rd;rd.c(0,0,649,89,32,28,0,0);var sd=new r("s_ui_cup_score",P,1,28,24,0,0,28,24,1);window.s_ui_cup_score=sd;sd.c(0,0,753,89,28,24,0,0);var td=new r("s_ui_endless_progress",P,1,408,12,0,0,408,12,1);window.s_ui_endless_progress=td;td.c(0,0,553,121,408,10,0,1);
var ud=new r("s_ui_endless_background",P,1,640,118,0,0,640,118,1);window.s_ui_endless_background=ud;ud.c(0,0,1,1,640,118,0,0);var vd=new r("s_ui_endless_progress_bonus",P,1,408,12,0,0,408,12,1);window.s_ui_endless_progress_bonus=vd;vd.c(0,0,1,129,408,10,0,1);var wd=new r("s_ui_heart",P,1,28,24,0,0,28,24,1);window.s_ui_heart=wd;wd.c(0,0,985,201,26,23,1,1);var xd=new r("s_ui_crown",P,1,24,20,0,0,24,20,1);window.s_ui_crown=xd;xd.c(0,0,785,97,24,20,0,0);
var yd=new r("s_ui_background_blank",Ac,1,640,118,0,0,640,118,1);window.s_ui_background_blank=yd;yd.c(0,1,1,1,640,117,0,0);var zd=new r("s_ui_highscore",Ac,1,26,36,13,12,26,36,1);window.s_ui_highscore=zd;zd.c(0,0,889,1,26,36,0,0);var Ad=new r("s_arrow_switch",Ac,1,234,42,6,11,234,42,1);window.s_arrow_switch=Ad;Ad.c(0,0,649,1,234,42,0,0);var Bd=new r("s_booster_bomb",P,1,50,50,25,25,50,50,1);window.s_booster_bomb=Bd;Bd.c(0,0,929,465,50,50,0,0);var Cd=new r("s_booster_fire",P,6,50,50,25,25,300,50,6);
window.s_booster_fire=Cd;Cd.c(0,0,705,385,50,50,0,0);Cd.c(1,0,913,409,50,50,0,0);Cd.c(2,0,969,409,50,50,0,0);Cd.c(3,0,913,57,50,50,0,0);Cd.c(4,0,705,441,50,50,0,0);Cd.c(5,0,817,449,50,50,0,0);var Dd=new r("s_booster_fire_trail",P,11,48,48,24,24,528,48,11);window.s_booster_fire_trail=Dd;Dd.c(0,0,353,337,48,46,0,1);Dd.c(1,0,705,553,48,48,0,0);Dd.c(2,0,873,577,46,46,0,1);Dd.c(3,0,921,577,44,44,2,2);Dd.c(4,0,761,585,42,42,3,3);Dd.c(5,0,985,1,38,38,5,5);Dd.c(6,0,985,41,36,36,6,6);
Dd.c(7,0,985,81,35,35,7,7);Dd.c(8,0,985,121,34,34,7,7);Dd.c(9,0,985,161,33,33,8,8);Dd.c(10,0,721,89,30,30,9,9);var Ed=new r("s_booster_white",P,1,50,50,25,25,50,50,1);window.s_booster_white=Ed;Ed.c(0,0,705,497,50,50,0,0);var Fd=new r("s_bubble_blocker",P,1,50,50,25,25,50,50,1);window.s_bubble_blocker=Fd;Fd.c(0,0,761,417,50,50,0,0);var Gd=new r("s_cannon",P,1,66,132,33,99,66,132,1);window.s_cannon=Gd;Gd.c(0,0,769,137,66,132,0,0);var Hd=new r("s_cannon_counter",P,1,154,80,120,34,154,80,1);
window.s_cannon_counter=Hd;Hd.c(0,0,649,1,154,80,0,0);var Id=new r("s_effect_star",P,1,47,46,23,24,47,46,1);window.s_effect_star=Id;Id.c(0,0,817,561,47,46,0,0);var Jd=new r("s_explosion",P,7,64,64,32,32,448,64,7);window.s_explosion=Jd;Jd.c(0,0,353,273,55,56,3,3);Jd.c(1,0,913,265,64,63,0,1);Jd.c(2,0,769,273,64,64,0,0);Jd.c(3,0,841,305,64,64,0,0);Jd.c(4,0,913,337,64,64,0,0);Jd.c(5,0,769,345,64,64,0,0);Jd.c(6,0,841,377,63,64,1,0);var Kd=new r("s_guideline",P,1,7,260,0,0,7,260,1);window.s_guideline=Kd;
Kd.c(0,0,969,1,7,259,0,1);var Ld=new r("s_guideline_pointer",P,1,21,21,10,10,21,21,1);window.s_guideline_pointer=Ld;Ld.c(0,0,817,97,21,21,0,0);var Md=new r("s_mistake",P,1,70,70,35,35,70,70,1);window.s_mistake=Md;Md.c(0,0,841,233,70,70,0,0);var Nd=new r("s_pop",P,5,64,64,32,32,320,64,5);window.s_pop=Nd;Nd.c(0,0,689,89,30,24,19,19);Nd.c(1,0,969,577,42,35,13,14);Nd.c(2,0,913,1,50,53,6,5);Nd.c(3,0,353,209,62,60,1,2);Nd.c(4,0,353,145,62,62,0,1);var Od=new r("s_tutorial_01",Bc,1,350,190,0,0,350,190,1);
window.s_tutorial_01=Od;Od.c(0,0,345,1,250,173,48,17);var Qd=new r("s_tutorial_02",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_02=Qd;Qd.c(0,0,1,129,250,173,48,17);var Rd=new r("s_tutorial_03",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_03=Rd;Rd.c(0,0,601,1,250,173,48,17);var Sd=new r("s_tutorial_04",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_04=Sd;Sd.c(0,0,1,1,340,126,0,37);var Td=new r("s_tutorial_05",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_05=Td;Td.c(0,0,857,113,93,93,129,49);
var Vd=new r("s_tutorial_06",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_06=Vd;Vd.c(0,0,857,1,119,109,117,42);var Wd=new r("s_tutorial_07",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_07=Wd;Wd.c(0,0,257,177,92,92,129,49);var Xd=new r("s_tutorial_08",Bc,1,350,190,0,0,350,190,1);window.s_tutorial_08=Xd;Xd.c(0,0,353,177,78,78,138,58);var Yd=new r("s_pop_floater",P,8,378,378,174,193,3024,378,8);window.s_pop_floater=Yd;Yd.c(0,0,417,137,349,241,3,69);Yd.c(1,0,353,385,346,267,5,54);
Yd.c(2,0,1,145,348,276,20,56);Yd.c(3,0,353,657,342,288,26,50);Yd.c(4,0,697,657,319,292,22,46);Yd.c(5,1,345,1,337,304,14,41);Yd.c(6,0,1,425,343,305,12,41);Yd.c(7,1,1,1,341,304,13,41);var Zd=new r("s_icon_toggle_sfx_on",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_sfx_on=Zd;Zd.c(0,0,929,713,49,31,7,17);var $d=new r("s_icon_toggle_sfx_off",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_sfx_off=$d;$d.c(0,0,929,625,53,31,7,17);var ae=new r("s_icon_toggle_music_on",O,1,67,67,0,0,67,67,1);
window.s_icon_toggle_music_on=ae;ae.c(0,0,985,625,38,41,13,16);var be=new r("s_icon_toggle_music_off",O,1,67,67,0,0,67,67,1);window.s_icon_toggle_music_off=be;be.c(0,0,929,665,51,41,8,16);var ce=new r("s_btn_small_exit",O,2,100,92,0,0,200,92,2);window.s_btn_small_exit=ce;ce.c(0,0,841,289,100,92,0,0);ce.c(1,0,841,193,100,92,0,0);var de=new r("s_btn_small_pause",P,2,100,92,0,0,200,92,2);window.s_btn_small_pause=de;de.c(0,0,809,1,100,92,0,0);de.c(1,0,841,137,100,92,0,0);
var ee=new r("s_btn_small_options",O,2,100,92,0,0,200,92,2);window.s_btn_small_options=ee;ee.c(0,0,841,385,100,92,0,0);ee.c(1,0,825,481,100,92,0,0);var fe=new r("s_btn_small_retry",zc,2,100,92,0,0,200,92,2);window.s_btn_small_retry=fe;fe.c(0,1,897,297,100,92,0,0);fe.c(1,1,897,393,100,92,0,0);var ge=new r("s_btn_standard",O,2,96,92,0,0,192,92,2);window.s_btn_standard=ge;ge.c(0,0,825,673,96,92,0,0);ge.c(1,0,825,577,96,92,0,0);var he=new r("s_btn_toggle",O,2,162,92,0,0,324,92,2);
window.s_btn_toggle=he;he.c(0,0,841,1,162,92,0,0);he.c(1,0,841,97,162,92,0,0);var ie=new r("s_icon_toggle_fxoff",O,2,227,92,0,0,454,92,2);window.s_icon_toggle_fxoff=ie;ie.c(0,0,697,809,227,92,0,0);ie.c(1,0,593,617,227,92,0,0);var je=new r("s_icon_toggle_fxon",O,2,227,92,0,0,454,92,2);window.s_icon_toggle_fxon=je;je.c(0,0,1,737,227,92,0,0);je.c(1,0,465,809,227,92,0,0);var ke=new r("s_icon_toggle_musicoff",O,2,227,92,0,0,454,92,2);window.s_icon_toggle_musicoff=ke;ke.c(0,0,233,737,227,92,0,0);
ke.c(1,0,593,713,227,92,0,0);var le=new r("s_icon_toggle_musicon",O,2,227,92,0,0,454,92,2);window.s_icon_toggle_musicon=le;le.c(0,0,593,425,227,92,0,0);le.c(1,0,593,521,227,92,0,0);var me=new r("s_btn_bigtext_landscape",Cc,1,274,104,0,0,274,104,1);window.s_btn_bigtext_landscape=me;me.c(0,0,1,1,274,104,0,0);var ne=new r("s_btn_small_hint",Cc,1,200,92,0,0,200,92,1);window.s_btn_small_hint=ne;ne.c(0,0,281,1,200,92,0,0);var oe=new r("s_btn_small_shuffle",Cc,1,200,92,0,0,200,92,1);
window.s_btn_small_shuffle=oe;oe.c(0,0,489,1,200,92,0,0);var pe=new r("s_btn_small_undo",Cc,1,200,92,0,0,200,92,1);window.s_btn_small_undo=pe;pe.c(0,0,697,1,200,92,0,0);var qe=new r("s_btn_big_start",zc,2,154,152,0,0,308,152,2);window.s_btn_big_start=qe;qe.c(0,1,161,625,154,152,0,0);qe.c(1,1,1,625,154,152,0,0);var re=new r("s_btn_bigtext",xc,2,151,152,0,0,302,152,2);window.s_btn_bigtext=re;re.c(0,0,841,1,151,152,0,0);re.c(1,0,681,1,151,152,0,0);
var se=new r("s_btn_big_restart",zc,2,154,152,0,0,308,152,2);window.s_btn_big_restart=se;se.c(0,1,345,609,154,152,0,0);se.c(1,1,505,609,154,152,0,0);var te=new r("s_overlay_assignment",Ac,1,593,608,0,0,593,608,1);window.s_overlay_assignment=te;te.c(0,1,1,121,515,608,78,0);var ue=new r("s_overlay_options",O,1,588,733,0,0,588,733,1);window.s_overlay_options=ue;ue.c(0,0,1,1,588,733,0,0);var ve=new r("s_screen_start",wc,1,640,960,0,0,640,960,1);window.s_screen_start=ve;ve.c(0,0,1,1,640,960,0,0);
var we=new r("s_tutorial",O,1,522,564,0,0,522,564,1);window.s_tutorial=we;we.c(0,1,1,1,522,564,0,0);var xe=new r("s_overlay_endless",zc,1,625,733,0,0,625,733,1);window.s_overlay_endless=xe;xe.c(0,0,1,1,625,733,0,0);var ye=new r("s_bubbles",P,6,50,50,25,25,300,50,6);window.s_bubbles=ye;ye.c(0,0,761,473,50,50,0,0);ye.c(1,0,761,529,50,50,0,0);ye.c(2,0,929,521,50,50,0,0);ye.c(3,0,817,505,50,50,0,0);ye.c(4,0,873,521,50,50,0,0);ye.c(5,0,873,465,50,50,0,0);var ze=new r("s_border",P,1,550,2,0,0,550,2,1);
window.s_border=ze;ze.c(0,0,1,121,550,2,0,0);var Ae=new r("s_background",Ac,1,640,960,0,0,640,960,1);window.s_background=Ae;Ae.c(0,0,1,1,640,960,0,0);var Be=new r("s_logo",xc,1,516,254,0,0,516,254,1);window.s_logo=Be;Be.c(0,0,1,1,516,254,0,0);var Ce=new xa("scoreFloater_neg");window.scoreFloater_neg=Ce;Ce.b=new r("scoreFloater_negImage",Dc,13,34,59,0,0);Ce.b.c(0,0,625,65,1,1,0,0,1,1,1);Ce.b.c(1,0,865,353,26,25,4,14,1,1,1);Ce.b.c(2,0,953,353,21,11,7,23,1,1,1);Ce.b.c(3,0,169,353,23,30,6,12,1,1,1);
Ce.b.c(4,0,1001,281,22,30,7,12,1,1,1);Ce.b.c(5,0,889,321,24,30,6,12,1,1,1);Ce.b.c(6,0,857,321,23,30,6,12,1,1,1);Ce.b.c(7,0,825,321,25,30,5,12,1,1,1);Ce.b.c(8,0,921,321,23,30,6,12,1,1,1);Ce.b.c(9,0,953,321,24,30,6,12,1,1,1);Ce.b.c(10,0,985,321,23,30,5,12,1,1,1);Ce.b.c(11,0,137,329,23,30,6,12,1,1,1);Ce.b.c(12,0,569,321,24,30,5,12,1,1,1);
Ce.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,1,-1,2,-1,-1,3,4,5,6,7,8,9,10,11,12,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
Ce.left=[12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,8,12,9,12,12,8,8,8,8,8,8,8,8,8,8,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,
12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12];
Ce.width=[10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,18,10,16,10,10,18,18,18,18,18,18,18,18,18,18,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10];Ce.top=8;Ce.height=43;Ce.ih=38;var De=new xa("scoreFloater_pos");window.scoreFloater_pos=De;De.b=new r("scoreFloater_posImage",Dc,13,34,59,0,0);De.b.c(0,0,65,65,1,1,0,0,1,1,1);De.b.c(1,0,897,353,26,25,4,14,1,1,1);
De.b.c(2,0,929,353,21,11,7,23,1,1,1);De.b.c(3,0,25,329,23,30,6,12,1,1,1);De.b.c(4,0,1,329,22,30,7,12,1,1,1);De.b.c(5,0,793,321,24,30,6,12,1,1,1);De.b.c(6,0,601,321,23,30,6,12,1,1,1);De.b.c(7,0,697,321,25,30,5,12,1,1,1);De.b.c(8,0,633,321,23,30,6,12,1,1,1);De.b.c(9,0,761,321,24,30,6,12,1,1,1);De.b.c(10,0,729,321,23,30,5,12,1,1,1);De.b.c(11,0,665,321,23,30,6,12,1,1,1);De.b.c(12,0,105,329,24,30,5,12,1,1,1);
De.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,1,-1,2,-1,-1,3,4,5,6,7,8,9,10,11,12,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
De.left=[12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,8,12,9,12,12,8,8,8,8,8,8,8,8,8,8,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,
12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12];
De.width=[10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,18,10,16,10,10,18,18,18,18,18,18,18,18,18,18,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10];De.top=8;De.height=43;De.ih=38;var Q=new xa("VerdanaFloater1");window.VerdanaFloater1=Q;Q.b=new r("VerdanaFloater1Image",Dc,59,44,46,0,0);Q.b.c(0,0,617,57,1,1,0,0,1,1,1);Q.b.c(1,0,681,353,17,30,12,11,1,1,1);
Q.b.c(2,0,529,321,31,30,4,11,1,1,1);Q.b.c(3,0,649,353,28,30,6,11,1,1,1);Q.b.c(4,0,801,353,28,30,6,11,1,1,1);Q.b.c(5,0,737,353,30,30,5,11,1,1,1);Q.b.c(6,0,265,353,25,30,7,11,1,1,1);Q.b.c(7,0,361,353,25,30,8,11,1,1,1);Q.b.c(8,0,705,353,29,30,5,11,1,1,1);Q.b.c(9,0,201,353,29,30,5,11,1,1,1);Q.b.c(10,0,553,353,23,30,9,11,1,1,1);Q.b.c(11,0,833,353,23,30,8,11,1,1,1);Q.b.c(12,0,393,353,29,30,6,11,1,1,1);Q.b.c(13,0,457,353,26,30,8,11,1,1,1);Q.b.c(14,0,249,321,32,30,4,11,1,1,1);
Q.b.c(15,0,521,353,29,30,5,11,1,1,1);Q.b.c(16,0,489,321,31,30,4,11,1,1,1);Q.b.c(17,0,425,353,27,30,7,11,1,1,1);Q.b.c(18,0,177,281,31,35,4,11,1,1,1);Q.b.c(19,0,297,353,30,30,6,11,1,1,1);Q.b.c(20,0,233,353,28,30,6,11,1,1,1);Q.b.c(21,0,489,353,29,30,5,11,1,1,1);Q.b.c(22,0,585,353,28,30,6,11,1,1,1);Q.b.c(23,0,289,321,31,30,4,11,1,1,1);Q.b.c(24,0,217,201,38,30,1,11,1,1,1);Q.b.c(25,0,361,321,31,30,4,11,1,1,1);Q.b.c(26,0,401,321,31,30,5,11,1,1,1);Q.b.c(27,0,769,353,28,30,6,11,1,1,1);
Q.b.c(28,0,1,209,31,37,4,4,1,1,1);Q.b.c(29,0,897,201,31,37,4,4,1,1,1);Q.b.c(30,0,625,241,31,36,4,5,1,1,1);Q.b.c(31,0,665,241,31,36,4,5,1,1,1);Q.b.c(32,0,249,281,31,35,4,6,1,1,1);Q.b.c(33,0,321,281,31,35,4,6,1,1,1);Q.b.c(34,0,457,201,37,30,0,11,1,1,1);Q.b.c(35,0,113,249,28,35,6,11,1,1,1);Q.b.c(36,0,425,201,25,37,7,4,1,1,1);Q.b.c(37,0,529,201,25,37,7,4,1,1,1);Q.b.c(38,0,497,201,25,37,7,4,1,1,1);Q.b.c(39,0,145,249,25,35,7,6,1,1,1);Q.b.c(40,0,393,201,23,37,9,4,1,1,1);
Q.b.c(41,0,297,201,23,37,9,4,1,1,1);Q.b.c(42,0,601,201,23,37,9,4,1,1,1);Q.b.c(43,0,457,273,23,35,9,6,1,1,1);Q.b.c(44,0,169,321,32,30,3,11,1,1,1);Q.b.c(45,0,705,241,29,36,5,5,1,1,1);Q.b.c(46,0,561,201,31,37,4,4,1,1,1);Q.b.c(47,0,817,201,31,37,4,4,1,1,1);Q.b.c(48,0,857,201,31,37,4,4,1,1,1);Q.b.c(49,0,801,241,31,36,4,5,1,1,1);Q.b.c(50,0,65,281,31,35,4,6,1,1,1);Q.b.c(51,0,65,321,31,33,4,10,1,1,1);Q.b.c(52,0,785,201,28,37,6,4,1,1,1);Q.b.c(53,0,753,201,28,37,6,4,1,1,1);
Q.b.c(54,0,721,201,28,37,6,4,1,1,1);Q.b.c(55,0,217,273,28,35,6,6,1,1,1);Q.b.c(56,0,681,201,31,37,5,4,1,1,1);Q.b.c(57,0,617,353,27,30,7,11,1,1,1);Q.b.c(58,0,329,321,27,31,7,10,1,1,1);
Q.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,-1,51,52,53,54,55,56,57,58,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
Q.left=[18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,12,12,13,11,13,14,12,11,15,15,12,14,10,11,11,13,11,12,13,13,12,12,8,12,13,13,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,
18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,12,12,12,12,12,12,8,13,13,13,13,13,15,15,15,15,11,11,11,11,11,11,11,18,11,12,12,12,12,13,13,13,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18];
Q.width=[8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,10,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,19,19,18,21,17,16,20,21,13,14,19,16,24,21,21,18,21,19,17,17,20,19,28,19,18,17,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,19,19,19,19,19,19,27,18,17,17,17,17,13,13,13,13,21,21,21,21,21,21,21,8,21,20,20,20,
20,18,18,18,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8];Q.top=8;Q.height=30;Q.ih=33;var R=new xa("VerdanaFloater2");window.VerdanaFloater2=R;R.b=new r("VerdanaFloater2Image",Dc,59,45,48,0,0);R.b.c(0,0,617,65,1,1,0,0,1,1,1);R.b.c(1,0,1009,41,13,34,16,10,1,1,1);R.b.c(2,0,489,281,30,34,8,10,1,1,1);R.b.c(3,0,737,281,25,34,11,10,1,1,1);R.b.c(4,0,681,281,26,34,9,10,1,1,1);R.b.c(5,0,769,281,27,34,10,10,1,1,1);R.b.c(6,0,833,281,22,34,12,10,1,1,1);R.b.c(7,0,881,281,22,34,12,10,1,1,1);
R.b.c(8,0,937,281,28,34,8,10,1,1,1);R.b.c(9,0,905,281,25,34,10,10,1,1,1);R.b.c(10,0,857,281,19,34,13,10,1,1,1);R.b.c(11,0,713,281,21,34,12,10,1,1,1);R.b.c(12,0,425,281,27,34,11,10,1,1,1);R.b.c(13,0,1001,241,22,34,13,10,1,1,1);R.b.c(14,0,361,281,29,34,8,10,1,1,1);R.b.c(15,0,393,281,26,34,10,10,1,1,1);R.b.c(16,0,553,281,30,34,8,10,1,1,1);R.b.c(17,0,649,281,25,34,11,10,1,1,1);R.b.c(18,0,81,201,30,38,8,10,1,1,1);R.b.c(19,0,585,281,27,34,11,10,1,1,1);R.b.c(20,0,521,281,26,34,10,10,1,1,1);
R.b.c(21,0,617,281,25,34,10,10,1,1,1);R.b.c(22,0,801,281,27,34,9,10,1,1,1);R.b.c(23,0,217,313,29,34,8,10,1,1,1);R.b.c(24,0,257,201,38,34,4,10,1,1,1);R.b.c(25,0,1,289,29,34,8,10,1,1,1);R.b.c(26,0,969,281,29,34,8,10,1,1,1);R.b.c(27,0,105,289,25,34,10,10,1,1,1);R.b.c(28,0,769,105,30,41,8,3,1,1,1);R.b.c(29,0,457,105,30,41,8,3,1,1,1);R.b.c(30,0,481,57,30,44,8,0,1,1,1);R.b.c(31,0,225,153,30,40,8,4,1,1,1);R.b.c(32,0,193,153,30,40,8,4,1,1,1);R.b.c(33,0,161,153,30,40,8,4,1,1,1);
R.b.c(34,0,937,201,37,34,3,10,1,1,1);R.b.c(35,0,185,201,26,38,9,10,1,1,1);R.b.c(36,0,433,105,22,41,12,3,1,1,1);R.b.c(37,0,409,105,22,41,12,3,1,1,1);R.b.c(38,0,665,97,22,41,12,3,1,1,1);R.b.c(39,0,913,105,22,40,12,4,1,1,1);R.b.c(40,0,385,105,19,41,13,3,1,1,1);R.b.c(41,0,489,105,19,41,13,3,1,1,1);R.b.c(42,0,513,105,20,41,13,3,1,1,1);R.b.c(43,0,1001,105,19,40,13,4,1,1,1);R.b.c(44,0,33,289,29,34,8,10,1,1,1);R.b.c(45,0,937,105,26,40,10,4,1,1,1);R.b.c(46,0,569,105,30,41,8,3,1,1,1);
R.b.c(47,0,297,57,30,44,8,0,1,1,1);R.b.c(48,0,801,105,30,41,8,3,1,1,1);R.b.c(49,0,129,113,30,40,8,4,1,1,1);R.b.c(50,0,337,145,30,40,8,4,1,1,1);R.b.c(51,0,361,201,30,37,8,9,1,1,1);R.b.c(52,0,737,105,27,41,9,3,1,1,1);R.b.c(53,0,601,105,27,41,9,3,1,1,1);R.b.c(54,0,537,105,27,41,9,3,1,1,1);R.b.c(55,0,81,153,27,40,9,4,1,1,1);R.b.c(56,0,633,105,29,41,8,3,1,1,1);R.b.c(57,0,137,289,25,34,11,10,1,1,1);R.b.c(58,0,289,281,25,35,11,9,1,1,1);
R.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,-1,51,52,53,54,55,56,57,58,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
R.left=[18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,17,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,12,12,12,11,13,13,11,11,15,15,12,14,9,11,11,12,11,12,13,13,11,12,7,12,12,13,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,
18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,12,12,12,12,12,12,7,12,13,13,13,13,15,15,15,15,11,11,11,11,11,11,11,18,11,11,11,11,11,12,12,13,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18,18];
R.width=[9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,11,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,21,21,20,23,19,18,22,23,15,15,21,17,26,23,23,20,23,21,19,19,22,21,31,21,20,19,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,21,21,21,21,21,21,30,20,19,19,19,19,15,15,15,15,23,23,23,23,23,23,23,9,23,22,22,22,
22,20,20,19,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9,9];R.top=7;R.height=34;R.ih=35;var S=new xa("VerdanaFloater3");window.VerdanaFloater3=S;S.b=new r("VerdanaFloater3Image",Dc,60,48,51,0,0);S.b.c(0,0,625,57,1,1,0,0,1,1,1);S.b.c(1,0,1009,1,14,36,17,12,1,1,1);S.b.c(2,0,761,241,32,36,8,12,1,1,1);S.b.c(3,0,873,241,27,36,11,12,1,1,1);S.b.c(4,0,841,241,26,36,11,12,1,1,1);S.b.c(5,0,905,241,29,36,10,12,1,1,1);S.b.c(6,0,1,249,24,36,12,12,1,1,1);S.b.c(7,0,969,241,24,36,13,12,1,1,1);
S.b.c(8,0,937,241,29,36,9,12,1,1,1);S.b.c(9,0,33,249,28,36,10,12,1,1,1);S.b.c(10,0,737,241,22,36,14,12,1,1,1);S.b.c(11,0,641,153,21,36,12,12,1,1,1);S.b.c(12,0,249,241,29,36,11,12,1,1,1);S.b.c(13,0,281,241,24,36,13,12,1,1,1);S.b.c(14,0,73,241,31,36,8,12,1,1,1);S.b.c(15,0,113,209,28,36,10,12,1,1,1);S.b.c(16,0,457,233,30,36,9,12,1,1,1);S.b.c(17,0,217,233,27,36,12,12,1,1,1);S.b.c(18,0,297,153,30,39,9,12,1,1,1);S.b.c(19,0,41,209,29,36,11,12,1,1,1);S.b.c(20,0,185,241,27,36,11,12,1,1,1);
S.b.c(21,0,385,241,28,36,10,12,1,1,1);S.b.c(22,0,553,241,27,36,10,12,1,1,1);S.b.c(23,0,585,241,32,36,8,12,1,1,1);S.b.c(24,0,337,105,41,36,4,12,1,1,1);S.b.c(25,0,313,241,32,36,8,12,1,1,1);S.b.c(26,0,489,241,30,36,10,12,1,1,1);S.b.c(27,0,521,241,27,36,10,12,1,1,1);S.b.c(28,0,513,57,32,44,8,4,1,1,1);S.b.c(29,0,409,57,32,44,8,4,1,1,1);S.b.c(30,0,809,1,32,48,8,0,1,1,1);S.b.c(31,0,1,65,32,43,8,5,1,1,1);S.b.c(32,0,257,105,32,42,8,6,1,1,1);S.b.c(33,0,297,105,32,42,8,6,1,1,1);
S.b.c(34,0,81,113,40,36,3,12,1,1,1);S.b.c(35,0,489,153,26,39,11,12,1,1,1);S.b.c(36,0,553,57,24,44,12,4,1,1,1);S.b.c(37,0,449,57,24,44,12,4,1,1,1);S.b.c(38,0,353,57,24,44,12,4,1,1,1);S.b.c(39,0,161,105,24,42,12,6,1,1,1);S.b.c(40,0,665,49,22,44,14,4,1,1,1);S.b.c(41,0,329,57,22,44,14,4,1,1,1);S.b.c(42,0,385,57,22,44,14,4,1,1,1);S.b.c(43,0,41,65,22,42,14,6,1,1,1);S.b.c(44,0,417,241,31,36,8,12,1,1,1);S.b.c(45,0,945,57,28,43,10,5,1,1,1);S.b.c(46,0,585,57,30,44,9,4,1,1,1);
S.b.c(47,0,633,49,30,48,9,0,1,1,1);S.b.c(48,0,833,57,30,44,9,4,1,1,1);S.b.c(49,0,977,57,30,43,9,5,1,1,1);S.b.c(50,0,225,105,30,42,9,6,1,1,1);S.b.c(51,0,457,313,27,32,11,15,1,1,1);S.b.c(52,0,969,105,30,40,9,10,1,1,1);S.b.c(53,0,737,57,27,44,10,4,1,1,1);S.b.c(54,0,865,57,27,44,10,4,1,1,1);S.b.c(55,0,769,57,27,44,10,4,1,1,1);S.b.c(56,0,193,105,27,42,10,6,1,1,1);S.b.c(57,0,801,57,30,44,10,4,1,1,1);S.b.c(58,0,353,241,27,36,12,12,1,1,1);S.b.c(59,0,977,201,26,37,12,11,1,1,1);
S.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,56,57,58,59,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
S.left=[19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,18,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,12,12,13,11,13,14,11,11,16,15,12,14,9,11,11,13,11,12,13,13,11,12,7,12,13,13,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,
19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,12,12,12,12,12,12,7,13,13,13,13,13,16,16,16,16,11,11,11,11,11,11,11,11,11,11,11,11,11,13,13,13,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19,19];
S.width=[10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,12,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,24,23,22,25,21,20,25,25,16,17,23,19,29,26,26,22,26,24,22,21,25,23,34,23,22,21,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,
10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,24,24,24,24,24,24,33,22,21,21,21,21,16,16,16,16,25,26,26,26,26,26,26,26,26,25,25,25,25,22,22,22,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10,10];S.top=7;S.height=37;S.ih=38;var T=new xa("VerdanaFloater4");window.VerdanaFloater4=T;T.b=new r("VerdanaFloater4Image",Dc,59,58,61,0,0);T.b.c(0,0,73,65,1,1,0,0,1,1,1);T.b.c(1,0,665,145,21,39,19,16,1,1,1);
T.b.c(2,0,561,153,36,39,9,16,1,1,1);T.b.c(3,0,521,153,33,39,12,16,1,1,1);T.b.c(4,0,873,105,34,40,14,15,1,1,1);T.b.c(5,0,369,153,36,39,11,16,1,1,1);T.b.c(6,0,449,153,33,39,14,16,1,1,1);T.b.c(7,0,409,153,32,39,14,16,1,1,1);T.b.c(8,0,257,153,35,40,12,15,1,1,1);T.b.c(9,0,601,153,38,39,11,16,1,1,1);T.b.c(10,0,329,193,30,39,14,16,1,1,1);T.b.c(11,0,41,161,31,39,13,16,1,1,1);T.b.c(12,0,145,201,38,39,12,16,1,1,1);T.b.c(13,0,113,161,28,39,15,16,1,1,1);T.b.c(14,0,897,57,43,39,9,16,1,1,1);
T.b.c(15,0,641,193,38,39,11,16,1,1,1);T.b.c(16,0,1,113,36,40,12,15,1,1,1);T.b.c(17,0,969,153,34,39,13,16,1,1,1);T.b.c(18,0,257,57,36,46,12,15,1,1,1);T.b.c(19,0,889,153,34,39,12,16,1,1,1);T.b.c(20,0,41,113,35,40,12,15,1,1,1);T.b.c(21,0,769,153,33,39,16,16,1,1,1);T.b.c(22,0,729,153,35,39,13,16,1,1,1);T.b.c(23,0,849,153,35,39,15,16,1,1,1);T.b.c(24,0,161,57,47,39,10,16,1,1,1);T.b.c(25,0,689,105,41,39,9,16,1,1,1);T.b.c(26,0,929,153,34,39,16,16,1,1,1);T.b.c(27,0,809,153,36,39,12,16,1,1,1);
T.b.c(28,0,553,1,36,50,9,5,1,1,1);T.b.c(29,0,593,1,36,50,9,5,1,1,1);T.b.c(30,0,41,1,36,55,9,0,1,1,1);T.b.c(31,0,689,1,37,49,9,6,1,1,1);T.b.c(32,0,849,1,36,48,9,7,1,1,1);T.b.c(33,0,121,57,36,47,9,8,1,1,1);T.b.c(34,0,633,1,50,39,3,16,1,1,1);T.b.c(35,0,217,57,34,46,14,15,1,1,1);T.b.c(36,0,313,1,33,50,14,5,1,1,1);T.b.c(37,0,241,1,33,50,14,5,1,1,1);T.b.c(38,0,353,1,33,50,14,5,1,1,1);T.b.c(39,0,969,1,33,48,14,7,1,1,1);T.b.c(40,0,281,1,30,50,14,5,1,1,1);T.b.c(41,0,201,1,31,50,14,5,1,1,1);
T.b.c(42,0,161,1,31,50,14,5,1,1,1);T.b.c(43,0,929,1,31,48,14,7,1,1,1);T.b.c(44,0,689,153,36,39,11,16,1,1,1);T.b.c(45,0,729,1,38,49,11,6,1,1,1);T.b.c(46,0,81,1,36,50,12,5,1,1,1);T.b.c(47,0,1,1,36,55,12,0,1,1,1);T.b.c(48,0,433,1,36,50,12,5,1,1,1);T.b.c(49,0,769,1,36,49,12,6,1,1,1);T.b.c(50,0,889,1,36,48,12,7,1,1,1);T.b.c(51,0,689,57,41,44,9,13,1,1,1);T.b.c(52,0,473,1,35,50,13,5,1,1,1);T.b.c(53,0,393,1,35,50,13,5,1,1,1);T.b.c(54,0,513,1,35,50,13,5,1,1,1);T.b.c(55,0,81,57,35,48,13,7,1,1,1);
T.b.c(56,0,121,1,34,50,16,5,1,1,1);T.b.c(57,0,1,161,33,39,13,16,1,1,1);T.b.c(58,0,833,105,32,41,13,14,1,1,1);
T.index=[-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,0,1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,
-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,28,29,30,31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,46,47,48,49,50,-1,51,52,53,54,55,56,57,58,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1,-1];
T.left=[23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,22,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,15,15,16,14,17,17,14,14,19,19,15,18,12,14,14,16,14,15,16,17,14,15,9,15,16,17,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,
23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,15,15,15,15,15,15,9,16,17,17,17,17,19,19,19,19,14,14,14,14,14,14,14,23,14,14,14,14,14,16,16,16,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23,23];
T.width=[12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,14,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,27,27,26,29,24,23,29,30,19,19,27,22,34,30,30,26,30,28,25,24,29,27,40,27,26,24,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,
12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,27,27,27,27,27,27,39,26,24,24,24,24,19,19,19,19,29,30,30,30,30,30,30,12,30,29,29,29,29,26,26,25,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12,12];T.top=9;T.height=43;T.ih=45;var Ee=new za("f_default","fonts/f_default.woff","fonts/f_default.ttf","fonts");window.f_defaultLoader=Ee;var V=new Ca("f_default","Arial");window.f_default=V;D(V,12);V.fill=!0;V.setFillColor("Black");
V.Ta=1;Fa(V,!1);V.setStrokeColor("Black");Ga(V,1);Ia(V,"miter");V.Wa=1;Ha(V,!1);La(V,"left");Ma(V,"top");V.Qa=0;V.ka=0;var Fe=new za("ff_opensans_extrabold","fonts/ff_opensans_extrabold.woff","fonts/ff_opensans_extrabold.ttf","fonts");window.ff_opensans_extraboldLoader=Fe;var Ge=new za("ff_dimbo_regular","fonts/ff_dimbo_regular.woff","fonts/ff_dimbo_regular.ttf","fonts");window.ff_dimbo_regularLoader=Ge;var He=new za("floaterFontFace","fonts/floaterFontFace.woff","fonts/floaterFontFace.ttf","fonts");
window.floaterFontFaceLoader=He;var Ie=new za("floaterNumberFontFace","fonts/floaterNumberFontFace.woff","fonts/floaterNumberFontFace.ttf","fonts");window.floaterNumberFontFaceLoader=Ie;var Je=new Ca("floaterFontFace","Arial");window.floaterFontText1=Je;D(Je,24);Da(Je);Je.fill=!0;Je.setFillColor("#FFDE00");Je.Ta=1;Fa(Je,!0);Je.setStrokeColor("#6F1F00");Ga(Je,4);Ia(Je,"miter");Je.Wa=1;Ha(Je,!0);Ja(Je,!0,"rgba(57,0,0,0.46)",0,4,2);La(Je,"left");Ma(Je,"top");Je.Qa=0;Je.ka=0;
var Ke=new Ca("floaterFontFace","Arial");window.floaterFontText2=Ke;D(Ke,28);Da(Ke);Ke.fill=!0;Ea(Ke,2,["#FFF600","#00DB48","blue"],.65,.02);Ke.Ta=1;Fa(Ke,!0);Ke.setStrokeColor("#073400");Ga(Ke,4);Ia(Ke,"miter");Ke.Wa=1;Ha(Ke,!0);Ja(Ke,!0,"rgba(0,57,43,0.47)",0,4,2);La(Ke,"left");Ma(Ke,"top");Ke.Qa=0;Ke.ka=0;var Le=new Ca("floaterFontFace","Arial");window.floaterFontText3=Le;D(Le,30);Da(Le);Le.fill=!0;Ea(Le,3,["#FFF600","#FF8236","#FF0096"],.71,-.1);Le.Ta=1;Fa(Le,!0);Le.setStrokeColor("#4F0027");
Ga(Le,4);Ia(Le,"miter");Le.Wa=1;Ha(Le,!0);Ja(Le,!0,"rgba(41,0,0,0.48)",0,5,2);La(Le,"left");Ma(Le,"top");Le.Qa=0;Le.ka=0;var Me=new Ca("floaterFontFace","Arial");window.floaterFontText4=Me;D(Me,34);Da(Me);Me.fill=!0;Ea(Me,3,["#00FCFF","#893DFB","#FF00E4"],.72,-.04);Me.Ta=1;Fa(Me,!0);Me.setStrokeColor("#001637");Ga(Me,4);Ia(Me,"miter");Me.Wa=1;Ha(Me,!0);Ja(Me,!0,"rgba(0,35,75,0.49)",0,6,2);La(Me,"left");Ma(Me,"top");Me.Qa=0;Me.ka=0;var Ne=new Ca("floaterNumberFontFace","Arial");
window.floaterFontNumberPositive=Ne;D(Ne,30);Ne.fill=!0;Ne.setFillColor("White");Ne.Ta=1;Fa(Ne,!0);Ne.setStrokeColor("#00106F");Ga(Ne,2);Ia(Ne,"miter");Ne.Wa=1;Ha(Ne,!1);Ja(Ne,!0,"rgba(0,4,57,0.51)",0,4,2);La(Ne,"left");Ma(Ne,"top");Ne.Qa=0;Ne.ka=0;var Oe=new Ca("floaterNumberFontFace","Arial");window.floaterFontNumberNegative=Oe;D(Oe,30);Da(Oe);Oe.fill=!0;Oe.setFillColor("#FF1E00");Oe.Ta=1;Fa(Oe,!0);Oe.setStrokeColor("#3F0000");Ga(Oe,2);Ia(Oe,"miter");Oe.Wa=1;Ha(Oe,!1);
Ja(Oe,!0,"rgba(57,0,0,0.49)",0,4,2);La(Oe,"left");Ma(Oe,"top");Oe.Qa=0;Oe.ka=0;var Pe=new Ca("ff_opensans_bold","Arial");window.f_game_ui_tiny=Pe;D(Pe,11);Pe.fill=!0;Pe.setFillColor("#799EC5");Pe.Ta=1;Fa(Pe,!1);Pe.setStrokeColor("White");Ga(Pe,1);Ia(Pe,"miter");Pe.Wa=1;Ha(Pe,!1);La(Pe,"center");Ma(Pe,"middle");Pe.Qa=0;Pe.ka=0;var Qe=new Ca("ff_opensans_bold","Arial");window.f_game_ui=Qe;D(Qe,23);Qe.fill=!0;Qe.setFillColor("#799EC5");Qe.Ta=1;Fa(Qe,!1);Qe.setStrokeColor("Black");Ga(Qe,1);Ia(Qe,"miter");
Qe.Wa=1;Ha(Qe,!1);La(Qe,"center");Ma(Qe,"middle");Qe.Qa=0;Qe.ka=0;var Re=new Ca("ff_opensans_bolditalic","Arial");window.f_game_ui_large=Re;D(Re,52);Re.fill=!0;Re.setFillColor("#172348");Re.Ta=1;Fa(Re,!1);Re.setStrokeColor("Black");Ga(Re,1);Ia(Re,"miter");Re.Wa=1;Ha(Re,!1);La(Re,"center");Ma(Re,"middle");Re.Qa=0;Re.ka=0;var Se=new za("ff_opensans_bold","fonts/ff_opensans_bold.woff","fonts/ff_opensans_bold.ttf","fonts");window.ff_opensans_boldLoader=Se;
var Te=new za("ff_opensans_bolditalic","fonts/ff_opensans_bolditalic.woff","fonts/ff_opensans_bolditalic.ttf","fonts");window.ff_opensans_bolditalicLoader=Te;var Ue=new Ca("ff_opensans_bold","Arial");window.f_announcement=Ue;D(Ue,70);Ue.fill=!0;Ue.setFillColor("White");Ue.Ta=1;Fa(Ue,!0);Ue.setStrokeColor("#2C2C2C");Ga(Ue,6);Ia(Ue,"miter");Ue.Wa=1;Ha(Ue,!0);Ja(Ue,!0,"rgba(0,0,0,0.53)",0,5,2);La(Ue,"center");Ma(Ue,"top");Ue.Qa=0;Ue.ka=0;var Ve=new Ca("ff_opensans_bold","Arial");
window.f_bubble_points=Ve;D(Ve,30);Ve.fill=!0;Ea(Ve,2,["White","#DFDFDF","blue"],.6,0);Ve.Ta=1;Fa(Ve,!0);Ve.setStrokeColor("#454545");Ga(Ve,6);Ia(Ve,"round");Ve.Wa=1;Ha(Ve,!0);La(Ve,"left");Ma(Ve,"top");Ve.Qa=0;Ve.ka=0;var We=new Ca("ff_opensans_bold","Arial");window.f_bubbles_left=We;D(We,30);We.fill=!0;We.setFillColor("#4E4E4E");We.Ta=1;Fa(We,!1);We.setStrokeColor("Black");Ga(We,1);Ia(We,"miter");We.Wa=1;Ha(We,!1);La(We,"center");Ma(We,"middle");We.Qa=0;We.ka=0;
var Xe=new Ca("ff_opensans_bold","Arial");window.f_special_points=Xe;D(Xe,40);Xe.fill=!0;Ea(Xe,2,["Yellow","#FF8040","Red"],.6,0);Xe.Ta=1;Fa(Xe,!0);Xe.setStrokeColor("#454545");Ga(Xe,6);Ia(Xe,"round");Xe.Wa=1;Ha(Xe,!0);La(Xe,"left");Ma(Xe,"top");Xe.Qa=0;Xe.ka=0;var Ye=new Ca("ff_opensans_bold","Arial");window.f_switch=Ye;D(Ye,16);Ye.fill=!0;Ye.setFillColor("#818181");Ye.Ta=1;Fa(Ye,!1);Ye.setStrokeColor("#454545");Ga(Ye,1);Ia(Ye,"miter");Ye.Wa=1;Ha(Ye,!1);La(Ye,"left");Ma(Ye,"top");Ye.Qa=0;Ye.ka=0;
var Ze=new Ca("ff_opensans_bolditalic","Arial");window.f_nice=Ze;D(Ze,70);Da(Ze);Ze.fill=!0;Ea(Ze,2,["#FFF600","#00DB48","blue"],.65,.02);Ze.Ta=1;Fa(Ze,!0);Ze.setStrokeColor("#073400");Ga(Ze,7);Ia(Ze,"round");Ze.Wa=1;Ha(Ze,!0);Ja(Ze,!0,"rgba(0,57,43,0.47)",0,4,2);La(Ze,"left");Ma(Ze,"top");Ze.Qa=0;Ze.ka=0;var $e=new Ca("ff_opensans_bolditalic","Arial");window.f_great=$e;D($e,75);Da($e);$e.fill=!0;Ea($e,3,["#FFF600","#FF8236","#FF0096"],.71,-.1);$e.Ta=1;Fa($e,!0);$e.setStrokeColor("#4F0027");
Ga($e,7);Ia($e,"round");$e.Wa=1;Ha($e,!0);Ja($e,!0,"rgba(41,0,0,0.48)",0,5,2);La($e,"left");Ma($e,"top");$e.Qa=0;$e.ka=0;var af=new Ca("ff_opensans_bolditalic","Arial");window.f_awesome=af;D(af,90);Da(af);af.fill=!0;Ea(af,3,["#00FCFF","#893DFB","#FF00E4"],.72,-.04);af.Ta=1;Fa(af,!0);af.setStrokeColor("#001637");Ga(af,8);Ia(af,"round");af.Wa=1;Ha(af,!0);Ja(af,!0,"rgba(0,35,75,0.49)",0,6,2);La(af,"left");Ma(af,"top");af.Qa=0;af.ka=0;
var bf=new za("f_themeDefault","fonts/f_themeDefault.woff","fonts/f_themeDefault.ttf","fonts");window.f_themeDefaultLoader=bf;var cf=new Ca("f_themeDefault","Arial");window.f_themeDefault=cf;D(cf,64);cf.fill=!0;cf.setFillColor("Black");cf.Ta=1;Fa(cf,!1);cf.setStrokeColor("White");Ga(cf,5);Ia(cf,"miter");cf.Wa=1;Ha(cf,!0);La(cf,"left");Ma(cf,"top");cf.Qa=0;cf.ka=0;var df=new qb("as_music","audio/as_music.mp3","audio/as_music.ogg","audio_music");window.as_music=df;
var W=new qb("audioSprite","audio/audioSprite.mp3","audio/audioSprite.ogg","audio");window.audioSprite=W;var ef=new F("a_music",df,0,36571,1,1,["music"]);window.a_music=ef;var ff=new F("a_bigPop",W,0,1328,1,10,["game"]);window.a_bigPop=ff;var gf=new F("a_bomb",W,3E3,1247,1,10,["game"]);window.a_bomb=gf;var hf=new F("a_colorBomb",W,6E3,871,1,10,["game"]);window.a_colorBomb=hf;var jf=new F("a_combo_01",W,8E3,598,1,10,["game"]);window.a_combo_01=jf;var kf=new F("a_combo_02",W,1E4,678,1,10,["game"]);
window.a_combo_02=kf;var lf=new F("a_combo_03",W,12E3,730,1,10,["game"]);window.a_combo_03=lf;var mf=new F("a_combo_04",W,14E3,1225,1,10,["game"]);window.a_combo_04=mf;var nf=new F("a_fireBallNext",W,17E3,1107,1,10,["game"]);window.a_fireBallNext=nf;var of=new F("a_fireBallShoot",W,2E4,968,1,10,["game"]);window.a_fireBallShoot=of;var pf=new F("a_glassNext",W,22E3,519,1,10,["game"]);window.a_glassNext=pf;var qf=new F("a_hit",W,24E3,54,1,10,["game"]);window.a_hit=qf;
var rf=new F("a_pop_01",W,26E3,145,1,10,["game"]);window.a_pop_01=rf;var sf=new F("a_pop_02",W,28E3,140,1,10,["game"]);window.a_pop_02=sf;var tf=new F("a_pop_03",W,3E4,164,1,10,["game"]);window.a_pop_03=tf;var uf=new F("a_pop_04",W,32E3,163,1,10,["game"]);window.a_pop_04=uf;var vf=new F("a_pop_05",W,34E3,149,1,10,["game"]);window.a_pop_05=vf;var wf=new F("a_pop_06",W,36E3,103,1,10,["game"]);window.a_pop_06=wf;var xf=new F("a_shoot",W,38E3,198,1,10,["game"]);window.a_shoot=xf;
var yf=new F("a_swap",W,4E4,285,.5,10,["game"]);window.a_swap=yf;var zf=new F("a_floater_popup",W,42E3,306,1,10,["game"]);window.a_floater_popup=zf;var Af=new F("a_levelStart",W,44E3,1002,1,10,["sfx"]);window.a_levelStart=Af;var Bf=new F("a_levelComplete",W,47E3,1002,1,10,["sfx"]);window.a_levelComplete=Bf;var Cf=new F("a_mouseDown",W,5E4,471,1,10,["sfx"]);window.a_mouseDown=Cf;var Df=new F("a_levelend_star_01",W,52E3,1161,1,10,["sfx"]);window.a_levelend_star_01=Df;
var Ff=new F("a_levelend_star_02",W,55E3,1070,1,10,["sfx"]);window.a_levelend_star_02=Ff;var Gf=new F("a_levelend_star_03",W,58E3,1039,1,10,["sfx"]);window.a_levelend_star_03=Gf;var Hf=new F("a_levelend_fail",W,61E3,1572,1,10,["sfx"]);window.a_levelend_fail=Hf;var If=new F("a_levelend_score_counter",W,64E3,54,1,10,["sfx"]);window.a_levelend_score_counter=If;var Jf=new F("a_levelend_score_end",W,66E3,888,1,10,["sfx"]);window.a_levelend_score_end=Jf;var Kf=new F("a_medal",W,68E3,1225,1,10,["sfx"]);
window.a_medal=Kf;N=N||{};N["nl-nl"]=N["nl-nl"]||{};N["nl-nl"].loadingScreenLoading="Laden...";N["nl-nl"].startScreenPlay="SPELEN";N["nl-nl"].levelMapScreenTotalScore="Totale score";N["nl-nl"].levelEndScreenTitle_level="Level <VALUE>";N["nl-nl"].levelEndScreenTitle_difficulty="Goed Gedaan!";N["nl-nl"].levelEndScreenTitle_endless="Level <VALUE>";N["nl-nl"].levelEndScreenTotalScore="Totale score";N["nl-nl"].levelEndScreenSubTitle_levelFailed="Level niet gehaald";N["nl-nl"].levelEndScreenTimeLeft="Tijd over";
N["nl-nl"].levelEndScreenTimeBonus="Tijdbonus";N["nl-nl"].levelEndScreenHighScore="High score";N["nl-nl"].optionsStartScreen="Hoofdmenu";N["nl-nl"].optionsQuit="Stop";N["nl-nl"].optionsResume="Terug naar spel";N["nl-nl"].optionsTutorial="Speluitleg";N["nl-nl"].optionsHighScore="High scores";N["nl-nl"].optionsMoreGames="Meer Spellen";N["nl-nl"].optionsDifficulty_easy="Makkelijk";N["nl-nl"].optionsDifficulty_medium="Gemiddeld";N["nl-nl"].optionsDifficulty_hard="Moeilijk";
N["nl-nl"].optionsMusic_on="Aan";N["nl-nl"].optionsMusic_off="Uit";N["nl-nl"].optionsSFX_on="Aan";N["nl-nl"].optionsSFX_off="Uit";N["nl-nl"]["optionsLang_en-us"]="Engels (US)";N["nl-nl"]["optionsLang_en-gb"]="Engels (GB)";N["nl-nl"]["optionsLang_nl-nl"]="Nederlands";N["nl-nl"].gameEndScreenTitle="Gefeliciteerd!\nJe hebt gewonnen.";N["nl-nl"].gameEndScreenBtnText="Ga verder";N["nl-nl"].optionsTitle="Instellingen";N["nl-nl"].optionsQuitConfirmationText="Pas op!\n\nAls je nu stopt verlies je alle voortgang in dit level. Weet je zeker dat je wilt stoppen?";
N["nl-nl"].optionsQuitConfirmBtn_No="Nee";N["nl-nl"].optionsQuitConfirmBtn_Yes="Ja, ik weet het zeker";N["nl-nl"].levelMapScreenTitle="Kies een level";N["nl-nl"].optionsRestartConfirmationText="Pas op!\n\nAls je nu herstart verlies je alle voortgang in dit level. Weet je zeker dat je wilt herstarten?";N["nl-nl"].optionsRestart="Herstart";N["nl-nl"].optionsSFXBig_on="Geluid aan";N["nl-nl"].optionsSFXBig_off="Geluid uit";N["nl-nl"].optionsAbout_title="Over ons";N["nl-nl"].optionsAbout_text="CoolGames\nwww.coolgames.com\nCopyright \u00a9 2016";
N["nl-nl"].optionsAbout_backBtn="Terug";N["nl-nl"].optionsAbout_version="versie:";N["nl-nl"].optionsAbout="Over ons";N["nl-nl"].levelEndScreenMedal="VERBETERD!";N["nl-nl"].startScreenQuestionaire="Wat vind jij?";N["nl-nl"].levelMapScreenWorld_0="Kies een level";N["nl-nl"].startScreenByTinglyGames="door: CoolGames";N["nl-nl"]["optionsLang_de-de"]="Duits";N["nl-nl"]["optionsLang_tr-tr"]="Turks";N["nl-nl"].optionsAbout_header="Ontwikkeld door:";N["nl-nl"].levelEndScreenViewHighscoreBtn="Scores bekijken";
N["nl-nl"].levelEndScreenSubmitHighscoreBtn="Score verzenden";N["nl-nl"].challengeStartScreenTitle_challengee_friend="Je bent uitgedaagd door:";N["nl-nl"].challengeStartTextScore="Punten van <NAME>:";N["nl-nl"].challengeStartTextTime="Tijd van <NAME>:";N["nl-nl"].challengeStartScreenToWin="Te winnen aantal Fairplay munten:";N["nl-nl"].challengeEndScreenWinnings="Je hebt <AMOUNT> Fairplay munten gewonnen!";N["nl-nl"].challengeEndScreenOutcomeMessage_WON="Je hebt de uitdaging gewonnen!";
N["nl-nl"].challengeEndScreenOutcomeMessage_LOST="Je hebt de uitdaging verloren.";N["nl-nl"].challengeEndScreenOutcomeMessage_TIED="Jullie hebben gelijk gespeeld.";N["nl-nl"].challengeCancelConfirmText="Je staat op het punt de uitdaging te annuleren. Je inzet wordt teruggestort minus de uitdagingskosten. Weet je zeker dat je de uitdaging wilt annuleren? ";N["nl-nl"].challengeCancelConfirmBtn_yes="Ja";N["nl-nl"].challengeCancelConfirmBtn_no="Nee";N["nl-nl"].challengeEndScreensBtn_submit="Verstuur uitdaging";
N["nl-nl"].challengeEndScreenBtn_cancel="Annuleer uitdaging";N["nl-nl"].challengeEndScreenName_you="Jij";N["nl-nl"].challengeEndScreenChallengeSend_error="Er is een fout opgetreden bij het versturen van de uitdaging. Probeer het later nog een keer.";N["nl-nl"].challengeEndScreenChallengeSend_success="Je uitdaging is verstuurd!";N["nl-nl"].challengeCancelMessage_error="Er is een fout opgetreden bij het annuleren van de uitdaging. Probeer het later nog een keer.";
N["nl-nl"].challengeCancelMessage_success="De uitdaging is geannuleerd.";N["nl-nl"].challengeEndScreenScoreSend_error="Er is een fout opgetreden tijdens de communicatie met de server. Probeer het later nog een keer.";N["nl-nl"].challengeStartScreenTitle_challengee_stranger="Jouw tegenstander:";N["nl-nl"].challengeStartScreenTitle_challenger_friend="Jouw tegenstander:";N["nl-nl"].challengeStartScreenTitle_challenger_stranger="Je zet een uitdaging voor:";
N["nl-nl"].challengeStartTextTime_challenger="Speel het spel en zet een tijd neer.";N["nl-nl"].challengeStartTextScore_challenger="Speel het spel en zet een score neer.";N["nl-nl"].challengeForfeitConfirmText="Je staat op het punt de uitdaging op te geven. Weet je zeker dat je dit wilt doen?";N["nl-nl"].challengeForfeitConfirmBtn_yes="Ja";N["nl-nl"].challengeForfeitConfirmBtn_no="Nee";N["nl-nl"].challengeForfeitMessage_success="Je hebt de uitdaging opgegeven.";
N["nl-nl"].challengeForfeitMessage_error="Er is een fout opgetreden tijdens het opgeven van de uitdaging. Probeer het later nog een keer.";N["nl-nl"].optionsChallengeForfeit="Geef op";N["nl-nl"].optionsChallengeCancel="Stop";N["nl-nl"].challengeLoadingError_notValid="Sorry, deze uitdaging kan niet meer gespeeld worden.";N["nl-nl"].challengeLoadingError_notStarted="Kan de server niet bereiken. Probeer het later nog een keer.";N["nl-nl"].levelEndScreenHighScore_time="Beste tijd:";
N["nl-nl"].levelEndScreenTotalScore_time="Totale tijd:";N["nl-nl"]["optionsLang_fr-fr"]="Frans";N["nl-nl"]["optionsLang_ko-kr"]="Koreaans";N["nl-nl"]["optionsLang_ar-eg"]="Arabisch";N["nl-nl"]["optionsLang_es-es"]="Spaans";N["nl-nl"]["optionsLang_pt-br"]="Braziliaans-Portugees";N["nl-nl"]["optionsLang_ru-ru"]="Russisch";N["nl-nl"].optionsExit="Stoppen";N["nl-nl"].levelEndScreenTotalScore_number="Totale score:";N["nl-nl"].levelEndScreenHighScore_number="Topscore:";
N["nl-nl"].challengeEndScreenChallengeSend_submessage="<NAME> heeft 72 uur om de uitdaging aan te nemen of te weigeren. Als <NAME> je uitdaging weigert of niet accepteert binnen 72 uur worden je inzet en uitdagingskosten teruggestort.";N["nl-nl"].challengeEndScreenChallengeSend_submessage_stranger="Als niemand binnen 72 uur je uitdaging accepteert, worden je inzet en uitdagingskosten teruggestort.";N["nl-nl"].challengeForfeitMessage_winnings="<NAME> heeft <AMOUNT> Fairplay munten gewonnen!";
N["nl-nl"].optionsAbout_header_publisher="Published by:";N["nl-nl"]["optionsLang_jp-jp"]="Japans";N["en-us"]=N["en-us"]||{};N["en-us"].loadingScreenLoading="Loading...";N["en-us"].startScreenPlay="PLAY";N["en-us"].levelMapScreenTotalScore="Total score";N["en-us"].levelEndScreenTitle_level="Level <VALUE>";N["en-us"].levelEndScreenTitle_difficulty="Well done!";N["en-us"].levelEndScreenTitle_endless="Stage <VALUE>";N["en-us"].levelEndScreenTotalScore="Total score";
N["en-us"].levelEndScreenSubTitle_levelFailed="Level failed";N["en-us"].levelEndScreenTimeLeft="Time remaining";N["en-us"].levelEndScreenTimeBonus="Time bonus";N["en-us"].levelEndScreenHighScore="High score";N["en-us"].optionsStartScreen="Main menu";N["en-us"].optionsQuit="Quit";N["en-us"].optionsResume="Resume";N["en-us"].optionsTutorial="How to play";N["en-us"].optionsHighScore="High scores";N["en-us"].optionsMoreGames="More Games";N["en-us"].optionsDifficulty_easy="Easy";
N["en-us"].optionsDifficulty_medium="Medium";N["en-us"].optionsDifficulty_hard="Difficult";N["en-us"].optionsMusic_on="On";N["en-us"].optionsMusic_off="Off";N["en-us"].optionsSFX_on="On";N["en-us"].optionsSFX_off="Off";N["en-us"]["optionsLang_en-us"]="English (US)";N["en-us"]["optionsLang_en-gb"]="English (GB)";N["en-us"]["optionsLang_nl-nl"]="Dutch";N["en-us"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";N["en-us"].gameEndScreenBtnText="Continue";N["en-us"].optionsTitle="Settings";
N["en-us"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";N["en-us"].optionsQuitConfirmBtn_No="No";N["en-us"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";N["en-us"].levelMapScreenTitle="Select a level";N["en-us"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";N["en-us"].optionsRestart="Restart";
N["en-us"].optionsSFXBig_on="Sound on";N["en-us"].optionsSFXBig_off="Sound off";N["en-us"].optionsAbout_title="About";N["en-us"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["en-us"].optionsAbout_backBtn="Back";N["en-us"].optionsAbout_version="version:";N["en-us"].optionsAbout="About";N["en-us"].levelEndScreenMedal="IMPROVED!";N["en-us"].startScreenQuestionaire="What do you think?";N["en-us"].levelMapScreenWorld_0="Select a level";N["en-us"].startScreenByTinglyGames="by: CoolGames";
N["en-us"]["optionsLang_de-de"]="German";N["en-us"]["optionsLang_tr-tr"]="Turkish";N["en-us"].optionsAbout_header="Developed by:";N["en-us"].levelEndScreenViewHighscoreBtn="View scores";N["en-us"].levelEndScreenSubmitHighscoreBtn="Submit score";N["en-us"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["en-us"].challengeStartTextScore="<NAME>'s score:";N["en-us"].challengeStartTextTime="<NAME>'s time:";N["en-us"].challengeStartScreenToWin="Amount to win:";
N["en-us"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["en-us"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["en-us"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["en-us"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["en-us"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["en-us"].challengeCancelConfirmBtn_yes="Yes";N["en-us"].challengeCancelConfirmBtn_no="No";N["en-us"].challengeEndScreensBtn_submit="Submit challenge";N["en-us"].challengeEndScreenBtn_cancel="Cancel challenge";N["en-us"].challengeEndScreenName_you="You";N["en-us"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["en-us"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
N["en-us"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["en-us"].challengeCancelMessage_success="Your challenge has been cancelled.";N["en-us"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["en-us"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["en-us"].challengeStartScreenTitle_challenger_friend="You are challenging:";
N["en-us"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["en-us"].challengeStartTextTime_challenger="Play the game and set a time.";N["en-us"].challengeStartTextScore_challenger="Play the game and set a score.";N["en-us"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["en-us"].challengeForfeitConfirmBtn_yes="Yes";N["en-us"].challengeForfeitConfirmBtn_no="No";N["en-us"].challengeForfeitMessage_success="You have forfeited the challenge.";
N["en-us"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["en-us"].optionsChallengeForfeit="Forfeit";N["en-us"].optionsChallengeCancel="Quit";N["en-us"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["en-us"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["en-us"].levelEndScreenHighScore_time="Best time:";N["en-us"].levelEndScreenTotalScore_time="Total time:";
N["en-us"]["optionsLang_fr-fr"]="French";N["en-us"]["optionsLang_ko-kr"]="Korean";N["en-us"]["optionsLang_ar-eg"]="Arabic";N["en-us"]["optionsLang_es-es"]="Spanish";N["en-us"]["optionsLang_pt-br"]="Brazilian-Portuguese";N["en-us"]["optionsLang_ru-ru"]="Russian";N["en-us"].optionsExit="Exit";N["en-us"].levelEndScreenTotalScore_number="Total score:";N["en-us"].levelEndScreenHighScore_number="High score:";N["en-us"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["en-us"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["en-us"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["en-us"].optionsAbout_header_publisher="Published by:";N["en-us"]["optionsLang_jp-jp"]="Japanese";N["en-gb"]=N["en-gb"]||{};N["en-gb"].loadingScreenLoading="Loading...";N["en-gb"].startScreenPlay="PLAY";
N["en-gb"].levelMapScreenTotalScore="Total score";N["en-gb"].levelEndScreenTitle_level="Level <VALUE>";N["en-gb"].levelEndScreenTitle_difficulty="Well done!";N["en-gb"].levelEndScreenTitle_endless="Stage <VALUE>";N["en-gb"].levelEndScreenTotalScore="Total score";N["en-gb"].levelEndScreenSubTitle_levelFailed="Level failed";N["en-gb"].levelEndScreenTimeLeft="Time remaining";N["en-gb"].levelEndScreenTimeBonus="Time bonus";N["en-gb"].levelEndScreenHighScore="High score";
N["en-gb"].optionsStartScreen="Main menu";N["en-gb"].optionsQuit="Quit";N["en-gb"].optionsResume="Resume";N["en-gb"].optionsTutorial="How to play";N["en-gb"].optionsHighScore="High scores";N["en-gb"].optionsMoreGames="More Games";N["en-gb"].optionsDifficulty_easy="Easy";N["en-gb"].optionsDifficulty_medium="Medium";N["en-gb"].optionsDifficulty_hard="Difficult";N["en-gb"].optionsMusic_on="On";N["en-gb"].optionsMusic_off="Off";N["en-gb"].optionsSFX_on="On";N["en-gb"].optionsSFX_off="Off";
N["en-gb"]["optionsLang_en-us"]="English (US)";N["en-gb"]["optionsLang_en-gb"]="English (GB)";N["en-gb"]["optionsLang_nl-nl"]="Dutch";N["en-gb"].gameEndScreenTitle="Congratulations!\nYou have completed the game.";N["en-gb"].gameEndScreenBtnText="Continue";N["en-gb"].optionsTitle="Settings";N["en-gb"].optionsQuitConfirmationText="Attention!\n\nIf you quit now you will lose all progress made during this level. Are you sure you want to quit?";N["en-gb"].optionsQuitConfirmBtn_No="No";
N["en-gb"].optionsQuitConfirmBtn_Yes="Yes, I'm sure";N["en-gb"].levelMapScreenTitle="Select a level";N["en-gb"].optionsRestartConfirmationText="Attention!\n\nIf you restart now you will lose all progress made during this level. Are you sure you want to restart?";N["en-gb"].optionsRestart="Restart";N["en-gb"].optionsSFXBig_on="Sound on";N["en-gb"].optionsSFXBig_off="Sound off";N["en-gb"].optionsAbout_title="About";N["en-gb"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";
N["en-gb"].optionsAbout_backBtn="Back";N["en-gb"].optionsAbout_version="version:";N["en-gb"].optionsAbout="About";N["en-gb"].levelEndScreenMedal="IMPROVED!";N["en-gb"].startScreenQuestionaire="What do you think?";N["en-gb"].levelMapScreenWorld_0="Select a level";N["en-gb"].startScreenByTinglyGames="by: CoolGames";N["en-gb"]["optionsLang_de-de"]="German";N["en-gb"]["optionsLang_tr-tr"]="Turkish";N["en-gb"].optionsAbout_header="Developed by:";N["en-gb"].levelEndScreenViewHighscoreBtn="View scores";
N["en-gb"].levelEndScreenSubmitHighscoreBtn="Submit score";N["en-gb"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["en-gb"].challengeStartTextScore="<NAME>'s score:";N["en-gb"].challengeStartTextTime="<NAME>'s time:";N["en-gb"].challengeStartScreenToWin="Amount to win:";N["en-gb"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["en-gb"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";
N["en-gb"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["en-gb"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["en-gb"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";N["en-gb"].challengeCancelConfirmBtn_yes="Yes";N["en-gb"].challengeCancelConfirmBtn_no="No";N["en-gb"].challengeEndScreensBtn_submit="Submit challenge";
N["en-gb"].challengeEndScreenBtn_cancel="Cancel challenge";N["en-gb"].challengeEndScreenName_you="You";N["en-gb"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["en-gb"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";N["en-gb"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["en-gb"].challengeCancelMessage_success="Your challenge has been cancelled.";
N["en-gb"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["en-gb"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["en-gb"].challengeStartScreenTitle_challenger_friend="You are challenging:";N["en-gb"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["en-gb"].challengeStartTextTime_challenger="Play the game and set a time.";
N["en-gb"].challengeStartTextScore_challenger="Play the game and set a score.";N["en-gb"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you wish to proceed?";N["en-gb"].challengeForfeitConfirmBtn_yes="Yes";N["en-gb"].challengeForfeitConfirmBtn_no="No";N["en-gb"].challengeForfeitMessage_success="You have forfeited the challenge.";N["en-gb"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
N["en-gb"].optionsChallengeForfeit="Forfeit";N["en-gb"].optionsChallengeCancel="Quit";N["en-gb"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["en-gb"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["en-gb"].levelEndScreenHighScore_time="Best time:";N["en-gb"].levelEndScreenTotalScore_time="Total time:";N["en-gb"]["optionsLang_fr-fr"]="French";N["en-gb"]["optionsLang_ko-kr"]="Korean";N["en-gb"]["optionsLang_ar-eg"]="Arabic";
N["en-gb"]["optionsLang_es-es"]="Spanish";N["en-gb"]["optionsLang_pt-br"]="Brazilian-Portuguese";N["en-gb"]["optionsLang_ru-ru"]="Russian";N["en-gb"].optionsExit="Exit";N["en-gb"].levelEndScreenTotalScore_number="Total score:";N["en-gb"].levelEndScreenHighScore_number="High score:";N["en-gb"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["en-gb"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["en-gb"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["en-gb"].optionsAbout_header_publisher="Published by:";N["en-gb"]["optionsLang_jp-jp"]="Japanese";N["de-de"]=N["de-de"]||{};N["de-de"].loadingScreenLoading="Laden ...";N["de-de"].startScreenPlay="SPIELEN";
N["de-de"].levelMapScreenTotalScore="Gesamtpunkte";N["de-de"].levelEndScreenTitle_level="Level <VALUE>";N["de-de"].levelEndScreenTitle_difficulty="Sehr gut!";N["de-de"].levelEndScreenTitle_endless="Stufe <VALUE>";N["de-de"].levelEndScreenTotalScore="Gesamtpunkte";N["de-de"].levelEndScreenSubTitle_levelFailed="Level nicht geschafft";N["de-de"].levelEndScreenTimeLeft="Restzeit";N["de-de"].levelEndScreenTimeBonus="Zeitbonus";N["de-de"].levelEndScreenHighScore="Highscore";
N["de-de"].optionsStartScreen="Hauptmen\u00fc";N["de-de"].optionsQuit="Beenden";N["de-de"].optionsResume="Weiterspielen";N["de-de"].optionsTutorial="So wird gespielt";N["de-de"].optionsHighScore="Highscores";N["de-de"].optionsMoreGames="Weitere Spiele";N["de-de"].optionsDifficulty_easy="Einfach";N["de-de"].optionsDifficulty_medium="Mittel";N["de-de"].optionsDifficulty_hard="Schwer";N["de-de"].optionsMusic_on="EIN";N["de-de"].optionsMusic_off="AUS";N["de-de"].optionsSFX_on="EIN";
N["de-de"].optionsSFX_off="AUS";N["de-de"]["optionsLang_en-us"]="Englisch (US)";N["de-de"]["optionsLang_en-gb"]="Englisch (GB)";N["de-de"]["optionsLang_nl-nl"]="Holl\u00e4ndisch";N["de-de"].gameEndScreenTitle="Gl\u00fcckwunsch!\nDu hast das Spiel abgeschlossen.";N["de-de"].gameEndScreenBtnText="Weiter";N["de-de"].optionsTitle="Einstellungen";N["de-de"].optionsQuitConfirmationText="Achtung!\n\nWenn du jetzt aufh\u00f6rst, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich aufh\u00f6ren?";
N["de-de"].optionsQuitConfirmBtn_No="NEIN";N["de-de"].optionsQuitConfirmBtn_Yes="Ja, ich bin mir sicher";N["de-de"].levelMapScreenTitle="W\u00e4hle ein Level";N["de-de"].optionsRestartConfirmationText="Achtung!\n\nWenn du jetzt neu startest, verlierst du alle in diesem Level gemachten Fortschritte. Willst du wirklich neu starten?";N["de-de"].optionsRestart="Neustart";N["de-de"].optionsSFXBig_on="Sound EIN";N["de-de"].optionsSFXBig_off="Sound AUS";N["de-de"].optionsAbout_title="\u00dcber";
N["de-de"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["de-de"].optionsAbout_backBtn="Zur\u00fcck";N["de-de"].optionsAbout_version="Version:";N["de-de"].optionsAbout="\u00dcber";N["de-de"].levelEndScreenMedal="VERBESSERT!";N["de-de"].startScreenQuestionaire="Deine Meinung z\u00e4hlt!";N["de-de"].levelMapScreenWorld_0="W\u00e4hle ein Level";N["de-de"].startScreenByTinglyGames="von: CoolGames";N["de-de"]["optionsLang_de-de"]="Deutsch";N["de-de"]["optionsLang_tr-tr"]="T\u00fcrkisch";
N["de-de"].optionsAbout_header="Entwickelt von:";N["de-de"].levelEndScreenViewHighscoreBtn="Punktzahlen ansehen";N["de-de"].levelEndScreenSubmitHighscoreBtn="Punktzahl senden";N["de-de"].challengeStartScreenTitle_challengee_friend="Dein Gegner:";N["de-de"].challengeStartTextScore="Punktzahl von <NAME>:";N["de-de"].challengeStartTextTime="Zeit von <NAME>:";N["de-de"].challengeStartScreenToWin="Einsatz:";N["de-de"].challengeEndScreenWinnings="Du hast <AMOUNT> Fairm\u00fcnzen gewonnen!";
N["de-de"].challengeEndScreenOutcomeMessage_WON="Du hast die Partie gewonnen!";N["de-de"].challengeEndScreenOutcomeMessage_LOST="Leider hat Dein Gegner die Partie gewonnen.";N["de-de"].challengeEndScreenOutcomeMessage_TIED="Gleichstand!";N["de-de"].challengeCancelConfirmText="Willst Du Deine Wette wirklich zur\u00fcckziehen? Dein Wetteinsatz wird Dir zur\u00fcckgegeben minus die Einsatzgeb\u00fchr.";N["de-de"].challengeCancelConfirmBtn_yes="Ja";N["de-de"].challengeCancelConfirmBtn_no="Nein";
N["de-de"].challengeEndScreensBtn_submit="Herausfordern";N["de-de"].challengeEndScreenBtn_cancel="Zur\u00fcckziehen";N["de-de"].challengeEndScreenName_you="Du";N["de-de"].challengeEndScreenChallengeSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";N["de-de"].challengeEndScreenChallengeSend_success="Herausforderung verschickt!";N["de-de"].challengeCancelMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
N["de-de"].challengeCancelMessage_success="Du hast die Wette erfolgreich zur\u00fcckgezogen.";N["de-de"].challengeEndScreenScoreSend_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";N["de-de"].challengeStartScreenTitle_challengee_stranger="Dein Gegner wird:";N["de-de"].challengeStartScreenTitle_challenger_friend="Du hast den folgenden Spieler herausgefordert:";N["de-de"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
N["de-de"].challengeStartTextTime_challenger="Spiel um die niedrigste Zeit!";N["de-de"].challengeStartTextScore_challenger="Spiel um die hochste Punktzahl!";N["de-de"].challengeForfeitConfirmText="Willst du Die Partie wirklich aufgeben?";N["de-de"].challengeForfeitConfirmBtn_yes="Ja";N["de-de"].challengeForfeitConfirmBtn_no="Nein";N["de-de"].challengeForfeitMessage_success="You have forfeited the challenge.";N["de-de"].challengeForfeitMessage_error="Leider ist ein Fehler aufgetreten. Probiere es bitte nochmal sp\u00e4ter.";
N["de-de"].optionsChallengeForfeit="Aufgeben";N["de-de"].optionsChallengeCancel="Zur\u00fcckziehen";N["de-de"].challengeLoadingError_notValid="Leider ist diese Partie nicht mehr aktuel.";N["de-de"].challengeLoadingError_notStarted="Leider ist ein Fehler\u00a0aufgetreten. Es konnte keiner Verbindung zum Server hergestellt werden. Versuche es bitte nochmal sp\u00e4ter.";N["de-de"].levelEndScreenHighScore_time="Bestzeit:";N["de-de"].levelEndScreenTotalScore_time="Gesamtzeit:";
N["de-de"]["optionsLang_fr-fr"]="Franz\u00f6sisch";N["de-de"]["optionsLang_ko-kr"]="Koreanisch";N["de-de"]["optionsLang_ar-eg"]="Arabisch";N["de-de"]["optionsLang_es-es"]="Spanisch";N["de-de"]["optionsLang_pt-br"]="Portugiesisch (Brasilien)";N["de-de"]["optionsLang_ru-ru"]="Russisch";N["de-de"].optionsExit="Verlassen";N["de-de"].levelEndScreenTotalScore_number="Gesamtpunktzahl:";N["de-de"].levelEndScreenHighScore_number="Highscore:";N["de-de"].challengeEndScreenChallengeSend_submessage="<NAME> hat 72 Stunden um die Wette anzunehmen oder abzulehnen. Sollte <NAME> nicht reagieren oder ablehnen werden Dir Dein Wetteinsatz und die Geb\u00fchr zur\u00fcckerstattet.";
N["de-de"].challengeEndScreenChallengeSend_submessage_stranger="Als niemanden Deine Herausforderung innerhalb von 72 Stunden annimmt, werden Dir Deinen Wetteinsatz Einsatzgeb\u00fchr zur\u00fcckerstattet.";N["de-de"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["de-de"].optionsAbout_header_publisher="Published by:";N["de-de"]["optionsLang_jp-jp"]="Japanese";N["fr-fr"]=N["fr-fr"]||{};N["fr-fr"].loadingScreenLoading="Chargement...";N["fr-fr"].startScreenPlay="JOUER";
N["fr-fr"].levelMapScreenTotalScore="Score total";N["fr-fr"].levelEndScreenTitle_level="Niveau <VALUE>";N["fr-fr"].levelEndScreenTitle_difficulty="Bien jou\u00e9 !";N["fr-fr"].levelEndScreenTitle_endless="Sc\u00e8ne <VALUE>";N["fr-fr"].levelEndScreenTotalScore="Score total";N["fr-fr"].levelEndScreenSubTitle_levelFailed="\u00c9chec du niveau";N["fr-fr"].levelEndScreenTimeLeft="Temps restant";N["fr-fr"].levelEndScreenTimeBonus="Bonus de temps";N["fr-fr"].levelEndScreenHighScore="Meilleur score";
N["fr-fr"].optionsStartScreen="Menu principal";N["fr-fr"].optionsQuit="Quitter";N["fr-fr"].optionsResume="Reprendre";N["fr-fr"].optionsTutorial="Comment jouer";N["fr-fr"].optionsHighScore="Meilleurs scores";N["fr-fr"].optionsMoreGames="Plus de jeux";N["fr-fr"].optionsDifficulty_easy="Facile";N["fr-fr"].optionsDifficulty_medium="Moyen";N["fr-fr"].optionsDifficulty_hard="Difficile";N["fr-fr"].optionsMusic_on="Avec";N["fr-fr"].optionsMusic_off="Sans";N["fr-fr"].optionsSFX_on="Avec";
N["fr-fr"].optionsSFX_off="Sans";N["fr-fr"]["optionsLang_en-us"]="Anglais (US)";N["fr-fr"]["optionsLang_en-gb"]="Anglais (UK)";N["fr-fr"]["optionsLang_nl-nl"]="N\u00e9erlandais";N["fr-fr"].gameEndScreenTitle="F\u00e9licitations !\nVous avez termin\u00e9 le jeu.";N["fr-fr"].gameEndScreenBtnText="Continuer";N["fr-fr"].optionsTitle="Param\u00e8tres";N["fr-fr"].optionsQuitConfirmationText="Attention !\n\nEn quittant maintenant, vous perdrez votre progression pour le niveau en cours. Quitter quand m\u00eame ?";
N["fr-fr"].optionsQuitConfirmBtn_No="Non";N["fr-fr"].optionsQuitConfirmBtn_Yes="Oui";N["fr-fr"].levelMapScreenTitle="Choisir un niveau";N["fr-fr"].optionsRestartConfirmationText="Attention !\n\nEn recommen\u00e7ant maintenant, vous perdrez votre progression pour le niveau en cours. Recommencer quand m\u00eame ?";N["fr-fr"].optionsRestart="Recommencer";N["fr-fr"].optionsSFXBig_on="Avec son";N["fr-fr"].optionsSFXBig_off="Sans son";N["fr-fr"].optionsAbout_title="\u00c0 propos";
N["fr-fr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["fr-fr"].optionsAbout_backBtn="Retour";N["fr-fr"].optionsAbout_version="Version :";N["fr-fr"].optionsAbout="\u00c0 propos";N["fr-fr"].levelEndScreenMedal="RECORD BATTU !";N["fr-fr"].startScreenQuestionaire="Un avis sur le jeu ?";N["fr-fr"].levelMapScreenWorld_0="Choisir un niveau";N["fr-fr"].startScreenByTinglyGames="Un jeu CoolGames";N["fr-fr"]["optionsLang_de-de"]="Allemand";N["fr-fr"]["optionsLang_tr-tr"]="Turc";
N["fr-fr"].optionsAbout_header="D\u00e9velopp\u00e9 par :";N["fr-fr"].levelEndScreenViewHighscoreBtn="Voir les scores";N["fr-fr"].levelEndScreenSubmitHighscoreBtn="Publier un score";N["fr-fr"].challengeStartScreenTitle_challengee_friend="Votre adversaire\u00a0:";N["fr-fr"].challengeStartTextScore="Son score :";N["fr-fr"].challengeStartTextTime="Son temps\u00a0:";N["fr-fr"].challengeStartScreenToWin="\u00c0 gagner\u00a0:";N["fr-fr"].challengeEndScreenWinnings="Vous avez gagn\u00e9 <AMOUNT> fairpoints.";
N["fr-fr"].challengeEndScreenOutcomeMessage_WON="Vainqueur\u00a0!";N["fr-fr"].challengeEndScreenOutcomeMessage_LOST="Zut\u00a0!";N["fr-fr"].challengeEndScreenOutcomeMessage_TIED="Ex-aequo\u00a0!";N["fr-fr"].challengeCancelConfirmText="Si vous annulez, on vous remboursera le montant du pari moins les frais de pari. Voulez-vous continuer\u00a0? ";N["fr-fr"].challengeCancelConfirmBtn_yes="Oui";N["fr-fr"].challengeCancelConfirmBtn_no="Non";N["fr-fr"].challengeEndScreensBtn_submit="Lancer le d\u00e9fi";
N["fr-fr"].challengeEndScreenBtn_cancel="Annuler le d\u00e9fi";N["fr-fr"].challengeEndScreenName_you="Moi";N["fr-fr"].challengeEndScreenChallengeSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";N["fr-fr"].challengeEndScreenChallengeSend_success="D\u00e9fi lanc\u00e9.";N["fr-fr"].challengeCancelMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";N["fr-fr"].challengeCancelMessage_success="D\u00e9fi annul\u00e9.";
N["fr-fr"].challengeEndScreenScoreSend_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";N["fr-fr"].challengeStartScreenTitle_challengee_stranger="Votre adversaire\u00a0:";N["fr-fr"].challengeStartScreenTitle_challenger_friend="Votre adversaire\u00a0:";N["fr-fr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["fr-fr"].challengeStartTextTime_challenger="Finissez le plus vite possible !";N["fr-fr"].challengeStartTextScore_challenger="Essayez d\u2019atteindre le plus haut score !";
N["fr-fr"].challengeForfeitConfirmText="Voulez-vous vraiment abandonner la partie ?";N["fr-fr"].challengeForfeitConfirmBtn_yes="Oui";N["fr-fr"].challengeForfeitConfirmBtn_no="Non";N["fr-fr"].challengeForfeitMessage_success="Vous avez abandonn\u00e9.";N["fr-fr"].challengeForfeitMessage_error="Une erreur est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";N["fr-fr"].optionsChallengeForfeit="Abandonner";N["fr-fr"].optionsChallengeCancel="Annuler";N["fr-fr"].challengeLoadingError_notValid="D\u00e9sol\u00e9, cette partie n'existe plus.";
N["fr-fr"].challengeLoadingError_notStarted="Une erreur de connexion est survenue. Veuillez r\u00e9essayer ult\u00e9rieurement.";N["fr-fr"].levelEndScreenHighScore_time="Meilleur temps :";N["fr-fr"].levelEndScreenTotalScore_time="Temps total :";N["fr-fr"]["optionsLang_fr-fr"]="Fran\u00e7ais";N["fr-fr"]["optionsLang_ko-kr"]="Cor\u00e9en";N["fr-fr"]["optionsLang_ar-eg"]="Arabe";N["fr-fr"]["optionsLang_es-es"]="Espagnol";N["fr-fr"]["optionsLang_pt-br"]="Portugais - Br\u00e9silien";
N["fr-fr"]["optionsLang_ru-ru"]="Russe";N["fr-fr"].optionsExit="Quitter";N["fr-fr"].levelEndScreenTotalScore_number="Score total :";N["fr-fr"].levelEndScreenHighScore_number="Meilleur score :";N["fr-fr"].challengeEndScreenChallengeSend_submessage="<NAME> a 72 heures pour accepter votre d\u00e9fi. Si <NAME> refuse ou n\u2019accepte pas dans ce d\u00e9lai vous serez rembours\u00e9 le montant de votre pari et les frais de pari.";N["fr-fr"].challengeEndScreenChallengeSend_submessage_stranger="Si personne n\u2019accepte votre pari d\u2019ici 72 heures, on vous remboursera le montant du pari y compris les frais.";
N["fr-fr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["fr-fr"].optionsAbout_header_publisher="Published by:";N["fr-fr"]["optionsLang_jp-jp"]="Japanese";N["pt-br"]=N["pt-br"]||{};N["pt-br"].loadingScreenLoading="Carregando...";N["pt-br"].startScreenPlay="JOGAR";N["pt-br"].levelMapScreenTotalScore="Pontua\u00e7\u00e3o";N["pt-br"].levelEndScreenTitle_level="N\u00edvel <VALUE>";N["pt-br"].levelEndScreenTitle_difficulty="Muito bem!";
N["pt-br"].levelEndScreenTitle_endless="Fase <VALUE>";N["pt-br"].levelEndScreenTotalScore="Pontua\u00e7\u00e3o";N["pt-br"].levelEndScreenSubTitle_levelFailed="Tente novamente";N["pt-br"].levelEndScreenTimeLeft="Tempo restante";N["pt-br"].levelEndScreenTimeBonus="B\u00f4nus de tempo";N["pt-br"].levelEndScreenHighScore="Recorde";N["pt-br"].optionsStartScreen="Menu principal";N["pt-br"].optionsQuit="Sair";N["pt-br"].optionsResume="Continuar";N["pt-br"].optionsTutorial="Como jogar";
N["pt-br"].optionsHighScore="Recordes";N["pt-br"].optionsMoreGames="Mais jogos";N["pt-br"].optionsDifficulty_easy="F\u00e1cil";N["pt-br"].optionsDifficulty_medium="M\u00e9dio";N["pt-br"].optionsDifficulty_hard="Dif\u00edcil";N["pt-br"].optionsMusic_on="Sim";N["pt-br"].optionsMusic_off="N\u00e3o";N["pt-br"].optionsSFX_on="Sim";N["pt-br"].optionsSFX_off="N\u00e3o";N["pt-br"]["optionsLang_en-us"]="Ingl\u00eas (EUA)";N["pt-br"]["optionsLang_en-gb"]="Ingl\u00eas (GB)";N["pt-br"]["optionsLang_nl-nl"]="Holand\u00eas";
N["pt-br"].gameEndScreenTitle="Parab\u00e9ns!\nVoc\u00ea concluiu o jogo.";N["pt-br"].gameEndScreenBtnText="Continuar";N["pt-br"].optionsTitle="Configura\u00e7\u00f5es";N["pt-br"].optionsQuitConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea sair agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo sair?";N["pt-br"].optionsQuitConfirmBtn_No="N\u00e3o";N["pt-br"].optionsQuitConfirmBtn_Yes="Sim, tenho certeza.";N["pt-br"].levelMapScreenTitle="Selecione um n\u00edvel";
N["pt-br"].optionsRestartConfirmationText="Aten\u00e7\u00e3o!\n\nSe voc\u00ea reiniciar agora, perder\u00e1 todo progresso realizado neste n\u00edvel. Deseja mesmo reiniciar?";N["pt-br"].optionsRestart="Reiniciar";N["pt-br"].optionsSFXBig_on="Com som";N["pt-br"].optionsSFXBig_off="Sem som";N["pt-br"].optionsAbout_title="Sobre";N["pt-br"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["pt-br"].optionsAbout_backBtn="Voltar";N["pt-br"].optionsAbout_version="vers\u00e3o:";
N["pt-br"].optionsAbout="Sobre";N["pt-br"].levelEndScreenMedal="MELHOROU!";N["pt-br"].startScreenQuestionaire="O que voc\u00ea achou?";N["pt-br"].levelMapScreenWorld_0="Selecione um n\u00edvel";N["pt-br"].startScreenByTinglyGames="da: CoolGames";N["pt-br"]["optionsLang_de-de"]="Alem\u00e3o";N["pt-br"]["optionsLang_tr-tr"]="Turco";N["pt-br"].optionsAbout_header="Desenvolvido por:";N["pt-br"].levelEndScreenViewHighscoreBtn="Ver pontua\u00e7\u00f5es";N["pt-br"].levelEndScreenSubmitHighscoreBtn="Enviar recorde";
N["pt-br"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["pt-br"].challengeStartTextScore="<NAME>'s score:";N["pt-br"].challengeStartTextTime="<NAME>'s time:";N["pt-br"].challengeStartScreenToWin="Amount to win:";N["pt-br"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["pt-br"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["pt-br"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";
N["pt-br"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["pt-br"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";N["pt-br"].challengeCancelConfirmBtn_yes="Yes";N["pt-br"].challengeCancelConfirmBtn_no="No";N["pt-br"].challengeEndScreensBtn_submit="Submit challenge";N["pt-br"].challengeEndScreenBtn_cancel="Cancel challenge";N["pt-br"].challengeEndScreenName_you="You";
N["pt-br"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["pt-br"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";N["pt-br"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["pt-br"].challengeCancelMessage_success="Your challenge has been cancelled.";N["pt-br"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";
N["pt-br"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["pt-br"].challengeStartScreenTitle_challenger_friend="You are challenging:";N["pt-br"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["pt-br"].challengeStartTextTime_challenger="Play the game and set a time.";N["pt-br"].challengeStartTextScore_challenger="Play the game and set a score.";N["pt-br"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";
N["pt-br"].challengeForfeitConfirmBtn_yes="Yes";N["pt-br"].challengeForfeitConfirmBtn_no="No";N["pt-br"].challengeForfeitMessage_success="You have forfeited the challenge.";N["pt-br"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["pt-br"].optionsChallengeForfeit="Desistir";N["pt-br"].optionsChallengeCancel="Sair do Jogo";N["pt-br"].challengeLoadingError_notValid="Desculpe, este desafio n\u00e3o \u00e9 mais v\u00e1lido.";
N["pt-br"].challengeLoadingError_notStarted="Imposs\u00edvel conectar ao servidor. Por favor, tente novamente mais tarde.";N["pt-br"].levelEndScreenHighScore_time="Tempo recorde:";N["pt-br"].levelEndScreenTotalScore_time="Tempo total:";N["pt-br"]["optionsLang_fr-fr"]="Franc\u00eas";N["pt-br"]["optionsLang_ko-kr"]="Coreano";N["pt-br"]["optionsLang_ar-eg"]="\u00c1rabe";N["pt-br"]["optionsLang_es-es"]="Espanhol";N["pt-br"]["optionsLang_pt-br"]="Portugu\u00eas do Brasil";
N["pt-br"]["optionsLang_ru-ru"]="Russo";N["pt-br"].optionsExit="Sa\u00edda";N["pt-br"].levelEndScreenTotalScore_number="Pontua\u00e7\u00e3o total:";N["pt-br"].levelEndScreenHighScore_number="Pontua\u00e7\u00e3o m\u00e1xima:";N["pt-br"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["pt-br"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["pt-br"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["pt-br"].optionsAbout_header_publisher="Published by:";N["pt-br"]["optionsLang_jp-jp"]="Japanese";N["es-es"]=N["es-es"]||{};N["es-es"].loadingScreenLoading="Cargando...";N["es-es"].startScreenPlay="JUGAR";
N["es-es"].levelMapScreenTotalScore="Punt. total";N["es-es"].levelEndScreenTitle_level="Nivel <VALUE>";N["es-es"].levelEndScreenTitle_difficulty="\u00a1Muy bien!";N["es-es"].levelEndScreenTitle_endless="Fase <VALUE>";N["es-es"].levelEndScreenTotalScore="Punt. total";N["es-es"].levelEndScreenSubTitle_levelFailed="Nivel fallido";N["es-es"].levelEndScreenTimeLeft="Tiempo restante";N["es-es"].levelEndScreenTimeBonus="Bonif. tiempo";N["es-es"].levelEndScreenHighScore="R\u00e9cord";
N["es-es"].optionsStartScreen="Men\u00fa principal";N["es-es"].optionsQuit="Salir";N["es-es"].optionsResume="Seguir";N["es-es"].optionsTutorial="C\u00f3mo jugar";N["es-es"].optionsHighScore="R\u00e9cords";N["es-es"].optionsMoreGames="M\u00e1s juegos";N["es-es"].optionsDifficulty_easy="F\u00e1cil";N["es-es"].optionsDifficulty_medium="Normal";N["es-es"].optionsDifficulty_hard="Dif\u00edcil";N["es-es"].optionsMusic_on="S\u00ed";N["es-es"].optionsMusic_off="No";N["es-es"].optionsSFX_on="S\u00ed";
N["es-es"].optionsSFX_off="No";N["es-es"]["optionsLang_en-us"]="Ingl\u00e9s (EE.UU.)";N["es-es"]["optionsLang_en-gb"]="Ingl\u00e9s (GB)";N["es-es"]["optionsLang_nl-nl"]="Neerland\u00e9s";N["es-es"].gameEndScreenTitle="\u00a1Enhorabuena!\nHas terminado el juego.";N["es-es"].gameEndScreenBtnText="Continuar";N["es-es"].optionsTitle="Ajustes";N["es-es"].optionsQuitConfirmationText="\u00a1Aviso!\n\nSi sales ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres salir?";
N["es-es"].optionsQuitConfirmBtn_No="No";N["es-es"].optionsQuitConfirmBtn_Yes="S\u00ed, seguro";N["es-es"].levelMapScreenTitle="Elige un nivel";N["es-es"].optionsRestartConfirmationText="\u00a1Aviso!\n\nSi reinicias ahora, perder\u00e1s el progreso que hayas realizado en el nivel. \u00bfSeguro que quieres reiniciar?";N["es-es"].optionsRestart="Reiniciar";N["es-es"].optionsSFXBig_on="Sonido s\u00ed";N["es-es"].optionsSFXBig_off="Sonido no";N["es-es"].optionsAbout_title="Acerca de";
N["es-es"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["es-es"].optionsAbout_backBtn="Atr\u00e1s";N["es-es"].optionsAbout_version="versi\u00f3n:";N["es-es"].optionsAbout="Acerca de";N["es-es"].levelEndScreenMedal="\u00a1SUPERADO!";N["es-es"].startScreenQuestionaire="\u00bfQu\u00e9 te parece?";N["es-es"].levelMapScreenWorld_0="Elige un nivel";N["es-es"].startScreenByTinglyGames="de: CoolGames";N["es-es"]["optionsLang_de-de"]="Alem\u00e1n";N["es-es"]["optionsLang_tr-tr"]="Turco";
N["es-es"].optionsAbout_header="Desarrollado por:";N["es-es"].levelEndScreenViewHighscoreBtn="Ver puntuaciones";N["es-es"].levelEndScreenSubmitHighscoreBtn="Enviar puntuaci\u00f3n";N["es-es"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["es-es"].challengeStartTextScore="<NAME>'s score:";N["es-es"].challengeStartTextTime="<NAME>'s time:";N["es-es"].challengeStartScreenToWin="Amount to win:";N["es-es"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";
N["es-es"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["es-es"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["es-es"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["es-es"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";N["es-es"].challengeCancelConfirmBtn_yes="Yes";N["es-es"].challengeCancelConfirmBtn_no="No";
N["es-es"].challengeEndScreensBtn_submit="Submit challenge";N["es-es"].challengeEndScreenBtn_cancel="Cancel challenge";N["es-es"].challengeEndScreenName_you="You";N["es-es"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["es-es"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";N["es-es"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
N["es-es"].challengeCancelMessage_success="Your challenge has been cancelled.";N["es-es"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["es-es"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["es-es"].challengeStartScreenTitle_challenger_friend="You are challenging:";N["es-es"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
N["es-es"].challengeStartTextTime_challenger="Play the game and set a time.";N["es-es"].challengeStartTextScore_challenger="Play the game and set a score.";N["es-es"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["es-es"].challengeForfeitConfirmBtn_yes="Yes";N["es-es"].challengeForfeitConfirmBtn_no="No";N["es-es"].challengeForfeitMessage_success="You have forfeited the challenge.";N["es-es"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
N["es-es"].optionsChallengeForfeit="Rendirse";N["es-es"].optionsChallengeCancel="Abandonar";N["es-es"].challengeLoadingError_notValid="Lo sentimos, este reto ya no es v\u00e1lido.";N["es-es"].challengeLoadingError_notStarted="Imposible conectar con el servidor. Int\u00e9ntalo m\u00e1s tarde.";N["es-es"].levelEndScreenHighScore_time="Mejor tiempo:";N["es-es"].levelEndScreenTotalScore_time="Tiempo total:";N["es-es"]["optionsLang_fr-fr"]="Franc\u00e9s";N["es-es"]["optionsLang_ko-kr"]="Coreano";
N["es-es"]["optionsLang_ar-eg"]="\u00c1rabe";N["es-es"]["optionsLang_es-es"]="Espa\u00f1ol";N["es-es"]["optionsLang_pt-br"]="Portugu\u00e9s brasile\u00f1o";N["es-es"]["optionsLang_ru-ru"]="Ruso";N["es-es"].optionsExit="Salir";N["es-es"].levelEndScreenTotalScore_number="Puntos totales:";N["es-es"].levelEndScreenHighScore_number="Mejor puntuaci\u00f3n:";N["es-es"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["es-es"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["es-es"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["es-es"].optionsAbout_header_publisher="Published by:";N["es-es"]["optionsLang_jp-jp"]="Japanese";N["tr-tr"]=N["tr-tr"]||{};N["tr-tr"].loadingScreenLoading="Y\u00fckleniyor...";N["tr-tr"].startScreenPlay="OYNA";
N["tr-tr"].levelMapScreenTotalScore="Toplam skor";N["tr-tr"].levelEndScreenTitle_level="Seviye <VALUE>";N["tr-tr"].levelEndScreenTitle_difficulty="Bravo!";N["tr-tr"].levelEndScreenTitle_endless="Seviye <VALUE>";N["tr-tr"].levelEndScreenTotalScore="Toplam skor";N["tr-tr"].levelEndScreenSubTitle_levelFailed="Seviye ba\u015far\u0131s\u0131z";N["tr-tr"].levelEndScreenTimeLeft="Kalan S\u00fcre";N["tr-tr"].levelEndScreenTimeBonus="S\u00fcre Bonusu";N["tr-tr"].levelEndScreenHighScore="Y\u00fcksek skor";
N["tr-tr"].optionsStartScreen="Ana men\u00fc";N["tr-tr"].optionsQuit="\u00c7\u0131k";N["tr-tr"].optionsResume="Devam et";N["tr-tr"].optionsTutorial="Nas\u0131l oynan\u0131r";N["tr-tr"].optionsHighScore="Y\u00fcksek skorlar";N["tr-tr"].optionsMoreGames="Daha Fazla Oyun";N["tr-tr"].optionsDifficulty_easy="Kolay";N["tr-tr"].optionsDifficulty_medium="Orta";N["tr-tr"].optionsDifficulty_hard="Zorluk";N["tr-tr"].optionsMusic_on="A\u00e7\u0131k";N["tr-tr"].optionsMusic_off="Kapal\u0131";
N["tr-tr"].optionsSFX_on="A\u00e7\u0131k";N["tr-tr"].optionsSFX_off="Kapal\u0131";N["tr-tr"]["optionsLang_en-us"]="\u0130ngilizce (US)";N["tr-tr"]["optionsLang_en-gb"]="\u0130ngilizce (GB)";N["tr-tr"]["optionsLang_nl-nl"]="Hollandaca";N["tr-tr"].gameEndScreenTitle="Tebrikler!\nOyunu tamamlad\u0131n.";N["tr-tr"].gameEndScreenBtnText="Devam";N["tr-tr"].optionsTitle="Ayarlar";N["tr-tr"].optionsQuitConfirmationText="Dikkat!\n\u015eimdi \u00e7\u0131karsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. \u00c7\u0131kmak istedi\u011finizden emin misiniz?";
N["tr-tr"].optionsQuitConfirmBtn_No="Hay\u0131r";N["tr-tr"].optionsQuitConfirmBtn_Yes="Evet, eminim";N["tr-tr"].levelMapScreenTitle="Bir seviye se\u00e7";N["tr-tr"].optionsRestartConfirmationText="Dikkat!\n\u015eimdi tekrar ba\u015flarsan bu seviyede yap\u0131lan t\u00fcm ilerleme kaybedilecek. Ba\u015ftan ba\u015flamak istedi\u011finden emin misin?";N["tr-tr"].optionsRestart="Tekrar ba\u015flat";N["tr-tr"].optionsSFXBig_on="Ses a\u00e7\u0131k";N["tr-tr"].optionsSFXBig_off="Ses kapal\u0131";
N["tr-tr"].optionsAbout_title="Hakk\u0131nda";N["tr-tr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["tr-tr"].optionsAbout_backBtn="Geri";N["tr-tr"].optionsAbout_version="s\u00fcr\u00fcm:";N["tr-tr"].optionsAbout="Hakk\u0131nda";N["tr-tr"].levelEndScreenMedal="\u0130Y\u0130LE\u015eT\u0130!";N["tr-tr"].startScreenQuestionaire="Ne dersin?";N["tr-tr"].levelMapScreenWorld_0="Bir seviye se\u00e7";N["tr-tr"].startScreenByTinglyGames="taraf\u0131ndan: CoolGames";
N["tr-tr"]["optionsLang_de-de"]="Almanca";N["tr-tr"]["optionsLang_tr-tr"]="T\u00fcrk\u00e7e";N["tr-tr"].optionsAbout_header="Haz\u0131rlayan:";N["tr-tr"].levelEndScreenViewHighscoreBtn="Puanlar\u0131 g\u00f6ster:";N["tr-tr"].levelEndScreenSubmitHighscoreBtn="Puan g\u00f6nder";N["tr-tr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["tr-tr"].challengeStartTextScore="<NAME>'s score:";N["tr-tr"].challengeStartTextTime="<NAME>'s time:";
N["tr-tr"].challengeStartScreenToWin="Amount to win:";N["tr-tr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["tr-tr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["tr-tr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["tr-tr"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["tr-tr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["tr-tr"].challengeCancelConfirmBtn_yes="Yes";N["tr-tr"].challengeCancelConfirmBtn_no="No";N["tr-tr"].challengeEndScreensBtn_submit="Submit challenge";N["tr-tr"].challengeEndScreenBtn_cancel="Cancel challenge";N["tr-tr"].challengeEndScreenName_you="You";N["tr-tr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["tr-tr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
N["tr-tr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["tr-tr"].challengeCancelMessage_success="Your challenge has been cancelled.";N["tr-tr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["tr-tr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["tr-tr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
N["tr-tr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["tr-tr"].challengeStartTextTime_challenger="Play the game and set a time.";N["tr-tr"].challengeStartTextScore_challenger="Play the game and set a score.";N["tr-tr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["tr-tr"].challengeForfeitConfirmBtn_yes="Yes";N["tr-tr"].challengeForfeitConfirmBtn_no="No";N["tr-tr"].challengeForfeitMessage_success="You have forfeited the challenge.";
N["tr-tr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["tr-tr"].optionsChallengeForfeit="Vazge\u00e7";N["tr-tr"].optionsChallengeCancel="\u00c7\u0131k\u0131\u015f";N["tr-tr"].challengeLoadingError_notValid="\u00dczg\u00fcn\u00fcz, bu zorluk art\u0131k ge\u00e7erli de\u011fil.";N["tr-tr"].challengeLoadingError_notStarted="Sunucuya ba\u011flan\u0131lam\u0131yor. L\u00fctfen daha sonra tekrar deneyin.";
N["tr-tr"].levelEndScreenHighScore_time="En \u0130yi Zaman:";N["tr-tr"].levelEndScreenTotalScore_time="Toplam Zaman:";N["tr-tr"]["optionsLang_fr-fr"]="Frans\u0131zca";N["tr-tr"]["optionsLang_ko-kr"]="Korece";N["tr-tr"]["optionsLang_ar-eg"]="Arap\u00e7a";N["tr-tr"]["optionsLang_es-es"]="\u0130spanyolca";N["tr-tr"]["optionsLang_pt-br"]="Brezilya Portekizcesi";N["tr-tr"]["optionsLang_ru-ru"]="Rus\u00e7a";N["tr-tr"].optionsExit="\u00c7\u0131k\u0131\u015f";N["tr-tr"].levelEndScreenTotalScore_number="Toplam Puan:";
N["tr-tr"].levelEndScreenHighScore_number="Y\u00fcksek Puan:";N["tr-tr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";N["tr-tr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
N["tr-tr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["tr-tr"].optionsAbout_header_publisher="Published by:";N["tr-tr"]["optionsLang_jp-jp"]="Japanese";N["ru-ru"]=N["ru-ru"]||{};N["ru-ru"].loadingScreenLoading="\u0417\u0430\u0433\u0440\u0443\u0437\u043a\u0430...";N["ru-ru"].startScreenPlay="\u0418\u0413\u0420\u0410\u0422\u042c";N["ru-ru"].levelMapScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";N["ru-ru"].levelEndScreenTitle_level="\u0423\u0440\u043e\u0432\u0435\u043d\u044c <VALUE>";
N["ru-ru"].levelEndScreenTitle_difficulty="\u0425\u043e\u0440\u043e\u0448\u0438\u0439 \u0440\u0435\u0437\u0443\u043b\u044c\u0442\u0430\u0442!";N["ru-ru"].levelEndScreenTitle_endless="\u042d\u0442\u0430\u043f <VALUE>";N["ru-ru"].levelEndScreenTotalScore="\u041e\u0431\u0449\u0438\u0439 \u0441\u0447\u0435\u0442";N["ru-ru"].levelEndScreenSubTitle_levelFailed="\u0423\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u043f\u0440\u043e\u0439\u0434\u0435\u043d";N["ru-ru"].levelEndScreenTimeLeft="\u041e\u0441\u0442\u0430\u0432\u0448\u0435\u0435\u0441\u044f \u0432\u0440\u0435\u043c\u044f";
N["ru-ru"].levelEndScreenTimeBonus="\u0414\u043e\u043f\u043e\u043b\u043d\u0438\u0442\u0435\u043b\u044c\u043d\u043e\u0435 \u0432\u0440\u0435\u043c\u044f";N["ru-ru"].levelEndScreenHighScore="\u0420\u0435\u043a\u043e\u0440\u0434";N["ru-ru"].optionsStartScreen="\u0413\u043b\u0430\u0432\u043d\u043e\u0435 \u043c\u0435\u043d\u044e";N["ru-ru"].optionsQuit="\u0412\u044b\u0439\u0442\u0438";N["ru-ru"].optionsResume="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";N["ru-ru"].optionsTutorial="\u041a\u0430\u043a \u0438\u0433\u0440\u0430\u0442\u044c";
N["ru-ru"].optionsHighScore="\u0420\u0435\u043a\u043e\u0440\u0434\u044b";N["ru-ru"].optionsMoreGames="\u0411\u043e\u043b\u044c\u0448\u0435 \u0438\u0433\u0440";N["ru-ru"].optionsDifficulty_easy="\u041b\u0435\u0433\u043a\u0438\u0439";N["ru-ru"].optionsDifficulty_medium="\u0421\u0440\u0435\u0434\u043d\u0438\u0439";N["ru-ru"].optionsDifficulty_hard="\u0421\u043b\u043e\u0436\u043d\u044b\u0439";N["ru-ru"].optionsMusic_on="\u0412\u043a\u043b.";N["ru-ru"].optionsMusic_off="\u0412\u044b\u043a\u043b.";
N["ru-ru"].optionsSFX_on="\u0412\u043a\u043b.";N["ru-ru"].optionsSFX_off="\u0412\u044b\u043a\u043b.";N["ru-ru"]["optionsLang_en-us"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0421\u0428\u0410)";N["ru-ru"]["optionsLang_en-gb"]="\u0410\u043d\u0433\u043b\u0438\u0439\u0441\u043a\u0438\u0439 (\u0412\u0411)";N["ru-ru"]["optionsLang_nl-nl"]="\u041d\u0438\u0434\u0435\u0440\u043b\u0430\u043d\u0434\u0441\u043a\u0438\u0439";N["ru-ru"].gameEndScreenTitle="\u041f\u043e\u0437\u0434\u0440\u0430\u0432\u043b\u044f\u0435\u043c!\n\u0412\u044b \u043f\u0440\u043e\u0448\u043b\u0438 \u0438\u0433\u0440\u0443.";
N["ru-ru"].gameEndScreenBtnText="\u041f\u0440\u043e\u0434\u043e\u043b\u0436\u0438\u0442\u044c";N["ru-ru"].optionsTitle="\u041d\u0430\u0441\u0442\u0440\u043e\u0439\u043a\u0438";N["ru-ru"].optionsQuitConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0432\u044b\u0439\u0434\u0435\u0442\u0435 \u0441\u0435\u0439\u0447\u0430\u0441, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u0432\u044b\u0439\u0442\u0438?";
N["ru-ru"].optionsQuitConfirmBtn_No="\u041d\u0435\u0442";N["ru-ru"].optionsQuitConfirmBtn_Yes="\u0414\u0430, \u0432\u044b\u0439\u0442\u0438";N["ru-ru"].levelMapScreenTitle="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";N["ru-ru"].optionsRestartConfirmationText="\u0412\u043d\u0438\u043c\u0430\u043d\u0438\u0435!\n\n\u0415\u0441\u043b\u0438 \u0432\u044b \u0441\u0435\u0439\u0447\u0430\u0441 \u043d\u0430\u0447\u043d\u0435\u0442\u0435 \u0438\u0433\u0440\u0443 \u0437\u0430\u043d\u043e\u0432\u043e, \u0443\u0440\u043e\u0432\u0435\u043d\u044c \u043d\u0435 \u0431\u0443\u0434\u0435\u0442 \u0437\u0430\u0441\u0447\u0438\u0442\u0430\u043d. \u0412\u044b \u0443\u0432\u0435\u0440\u0435\u043d\u044b, \u0447\u0442\u043e \u0445\u043e\u0442\u0438\u0442\u0435 \u043d\u0430\u0447\u0430\u0442\u044c \u0437\u0430\u043d\u043e\u0432\u043e?";
N["ru-ru"].optionsRestart="\u0417\u0430\u043d\u043e\u0432\u043e";N["ru-ru"].optionsSFXBig_on="\u0417\u0432\u0443\u043a \u0432\u043a\u043b.";N["ru-ru"].optionsSFXBig_off="\u0417\u0432\u0443\u043a \u0432\u044b\u043a\u043b.";N["ru-ru"].optionsAbout_title="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";N["ru-ru"].optionsAbout_text="\u00a9 CoolGames\nwww.coolgames.com\n2016";N["ru-ru"].optionsAbout_backBtn="\u041d\u0430\u0437\u0430\u0434";N["ru-ru"].optionsAbout_version="\u0412\u0435\u0440\u0441\u0438\u044f:";
N["ru-ru"].optionsAbout="\u041e \u043f\u0440\u043e\u0433\u0440\u0430\u043c\u043c\u0435";N["ru-ru"].levelEndScreenMedal="\u041d\u041e\u0412\u042b\u0419 \u0420\u0415\u041a\u041e\u0420\u0414!";N["ru-ru"].startScreenQuestionaire="\u041a\u0430\u043a \u0432\u0430\u043c \u0438\u0433\u0440\u0430?";N["ru-ru"].levelMapScreenWorld_0="\u0412\u044b\u0431\u0435\u0440\u0438\u0442\u0435 \u0443\u0440\u043e\u0432\u0435\u043d\u044c";N["ru-ru"].startScreenByTinglyGames="\u0420\u0430\u0437\u0440\u0430\u0431\u043e\u0442\u0447\u0438\u043a\u0438: CoolGames";
N["ru-ru"]["optionsLang_de-de"]="\u041d\u0435\u043c\u0435\u0446\u043a\u0438\u0439";N["ru-ru"]["optionsLang_tr-tr"]="\u0422\u0443\u0440\u0435\u0446\u043a\u0438\u0439";N["ru-ru"].optionsAbout_header="Developed by:";N["ru-ru"].levelEndScreenViewHighscoreBtn="View scores";N["ru-ru"].levelEndScreenSubmitHighscoreBtn="Submit score";N["ru-ru"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["ru-ru"].challengeStartTextScore="<NAME>'s score:";
N["ru-ru"].challengeStartTextTime="<NAME>'s time:";N["ru-ru"].challengeStartScreenToWin="Amount to win:";N["ru-ru"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["ru-ru"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["ru-ru"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["ru-ru"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["ru-ru"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["ru-ru"].challengeCancelConfirmBtn_yes="Yes";N["ru-ru"].challengeCancelConfirmBtn_no="No";N["ru-ru"].challengeEndScreensBtn_submit="Submit challenge";N["ru-ru"].challengeEndScreenBtn_cancel="Cancel challenge";N["ru-ru"].challengeEndScreenName_you="You";N["ru-ru"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["ru-ru"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
N["ru-ru"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["ru-ru"].challengeCancelMessage_success="Your challenge has been cancelled.";N["ru-ru"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["ru-ru"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["ru-ru"].challengeStartScreenTitle_challenger_friend="You are challenging:";
N["ru-ru"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["ru-ru"].challengeStartTextTime_challenger="Play the game and set a time.";N["ru-ru"].challengeStartTextScore_challenger="Play the game and set a score.";N["ru-ru"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["ru-ru"].challengeForfeitConfirmBtn_yes="Yes";N["ru-ru"].challengeForfeitConfirmBtn_no="No";N["ru-ru"].challengeForfeitMessage_success="You have forfeited the challenge.";
N["ru-ru"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["ru-ru"].optionsChallengeForfeit="Forfeit";N["ru-ru"].optionsChallengeCancel="Quit";N["ru-ru"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["ru-ru"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["ru-ru"].levelEndScreenHighScore_time="Best time:";N["ru-ru"].levelEndScreenTotalScore_time="Total time:";
N["ru-ru"]["optionsLang_fr-fr"]="\u0424\u0440\u0430\u043d\u0446\u0443\u0437\u0441\u043a\u0438\u0439";N["ru-ru"]["optionsLang_ko-kr"]="\u041a\u043e\u0440\u0435\u0439\u0441\u043a\u0438\u0439";N["ru-ru"]["optionsLang_ar-eg"]="\u0410\u0440\u0430\u0431\u0441\u043a\u0438\u0439";N["ru-ru"]["optionsLang_es-es"]="\u0418\u0441\u043f\u0430\u043d\u0441\u043a\u0438\u0439";N["ru-ru"]["optionsLang_pt-br"]="\u0411\u0440\u0430\u0437\u0438\u043b\u044c\u0441\u043a\u0438\u0439 \u043f\u043e\u0440\u0442\u0443\u0433\u0430\u043b\u044c\u0441\u043a\u0438\u0439";
N["ru-ru"]["optionsLang_ru-ru"]="\u0420\u0443\u0441\u0441\u043a\u0438\u0439";N["ru-ru"].optionsExit="Exit";N["ru-ru"].levelEndScreenTotalScore_number="Total score:";N["ru-ru"].levelEndScreenHighScore_number="High score:";N["ru-ru"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["ru-ru"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["ru-ru"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["ru-ru"].optionsAbout_header_publisher="Published by:";N["ru-ru"]["optionsLang_jp-jp"]="Japanese";N["ar-eg"]=N["ar-eg"]||{};N["ar-eg"].loadingScreenLoading="\u064a\u062a\u0645 \u0627\u0644\u0622\u0646 \u0627\u0644\u062a\u062d\u0645\u064a\u0644...";
N["ar-eg"].startScreenPlay="\u062a\u0634\u063a\u064a\u0644";N["ar-eg"].levelMapScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";N["ar-eg"].levelEndScreenTitle_level="\u0627\u0644\u0645\u0633\u062a\u0648\u0649 <VALUE>";N["ar-eg"].levelEndScreenTitle_difficulty="\u0623\u062d\u0633\u0646\u062a!";N["ar-eg"].levelEndScreenTitle_endless="\u0627\u0644\u0645\u0631\u062d\u0644\u0629 <VALUE>";N["ar-eg"].levelEndScreenTotalScore="\u0627\u0644\u0646\u062a\u064a\u062c\u0629 \u0627\u0644\u0625\u062c\u0645\u0627\u0644\u064a\u0629";
N["ar-eg"].levelEndScreenSubTitle_levelFailed="\u0644\u0642\u062f \u0641\u0634\u0644\u062a \u0641\u064a \u0627\u062c\u062a\u064a\u0627\u0632 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649";N["ar-eg"].levelEndScreenTimeLeft="\u0627\u0644\u0648\u0642\u062a \u0627\u0644\u0645\u062a\u0628\u0642\u064a";N["ar-eg"].levelEndScreenTimeBonus="\u0645\u0643\u0627\u0641\u0623\u0629 \u0627\u0644\u0648\u0642\u062a";N["ar-eg"].levelEndScreenHighScore="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";
N["ar-eg"].optionsStartScreen="\u0627\u0644\u0642\u0627\u0626\u0645\u0629 \u0627\u0644\u0631\u0626\u064a\u0633\u064a\u0629";N["ar-eg"].optionsQuit="\u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629";N["ar-eg"].optionsResume="\u0627\u0633\u062a\u0626\u0646\u0627\u0641";N["ar-eg"].optionsTutorial="\u0637\u0631\u064a\u0642\u0629 \u0627\u0644\u0644\u0639\u0628";N["ar-eg"].optionsHighScore="\u0623\u0639\u0644\u0649 \u0627\u0644\u0646\u062a\u0627\u0626\u062c";
N["ar-eg"].optionsMoreGames="\u0627\u0644\u0645\u0632\u064a\u062f \u0645\u0646 \u0627\u0644\u0623\u0644\u0639\u0627\u0628";N["ar-eg"].optionsDifficulty_easy="\u0633\u0647\u0644";N["ar-eg"].optionsDifficulty_medium="\u0645\u062a\u0648\u0633\u0637";N["ar-eg"].optionsDifficulty_hard="\u0635\u0639\u0628";N["ar-eg"].optionsMusic_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";N["ar-eg"].optionsMusic_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0648\u0633\u064a\u0642\u0649";
N["ar-eg"].optionsSFX_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";N["ar-eg"].optionsSFX_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0645\u0624\u062b\u0631\u0627\u062a \u0627\u0644\u0635\u0648\u062a\u064a\u0629";N["ar-eg"]["optionsLang_en-us"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0648\u0644\u0627\u064a\u0627\u062a \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";
N["ar-eg"]["optionsLang_en-gb"]="\u0627\u0644\u0625\u0646\u062c\u0644\u064a\u0632\u064a\u0629 (\u0627\u0644\u0645\u0645\u0644\u0643\u0629 \u0627\u0644\u0645\u062a\u062d\u062f\u0629)";N["ar-eg"]["optionsLang_nl-nl"]="\u0627\u0644\u0647\u0648\u0644\u0646\u062f\u064a\u0629";N["ar-eg"].gameEndScreenTitle="\u062a\u0647\u0627\u0646\u064a\u0646\u0627!\n\u0644\u0642\u062f \u0623\u0643\u0645\u0644\u062a \u0627\u0644\u0644\u0639\u0628\u0629.";N["ar-eg"].gameEndScreenBtnText="\u0645\u062a\u0627\u0628\u0639\u0629";
N["ar-eg"].optionsTitle="\u0627\u0644\u0625\u0639\u062f\u0627\u062f\u0627\u062a";N["ar-eg"].optionsQuitConfirmationText="\u0627\u0646\u062a\u0628\u0647!n\n\u0625\u0630\u0627 \u062e\u0631\u062c\u062a \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0627\u0644\u062e\u0631\u0648\u062c \u0645\u0646 \u0627\u0644\u0644\u0639\u0628\u0629\u061f";
N["ar-eg"].optionsQuitConfirmBtn_No="\u0644\u0627";N["ar-eg"].optionsQuitConfirmBtn_Yes="\u0646\u0639\u0645\u060c \u0645\u062a\u0623\u0643\u062f";N["ar-eg"].levelMapScreenTitle="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";N["ar-eg"].optionsRestartConfirmationText="\u0627\u0646\u062a\u0628\u0647!\n\n\u0625\u0630\u0627 \u0642\u0645\u062a \u0628\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0622\u0646\u060c \u0641\u0633\u062a\u0641\u0642\u062f \u0643\u0644 \u0627\u0644\u062a\u0642\u062f\u0645 \u0627\u0644\u0630\u064a \u0623\u062d\u0631\u0632\u062a\u0647 \u062e\u0644\u0627\u0644 \u0647\u0630\u0627 \u0627\u0644\u0645\u0633\u062a\u0648\u0649. \u0647\u0644 \u0623\u0646\u062a \u0645\u062a\u0623\u0643\u062f \u0645\u0646 \u0623\u0646\u0643 \u062a\u0631\u064a\u062f \u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644\u061f";
N["ar-eg"].optionsRestart="\u0625\u0639\u0627\u062f\u0629 \u0627\u0644\u062a\u0634\u063a\u064a\u0644";N["ar-eg"].optionsSFXBig_on="\u062a\u0634\u063a\u064a\u0644 \u0627\u0644\u0635\u0648\u062a";N["ar-eg"].optionsSFXBig_off="\u0625\u064a\u0642\u0627\u0641 \u0627\u0644\u0635\u0648\u062a";N["ar-eg"].optionsAbout_title="\u062d\u0648\u0644";N["ar-eg"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["ar-eg"].optionsAbout_backBtn="\u0627\u0644\u0633\u0627\u0628\u0642";
N["ar-eg"].optionsAbout_version="\u0627\u0644\u0625\u0635\u062f\u0627\u0631:";N["ar-eg"].optionsAbout="\u062d\u0648\u0644";N["ar-eg"].levelEndScreenMedal="\u0644\u0642\u062f \u062a\u062d\u0633\u0651\u0646\u062a!";N["ar-eg"].startScreenQuestionaire="\u0645\u0627 \u0631\u0623\u064a\u0643\u061f";N["ar-eg"].levelMapScreenWorld_0="\u062a\u062d\u062f\u064a\u062f \u0645\u0633\u062a\u0648\u0649";N["ar-eg"].startScreenByTinglyGames="\u0628\u0648\u0627\u0633\u0637\u0629: CoolGames";
N["ar-eg"]["optionsLang_de-de"]="\u0627\u0644\u0623\u0644\u0645\u0627\u0646\u064a\u0629";N["ar-eg"]["optionsLang_tr-tr"]="\u0627\u0644\u062a\u0631\u0643\u064a\u0629";N["ar-eg"].optionsAbout_header="Developed by:";N["ar-eg"].levelEndScreenViewHighscoreBtn="View scores";N["ar-eg"].levelEndScreenSubmitHighscoreBtn="Submit score";N["ar-eg"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["ar-eg"].challengeStartTextScore="<NAME>'s score:";
N["ar-eg"].challengeStartTextTime="<NAME>'s time:";N["ar-eg"].challengeStartScreenToWin="Amount to win:";N["ar-eg"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["ar-eg"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["ar-eg"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["ar-eg"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["ar-eg"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["ar-eg"].challengeCancelConfirmBtn_yes="Yes";N["ar-eg"].challengeCancelConfirmBtn_no="No";N["ar-eg"].challengeEndScreensBtn_submit="Submit challenge";N["ar-eg"].challengeEndScreenBtn_cancel="Cancel challenge";N["ar-eg"].challengeEndScreenName_you="You";N["ar-eg"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["ar-eg"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
N["ar-eg"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["ar-eg"].challengeCancelMessage_success="Your challenge has been cancelled.";N["ar-eg"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["ar-eg"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["ar-eg"].challengeStartScreenTitle_challenger_friend="You are challenging:";
N["ar-eg"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["ar-eg"].challengeStartTextTime_challenger="Play the game and set a time.";N["ar-eg"].challengeStartTextScore_challenger="Play the game and set a score.";N["ar-eg"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["ar-eg"].challengeForfeitConfirmBtn_yes="Yes";N["ar-eg"].challengeForfeitConfirmBtn_no="No";N["ar-eg"].challengeForfeitMessage_success="You have forfeited the challenge.";
N["ar-eg"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["ar-eg"].optionsChallengeForfeit="Forfeit";N["ar-eg"].optionsChallengeCancel="Quit";N["ar-eg"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["ar-eg"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["ar-eg"].levelEndScreenHighScore_time="Best time:";N["ar-eg"].levelEndScreenTotalScore_time="Total time:";
N["ar-eg"]["optionsLang_fr-fr"]="\u0627\u0644\u0641\u0631\u0646\u0633\u064a\u0629";N["ar-eg"]["optionsLang_ko-kr"]="\u0627\u0644\u0643\u0648\u0631\u064a\u0629";N["ar-eg"]["optionsLang_ar-eg"]="\u0627\u0644\u0639\u0631\u0628\u064a\u0629";N["ar-eg"]["optionsLang_es-es"]="\u0627\u0644\u0625\u0633\u0628\u0627\u0646\u064a\u0629";N["ar-eg"]["optionsLang_pt-br"]="\u0627\u0644\u0628\u0631\u0627\u0632\u064a\u0644\u064a\u0629 - \u0627\u0644\u0628\u0631\u062a\u063a\u0627\u0644\u064a\u0629";
N["ar-eg"]["optionsLang_ru-ru"]="\u0627\u0644\u0631\u0648\u0633\u064a\u0629";N["ar-eg"].optionsExit="Exit";N["ar-eg"].levelEndScreenTotalScore_number="Total score:";N["ar-eg"].levelEndScreenHighScore_number="High score:";N["ar-eg"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["ar-eg"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["ar-eg"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["ar-eg"].optionsAbout_header_publisher="Published by:";N["ar-eg"]["optionsLang_jp-jp"]="Japanese";N["ko-kr"]=N["ko-kr"]||{};N["ko-kr"].loadingScreenLoading="\ubd88\ub7ec\uc624\uae30 \uc911...";N["ko-kr"].startScreenPlay="PLAY";
N["ko-kr"].levelMapScreenTotalScore="\ucd1d \uc810\uc218";N["ko-kr"].levelEndScreenTitle_level="\ub808\ubca8 <VALUE>";N["ko-kr"].levelEndScreenTitle_difficulty="\uc798 \ud588\uc5b4\uc694!";N["ko-kr"].levelEndScreenTitle_endless="\uc2a4\ud14c\uc774\uc9c0 <VALUE>";N["ko-kr"].levelEndScreenTotalScore="\ucd1d \uc810\uc218";N["ko-kr"].levelEndScreenSubTitle_levelFailed="\ub808\ubca8 \uc2e4\ud328";N["ko-kr"].levelEndScreenTimeLeft="\ub0a8\uc740 \uc2dc\uac04";N["ko-kr"].levelEndScreenTimeBonus="\uc2dc\uac04 \ubcf4\ub108\uc2a4";
N["ko-kr"].levelEndScreenHighScore="\ucd5c\uace0 \uc810\uc218";N["ko-kr"].optionsStartScreen="\uba54\uc778 \uba54\ub274";N["ko-kr"].optionsQuit="\uc885\ub8cc";N["ko-kr"].optionsResume="\uacc4\uc18d";N["ko-kr"].optionsTutorial="\uac8c\uc784 \ubc29\ubc95";N["ko-kr"].optionsHighScore="\ucd5c\uace0 \uc810\uc218";N["ko-kr"].optionsMoreGames="\ub354 \ub9ce\uc740 \uac8c\uc784";N["ko-kr"].optionsDifficulty_easy="\uac04\ub2e8";N["ko-kr"].optionsDifficulty_medium="\uc911";
N["ko-kr"].optionsDifficulty_hard="\uc0c1";N["ko-kr"].optionsMusic_on="\ucf1c\uae30";N["ko-kr"].optionsMusic_off="\ub044\uae30";N["ko-kr"].optionsSFX_on="\ucf1c\uae30";N["ko-kr"].optionsSFX_off="\ub044\uae30";N["ko-kr"]["optionsLang_en-us"]="\uc601\uc5b4(US)";N["ko-kr"]["optionsLang_en-gb"]="\uc601\uc5b4(GB)";N["ko-kr"]["optionsLang_nl-nl"]="\ub124\ub35c\ub780\ub4dc\uc5b4";N["ko-kr"].gameEndScreenTitle="\ucd95\ud558\ud569\ub2c8\ub2e4!\n\uac8c\uc784\uc744 \uc644\ub8cc\ud588\uc2b5\ub2c8\ub2e4.";
N["ko-kr"].gameEndScreenBtnText="\uacc4\uc18d";N["ko-kr"].optionsTitle="\uc124\uc815";N["ko-kr"].optionsQuitConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \uc885\ub8cc\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \uc885\ub8cc\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";N["ko-kr"].optionsQuitConfirmBtn_No="\uc544\ub2c8\uc624";N["ko-kr"].optionsQuitConfirmBtn_Yes="\ub124, \ud655\uc2e4\ud569\ub2c8\ub2e4";
N["ko-kr"].levelMapScreenTitle="\ub808\ubca8 \uc120\ud0dd";N["ko-kr"].optionsRestartConfirmationText="\uc8fc\uc758!\n\n\uc9c0\uae08 \ub2e4\uc2dc \uc2dc\uc791\ud558\uba74 \uc774 \ub808\ubca8\uc758 \ubaa8\ub4e0 \uc9c4\ud589 \ub0b4\uc6a9\uc744 \uc783\uac8c\ub429\ub2c8\ub2e4. \uc815\ub9d0 \ub2e4\uc2dc \uc2dc\uc791\ud558\uc2dc\uaca0\uc2b5\ub2c8\uae4c?";N["ko-kr"].optionsRestart="\ub2e4\uc2dc \uc2dc\uc791";N["ko-kr"].optionsSFXBig_on="\uc74c\ud5a5 \ucf1c\uae30";N["ko-kr"].optionsSFXBig_off="\uc74c\ud5a5 \ub044\uae30";
N["ko-kr"].optionsAbout_title="\uad00\ub828 \uc815\ubcf4";N["ko-kr"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["ko-kr"].optionsAbout_backBtn="\ub4a4\ub85c";N["ko-kr"].optionsAbout_version="\ubc84\uc804:";N["ko-kr"].optionsAbout="\uad00\ub828 \uc815\ubcf4";N["ko-kr"].levelEndScreenMedal="\ud5a5\uc0c1\ud588\uad70\uc694!";N["ko-kr"].startScreenQuestionaire="\uc5b4\ub5bb\uac8c \uc0dd\uac01\ud558\uc138\uc694?";N["ko-kr"].levelMapScreenWorld_0="\ub808\ubca8 \uc120\ud0dd";
N["ko-kr"].startScreenByTinglyGames="\uc81c\uc791: CoolGames";N["ko-kr"]["optionsLang_de-de"]="\ub3c5\uc77c\uc5b4";N["ko-kr"]["optionsLang_tr-tr"]="\ud130\ud0a4\uc5b4";N["ko-kr"].optionsAbout_header="Developed by:";N["ko-kr"].levelEndScreenViewHighscoreBtn="View scores";N["ko-kr"].levelEndScreenSubmitHighscoreBtn="Submit score";N["ko-kr"].challengeStartScreenTitle_challengee_friend="You have been challenged by:";N["ko-kr"].challengeStartTextScore="<NAME>'s score:";
N["ko-kr"].challengeStartTextTime="<NAME>'s time:";N["ko-kr"].challengeStartScreenToWin="Amount to win:";N["ko-kr"].challengeEndScreenWinnings="You have won <AMOUNT> fairpoints";N["ko-kr"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["ko-kr"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["ko-kr"].challengeEndScreenOutcomeMessage_TIED="You tied.";N["ko-kr"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["ko-kr"].challengeCancelConfirmBtn_yes="Yes";N["ko-kr"].challengeCancelConfirmBtn_no="No";N["ko-kr"].challengeEndScreensBtn_submit="Submit challenge";N["ko-kr"].challengeEndScreenBtn_cancel="Cancel challenge";N["ko-kr"].challengeEndScreenName_you="You";N["ko-kr"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["ko-kr"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";
N["ko-kr"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";N["ko-kr"].challengeCancelMessage_success="Your challenge has been cancelled.";N["ko-kr"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["ko-kr"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["ko-kr"].challengeStartScreenTitle_challenger_friend="You are challenging:";
N["ko-kr"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";N["ko-kr"].challengeStartTextTime_challenger="Play the game and set a time.";N["ko-kr"].challengeStartTextScore_challenger="Play the game and set a score.";N["ko-kr"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["ko-kr"].challengeForfeitConfirmBtn_yes="Yes";N["ko-kr"].challengeForfeitConfirmBtn_no="No";N["ko-kr"].challengeForfeitMessage_success="You have forfeited the challenge.";
N["ko-kr"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";N["ko-kr"].optionsChallengeForfeit="Forfeit";N["ko-kr"].optionsChallengeCancel="Quit";N["ko-kr"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["ko-kr"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["ko-kr"].levelEndScreenHighScore_time="Best time:";N["ko-kr"].levelEndScreenTotalScore_time="Total time:";
N["ko-kr"]["optionsLang_fr-fr"]="\ud504\ub791\uc2a4\uc5b4";N["ko-kr"]["optionsLang_ko-kr"]="\ud55c\uad6d\uc5b4";N["ko-kr"]["optionsLang_ar-eg"]="\uc544\ub77c\ube44\uc544\uc5b4";N["ko-kr"]["optionsLang_es-es"]="\uc2a4\ud398\uc778\uc5b4";N["ko-kr"]["optionsLang_pt-br"]="\ud3ec\ub974\ud22c\uac08\uc5b4(\ube0c\ub77c\uc9c8)";N["ko-kr"]["optionsLang_ru-ru"]="\ub7ec\uc2dc\uc544\uc5b4";N["ko-kr"].optionsExit="Exit";N["ko-kr"].levelEndScreenTotalScore_number="Total score:";
N["ko-kr"].levelEndScreenHighScore_number="High score:";N["ko-kr"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";N["ko-kr"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";
N["ko-kr"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["ko-kr"].optionsAbout_header_publisher="Published by:";N["ko-kr"]["optionsLang_jp-jp"]="Japanese";N["jp-jp"]=N["jp-jp"]||{};N["jp-jp"].loadingScreenLoading="\u30ed\u30fc\u30c9\u4e2d\u2026";N["jp-jp"].startScreenPlay="\u30d7\u30ec\u30a4";N["jp-jp"].levelMapScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";N["jp-jp"].levelEndScreenTitle_level="\u30ec\u30d9\u30eb <VALUE>";
N["jp-jp"].levelEndScreenTitle_difficulty="\u3084\u3063\u305f\u306d\uff01";N["jp-jp"].levelEndScreenTitle_endless="\u30b9\u30c6\u30fc\u30b8 <VALUE>";N["jp-jp"].levelEndScreenTotalScore="\u30c8\u30fc\u30bf\u30eb\u30b9\u30b3\u30a2";N["jp-jp"].levelEndScreenSubTitle_levelFailed="\u30b2\u30fc\u30e0\u30aa\u30fc\u30d0\u30fc";N["jp-jp"].levelEndScreenTimeLeft="\u6b8b\u308a\u6642\u9593";N["jp-jp"].levelEndScreenTimeBonus="\u30bf\u30a4\u30e0\u30dc\u30fc\u30ca\u30b9";N["jp-jp"].levelEndScreenHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";
N["jp-jp"].optionsStartScreen="\u30e1\u30a4\u30f3\u30e1\u30cb\u30e5\u30fc";N["jp-jp"].optionsQuit="\u3084\u3081\u308b";N["jp-jp"].optionsResume="\u518d\u958b";N["jp-jp"].optionsTutorial="\u3042\u305d\u3073\u65b9";N["jp-jp"].optionsHighScore="\u30cf\u30a4\u30b9\u30b3\u30a2";N["jp-jp"].optionsMoreGames="\u4ed6\u306e\u30b2\u30fc\u30e0";N["jp-jp"].optionsDifficulty_easy="\u304b\u3093\u305f\u3093";N["jp-jp"].optionsDifficulty_medium="\u3075\u3064\u3046";N["jp-jp"].optionsDifficulty_hard="\u96e3\u3057\u3044";
N["jp-jp"].optionsMusic_on="\u30aa\u30f3";N["jp-jp"].optionsMusic_off="\u30aa\u30d5";N["jp-jp"].optionsSFX_on="\u30aa\u30f3";N["jp-jp"].optionsSFX_off="\u30aa\u30d5";N["jp-jp"]["optionsLang_en-us"]="\u82f1\u8a9e\uff08\u7c73\u56fd\uff09";N["jp-jp"]["optionsLang_en-gb"]="\u82f1\u8a9e\uff08\u82f1\u56fd\uff09";N["jp-jp"]["optionsLang_nl-nl"]="\u30aa\u30e9\u30f3\u30c0\u8a9e";N["jp-jp"].gameEndScreenTitle="\u304a\u3081\u3067\u3068\u3046\uff01\n\u3059\u3079\u3066\u306e\u30ec\u30d9\u30eb\u3092\u30af\u30ea\u30a2\u3057\u307e\u3057\u305f\u3002";
N["jp-jp"].gameEndScreenBtnText="\u7d9a\u3051\u308b";N["jp-jp"].optionsTitle="\u8a2d\u5b9a";N["jp-jp"].optionsQuitConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u3084\u3081\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";N["jp-jp"].optionsQuitConfirmBtn_No="\u3044\u3044\u3048\u3001\u7d9a\u3051\u307e\u3059\u3002";N["jp-jp"].optionsQuitConfirmBtn_Yes="\u306f\u3044\u3001\u3084\u3081\u307e\u3059\u3002";
N["jp-jp"].levelMapScreenTitle="\u30ec\u30d9\u30eb\u9078\u629e";N["jp-jp"].optionsRestartConfirmationText="\u6ce8\u610f\uff01\n\n\u3053\u3053\u3067\u518d\u30b9\u30bf\u30fc\u30c8\u3059\u308b\u3068\n\u8a18\u9332\u304c\u30ea\u30bb\u30c3\u30c8\u3055\u308c\u307e\u3059\u304c\n\u3088\u308d\u3057\u3044\u3067\u3059\u304b\uff1f";N["jp-jp"].optionsRestart="\u518d\u30b9\u30bf\u30fc\u30c8";N["jp-jp"].optionsSFXBig_on="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30f3";N["jp-jp"].optionsSFXBig_off="\u30b5\u30a6\u30f3\u30c9 \u30aa\u30d5";
N["jp-jp"].optionsAbout_title="About";N["jp-jp"].optionsAbout_text="CoolGames\nwww.coolgames.com\n\u00a9 2016";N["jp-jp"].optionsAbout_backBtn="\u3082\u3069\u308b";N["jp-jp"].optionsAbout_version="version";N["jp-jp"].optionsAbout="About";N["jp-jp"].levelEndScreenMedal="\u8a18\u9332\u66f4\u65b0\uff01";N["jp-jp"].startScreenQuestionaire="\u3053\u306e\u30b2\u30fc\u30e0\u3078\u306e\u611f\u60f3";N["jp-jp"].levelMapScreenWorld_0="\u30ec\u30d9\u30eb\u9078\u629e";N["jp-jp"].startScreenByTinglyGames="by: CoolGames";
N["jp-jp"]["optionsLang_de-de"]="\u30c9\u30a4\u30c4\u8a9e";N["jp-jp"]["optionsLang_tr-tr"]="\u30c8\u30eb\u30b3\u8a9e";N["jp-jp"].optionsAbout_header="Developed by";N["jp-jp"].levelEndScreenViewHighscoreBtn="\u30b9\u30b3\u30a2\u3092\u307f\u308b";N["jp-jp"].levelEndScreenSubmitHighscoreBtn="\u30b9\u30b3\u30a2\u9001\u4fe1";N["jp-jp"].challengeStartScreenTitle_challengee_friend="\u304b\u3089\u6311\u6226\u3092\u53d7\u3051\u307e\u3057\u305f";N["jp-jp"].challengeStartTextScore="<NAME>\u306e\u30b9\u30b3\u30a2";
N["jp-jp"].challengeStartTextTime="<NAME>\u306e\u6642\u9593";N["jp-jp"].challengeStartScreenToWin="\u30dd\u30a4\u30f3\u30c8\u6570";N["jp-jp"].challengeEndScreenWinnings="<AMOUNT>\u30dd\u30a4\u30f3\u30c8\u7372\u5f97";N["jp-jp"].challengeEndScreenOutcomeMessage_WON="You have won the challenge!";N["jp-jp"].challengeEndScreenOutcomeMessage_LOST="You have lost the challenge.";N["jp-jp"].challengeEndScreenOutcomeMessage_TIED="\u540c\u70b9";N["jp-jp"].challengeCancelConfirmText="You are about to cancel the challenge. Your wager will be returned minus the challenge fee. Are you sure you want to cancel the challenge?";
N["jp-jp"].challengeCancelConfirmBtn_yes="Yes";N["jp-jp"].challengeCancelConfirmBtn_no="No";N["jp-jp"].challengeEndScreensBtn_submit="\u3042";N["jp-jp"].challengeEndScreenBtn_cancel="Cancel challenge";N["jp-jp"].challengeEndScreenName_you="You";N["jp-jp"].challengeEndScreenChallengeSend_error="An error occured while submitting the challenge. Please try again later.";N["jp-jp"].challengeEndScreenChallengeSend_success="Your challenge has been sent!";N["jp-jp"].challengeCancelMessage_error="An error occured while cancelling your challenge. Please try again later.";
N["jp-jp"].challengeCancelMessage_success="Your challenge has been cancelled.";N["jp-jp"].challengeEndScreenScoreSend_error="An error occured while communicating with the server. Please try again later.";N["jp-jp"].challengeStartScreenTitle_challengee_stranger="You have been matched with:";N["jp-jp"].challengeStartScreenTitle_challenger_friend="You are challenging:";N["jp-jp"].challengeStartScreenTitle_challenger_stranger="You are setting a score for:";
N["jp-jp"].challengeStartTextTime_challenger="Play the game and set a time.";N["jp-jp"].challengeStartTextScore_challenger="Play the game and set a score.";N["jp-jp"].challengeForfeitConfirmText="You are about to forfeit the challenge. Are you sure you want to proceed?";N["jp-jp"].challengeForfeitConfirmBtn_yes="Yes";N["jp-jp"].challengeForfeitConfirmBtn_no="No";N["jp-jp"].challengeForfeitMessage_success="You have forfeited the challenge.";N["jp-jp"].challengeForfeitMessage_error="An error occured while forfeiting the challenge. Please try again later.";
N["jp-jp"].optionsChallengeForfeit="Forfeit";N["jp-jp"].optionsChallengeCancel="Quit";N["jp-jp"].challengeLoadingError_notValid="Sorry, this challenge is no longer valid.";N["jp-jp"].challengeLoadingError_notStarted="Unable to connect to the server. Please try again later.";N["jp-jp"].levelEndScreenHighScore_time="Best time:";N["jp-jp"].levelEndScreenTotalScore_time="Total time:";N["jp-jp"]["optionsLang_fr-fr"]="French";N["jp-jp"]["optionsLang_ko-kr"]="Korean";N["jp-jp"]["optionsLang_ar-eg"]="Arabic";
N["jp-jp"]["optionsLang_es-es"]="Spanish";N["jp-jp"]["optionsLang_pt-br"]="Brazilian-Portuguese";N["jp-jp"]["optionsLang_ru-ru"]="Russian";N["jp-jp"].optionsExit="Exit";N["jp-jp"].levelEndScreenTotalScore_number="Total score:";N["jp-jp"].levelEndScreenHighScore_number="High score:";N["jp-jp"].challengeEndScreenChallengeSend_submessage="<NAME> has 72 hours to accept or decline your challenge. If <NAME> declines or doesn\u2019t accept within 72 hours your wager and challenge fee will be reimbursed.";
N["jp-jp"].challengeEndScreenChallengeSend_submessage_stranger="If no one accepts your challenge within 72 hours, the amount of your wager and the challenge fee will be returned to you.";N["jp-jp"].challengeForfeitMessage_winnings="<NAME> has won <AMOUNT> fairpoints!";N["jp-jp"].optionsAbout_header_publisher="Published by:";N["jp-jp"]["optionsLang_jp-jp"]="\u65e5\u672c\u8a9e";N=N||{};N["nl-nl"]=N["nl-nl"]||{};N["nl-nl"].game_ui_SCORE="SCORE";N["nl-nl"].game_ui_STAGE="LEVEL";
N["nl-nl"].game_ui_LIVES="LEVENS";N["nl-nl"].game_ui_TIME="TIJD";N["nl-nl"].game_ui_HIGHSCORE="HIGH SCORE";N["nl-nl"].game_ui_LEVEL="LEVEL";N["nl-nl"].game_ui_time_left="Resterende tijd";N["nl-nl"].game_ui_TIME_TO_BEAT="DOELTIJD";N["nl-nl"].game_ui_SCORE_TO_BEAT="DOELSCORE";N["nl-nl"].game_ui_HIGHSCORE_break="HIGH\nSCORE";N["en-us"]=N["en-us"]||{};N["en-us"].game_ui_SCORE="SCORE";N["en-us"].game_ui_STAGE="STAGE";N["en-us"].game_ui_LIVES="LIVES";N["en-us"].game_ui_TIME="TIME";
N["en-us"].game_ui_HIGHSCORE="HIGH SCORE";N["en-us"].game_ui_LEVEL="LEVEL";N["en-us"].game_ui_time_left="Time left";N["en-us"].game_ui_TIME_TO_BEAT="TIME TO BEAT";N["en-us"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";N["en-us"].game_ui_HIGHSCORE_break="HIGH\nSCORE";N["en-gb"]=N["en-gb"]||{};N["en-gb"].game_ui_SCORE="SCORE";N["en-gb"].game_ui_STAGE="STAGE";N["en-gb"].game_ui_LIVES="LIVES";N["en-gb"].game_ui_TIME="TIME";N["en-gb"].game_ui_HIGHSCORE="HIGH SCORE";N["en-gb"].game_ui_LEVEL="LEVEL";
N["en-gb"].game_ui_time_left="Time left";N["en-gb"].game_ui_TIME_TO_BEAT="TIME TO BEAT";N["en-gb"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";N["en-gb"].game_ui_HIGHSCORE_break="HIGH\nSCORE";N["de-de"]=N["de-de"]||{};N["de-de"].game_ui_SCORE="PUNKTE";N["de-de"].game_ui_STAGE="STUFE";N["de-de"].game_ui_LIVES="LEBEN";N["de-de"].game_ui_TIME="ZEIT";N["de-de"].game_ui_HIGHSCORE="HIGHSCORE";N["de-de"].game_ui_LEVEL="LEVEL";N["de-de"].game_ui_time_left="Restzeit";N["de-de"].game_ui_TIME_TO_BEAT="ZEITVORGABE";
N["de-de"].game_ui_SCORE_TO_BEAT="Zu schlagende Punktzahl";N["de-de"].game_ui_HIGHSCORE_break="HIGHSCORE";N["fr-fr"]=N["fr-fr"]||{};N["fr-fr"].game_ui_SCORE="SCORE";N["fr-fr"].game_ui_STAGE="SC\u00c8NE";N["fr-fr"].game_ui_LIVES="VIES";N["fr-fr"].game_ui_TIME="TEMPS";N["fr-fr"].game_ui_HIGHSCORE="MEILLEUR SCORE";N["fr-fr"].game_ui_LEVEL="NIVEAU";N["fr-fr"].game_ui_time_left="Temps restant";N["fr-fr"].game_ui_TIME_TO_BEAT="TEMPS \u00c0 BATTRE";N["fr-fr"].game_ui_SCORE_TO_BEAT="SCORE \u00c0 BATTRE";
N["fr-fr"].game_ui_HIGHSCORE_break="MEILLEUR\nSCORE";N["pt-br"]=N["pt-br"]||{};N["pt-br"].game_ui_SCORE="PONTOS";N["pt-br"].game_ui_STAGE="FASE";N["pt-br"].game_ui_LIVES="VIDAS";N["pt-br"].game_ui_TIME="TEMPO";N["pt-br"].game_ui_HIGHSCORE="RECORDE";N["pt-br"].game_ui_LEVEL="N\u00cdVEL";N["pt-br"].game_ui_time_left="Tempo restante";N["pt-br"].game_ui_TIME_TO_BEAT="HORA DE ARRASAR";N["pt-br"].game_ui_SCORE_TO_BEAT="RECORDE A SER SUPERADO";N["pt-br"].game_ui_HIGHSCORE_break="RECORDE";
N["es-es"]=N["es-es"]||{};N["es-es"].game_ui_SCORE="PUNTOS";N["es-es"].game_ui_STAGE="FASE";N["es-es"].game_ui_LIVES="VIDAS";N["es-es"].game_ui_TIME="TIEMPO";N["es-es"].game_ui_HIGHSCORE="R\u00c9CORD";N["es-es"].game_ui_LEVEL="NIVEL";N["es-es"].game_ui_time_left="Tiempo restante";N["es-es"].game_ui_TIME_TO_BEAT="TIEMPO OBJETIVO";N["es-es"].game_ui_SCORE_TO_BEAT="PUNTUACI\u00d3N OBJETIVO";N["es-es"].game_ui_HIGHSCORE_break="R\u00c9CORD";N["tr-tr"]=N["tr-tr"]||{};N["tr-tr"].game_ui_SCORE="SKOR";
N["tr-tr"].game_ui_STAGE="B\u00d6L\u00dcM";N["tr-tr"].game_ui_LIVES="HAYATLAR";N["tr-tr"].game_ui_TIME="S\u00dcRE";N["tr-tr"].game_ui_HIGHSCORE="Y\u00dcKSEK SKOR";N["tr-tr"].game_ui_LEVEL="SEV\u0130YE";N["tr-tr"].game_ui_time_left="Kalan zaman";N["tr-tr"].game_ui_TIME_TO_BEAT="B\u0130T\u0130RME ZAMANI";N["tr-tr"].game_ui_SCORE_TO_BEAT="B\u0130T\u0130RME PUANI";N["tr-tr"].game_ui_HIGHSCORE_break="Y\u00dcKSEK\nSKOR";N["ru-ru"]=N["ru-ru"]||{};N["ru-ru"].game_ui_SCORE="\u0420\u0415\u0417\u0423\u041b\u042c\u0422\u0410\u0422";
N["ru-ru"].game_ui_STAGE="\u042d\u0422\u0410\u041f";N["ru-ru"].game_ui_LIVES="\u0416\u0418\u0417\u041d\u0418";N["ru-ru"].game_ui_TIME="\u0412\u0420\u0415\u041c\u042f";N["ru-ru"].game_ui_HIGHSCORE="\u0420\u0415\u041a\u041e\u0420\u0414";N["ru-ru"].game_ui_LEVEL="\u0423\u0420\u041e\u0412\u0415\u041d\u042c";N["ru-ru"].game_ui_time_left="Time left";N["ru-ru"].game_ui_TIME_TO_BEAT="TIME TO BEAT";N["ru-ru"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";N["ru-ru"].game_ui_HIGHSCORE_break="\u0420\u0415\u041a\u041e\u0420\u0414";
N["ar-eg"]=N["ar-eg"]||{};N["ar-eg"].game_ui_SCORE="\u0627\u0644\u0646\u062a\u064a\u062c\u0629";N["ar-eg"].game_ui_STAGE="\u0645\u0631\u062d\u0644\u0629";N["ar-eg"].game_ui_LIVES="\u0639\u062f\u062f \u0627\u0644\u0645\u062d\u0627\u0648\u0644\u0627\u062a";N["ar-eg"].game_ui_TIME="\u0627\u0644\u0648\u0642\u062a";N["ar-eg"].game_ui_HIGHSCORE="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";N["ar-eg"].game_ui_LEVEL="\u0645\u0633\u062a\u0648\u0649";N["ar-eg"].game_ui_time_left="Time left";
N["ar-eg"].game_ui_TIME_TO_BEAT="TIME TO BEAT";N["ar-eg"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";N["ar-eg"].game_ui_HIGHSCORE_break="\u0623\u0639\u0644\u0649 \u0646\u062a\u064a\u062c\u0629";N["ko-kr"]=N["ko-kr"]||{};N["ko-kr"].game_ui_SCORE="\uc810\uc218";N["ko-kr"].game_ui_STAGE="\uc2a4\ud14c\uc774\uc9c0";N["ko-kr"].game_ui_LIVES="\uae30\ud68c";N["ko-kr"].game_ui_TIME="\uc2dc\uac04";N["ko-kr"].game_ui_HIGHSCORE="\ucd5c\uace0 \uc810\uc218";N["ko-kr"].game_ui_LEVEL="\ub808\ubca8";
N["ko-kr"].game_ui_time_left="Time left";N["ko-kr"].game_ui_TIME_TO_BEAT="TIME TO BEAT";N["ko-kr"].game_ui_SCORE_TO_BEAT="SCORE TO BEAT";N["ko-kr"].game_ui_HIGHSCORE_break="\ucd5c\uace0 \uc810\uc218";N["jp-jp"]=N["jp-jp"]||{};N["jp-jp"].game_ui_SCORE="\u30b9\u30b3\u30a2";N["jp-jp"].game_ui_STAGE="\u30b9\u30c6\u30fc\u30b8";N["jp-jp"].game_ui_LIVES="\u30e9\u30a4\u30d5";N["jp-jp"].game_ui_TIME="\u30bf\u30a4\u30e0";N["jp-jp"].game_ui_HIGHSCORE="\u30cf\u30a4\u30b9\u30b3\u30a2";
N["jp-jp"].game_ui_LEVEL="\u30ec\u30d9\u30eb";N["jp-jp"].game_ui_time_left="\u6b8b\u308a\u6642\u9593";N["jp-jp"].game_ui_TIME_TO_BEAT="\u30af\u30ea\u30a2\u307e\u3067\u3042\u3068";N["jp-jp"].game_ui_SCORE_TO_BEAT="\u30af\u30ea\u30a2\u307e\u3067\u3042\u3068";N["jp-jp"].game_ui_HIGHSCORE_break="\u30cf\u30a4\n\u30b9\u30b3\u30a2";var Lf={};
function Mf(){Lf={Qe:{ll:"en-us",pk:"en-us en-gb nl-nl de-de fr-fr pt-br es-es tr-tr ru-ru ar-eg ko-kr jp-jp".split(" ")},Yd:{ed:L(1040),rr:L(960),sc:L(640),rh:L(640),mg:L(0),xl:L(-80),lg:0,minHeight:L(780),rn:{id:"canvasBackground",depth:50},bd:{id:"canvasGame",depth:100,top:L(200,"round"),left:L(40,"round"),width:L(560,"round"),height:L(560,"round")},cd:{id:"canvasGameUI",depth:150,top:0,left:0,height:L(120,"round")},hg:{id:"canvasMain",depth:200}},sn:{ed:L(640),rr:L(640),sc:L(1152),rh:L(1152),
mg:L(0),xl:L(0),lg:0,minHeight:L(640),minWidth:L(850),rn:{id:"canvasBackground",depth:50},bd:{id:"canvasGame",depth:100,top:L(40,"round"),left:L(296,"round"),width:L(560,"round"),height:L(560,"round")},cd:{id:"canvasGameUI",depth:150,top:0,left:L(151),width:L(140)},hg:{id:"canvasMain",depth:200}},rc:{bigPlay:{type:"text",r:re,Ea:L(38),Gb:L(99),font:{align:"center",i:"middle",fontSize:M({big:46,small:30}),fillColor:"#01198a",I:{h:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}},rd:2,sd:L(30),fontSize:M({big:46,
small:30})},difficulty_toggle:{type:"toggleText",r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"0",r:Yc,U:"optionsDifficulty_easy"},{id:"1",r:Xc,U:"optionsDifficulty_medium"},{id:"2",r:Wc,U:"optionsDifficulty_hard"}],ai:L(30),bi:L(12),Pg:L(10),rd:2,sd:L(30),fontSize:M({big:40,small:20})},music_toggle:{type:"toggle",r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,
small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"on",r:le,U:"optionsMusic_on"},{id:"off",r:ke,U:"optionsMusic_off"}],ai:L(30),bi:L(12),Pg:0,rd:2,sd:L(30)},sfx_toggle:{type:"toggle",r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"on",r:je,U:"optionsSFX_on"},{id:"off",r:ie,U:"optionsSFX_off"}],ai:L(30),bi:L(12),Pg:0,rd:2,sd:L(30)},music_big_toggle:{type:"toggleText",
r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"on",r:"undefined"!==typeof ae?ae:void 0,U:"optionsMusic_on"},{id:"off",r:"undefined"!==typeof be?be:void 0,U:"optionsMusic_off"}],ai:L(28,"round"),bi:L(10),Pg:L(10),rd:2,sd:L(30),fontSize:M({big:40,small:20})},sfx_big_toggle:{type:"toggleText",r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",
I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"on",r:"undefined"!==typeof Zd?Zd:void 0,U:"optionsSFXBig_on"},{id:"off",r:"undefined"!==typeof $d?$d:void 0,U:"optionsSFXBig_off"}],ai:L(33,"round"),bi:L(12),Pg:L(10),rd:2,sd:L(30),fontSize:M({big:40,small:20})},language_toggle:{type:"toggleText",r:he,Ea:L(106),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},$:[{id:"en-us",r:Zc,U:"optionsLang_en-us"},
{id:"en-gb",r:$c,U:"optionsLang_en-gb"},{id:"nl-nl",r:ad,U:"optionsLang_nl-nl"},{id:"de-de",r:cd,U:"optionsLang_de-de"},{id:"fr-fr",r:dd,U:"optionsLang_fr-fr"},{id:"pt-br",r:ed,U:"optionsLang_pt-br"},{id:"es-es",r:fd,U:"optionsLang_es-es"},{id:"ru-ru",r:hd,U:"optionsLang_ru-ru"},{id:"ar-eg",r:id,U:"optionsLang_ar-eg"},{id:"ko-kr",r:jd,U:"optionsLang_ko-kr"},{id:"tr-tr",r:bd,U:"optionsLang_tr-tr"},{id:"jp-jp",r:gd,U:"optionsLang_jp-jp"}],ai:L(40),bi:L(20),Pg:L(10),rd:2,sd:L(30),fontSize:M({big:40,
small:20})},default_text:{type:"text",r:ge,Ea:L(40),Gb:L(40),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}},rd:2,sd:L(30),fontSize:M({big:40,small:20})},default_image:{type:"image",r:ge,Ea:L(40),Gb:L(40),sd:L(6)},options:{type:"image",r:ee}},pn:{bigPlay:{type:"text",r:re,Ea:L(40),Gb:L(76),font:{align:"center",i:"middle",fontSize:M({big:40,small:20}),fillColor:"#01198a",I:{h:!0,color:"#7bfdff",offsetX:0,offsetY:2,
blur:0}},rd:2,sd:L(30),fontSize:M({big:40,small:20})}},Ki:{green:{font:{align:"center",i:"middle",fillColor:"#018a17",I:{h:!0,color:"#d2ff7b",offsetX:0,offsetY:2,blur:0}}},blue:{font:{align:"center",i:"middle",fillColor:"#01198a",I:{h:!0,color:"#7bfdff",offsetX:0,offsetY:2,blur:0}}},bluegreen:{font:{align:"center",i:"middle",fillColor:"#004f89",I:{h:!0,color:"#7bffca",offsetX:0,offsetY:2,blur:0}}},orange:{font:{align:"center",i:"middle",fillColor:"#9a1900",I:{h:!0,color:"#ffb986",offsetX:0,offsetY:2,
blur:0}}},orangeyellow:{font:{align:"center",i:"middle",fillColor:"#8d2501",I:{h:!0,color:"#ffbe60",offsetX:0,offsetY:2,blur:0}}},pink:{font:{align:"center",i:"middle",fillColor:"#c6258f",I:{h:!0,color:"#ffbde9",offsetX:0,offsetY:2,blur:0}}},white:{font:{align:"center",i:"middle",fillColor:"#ffffff"}},pastel_pink:{font:{align:"center",i:"middle",fillColor:"#83574f"}},whiteWithRedBorder:{font:{align:"center",i:"middle",fillColor:"#ffffff",I:{h:!0,color:"#4c0200",offsetX:0,offsetY:2,blur:0}}},whiteWithBlueBorder:{font:{align:"center",
i:"middle",fillColor:"#ffffff",I:{h:!0,color:"#002534",offsetX:0,offsetY:2,blur:0}}}},buttons:{default_color:"green"},Na:{Fz:20},Id:{backgroundImage:"undefined"!==typeof ve?ve:void 0,Dx:0,ov:500,tl:5E3,mx:5E3,Gt:-1,Bz:12,Az:100,df:L(78),Tp:{align:"center"},pm:L(560),Fh:L(400),Gh:{align:"center"},Bg:L(680),xf:L(16),Oo:L(18),qj:L(8),Ps:L(8),Qs:L(9),Rs:L(9),Oj:{align:"center",fillColor:"#3B0057",fontSize:L(24)},gu:{align:"center"},hu:L(620),om:L(500),rj:"center",Dg:L(500),tj:L(60),bc:{align:"center"},
Sc:{align:"bottom",offset:L(20)},To:L(806),Ro:500,bx:L(20)},Qo:{rj:"right",pm:L(280),Bg:L(430),Dg:L(340),bc:{align:"right",offset:L(32)},Sc:L(560),To:L(560)},fm:{nn:L(860),backgroundImage:void 0!==typeof ve?ve:void 0,fw:700,dt:1800,yx:700,cy:2600,yh:void 0!==typeof ve?Be:void 0,Ed:700,ej:{align:"center"},Yk:{align:"center"},fj:void 0!==typeof Be?-Be.height:0,dj:{align:"top",offset:L(20)},io:1,Sr:1,jo:1,Tr:1,ho:1,Rr:1,jw:J,kw:sc,hw:J,iw:J,gw:J,by:{align:"center"},Ql:L(656),Bj:L(300),Ol:700,ay:700,
vr:L(368),Ik:L(796),Ui:L(440),ur:700,$o:L(36),wl:L(750),xx:500,rj:"center",Dg:L(500),tj:L(60),bc:{align:"center"},Sc:{align:"bottom",offset:L(20)},To:L(806),Ro:500,bx:L(20)},Np:{nn:L(0),Ql:L(456),Bj:L(320),vr:{align:"center"},Ik:L(346),Ui:L(460),$o:{align:"left",offset:L(32)},wl:L(528),rj:"right",Dg:L(340),bc:{align:"right",offset:L(32)},Sc:L(560),To:L(560)},yg:{Sx:{align:"center",offset:L(-230)},jp:{align:"top",offset:L(576)},Rx:"options",td:{i:"bottom"},Vg:{align:"center"},Rd:{align:"top",offset:L(35,
"round")},me:L(232),Mf:L(98),Uz:{align:"center",offset:L(-206)},iq:{align:"top",offset:L(30)},Tz:{align:"center",offset:L(206)},hq:{align:"top",offset:L(30)},type:"grid",Ox:3,QB:3,Px:5,RB:4,xr:!0,Pv:!0,so:L(78),Vr:{align:"top",offset:L(140)},Xr:{align:"top",offset:L(140)},Wr:L(20),rw:L(18),sw:L(18),Mw:{mo:{fontSize:M({big:60,small:30}),fillColor:"#3F4F5E",align:"center",i:"middle",I:{h:!0,color:"#D0D8EA",offsetX:0,offsetY:L(6),blur:0}}},Nw:{mo:{fontSize:M({big:32,small:16}),fillColor:"#3F4F5E",align:"center",
i:"middle",I:{h:!0,color:"#D0D8EA",offsetX:0,offsetY:L(2),blur:0}}},Js:L(438),Ks:L(438),Bs:{align:"center"},Cs:{align:"center"},Ts:{align:"center"},Us:{align:"center",offset:L(-22)},Fs:{align:"center"},Gs:{align:"center",offset:L(-10)},cz:{align:"center",offset:L(216)},Mt:{align:"top",offset:L(574)},Lt:{fontSize:M({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},Nt:L(10),qp:{fontSize:M({big:24,small:12}),fillColor:"#3F4F5E",align:"center"},lt:{align:"center"},mt:{align:"top",offset:L(588)},
fy:L(160),ey:L(40),backgroundImage:"undefined"!==typeof s_screen_levelselect?s_screen_levelselect:void 0,uz:L(10),vz:200,tz:L(200),nB:L(600),Jx:800,Ix:500},Ds:{iq:{align:"top",offset:L(20)},hq:{align:"top",offset:L(20)},Rd:{align:"top",offset:L(25,"round")},so:L(234),Vr:{align:"top",offset:L(110)},Xr:{align:"top",offset:L(110)},Mt:{align:"top",offset:L(536)},mt:{align:"top",offset:L(550)},jp:{align:"top",offset:L(538)}},rl:{nd:"undefined"!==typeof te?te:void 0,it:{align:"center"},mp:"undefined"!==
typeof te?-te.height:void 0,Jl:[{type:"y",Pa:0,duration:800,end:{align:"center",offset:L(-142)},lb:sc,Xb:Af}],lp:[{type:"y",Pa:0,duration:600,end:"undefined"!==typeof te?-te.height:void 0,lb:rc,Wq:!0}],Kq:{align:"center",i:"middle"},Lq:{align:"center"},Mq:0,Gi:L(500),dn:L(80),as:{align:"center",i:"middle"},cs:{align:"center"},ds:0,il:L(560),bs:L(80),jt:3500},Ko:{Jl:[{type:"y",Pa:0,duration:800,end:{align:"center"},lb:sc,Xb:Af}]},uA:{nd:"undefined"!==typeof s_overlay_challenge_start?s_overlay_challenge_start:
void 0,it:{align:"center"},mp:L(56),Ll:0,Ml:0,td:{align:"center",i:"top"},me:L(500),Mf:L(100),Vg:{align:"center"},Rd:L(90),zB:{align:"center",i:"middle"},EB:L(500),DB:L(80),IB:{align:"center"},JB:L(250),GC:{align:"center",i:"top"},IC:L(500),HC:L(40),JC:{align:"center"},KC:L(348),FC:{align:"center",i:"top"},MC:L(500),LC:L(50),OC:{align:"center"},PC:L(388),AD:{align:"center",i:"top"},CD:L(500),BD:L(40),FD:{align:"center"},GD:L(442),DD:0,ED:0,zD:{align:"center",i:"top"},ID:L(500),HD:L(50),JD:{align:"center"},
KD:L(482),yD:L(10),wD:0,xD:0,Fi:800,$m:sc,an:600,bn:rc,jt:3500},tA:{cA:500,Fi:800,NB:1500,OB:500,NC:2500,SC:500,QC:3200,RC:800,tB:4200,uB:300,mA:4500,XB:{align:"center"},YB:L(-800),VB:{align:"center"},WB:L(52),Ll:0,Ml:0,Sk:.8,Gr:"#000000",ap:{align:"center",i:"middle"},vB:L(360),qB:L(120),rB:L(4),sB:L(4),wB:{align:"center"},xB:L(340),iD:{align:"center"},jD:L(600),hD:L(500),gD:L(120),fD:{align:"center",i:"middle"},LD:{align:"center",i:"middle"},PD:L(360),MD:L(60),ND:L(4),OD:L(4),QD:{align:"center"},
RD:L(480),pD:L(460),kD:{align:"center"},lD:L(400),nA:{align:"center"},oA:L(500),LB:{align:"center",i:"middle"},MB:L(75,"round"),KB:L(48),PB:L(120),HB:L(214,"round"),AB:L(40),BB:L(4),CB:L(4),FB:0,GB:0,MA:{align:"center",i:"middle"},PA:L(220),OA:L(180),NA:L(80),KA:L(4),LA:L(4)},wa:{Kl:{Bn:"undefined"!==typeof s_overlay_difficulty?s_overlay_difficulty:void 0,Tv:"undefined"!==typeof xe?xe:void 0,Ow:"undefined"!==typeof s_overlay_level_win?s_overlay_level_win:void 0,Lw:"undefined"!==typeof s_overlay_level_fail?
s_overlay_level_fail:void 0},zz:500,Fi:800,$m:sc,an:800,bn:jc,yc:{align:"center"},ec:0,td:{align:"center",i:"middle",fontSize:M({big:26,small:13})},Vg:{align:"center"},Rd:L(58),me:L(500),Mf:L(100),Wt:{align:"center",i:"middle",fontSize:M({big:56,small:28})},oz:{align:"center"},pz:L(236),Fn:{align:"center",i:"top",fontSize:M({big:24,small:12})},Br:{align:"center"},Gn:L(144),Wi:{align:"center",i:"top",fontSize:M({big:56,small:28})},Ok:{align:"center"},th:L(176),Nk:L(200),Mk:L(60),Kj:{align:"center",
i:"top",fontSize:M({big:24,small:12})},Ff:{align:"center"},Mg:L(286),Tt:L(0),Nr:!1,Pd:L(14),jm:L(10),Lg:{align:"center",i:"top",fontSize:M({big:24,small:12})},Vh:L(10),Wh:L(4),Xh:L(200),eD:L(50),mv:{align:"center",offset:L(12)},Pq:L(549),bw:{align:"center",offset:L(162)},Or:L(489),Pi:{align:"center",offset:L(250)},oh:L(10),nh:L(90),kg:L(90),Hp:{align:"center",offset:L(-177,"round")},Ip:L(120),Jp:{align:"center"},Kp:L(96),Lp:{align:"center",offset:L(179,"round")},Mp:L(120),cD:200,Zy:500,It:800,Kt:0,
bz:0,az:300,$y:200,Jt:300,Sk:.8,$b:800,Gr:"#000000",Yo:L(508),vj:L(394),Ws:L(96),Xs:L(74),ul:3,Hh:400,nx:2500,pB:0,qx:L(100),Ys:1.5,vx:{align:"center"},wx:L(76),vl:L(180),ux:L(36),Zs:{align:"center",i:"middle",fontSize:M({big:22,small:12}),H:"ff_opensans_extrabold",fillColor:"#1d347f",I:{h:!0,color:"#68cbfa",offsetY:L(2)}},Vs:500,ox:500,px:L(-30),sx:500,rx:0,tx:4E3,vm:600,Iz:1500,Yq:500,kh:750,yw:{align:"center"},zw:L(290),js:L(350),Fx:1E3,type:{level:{sk:"level",od:!0,Rh:!0,Pj:"title_level",Gf:"totalScore",
qk:"retry",Uk:"next"},failed:{sk:"failed",od:!1,Rh:!1,Pj:"title_level",Xt:"subtitle_failed",qk:"exit",Uk:"retry"},endless:{sk:"endless",od:!1,Rh:!0,Pj:"title_endless",Hn:"totalScore",Gf:"highScore",qk:"exit",Uk:"retry"},difficulty:{sk:"difficulty",od:!1,Rh:!0,Pj:"title_difficulty",Hn:"timeLeft",Gf:["totalScore","timeBonus"],qk:"exit",Uk:"retry"}}},As:{oh:L(0),Rd:L(30),Gn:L(114),th:L(146),Mg:L(266),Pq:L(488),Or:L(428),Yo:{align:"center",offset:L(220)},vj:L(260)},lj:{backgroundImage:"undefined"!==typeof Ae?
Ae:void 0},options:{backgroundImage:ue,yc:{align:"center"},ec:0,td:{},Vg:{align:"center"},Rd:L(58),me:L(500),Mf:L(100),yk:L(460,"round"),xk:{align:"center"},Li:{align:"center",offset:L(36)},Xd:L(10,"round"),Pi:L(510),oh:L(10),nh:L(130),kg:L(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","moreGames","about"],levelMapScreen:["startScreen",["music","sfx"],"language","moreGames","about"],inGame:["resume","tutorial",["music","sfx"],"moreGames","quit"]},xj:800,yj:sc,Hl:600,Il:jc,nr:{align:"center"},
xn:L(260),Bk:L(460),wn:L(300),lr:{align:"center"},vn:L(460),kr:{align:"center"},un:L(560,"round"),Ri:L(460,"round"),Vl:{},Sd:"undefined"!==typeof we?we:void 0,ym:{align:"center"},Of:L(84,"round"),Am:{align:"center",i:"top"},Bm:L(480),$p:L(46),xu:{align:"center"},aq:L(110,"round"),uu:{align:"center"},Yp:L(160,"round"),wu:{align:"center"},Zp:L(446,"round"),zm:{i:"middle",align:"center",fontSize:M({big:36,small:18})},ci:L(480),vu:L(160),tu:{align:"center",offset:L(-80,"round")},Xp:L(556,"round"),su:{align:"center",
offset:L(80,"round")},Wp:L(556,"round"),zq:{align:"center",i:"top",fillColor:"#3C0058",fontSize:M({big:26,small:13}),ka:L(6)},Bq:L(480),Aq:L(50),Cq:{align:"center"},Sm:L(106,"round"),Dq:{align:"center",i:"top",fillColor:"#3C0058",fontSize:M({big:26,small:13}),ka:L(6)},mk:L(480),Bi:L(110),Um:{align:"center"},Ci:L(396,"round"),Tm:{align:"center"},lk:L(140),Rm:{align:"center"},kk:L(500),Ai:L(480),Vm:{align:"center",i:"top",fillColor:"#808080",fontSize:M({big:12,small:8})},Gq:{align:"center"},Wm:L(610),
Fq:L(440),Eq:L(20),gh:L(200),nk:L(200),Iu:L(80),Ju:L(140),Hu:L(10)},Tx:{Rd:L(12),Li:{align:"center",offset:L(16)},xn:L(200),wn:L(300),vn:L(400),un:L(500,"round"),Of:L(60,"round"),aq:L(80,"round"),Yp:L(134,"round"),Zp:L(410,"round"),Xp:L(500,"round"),Wp:L(500,"round"),Sm:L(86,"round"),lk:L(126),Ci:L(392,"round"),kk:L(490),Wm:L(590)},et:{backgroundImage:"undefined"!==typeof s_overlay_challenge_options?s_overlay_challenge_options:ue,yc:{align:"center"},ec:L(120),td:{},Vg:{align:"center"},Rd:L(200),yk:L(460,
"round"),xk:{align:"center"},Li:{align:"center",offset:L(140)},Xd:L(10,"round"),Pi:L(510),oh:L(10),nh:L(130),kg:L(90),buttons:{startScreen:["tutorial",["music","sfx"],"language","about"],inGame_challengee:["resume","tutorial",["music","sfx"],"forfeitChallenge"],inGame_challenger:["resume","tutorial",["music","sfx"],"cancelChallenge"]},xj:800,yj:sc,Hl:600,Il:jc,Vl:{},tC:{align:"center"},uC:L(360),sC:L(460),rC:L(300),nC:"default_text",oC:{align:"center"},pC:L(630),kC:"default_text",lC:{align:"center"},
mC:L(730,"round"),qC:L(460,"round"),mr:{},nr:{align:"center"},xn:L(200),Bk:L(460),wn:L(250),lr:{align:"center"},vn:L(520),kr:{align:"center"},un:L(620,"round"),Ri:L(460,"round"),ap:{},Bx:{align:"center"},Cx:L(200),bp:L(460),Ax:L(300),Sd:"undefined"!==typeof we?we:void 0,ym:{align:"center"},Of:L(0,"round"),Am:{align:"center",i:"top"},Bm:L(480),$p:L(50),xu:{align:"center"},aq:L(20,"round"),uu:{align:"center"},Yp:L(70,"round"),wu:{align:"center"},Zp:L(356,"round"),zm:{i:"middle",align:"center",fontSize:M({big:36,
small:18})},ci:L(480),vu:L(150),tu:L(224,"round"),Xp:L(636,"round"),su:L(350,"round"),Wp:L(636,"round"),zq:{align:"center",i:"top",fillColor:"#3C0058",fontSize:M({big:26,small:13}),ka:L(6)},Bq:L(480),Aq:L(50),Cq:{align:"center"},Sm:L(26,"round"),Dq:{align:"center",i:"top",fillColor:"#3C0058",fontSize:M({big:26,small:13}),ka:L(6)},mk:L(480),Bi:L(110),Um:{align:"center"},Ci:L(316,"round"),Tm:{align:"center"},lk:L(60),Rm:{align:"center"},kk:L(420),Ai:L(480),Vm:{align:"center",i:"top",fillColor:"#808080",
fontSize:M({big:12,small:8})},Gq:{align:"center"},Wm:L(530),Fq:L(440),Eq:L(20),gh:L(200),nk:L(200),Iu:L(80),Ju:L(100),Hu:L(10)},An:{backgroundImage:"undefined"!==typeof s_overlay_dialog?s_overlay_dialog:ue,yc:{align:"center"},ec:L(120),yk:L(460,"round"),xk:{align:"center"},Li:{align:"bottom",offset:L(20)},Xd:L(10,"round"),Pi:L(510),oh:L(10),nh:L(130),kg:L(90),xj:800,yj:sc,Hl:600,Il:jc,ot:{},ry:{align:"center"},sy:{align:"center",offset:L(40)},tp:L(460),sp:L(300),Vt:{},py:{align:"center"},qy:{align:"center",
offset:L(160)},oy:L(460),ny:L(200)},Vk:{backgroundImage:"undefined"!==typeof s_screen_end?s_screen_end:void 0,gu:{align:"center"},hu:L(152),om:L(560),yz:L(560),font:{align:"center",i:"middle",fontSize:M({big:52,small:26}),fillColor:"#FFFFFF"},xv:{align:"center"},cr:L(600),br:L(460),ar:"default_text"},bo:{cr:L(520)}}}
var Nf={ly:"boostermedia",Kz:!1,Ij:{$w:!1,Cn:"8784d238b5a81ab432d0bf303850ed8a 9f5ffc7a10e0bad054458b089947ce2f 0c73b027c77dd2c1ee6cd996c2c83efc 03a60a509d53952c91fc9865fbd492ef 0e26dbc8d26a0880786e55e3e950a320 7e77fcbd9a8ec327db79b6c753a5eef1 5ff97ceeea117a01f512adc7ece5ade7 54f5ededff723ca5c52bc75764ceb738 526ceb1f05b2418711e1eb59058e0b09 ae11a4449bebb3561a078bac793dc74b f51482fb5ecee35fd139f89728a7a616".split(" ")},Qe:{ll:"en-us",pk:["en-us"]}},Of=null;
function Pf(){Of={qa:{$q:250,vv:L(5),Qk:200,Rk:100,Ln:1.3,Hr:20,Zv:L(300),Ir:700,Hx:1E3,Bl:100,hy:90,iy:-.5,Cj:200,jy:100,ky:1.275},Ba:{Qk:250,Yv:4,Rk:300,Ln:2,Mn:.75},Gc:{yv:L({x:L(-99,"round"),y:L(26,"floor")}),hx:75,W:[{x:0,y:0,scale:1},{x:-L(55,"round"),y:L(19,"floor"),scale:.6}],scale:1,size:L(10),x:L(275,"round"),y:L(500,"round")},Yd:{bd:{id:"canvasGame",depth:100,top:L(200,"round"),left:L(46,"round"),width:L(550,"round"),height:L(560,"round")}},kb:{Mn:5},jd:{wv:!1,Dv:1,scale:1.5,Qy:.5,Vp:200,
Pz:20},pg:{Wk:"Bubbleshooter",de:"endless"},k:{kA:1.41},XA:{Wk:"Bubbleshooter"},fe:{Nv:L(10),fs:1,lineWidth:L(5),cC:L(5)},da:{Gw:5},Xe:{bubbles:[0,10,null,null,15,null,null,25,null,null,50,null,null,100,null,null,null,null,null,null,null],Kw:2,Ny:500,Oy:250,Bt:100},xz:{Zz:void 0,$z:!1,ZC:!1,My:!1},lB:9,Mo:[{name:"level_1",s:{Tc:1,Re:7,Ge:40,border:10,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.1)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[0,10,10,10,0,10,0],
Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,30,0,0,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_2_Cyan",
s:{Tc:2,Re:6,Ge:50,border:10,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[0,10,10,10,10,10,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,35,0,0,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,
1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_3_Colorbombs",s:{Tc:5,Re:6,Ge:40,border:10,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[0,10,10,10,10,10,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),
Jb:[90,30,0,999,0],Kb:[90,30,0,3,0],Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_4_Pink",s:{Tc:7,Re:5,Ge:60,border:9,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),
Jb:[10,10,10,10,10,10,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,30,0,3,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},
da:{Se:3}},{name:"level_5_Blockers",s:{Tc:10,Re:5,Ge:40,border:9,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[10,10,10,10,10,10,2],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,35,0,3,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,
0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_6_bombs",s:{Tc:12,Re:4,Ge:70,border:8,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[10,10,10,10,10,10,4],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),
Jb:[90,35,999,2,0],Kb:[90,35,2,2,0],Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_7_Fireball",s:{Tc:15,Re:4,Ge:40,border:8,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),
Jb:[10,10,10,10,10,10,6],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,40,2,2,0],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},
da:{Se:3}},{name:"level_8_theoretical end",s:{Tc:20,Re:3,Ge:80,border:7,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[10,10,10,10,10,10,10],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,40,1,1,999],Kb:[90,40,1,1,.5],Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,
0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}},{name:"level_9_impossible",s:{Tc:100,Re:2,Ge:90,border:7,cb:5,Md:500,description:"Description of level"},ca:{speed:L(1.2)},Ee:{nf:"pink red yellow blue cyan green blocker".split(" "),Jb:[10,10,10,10,10,10,10],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,
Sb:null},ub:{mf:"bubble_in_field bubble_not_in_field bomb colorbomb fireball perfect_bubble".split(" "),Jb:[90,90,1,1,.1],Kb:null,Lb:null,Mb:null,Nb:null,Ob:null,Pb:null,Qb:null,Rb:null,Sb:null,ue:[0,0,0,0,0,1],ve:[0,0,0,0,0,1],we:[0,0,0,0,0,1],xe:[0,0,0,0,0,1],ye:[0,0,0,0,0,1],ze:[0,0,0,0,0,1],Ae:[0,0,0,0,0,1],Be:[0,0,0,0,0,1],Ce:[0,0,0,0,0,1],te:[0,0,0,0,0,1]},Ec:{Ba:10,kb:10,Ne:10,all:10},kb:{rb:L(100)},Ba:{rb:L(100)},da:{Se:3}}]}}var Qf={};
function Rf(){Qf={Ur:"BubbleCharmsChristmas",buttons:{default_color:"christmasGreen",bigPlay:"christmasRed"},xc:{kn:1,Ii:500},fm:{pv:[{r:ve,x:0,y:0},{r:"undefined"!==typeof Be?Be:void 0,y:L(20,"round"),x:{align:"center"}}]},yg:{pv:[{r:"undefined"!==typeof s_screen_levelselect?s_screen_levelselect:void 0,x:0,y:0}],td:{H:cf.H,align:"center",i:"middle",fillColor:"#ffffff",fontSize:M({big:36,small:18})},Lt:{H:cf.H,fontSize:M({big:34,small:18}),fillColor:"#ffffff",align:"center"},qp:{H:cf.H,fontSize:M({big:34,
small:18}),fillColor:"#ffffff",align:"center"}},rl:{mp:-te.height,Kq:{align:"center",i:"top",fontSize:M({big:34,small:16}),fillColor:"#ffffff"},Lq:{align:"center"},Mq:L(472,"round"),Gi:L(400),dn:L(80),as:{H:cf.H,fontSize:L(60),fillColor:"#ffffff",align:"center",i:"middle"},cs:{align:"center"},ds:L(430,"round")},wa:{ec:L(14),td:{H:cf.H,align:"center",i:"middle",fontSize:M({big:44,small:22}),fillColor:"#ffffff"},qD:!0,Fn:{H:cf.H,align:"center",i:"top",fillColor:"#FFFFFF",fontSize:M({big:36,small:18})},
th:L(186),Wi:{align:"center",i:"top",fillColor:"#FFFFFF",fontSize:M({big:72,small:36})},Kj:{H:cf.H,i:"bottom",fillColor:"#ffffff",fontSize:M({big:36,small:18})},Pd:L(4),Lg:{i:"bottom",fillColor:"#ffffff",fontSize:M({big:30,small:15})},Wt:{H:cf.H,align:"center",i:"middle",fontSize:M({big:72,small:36}),fillColor:"#ffffff"},vj:L(350)},options:{ec:L(14),xj:800,yj:sc,Hl:600,Il:jc,Vl:{align:"center",i:"middle",fontSize:M({big:26,small:13}),fillColor:"#FFFFFF",stroke:!0,Uc:L(5,"round"),strokeColor:"#000000",
ke:!0},td:{H:cf.H,align:"center",i:"middle",fontSize:M({big:44,small:22}),fillColor:"#ffffff"},zm:{i:"middle",align:"center",fontSize:M({big:26,small:13}),fillColor:"#004f5d"},Am:{align:"center",i:"top",fontSize:M({big:36,small:18}),fillColor:"#004f5d"}},Vk:{font:{H:cf.H,align:"center",i:"middle",fontSize:M({big:72,small:36}),fillColor:"#037564",stroke:!0,Uc:L(5,"round"),strokeColor:"#ffffff",ke:!0}}}}var Sf=Sf||{};Sf.bj={Xk:"492fa4d6811cc12b7d7ba4ef92c1377b",cm:"47d3034af7337d6449d86d6e6aa5ff168fd285fc"};
K.j=K.j||{};K.j.el=function(){K.e.Bd()};K.j.iB=function(){};K.j.Xw=function(){};K.j.uo=function(){K.e.Bd()};K.j.fB=function(){};K.j.ns=function(){};K.j.rs=function(){};K.j.qs=function(){};K.j.Fw=function(){};K.j.os=function(){};K.j.ps=function(){};K.j.uw=function(){K.e.Bd()};K.j.vw=function(){K.e.Bd()};K.j.Dh=function(){K.e.Bd()};K.j.tw=function(){K.e.Bd()};K.j.ow=function(a){void 0===K.e.zj&&(K.e.zj=new Tf(!0));Uf(a)};K.j.yu=function(){var a=K.e.qd;void 0===K.e.zj&&(K.e.zj=new Tf(!0));Vf(a)};
K.j.Jd=function(a){window.open(a)};K.j.gj=function(){return[{b:qd,url:K.q.Co}]};K.j.gB=function(){};K.se=K.se||{};K.se.el=function(){K.e.Wj=!1};K.se.Xw=function(){};K.se.uo=function(){K.e.Wj=!1};K.se.Dh=function(){K.e.Wj=!1};function Wf(a,b){for(var c in a.prototype)b.prototype[c]=a.prototype[c]}function Xf(a,b,c,d){this.tm=this.wh=a;this.Fv=b;this.duration=1;this.ir=d;this.pf=c;this.zk=null;this.vb=0}function Yf(a,b){a.vb+=b;a.vb>a.duration&&a.zk&&(a.zk(),a.zk=null)}
Xf.prototype.O=function(){if(this.vb>=this.duration)return this.pf(this.duration,this.wh,this.tm-this.wh,this.duration);var a=this.pf(this.vb,this.wh,this.tm-this.wh,this.duration);this.ir&&(a=this.ir(a));return a};function Zf(a,b){a.wh=a.O();a.tm=b;a.duration=a.Fv;a.zk=void 0;a.vb=0}K.Uv=void 0!==K.environment?K.environment:"development";K.aA=void 0!==K.ga?K.ga:K.Uv;"undefined"!==typeof K.mediaUrl?ja(K.mediaUrl):ja(K.size);K.lv="backButton";K.vf="languageSet";K.Df="resizeEvent";
K.version={builder:"1.8.3.0","build-time":"12:19:57","build-date":"02-12-2016",audio:E.Hb?"web audio api":E.hb?"html5 audio":"no audio"};K.lA=new function(){this.sf=this.ix=3;g.t.Yh&&(this.sf=3>g.ab.ef?1:4.4>g.ab.ef?2:3);g.ab.ol&&(this.sf=7>g.ab.ef?2:3);g.ab.gq&&(this.sf=8>g.ab.ef?2:3);K.version.browser_name=g.name;K.version.browser_version=g.t.version;K.version.os_version=g.ab.version;K.version.browser_grade=this.sf};K.a={};"function"===typeof Mf&&Mf();"function"===typeof Pf&&Pf();
"function"===typeof Rf&&Rf();"function"===typeof initGameThemeSettings&&initGameThemeSettings();K.a.w="undefined"!==typeof Lf?Lf:{};K.a.k="undefined"!==typeof Of?Of:{};K.a.R="undefined"!==typeof Qf?Qf:{};K.a.YA="undefined"!==typeof gameThemeSettingsVar?gameThemeSettingsVar:{};K.Nh=window.publisherSettings;K.q="undefined"!==typeof game_configuration?game_configuration:{};"undefined"!==typeof Nf&&(K.q=Nf);if("undefined"!==typeof Sf)for(var $f in Sf)K.q[$f]=Sf[$f];
(function(){var a,b,c,d,f;K.m={};K.m.uq="undefined"!==typeof N?N:{};K.m.xb=void 0!==K.q.Qe&&void 0!==K.q.Qe.pk?K.q.Qe.pk:K.a.w.Qe.pk;f=[];for(b=0;b<K.m.xb.length;b++)f.push(K.m.xb[b]);if(K.q.qz)for(b=K.m.xb.length-1;0<=b;b--)0>K.q.qz.indexOf(K.m.xb[b])&&K.m.xb.splice(b,1);try{if(d=function(){var a,b,c,d,f;b={};if(a=window.location.search.substring(1))for(a=a.split("&"),d=0,f=a.length;d<f;d++)c=a[d].split("="),b[c[0]]=c[1];return b}(),d.lang)for(c=d.lang.toLowerCase().split("+"),b=K.m.xb.length-1;0<=
b;b--)0>c.indexOf(K.m.xb[b])&&K.m.xb.splice(b,1)}catch(h){}0===K.m.xb.length&&(0<f.length?K.m.xb=f:K.m.xb.push("en-us"));c=navigator.languages?navigator.languages:[navigator.language||navigator.userLanguage];for(b=0;b<c.length;b++)if("string"===typeof c[b]){f=c[b].toLowerCase();for(d=0;d<K.m.xb.length;d++)if(0<=K.m.xb[d].search(f)){a=K.m.xb[d];break}if(void 0!==a)break}void 0===a&&(a=void 0!==K.q.Qe&&void 0!==K.q.Qe.ll?K.q.Qe.ll:K.a.w.Qe.ll);K.m.Mm=0<=K.m.xb.indexOf(a)?a:K.m.xb[0];K.m.ek=K.m.uq[K.m.Mm];
if(void 0!==K.a.w.rc.language_toggle&&void 0!==K.a.w.rc.language_toggle.$){a=K.a.w.rc.language_toggle.$;c=[];for(b=0;b<a.length;b++)0<=K.m.xb.indexOf(a[b].id)&&c.push(a[b]);K.a.w.rc.language_toggle.$=c}K.m.N=function(a,b){var c,d,f,h;if(void 0!==K.m.ek&&void 0!==K.m.ek[a]){c=K.m.ek[a];if(d=c.match(/#touch{.*}\s*{.*}/g))for(h=0;h<d.length;h++)f=(f=g.ce.Sp||g.ce.cp)?d[h].match(/{[^}]*}/g)[1]:d[h].match(/{[^}]*}/g)[0],f=f.substring(1,f.length-1),c=c.replace(d[h],f);return c}return b};K.m.vt=function(a){K.m.Mm=
a;K.m.ek=K.m.uq[a];na(K.vf,a)};K.m.oo=function(){return K.m.Mm};K.m.mw=function(){return K.m.xb};K.m.Iw=function(a){return 0<=K.m.xb.indexOf(a)}})();K.Lv={ab:"",Vx:"",TB:"",Gk:""};K.d={};
K.d.createEvent=function(a,b){var c,d,f,h;d=b.detail||{};f=b.bubbles||!1;h=b.cancelable||!1;if("function"===typeof CustomEvent)c=new CustomEvent(a,{detail:d,bubbles:f,cancelable:h});else try{c=document.createEvent("CustomEvent"),c.initCustomEvent(a,f,h,d)}catch(k){c=document.createEvent("Event"),c.initEvent(a,f,h),c.data=d}return c};K.d.Ez=function(a){var b=Math.floor(a%6E4/1E3);return(0>a?"-":"")+Math.floor(a/6E4)+(10>b?":0":":")+b};
K.d.mj=function(a){function b(){}b.prototype=ag.prototype;a.prototype=new b};K.d.Fy=function(a,b,c,d,f,h){var k=!1,l=document.getElementById(a);l||(k=!0,l=document.createElement("canvas"),l.id=a);l.style.zIndex=b;l.style.top=c+"px";l.style.left=d+"px";l.width=f;l.height=h;k&&((a=document.getElementById("viewport"))?a.appendChild(l):document.body.appendChild(l));K.Yd.push(l);return l};
(function(){var a,b,c,d,f,h,k;K.xs=0;K.ys=0;K.bm=!1;K.Qz=g.t.Yh&&g.t.ef&&4<=g.t.ef;K.Xj=!1;K.Du=g.ce.Sp||g.ce.cp;K.orientation=0<=ba.indexOf("landscape")?"landscape":"portrait";k="landscape"===K.orientation?K.a.w.sn:K.a.w.Yd;h="landscape"===K.orientation?K.a.k.sn:K.a.k.Yd;if(void 0!==h){if(void 0!==h.bd)for(a in h.bd)k.bd[a]=h.bd[a];if(void 0!==h.cd)for(a in h.cd)k.cd[a]=h.cd[a]}b=function(){var a,b,c,d;if(K.Qz&&!K.Xj){K.Xj=!0;if(a=document.getElementsByTagName("canvas"))for(b=0;b<a.length;b++)if(c=
a[b],!c.getContext||!c.getContext("2d")){K.Xj=!1;return}b=document.createEvent("Event");b.ZB=[!1];b.initEvent("gameSetPause",!1,!1);window.dispatchEvent(b);d=[];for(b=0;b<a.length;b++){c=a[b];var f=c.getContext("2d");try{var h=f.getImageData(0,0,c.width,c.height);d.push(h)}catch(k){}f.clearRect(0,0,c.width,c.height);c.style.visibility="hidden"}setTimeout(function(){for(var b=0;b<a.length;b++)a[b].style.visibility="visible"},1);setTimeout(function(){for(var b=0;b<a.length;b++){var c=a[b].getContext("2d");
try{c.putImageData(d[b],0,0)}catch(f){}}b=document.createEvent("Event");b.initEvent("gameResume",!1,!1);window.dispatchEvent(b);K.Xj=!1},100)}};c=function(){var a,c,d,f,h,C,t,s,v;"landscape"===K.orientation?(a=[window.innerWidth,window.innerHeight],c=[k.rh,k.ed],d=k.minWidth):(a=[window.innerHeight,window.innerWidth],c=[k.ed,k.sc],d=k.minHeight);f=c[0]/c[1];h=a[0]/a[1];C=d/c[1];h<f?(h=h<C?Math.floor(a[0]/C):a[1],f=a[0]):(h=a[1],f=Math.floor(a[1]*f));t=h/c[1];!K.Du&&1<t&&(f=Math.min(a[0],c[0]),h=Math.min(a[1],
c[1]),t=1);a="landscape"===K.orientation?f:h;c="landscape"===K.orientation?h:f;v=s=0;window.innerHeight<Math.floor(k.ed*t)&&(s=Math.max(k.xl,window.innerHeight-Math.floor(k.ed*t)));window.innerWidth<Math.floor(k.sc*t)&&(v=Math.floor(Math.max(k.rh-k.sc,(window.innerWidth-Math.floor(k.sc*t))/t)),window.innerWidth<Math.floor(k.sc*t)+v*t&&(v+=Math.floor(Math.max((d-k.rh)/2,(window.innerWidth-(k.sc*t+v*t))/2/t))));K.Rq=k.ed-k.rr;K.qv=k.sc-k.rh;K.sa=s;K.qA=v;K.pA=Math.min(K.qv,-1*K.rA);K.rf=(k.cd.top||
k.mg)-K.sa;K.ha={top:-1*s,left:-1*v,height:Math.min(k.ed,Math.round(Math.min(c,window.innerHeight)/t)),width:Math.min(k.sc,Math.round(Math.min(a,window.innerWidth)/t))};K.DC="landscape"===K.orientation?{top:0,left:Math.floor((k.rh-k.minWidth)/2),width:k.minWidth,height:k.minHeight}:{top:Math.abs(k.xl),left:k.lg,width:k.sc,height:k.minHeight};d=Math.min(window.innerHeight,c);a=Math.min(window.innerWidth,a);"landscape"===K.orientation?document.getElementById("viewport").setAttribute("style","position:fixed; overflow:hidden; z-index: 0; width:"+
a+"px; left:50%; margin-left:"+-a/2+"px; height: "+d+"px; top:50%; margin-top:"+-d/2+"px"):document.getElementById("viewport").setAttribute("style","position:absolute; overflow:hidden; z-index: 0; width:"+a+"px; left:50%; margin-left:"+-a/2+"px; height: "+d+"px");d=function(a,b,c,d){var f,h,l,n;f=void 0!==b.top?b.top:k.mg;h=void 0!==b.left?b.left:k.lg;l=void 0!==b.width?b.width:k.sc;n=void 0!==b.height?b.height:k.ed;a.EA=Math.floor(t*f);a.DA=Math.floor(t*h);a.FA=Math.floor(t*l);a.CA=Math.floor(t*
n);!1!==c&&(f+=s);!1!==d&&(h+=v);a.setAttribute("style","position:absolute; left:"+Math.floor(t*h)+"px; top:"+Math.floor(t*f)+"px; width:"+Math.floor(t*l)+"px; height:"+Math.floor(t*n)+"px; z-index: "+b.depth)};d(K.hn,k.rn);d(K.ao,k.bd);d(K.lo,k.cd,!1,!0);d(K.he,k.hg);b();setTimeout(b,5E3);setTimeout(b,1E4);setTimeout(b,2E4);na(K.Df)};a=function(){if(K.xs===window.innerHeight&&K.ys===window.innerWidth||K.bm)return!1;document.documentElement.style["min-height"]=5E3;d=window.innerHeight;f=40;K.bm=window.setInterval(function(){document.documentElement.style.minHeight=
"";document.documentElement.style["min-height"]="";window.scrollTo(0,g.t.Yh?1:0);f--;if((g.t.Yh?0:window.innerHeight>d)||0>f)K.ys=window.innerWidth,K.xs=window.innerHeight,clearInterval(K.bm),K.bm=!1,document.documentElement.style["min-height"]=window.innerHeight+"px",document.getElementById("viewport").style.height=window.innerHeight+"px",c()},10)};K.Fd=k.bd.left||k.lg;K.Gd=k.bd.top||k.mg;K.ld=k.bd.width||k.sc;K.cj=k.bd.height||k.ed;K.sg=k.cd.left||k.lg;K.rf=k.cd.top||k.mg;K.$A=k.cd.width||k.sc;
K.ZA=k.cd.height||k.ed;K.dx=k.hg.left||k.lg;K.ex=k.hg.top||k.mg;K.fx=k.hg.width||k.sc;K.cx=k.hg.height||k.ed;h=function(a){return K.d.Fy(a.id,a.depth,void 0!==a.top?a.top:k.mg,void 0!==a.left?a.left:k.lg,void 0!==a.width?a.width:k.sc,void 0!==a.height?a.height:k.ed)};K.Yd=[];K.hn=h(k.rn);K.ao=h(k.bd);K.lo=h(k.cd);K.he=h(k.hg);c();document.body.addEventListener("touchmove",function(a){a.preventDefault()},!0);document.body.addEventListener("touchstart",a,!0);window.addEventListener("resize",a,!0);window.setInterval(a,
200);K.Qc={};K.Qc[K.rg]=K.hn;K.Qc[K.qf]=K.ao;K.Qc[K.al]=K.lo;K.Qc[K.xh]=K.he;K.Qc[K.qg]=K.hn;K.Qc[K.Hc]=K.he;K.Qc[K.Oe]=K.he})();
K.d.gv=function(){var a,b;if(b=document.getElementById("viewport"))a=document.createElement("img"),a.className="banner",a.src=ka.hf+"/media/banner_game_640x100.png",a.style.position="absolute",a.style.bottom="0px",a.style.width="100%",a.style.zIndex=300,b.appendChild(a),K.tv=!0,K.Ji=!0,b=function(a){K.tv&&K.Ji&&(K.j.Jd("http://www.tinglygames.com/html5-games/"),a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},a.addEventListener("mouseup",b,!0),a.addEventListener("touchend",
b,!0),a.addEventListener("mousedown",function(a){K.Ji&&(a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},!0),a.addEventListener("touchstart",function(a){K.Ji&&(a.preventDefault(),a.stopPropagation?a.stopPropagation():a.cancelBubble=!0)},!0)};K.d.YC=function(){var a,b=document.getElementsByClassName("banner");if(b){for(a=0;a<b.length;a++)b[a].style.display="inline";K.Ji=!0}};
K.d.eB=function(){var a,b=document.getElementsByClassName("banner");if(b){for(a=0;a<b.length;a++)b[a].style.display="none";K.Ji=!1}};K.d.no=function(a){return a===K.ao?{x:K.Fd,y:K.Gd}:a===K.lo?{x:K.sg,y:K.rf}:{x:K.dx,y:K.ex}};K.d.ug=function(a){return K.Qc[a]};K.d.ja=function(a){return K.Qc[a]?(p.canvas!==K.Qc[a]&&p.ja(K.Qc[a]),!0):!1};K.d.Ka=function(a,b){if(K.Qc[b]){var c=G;a.Ua!==b&&(c.yi=!0);a.Ua=b;a.canvas=K.Qc[b]}};
K.d.g=function(a,b,c,d){var f;b=b||0;c=c||0;d=d||0;if("number"===typeof a)return a;if("object"===typeof a)switch(f=a.offset||0,a.align){case "center":return Math.round(b/2-(c/2-d))+f;case "left":case "top":return f-d;case "right":case "bottom":return b-c-f-d;default:return f+0}return 0};
K.d.Ca=function(a,b,c,d){var f;b=b||0;c=c||0;if("number"===typeof a)return a;if("object"===typeof a)switch(f=a.offset||0,a.align){case "center":return"center"===d||"middle"===d?Math.round(b/2)+f:"left"===d||"top"===d?Math.round(b/2-c/2)+f:Math.round(b/2+c/2)-f;case "left":case "top":return"center"===d||"middle"===d?Math.round(c/2)+f:"left"===d||"top"===d?f:c+f;case "right":case "bottom":return"center"===d||"middle"===d?b-Math.round(c/2)-f:"left"===d||"top"===d?b-Math.round(c/2)-f:b-f;default:return f+
0}return 0};K.d.xA=function(a,b,c,d){switch(d){case "center":case "middle":return Math.round(b/2)+a;case "left":case "top":return a;case "right":case "bottom":return c+a}return 0};K.oa=K.oa||{};K.oa.Hy=!1;K.oa.ts=function(a){a instanceof Array&&(this.Xk=a[0],this.cm=a[1],this.uv="http://api.gameanalytics.com/v2/"+this.Xk,this.us=!0)};
K.oa.Wf=function(a,b){var c,d=JSON.stringify(b),f=window.Crypto.HmacSHA256(d,this.cm),f=window.Crypto.enc.Base64.stringify(f),h=this.uv+"/"+a;try{c=new XMLHttpRequest,c.open("POST",h,!0),this.Hy&&(c.onreadystatechange=function(){4===c.readyState&&(200===c.status?(console.log("GOOD! statusText: "+c.statusText),console.log(b)):console.log("ERROR ajax call error: "+c.statusText+", url: "+h))}),c.setRequestHeader("Content-Type","text/plain"),c.setRequestHeader("Authorization",f),c.send(d)}catch(k){}};
K.oa.Jc={oq:"user",nq:"session_end",Nu:"business",Ru:"resource",Yj:"progression",Gm:"design",ERROR:"error"};K.oa.Qf=function(){return{user_id:this.eq,session_id:this.Dy,build:this.Av,device:this.Gk,platform:"ios",os_version:"ios 10.1",sdk_version:"rest api v2",v:2,client_ts:Math.floor(Date.now()/1E3),manufacturer:"",session_num:1}};
K.oa.wc=function(a,b,c,d,f,h,k){b=void 0;fbInstant&&(b=fbInstant.Gk);this.Dy=a;h&&"object"===typeof h&&(this.eq=h.eq);this.Av=f;this.h=!0;this.us&&(this.Gk=b||k.Gk,this.platform=k.ab,this.UB=k.Vx);this.Wf("init",this.Qf())};K.oa.iz=function(a){var b=this.Qf(),c=[];b.category=a;c.push(b);this.Wf("events",c)};K.oa.In=function(a,b,c,d){a=[];b=this.Qf();b.length=Math.floor(c);b.category=d;a.push(b);this.Wf("events",a)};
K.oa.gb=function(a,b,c,d){var f=[],h=!1;if(this.h&&this.us){if(d)switch(d){case K.oa.Jc.oq:this.iz(d);h=!0;break;case K.oa.Jc.nq:this.In(0,0,c,d);h=!0;break;case K.oa.Jc.Nu:h=!0;break;case K.oa.Jc.Ru:h=!0;break;case K.oa.Jc.Yj:this.Xv(a,b,c,d);h=!0;break;case K.oa.Jc.Gm:this.Vv(a,b,c,d),h=!0}h||(d="",b&&(d=b instanceof Array?b.toString().replace(",",":"):d+b),b=this.Qf(),b.event_id=d+":"+a,b.value=c,f.push(b),this.Wf("design",f))}};K.oa.zC=function(a,b,c){this.gb(a,b,c)};K.oa.RA=function(){};
K.oa.SA=function(){};K.oa.Xv=function(a,b,c,d){var f=[],h=this.Qf();switch(a){case "Start:":h.category=d;h.event_id=a+b;break;case "Complete:":h.category=d;h.event_id=a+b;h.score=c;break;case "Fail:":h.category=d,h.event_id=a+b,h.score=c}f.push(h);this.Wf("events",f)};K.oa.Vv=function(a,b,c,d){var f=[],h=this.Qf();h.category=d;h.event_id=a+b;h.value=c;f.push(h);this.Wf("events",f)};K.oa.qt=function(a,b){var c=[],d=this.Qf();d.category="error";d.message=a;d.severity=b;c.push(d);this.Wf("events",c)};
function bg(){this.Ua=this.depth=0;this.visible=!1;this.h=!0;this.a=K.a.w.Na;this.gy=this.a.Fz;H(this);Pb(this,"system")}function cg(){var a=dg("userId","");""===a&&(a=eg(),fg("userId",a));return a}function eg(){return"xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(/[xy]/g,function(a){var b=16*Math.random()|0;return("x"===a?b:b&3|8).toString(16)})}e=bg.prototype;e.start=function(a){K.oa.ts(a);K.oa.wc(eg(),K.a.k.pg.Wk,K.a.R.id,K.q.ly,gg(),{eq:cg()},K.Lv)};e.gb=function(a,b,c,d){K.oa.gb(a,b,c,d)};
function hg(a,b,c,d){var f,h;for(f=0;f<a.la.length;f++)void 0!==a.la[f]&&a.la[f].tag===b&&(h=a.la[f],a.gb(c,d,h.l/1E3,K.oa.Jc.nq),h.h=!1)}function ig(){var a=K.Na,b=K.e.Tg,c;for(c=0;c<a.la.length;c++)void 0!==a.la[c]&&a.la[c].tag===b&&(a.la[c].paused+=1)}e.qt=function(a,b){K.oa.qt(a,b)};e.ac=function(){this.la=[]};
e.Z=function(a){var b,c=0;for(b=0;b<this.la.length;b++)this.la[b].h&&(0===this.la[b].paused&&(this.la[b].l+=a),c=b);c<this.la.length-1&&(a=this.la.length-Math.max(this.gy,c+1),0<a&&this.la.splice(this.la.length-a,a))};
function Tf(a,b,c){this.Ss=a||!1;this.host=b||"http://localhost:8080";this.Cy=c||this.host+"/services/storage/gamestate";this.Zt="undefined"!==typeof window.localStorage;this.Eo=this.cq=!1;var d=this;window.parent!==window&&(g.t.zp||g.ab.ol)&&(window.addEventListener("message",function(a){a=a.data;var b=a.command;"init"===b?d.cq="ok"===a.result:"getItem"===b&&d.bl&&("ok"===a.result?d.bl(a.value):d.bl(a.defaultValue))},!1),this.bl=null,window.parent.postMessage({command:"init"},"*"));this.wj=[];window.setTimeout(function(){d.Eo=
!0;for(var a=0;a<d.wj.length;++a)d.wj[a]();d.wj=[]},2E3)}function jg(){return"string"===typeof K.q.Ut&&""!==K.q.Ut?K.q.Ut:void 0!==K.a.k.pg&&void 0!==K.a.k.pg.Wk?K.a.k.pg.Wk:"0"}function Uf(a){var b=K.e.zj;"function"===typeof a&&(b.Eo?kg(b,a):b.wj.push(function(){kg(b,a)}))}function Vf(a){var b=K.e.zj;b.Eo?lg(b,a):b.wj.push(function(){lg(b,a)})}
function lg(a,b){var c=null,d=jg();try{c=JSON.stringify({lastChanged:new Date,gameState:JSON.stringify(b)})}catch(f){}if(a.cq)window.parent.postMessage({command:"setItem",key:"TG_"+d,value:c},"*");else{if(a.Zt)try{window.localStorage.setItem(d,c)}catch(h){}a.Ss||(c=new sb("gameState_"+d),c.text=void 0===JSON?"":JSON.stringify(b),tb(c,a.Cy+"/my_ip/"+d))}}
function kg(a,b){var c=null,d=null,f=jg();if(a.cq)a.bl=function(a){var d;try{c=JSON.parse(a),d=JSON.parse(c.gameState)}catch(f){d=null}b(d)},window.parent.postMessage({command:"getItem",key:"TG_"+f},"*");else{if(a.Zt)try{(c=window.localStorage.getItem(f))&&(c=JSON.parse(c))}catch(h){b(null);return}if(!a.Ss){var k=new sb("gameState_"+f),d=null;ub(k,Tf.vC+"/my_ip/"+f)&&(d=void 0===JSON?{}:JSON.parse(k.text))}try{if(c){if(d&&Date.parse(d.lastChanged)>Date.parse(c.lastChanged)){b(JSON.parse(d.gameState));
return}b(JSON.parse(c.gameState));return}if(d){b(JSON.parse(d.gameState));return}}catch(l){b(null);return}b(null)}}
function mg(a,b,c){console&&console.log&&console.log("Hosted on: "+(window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname));this.depth=1E3;this.kd=this.visible=!1!==c;this.h=!0;K.d.Ka(this,K.Hc);var d;this.a=K.a.w.Id;if("landscape"===K.orientation&&K.a.w.Qo)for(d in K.a.w.Qo)this.a[d]=K.a.w.Qo[d];for(d in K.a.R.Id)this.a[d]=K.a.R.Id[d];if(K.q.Id)for(d in K.q.Id)this.a[d]=K.q.Id[d];this.zb=a;this.er=b;this.wr=!1;this.Hi=0;this.jn=!1;this.rk=0;this.Ii=
this.a.ov;this.up=!0;this.Zw=.6/Math.log(this.a.tl+1);this.Ku=void 0!==K.q.Yw?K.q.Yw:this.a.Dx;this.jx=this.Ku+this.a.mx;H(this)}e=mg.prototype;e.Dp=function(a){var b;K.d.ja(K.qg);sa(0,0,this.canvas.width,this.canvas.height,"white",!1);b=V.P();(K.q.Id&&K.q.Id.Oj||this.a.Oj)&&A(b,K.q.Id&&K.q.Id.Oj?K.q.Id.Oj:this.a.Oj);a=K.m.N(a,"<"+a.toUpperCase()+">");b.o(a,this.canvas.width/2,this.canvas.height/2,this.a.om);this.error=!0;this.visible=this.kd=!1;this.canvas.Y=!0};
e.Ue=function(){this.xa&&(this.bc=K.d.g(this.a.bc,K.ha.width,this.xa.width)+K.ha.left,this.Sc=K.d.g(this.a.Sc,K.ha.height,this.xa.height)+K.ha.top)};
e.yn=function(){var a,b,c,d,f,h;if("function"===typeof K.j.gj&&(h=this.a.Dg,(this.Ja=K.j.gj())&&0<this.Ja.length)){this.xa?this.xa.clear():this.xa=new x(this.a.Dg,this.a.tj);y(this.xa);h/=this.Ja.length;for(c=0;c<this.Ja.length;c++)try{f=this.Ja[c].b,d=Math.min(1,Math.min((h-20)/f.width,this.a.tj/f.height)),a="center"===this.a.rj?h*c+Math.round((h-f.width*d)/2):h*c+Math.round(h-f.width*d)-10,b=this.xa.height-f.height*d,f instanceof r?f.S(0,a,b,d,d,0,1):p.context.drawImage(f,a,b,f.width*d,f.height*
d)}catch(k){}z(this.xa);this.sl=0;this.So=!0;this.sj=0;this.Cg=Vb(0,0,this.xa.width,this.xa.height);this.Ue()}};
e.Sa=function(){var a,b,c,d;this.up?p.clear():K.d.ja(K.qg);if(this.a.backgroundImage)if(d=this.a.backgroundImage,a=Math.abs(K.sa),1<d.D){c=(p.canvas.height-a)/d.ph;b=-(d.Qi*c-p.canvas.width)/2;c=p.context;var f=c.globalAlpha,h,k,l;c.globalAlpha=this.Hi;for(h=0;h<d.D;h+=1)k=b+h%d.Jh*d.width,l=a+d.height*Math.floor(h/d.Jh),d.cf.Da(d.Hf[h],d.If[h],d.Jf[h],d.$e[h],d.Ze[h],k-d.eb+d.af[h],l-d.Za+d.bf[h]);c.globalAlpha=f}else c=(this.canvas.height-a)/d.height,b=-Math.floor((d.width*c-this.canvas.width)/
2),d instanceof r?d.S(0,b,a,c,c,0,this.Hi):d instanceof x&&d.S(b,a,c,c,0,this.Hi);d=this.a.xf+this.a.Oo+this.a.Fh;b=Ec.height;a=Ec.width-(this.a.xf+this.a.Oo);this.Gh=K.d.g(this.a.Gh,p.canvas.width,d);this.Bg=K.d.g(this.a.Bg,p.canvas.height,b);Ec.Da(0,0,0,this.a.xf,b,this.Gh,this.Bg,1);Ec.Kk(0,this.a.xf,0,a,b,this.Gh+this.a.xf,this.Bg,this.a.Fh,b,1);Ec.Da(0,this.a.xf+a,0,this.a.Oo,b,this.Gh+this.a.xf+this.a.Fh,this.Bg,1)};
function ng(a){a.up&&(a.jn=!0);a.visible&&(a.Sa(),a.yn(),"function"===typeof K.j.qo&&(a.Ye=K.j.qo(),a.Ye instanceof x&&(a.Th=!0,a.Et=Math.floor((a.canvas.width-a.Ye.width)/2),a.Ft=Math.floor((a.canvas.height-a.Ye.height)/2))));K.e.pj&&ka.je("audio");K.e.oj&&ka.je("audio_music");ka.je("fonts")}
e.ac=function(){var a,b=!1;if(void 0!==K.q.Ij)if(!1===K.q.Ij.$w)b=!0;else{if(void 0!==K.q.Ij.Cn)for(a=0;a<K.q.Ij.Cn.length;a++){var c;a:{c=K.q.Ij.Cn[a];var d=void 0,f=void 0,h=d=void 0,f=void 0,f=window.location.origin?window.location.origin:window.location.protocol+"//"+window.location.hostname;if(0===f.indexOf("file://")&&c===og("file://"))c=!0;else{f=f.split(".");d=f.shift().split("://");d[0]+="://";f=d.concat(f);h="";for(d=f.length-1;0<=d;d--)if(h=f[d]+(0<d&&d<f.length-1?".":"")+h,og(h)===c){c=
!0;break a}c=!1}}if(c){b=!0;break}}}else b=!0;b&&"number"===typeof K.q.Cz&&(new Date).getTime()>K.q.Cz&&(b=!1);b?(this.mh=[],this.error=!1,this.ju=this.Yn=this.ok=this.l=0,this.ready=this.Th=!1,this.Vw=void 0!==this.a.Qs?this.a.Qs:this.a.xf-this.a.qj,this.Ww=void 0!==this.a.Rs?this.a.Rs:Math.floor((Ec.height-Fc.height)/2),this.Po=Fc.width-(this.a.qj+this.a.Ps),this.Xn=this.bt=this.Nq=!1,(this.Jj=ka.complete("start"))&&ng(this),this.Os=ka.complete("load"),this.visible&&(this.ku=document.getElementById("throbber_image"),
this.df=this.a.df,this.Tp=K.d.g(this.a.Tp,this.canvas.width,this.df),this.pm=K.d.g(this.a.pm,this.canvas.height,this.df))):G.pause()};
e.Z=function(a){this.l+=a;"function"===typeof K.j.qo&&void 0===this.Ye&&(this.Ye=K.j.qo(),this.Ye instanceof x&&(this.Th=!0,this.Et=Math.floor((this.canvas.width-this.Ye.width)/2),this.Ft=Math.floor((this.canvas.height-this.Ye.height)/2)));this.Th&&0<=this.a.Gt&&this.l>=this.a.Gt&&(this.Th=!1);this.jn&&(this.rk+=a,this.rk>=this.Ii?(this.jn=!1,this.Hi=1):this.Hi=jc(this.rk,0,1,this.Ii));this.Jj&&(this.ok+=a,this.Yn+=a);this.ju=Math.round(this.l/this.a.Az%(this.a.Bz-1));this.So&&(this.sl=0+this.sj/
this.a.Ro*1,this.sj+=a,this.sj>=this.a.Ro&&(this.So=!1,this.sl=1));"function"===typeof this.er&&this.er(Math.round((la("load")+la("audio")+la("audio_music"))/2));!this.ready&&this.Os&&(this.Xn||this.Yn>=this.a.tl)&&(!K.e.pj||this.Nq||E.hb&&this.ok>=this.a.tl)&&(!K.e.oj||this.bt||E.hb&&this.ok>=this.a.tl)&&(this.ready=!0);if(a=!this.wr&&!this.error&&this.ready&&this.l>=this.Ku)a=K.e,a=(a.zd&&a.kc&&!a.kc.Hw()?!1:!0)||this.l>=this.jx;a&&(this.wr=!0,this.zb())};
e.Bh=function(a,b,c){!this.Th&&this.Cg&&cc(this.Cg,this.bc,this.Sc,b,c)&&(this.Db=Math.floor((b-this.bc)/(this.xa.width/this.Ja.length)))};e.Ch=function(a,b,c){void 0!==this.Db&&(this.Ja[this.Db].url||this.Ja[this.Db].action)&&cc(this.Cg,this.bc,this.Sc,b,c)&&(b-=this.bc,b>=this.xa.width/this.Ja.length*this.Db&&b<this.xa.width/this.Ja.length*(this.Db+1)&&(this.Ja[this.Db].url?K.j.Jd(this.Ja[this.Db].url):this.Ja[this.Db].action()));this.Db=void 0};
e.Oc=function(a,b){"Load Complete"===a&&"start"===b.pb?(this.Jj=!0,ng(this)):"Load Complete"===a&&"load"===b.pb?this.Os=!0:"Load Complete"===a&&"audio"===b.pb?this.Nq=!0:"Load Complete"===a&&"audio_music"===b.pb?this.bt=!0:"Load Complete"===a&&"fonts"===b.pb&&(this.Xn=!0);a===K.Df&&this.Ue()};
e.za=function(){if(!this.error){this.up&&this.Jj?this.Sa():p.clear();try{this.ku&&p.context.drawImage(this.ku,this.df*this.ju,0,this.df,this.df,this.Tp,this.pm,this.df,this.df)}catch(a){}if(this.Jj){var b=0,c=this.Gh+this.Vw,d=this.Bg+this.Ww,f=Fc.height;Fc.Da(0,b,0,this.a.qj,f,c,d,1);b+=this.a.qj;c+=this.a.qj;this.ready?(Fc.Kk(0,b,0,this.Po,f,c,d,this.a.Fh,f,1),b+=this.Po,c+=this.a.Fh,Fc.Da(0,b,0,this.a.Ps,f,c,d,1)):Fc.Kk(0,b,0,this.Po,f,c,d,Math.floor(Math.min((la("load")+la("audio"))/500+this.Zw*
Math.log(this.l+1),1)*this.a.Fh),f,1);this.xa&&this.xa.fd(this.bc,this.Sc,this.sl)}this.Th&&this.Ye.o(this.Et,this.Ft)}};
function pg(){var a,b;b=this;this.depth=100;this.h=this.visible=!0;K.d.Ka(this,K.Hc);this.a=K.a.w.fm;if("landscape"===K.orientation&&K.a.w.Np)for(a in K.a.w.Np)this.a[a]=K.a.w.Np[a];this.rc=K.a.w.rc;if("landscape"===K.orientation&&K.a.w.pn)for(a in K.a.w.pn)this.rc[a]=K.a.w.pn[a];for(a in K.a.R.fm)this.a[a]=K.a.R.fm[a];this.mh=[];a=qg(K.e);this.fr=void 0!==a&&null!==a;this.Ya=new dc;this.Ya.V(this.a.fw,function(){b.Pt.call(b)});this.Ya.V(this.a.dt,function(){b.Rt.call(b)});this.Ya.V(K.n.em&&!this.fr?
this.a.cy:this.a.dt,function(){b.St.call(b)});this.Ya.V(this.a.yx,function(){b.Qt.call(b)});H(this,!1)}e=pg.prototype;e.Pt=function(){this.Zk=!0;this.a.yh&&(this.ej=K.d.g(this.a.ej,this.canvas.width,Be.width),this.Yk=K.d.g(this.a.Yk,this.canvas.width,Be.width),this.fj=K.d.g(this.a.fj,this.canvas.height,Be.height),this.dj=K.d.g(this.a.dj,this.canvas.height,Be.height),this.ko=this.ej,this.$k=this.fj,this.eo=this.a.io,this.fo=this.a.jo,this.co=this.a.ho,this.Nc=0,this.Ue())};
e.Rt=function(a){function b(a,b,c,d){return qc(a,b,c,d,3,15)}var c,d;K.n.em&&!this.fr&&(c=K.d.g(this.a.vr,this.canvas.width,this.a.Ui,Math.floor(this.a.Ui/2)),d=K.d.g(this.a.Ik,this.canvas.height,he.height,Math.floor(he.height/2)),c=new rg("difficulty_toggle",c,d,this.depth-20,sg()+"",this.a.Ui,{ea:function(a){tg(parseInt(a,10));return!0},vc:!0}),c.Kd=Math.floor(this.a.Ui/2),c.Ld=Math.floor(he.height/2),!1!==a&&(ug(c,"xScale",b,0,1,this.a.ur),ug(c,"yScale",b,0,1,this.a.ur)),this.Hk=c,this.Ik=c.y,
this.mh.push(c),this.Ue())};
e.St=function(a){function b(a,b,c,d){return qc(a,b,c,d,3,15)}var c,d=this;this.pp=!0;c=new vg("bigPlay",K.d.g(this.a.by,this.canvas.width,this.a.Bj,Math.floor(this.a.Bj/2)),K.d.g(this.a.Ql,this.canvas.height,re.height,Math.floor(re.height/2)),this.depth-20,"startScreenPlay",this.a.Bj,{ea:function(){I(G,d);var a=K.e,b,c,l;void 0===K.e.xc&&(void 0!==K.a.R.xc&&(void 0!==K.a.R.xc.rv&&(b=K.a.R.xc.rv),void 0!==K.a.R.xc.kn&&(ab(E,"music",K.a.R.xc.kn),a.Eg()||ob("music"),K.e.Nx=K.a.R.xc.kn),c=void 0!==K.a.R.xc.nv?
K.a.R.xc.nv:0,l=void 0!==K.a.R.xc.Ii?K.a.R.xc.Ii:0),void 0===b&&"undefined"!==typeof ef&&(b=ef),void 0!==b&&(K.e.xc=E.play(b,c,l),K.e.xc&&(E.Iq(K.e.xc,"music"),E.wt(K.e.xc,!0))));0!==a.ep&&K.j.ns();K.n.Qh&&!a.zd?a.screen=new wg:xg(a,0);return!0},vc:!0});c.Kd=Math.floor(this.a.Bj/2);c.Ld=Math.floor(re.height/2);!1!==a?(ug(c,"xScale",b,0,1,this.a.Ol),ug(c,"yScale",b,0,1,this.a.Ol),this.Pl=0):this.Pl=this.a.Ol;this.Nl=c;this.Ql=c.y;this.mh.push(c);this.Ue()};
function yg(a){var b=uc([sc,function(a,b,f,h){return qc(a,b,f,h,3,2)},gc],[!0,!1,!1],[.02,.1,.88]);a.kt=!0;ug(a.Nl,"xScale",tc(b),1,.25,4E3);ug(a.Nl,"yScale",tc(b),1,-.1,4E3)}e.Qt=function(a){var b;this.$s=!0;b=new ag(K.d.g(this.a.$o,this.canvas.width,ee.width),K.d.g(this.a.wl,this.canvas.height,ee.height),this.depth-20,new Xb(ee),[ee],{ea:K.e.Sh,vc:!0});!1!==a&&ug(b,"alpha",J,0,1,this.a.xx);this.Zo=b;this.wl=b.y;this.mh.push(b);this.Ue()};
e.Sa=function(){var a,b,c,d;if(a=this.a.backgroundImage)K.d.ja(K.qg),c=Math.abs(K.sa),1<a.D?(b=(p.canvas.height-c)/a.ph,d=-(a.Qi*b-p.canvas.width)/2,wa(a,d,c)):(b=(p.canvas.height-c)/a.height,d=-Math.floor((a.width*b-this.canvas.width)/2),a.S(0,d,c,b,b,0,1))};
e.yn=function(){var a,b,c,d,f,h;if("function"===typeof K.j.gj&&(h=this.a.Dg,(this.Ja=K.j.gj())&&0<this.Ja.length)){this.xa?this.xa.clear():this.xa=new x(this.a.Dg,this.a.tj);y(this.xa);h/=this.Ja.length;for(c in this.Ja)try{f=this.Ja[c].b,d=Math.min(1,Math.min((h-20)/f.width,this.a.tj/f.height)),a="center"===this.a.rj?h*c+Math.round((h-f.width*d)/2):h*c+Math.round(h-f.width*d)-10,b=this.xa.height-f.height*d,f instanceof r?f.S(0,a,b,d,d,0,1):p.context.drawImage(f,a,b,f.width*d,f.height*d)}catch(k){}z(this.xa);
this.sl=0;this.So=!0;this.sj=0;this.Cg=Vb(0,0,this.xa.width,this.xa.height);this.Ue()}};e.Ue=function(){var a;a=0;K.ha.height<this.a.nn&&(a=this.a.nn-K.ha.height);this.pp&&(this.Nl.y=this.Ql-a);this.$s&&(this.Zo.y=this.wl-a,this.Zo.x=K.d.g(this.a.$o,K.ha.width,ee.width)+K.ha.left);this.Hk&&(this.Hk.y=this.Ik-a);this.Zk&&this.Nc>=this.a.Ed&&(this.$k=this.dj-K.sa);this.xa&&(this.bc=K.d.g(this.a.bc,K.ha.width,this.xa.width)+K.ha.left,this.Sc=K.d.g(this.a.Sc,K.ha.height,this.xa.height)+K.ha.top)};
e.ac=function(){this.Sa();this.a.yh&&(K.d.ja(K.Hc),this.a.yh.o(0,0,-this.a.yh.height-10));this.yn();this.Ya.start()};e.nb=function(){var a;for(a=0;a<this.mh.length;a++)I(G,this.mh[a])};
e.Z=function(a){this.canvas.Y=!0;this.Zk&&this.Nc<this.a.Ed&&(this.ko=this.a.jw(this.Nc,this.ej,this.Yk-this.ej,this.a.Ed),this.$k=this.a.kw(this.Nc,this.fj,this.dj-this.fj,this.a.Ed)-K.sa,this.eo=this.a.hw(this.Nc,this.a.io,this.a.Sr-this.a.io,this.a.Ed),this.fo=this.a.iw(this.Nc,this.a.jo,this.a.Tr-this.a.jo,this.a.Ed),this.co=this.a.gw(this.Nc,this.a.ho,this.a.Rr-this.a.ho,this.a.Ed),this.Nc+=a,this.Nc>=this.a.Ed&&(this.ko=this.Yk,this.$k=this.dj-K.sa,this.eo=this.a.Sr,this.fo=this.a.Tr,this.co=
this.a.Rr));this.pp&&(!this.kt&&this.Pl>=this.a.Ol+this.a.ay&&yg(this),this.Pl+=a)};e.Bh=function(a,b,c){this.Cg&&cc(this.Cg,this.bc,this.Sc,b,c)&&(this.Db=Math.floor((b-this.bc)/(this.xa.width/this.Ja.length)))};
e.Ch=function(a,b,c){void 0!==this.Db&&(this.Ja[this.Db].url||this.Ja[this.Db].action)&&cc(this.Cg,this.bc,this.Sc,b,c)&&(b-=this.bc,b>=this.xa.width/this.Ja.length*this.Db&&b<this.xa.width/this.Ja.length*(this.Db+1)&&(this.Ja[this.Db].url?K.j.Jd(this.Ja[this.Db].url):this.Ja[this.Db].action()));this.Db=void 0};e.Ub=function(){this.Bb=!0};
e.Vb=function(){this.Bb&&(this.Ya.stop(),this.Zk?this.Nc<this.a.Ed&&(this.Nc=this.a.Ed-1):(this.Pt(),this.Nc=this.a.Ed-1),this.Hk?zg(this.Hk):this.Rt(!1),this.$s?zg(this.Zo):this.Qt(!1),this.pp?(zg(this.Nl),this.kt&&yg(this)):this.St(!1),this.Bb=!1)};e.Oc=function(a){a===K.Df&&(this.Sa(),this.Ue())};e.za=function(){this.Zk&&this.a.yh&&this.a.yh.S(0,this.ko,this.$k,this.eo,this.fo,0,this.co);this.xa&&this.xa.o(this.bc,this.Sc);this.kd=!1};
function wg(){this.depth=100;this.h=this.visible=!0;K.d.Ka(this,K.Hc);var a;this.a=K.a.w.yg;if("landscape"===K.orientation)for(a in K.a.w.Ds)this.a[a]=K.a.w.Ds[a];this.Ha=K.a.k.mB;if(K.a.k.yg)for(a in K.a.k.yg)this.a[a]=K.a.k.yg[a];this.Fc=K.a.w.rc;for(var b in K.a.R.yg)this.a[b]=K.a.R.yg[b];this.Ag=-1;this.Xa=0;this.Mo=[];H(this)}e=wg.prototype;
e.Sa=function(){var a,b,c,d;K.d.ja(K.qg);if(a=this.a.backgroundImage?this.a.backgroundImage:void 0)c=Math.abs(K.sa),1<a.D?(b=(p.canvas.height-c)/a.ph,d=-(a.Qi*b-p.canvas.width)/2,wa(a,d,c)):(b=(p.canvas.height-c)/a.height,d=-Math.floor((a.width*b-this.canvas.width)/2),a.S(0,d,c,b,b,0,1));var f;b=K.a.w.wa.type[K.n.de].od;K.a.k.wa&&K.a.k.wa.type&&K.a.k.wa.type[K.n.de]&&K.a.k.wa.type[K.n.de]&&(b=!1===K.a.k.wa.type[K.n.de].od?!1:b);void 0!==this.Ha&&void 0!==this.Ha.od&&(b=this.Ha.od);c=K.d.g(this.a.cz,
this.canvas.width,Lc.width);a=K.d.g(this.a.Mt,K.ha.height,Lc.height)+K.ha.top;b&&(Lc.o(0,c,a),b=V.P(),A(b,this.a.Lt),La(b,"center"),b.o(this.J+" / "+this.Up,c+Math.floor(Lc.width/2),a+Lc.height+this.a.Nt));if(void 0!==this.Ha&&void 0!==this.Ha.Ky?this.Ha.Ky:1)b=V.P(),void 0!==this.a.dy?A(b,this.a.dy):A(b,this.a.qp),c=K.m.N("levelMapScreenTotalScore","<TOTAL SCORE:>"),d=Sa(b,c,this.a.fy,this.a.ey),d<b.fontSize&&D(b,d),d=K.d.Ca(this.a.lt,this.canvas.width,b.aa(c),b.align),f=K.d.Ca(this.a.mt,K.ha.height,
b.T(c),b.i)+K.ha.top,b.o(c,d,f),c=""+this.Sl,A(b,this.a.qp),d=K.d.Ca(this.a.lt,this.canvas.width,b.aa(c),b.align),b.o(c,d,a+Lc.height+this.a.Nt)};
function Ag(a){if("grid"===a.a.type){y(a.nj);p.clear();a.zg=[];var b;b=function(b,d,f){var h,k,l,n,q,u,B,C,t,s,v,w,U,ra,Z,ga,Oa,Ya,Pd,nc,Ud,ac,Ef;k=K.n.na[b];Pd=a.nc?a.a.rw:a.a.sw;nc=a.a.so;Ud=Pd;if(a.a.Cv)h=a.a.Cv[b];else{Ya=a.nc?a.a.Ox:a.a.Px;for(ac=Math.floor(k/Ya);1<Math.abs(ac-Ya);)Ya-=1,ac=Math.floor(k/Ya);for(h=[];0<k;)h.push(Math.min(Ya,k)),k-=Ya}ac=h.length;Oa=Math.round(((a.nc?a.a.Js:a.a.Ks)-(ac+1)*Pd)/ac);Ef=a.a.Bv?a.a.Bv:!1;if(!Ef){Ya=1;for(k=0;k<ac;k++)Ya=Math.max(h[k],Ya);ga=Math.round((a.canvas.width-
2*nc)/Ya)}for(k=n=0;k<ac;k++){Ya=h[k];Ef&&(ga=Math.round((a.canvas.width-2*nc)/Ya));for(l=0;l<Ya;l++){t=a.a.xr;U=a.a.Pv;v=K.n.Ti||"locked";w=0;q=Bg(b,n,void 0,void 0);"object"===typeof q&&null!==q&&(void 0!==q.state&&(v=q.state),"object"===typeof q.stats&&null!==q.stats&&(w=q.stats.stars||0));ra="locked"===v;"function"===typeof K.k.nw&&(u=K.k.nw(Cg(K.e,b,n),b,n,v))&&(U=ra=t=!1);q=nc+d;C=Ud;Z=s=1;if(!1!==U){B=a.nc?Gc:Mc;if("played"===v)switch(w){case 1:B=a.nc?Hc:Nc;break;case 2:B=a.nc?Ic:Oc;break;
case 3:B=a.nc?Jc:Pc}else a.nc||"locked"!==v||(B=Sc);B.width>ga&&(Z=ga/B.width);B.height>Oa&&(Z=Math.min(s,Oa/B.height));q+=Math.round((ga-B.width*Z)/2);C+=Math.round((Oa-B.height*Z)/2);B.S(0,q,C,Z,Z,0,1);f&&(a.zg[n]={x:q,y:C})}u&&(u.width>ga&&(s=ga/u.width),u.height>Oa&&(s=Math.min(s,Oa/u.height)),void 0!==B?(w=K.d.g(a.a.Bs,B.width*Z,u.width*s),U=K.d.g(a.a.Cs,B.height*Z,u.height*s)):(w=K.d.g(a.a.Bs,ga,u.width*s),U=K.d.g(a.a.Cs,Oa,u.height*s),f&&(a.zg[n]={x:q+w,y:C+U})),u instanceof x?u.S(q+w,C+U,
s,s,0,1):u.S(0,q+w,C+U,s,s,0,1));!1===t||ra||(t=""+(K.n.Tj?n+1:Cg(K.e,b,n)+1),s=a.fonts.mo,"locked"===v&&void 0!==a.fonts.ax?s=a.fonts.ax:"unlocked"===v&&void 0!==a.fonts.Nz?s=a.fonts.Nz:"played"===v&&void 0!==a.fonts.played&&(s=a.fonts.played),void 0!==B?(w=K.d.Ca(a.a.Fs,B.width*Z,s.aa(t),s.align),U=K.d.Ca(a.a.Gs,B.height*Z,s.T(t),s.i)):(w=K.d.Ca(a.a.Fs,ga,s.aa(t),s.align),U=K.d.Ca(a.a.Gs,Oa,s.T(t),s.i)),s.o(t,q+w,C+U));a.nc&&ra&&(void 0!==B?(w=K.d.g(a.a.Ts,B.width*Z,Kc.width),U=K.d.g(a.a.Us,B.height*
Z,Kc.height)):(w=K.d.g(a.a.Ts,ga,Kc.width),U=K.d.g(a.a.Us,Oa,Kc.height)),Kc.o(0,q+w,C+U));nc+=ga;n++}nc=a.a.so;Ud+=Oa+Pd}};a.ij&&b(a.B-1,0);b(a.B,a.canvas.width,!0);a.hj&&b(a.B+1,2*a.canvas.width);z(a.nj)}}function Dg(a,b){switch(b-a.B){case 0:a.dp=0;break;case 1:a.dp=-a.canvas.width;break;case -1:a.dp=a.canvas.width}a.Te=!0;a.Al=0;a.moveStart=a.Xa;a.at=a.dp-a.Xa;a.zl=Math.min(a.a.Jx-a.$h,Math.round(Math.abs(a.at)/(a.km/1E3)));a.zl=Math.max(a.a.Ix,a.zl)}
function Eg(a){if(1<K.n.na.length){var b,c;b=K.d.g(a.a.Uz,a.canvas.width,Rc.width);c=K.d.g(a.a.iq,K.ha.height,Rc.height)+K.ha.top;a.Af=new ag(b,c,a.depth-20,new Xb(Rc),[Rc],function(){a.le="previous";Dg(a,a.B-1);return!0});b=K.d.g(a.a.Tz,a.canvas.width,Qc.width);c=K.d.g(a.a.hq,K.ha.height,Qc.height)+K.ha.top;a.zf=new ag(b,c,a.depth-20,new Xb(Qc),[Qc],function(){a.le="next";Dg(a,a.B+1);return!0});Fg(a)}else a.wf-=a.a.Wr}
function Fg(a){if(1<K.n.na.length){var b;a.ij?(b=[Rc],a.Af.Cb=!0):(b=[new x(Rc.width,Rc.height)],y(b[0]),Rc.o(1,0,0),z(b[0]),a.Af.Cb=!1);Gg(a.Af,b);a.hj?(b=[Qc],a.zf.Cb=!0):(b=[new x(Qc.width,Qc.height)],y(b[0]),Qc.o(1,0,0),z(b[0]),a.zf.Cb=!1);Gg(a.zf,b)}}
function Hg(a){var b,c,d;y(a.Ug);p.clear();b=V.P();a.a.td&&A(b,a.a.td);La(b,"center");Ma(b,"middle");c=K.m.N("levelMapScreenWorld_"+a.B,"<LEVELMAPSCREENWORLD_"+a.B+">");d=Sa(b,c,a.a.me-(b.stroke?b.Uc:0),a.a.Mf-(b.stroke?b.Uc:0),!1);d<b.fontSize&&D(b,d);b.o(c,a.Ug.width/2,a.Ug.height/2);z(a.Ug);a.canvas.Y=!0}
e.ac=function(){var a,b,c,d=this;this.nc=this.a.nc?!0:!1;if(!this.nc){for(a=0;a<K.n.na.length;a++)if(9<K.n.na[a]){b=!0;break}b||(this.nc=!0)}this.nj=new x(3*this.canvas.width,this.nc?this.a.Js:this.a.Ks);this.Hs=-this.canvas.width;this.Is=this.nc?this.a.Vr:this.a.Xr;this.wf=K.d.g(this.Is,K.ha.height,this.nj.height)+K.ha.top;this.Ug=new x(this.a.me,this.a.Mf);this.Gz=K.d.g(this.a.Vg,this.canvas.width,this.a.me);this.nu=K.d.g(this.a.Rd,K.ha.height,this.Ug.height)+K.ha.top;this.Es="undefined"!==typeof s_level_mask?
s_level_mask:this.nc?Xb(Gc):Xb(Mc);this.a.xr&&(this.fonts={},a=function(a){var b,c;for(b in a)c=V.P(),A(c,a[b]),d.fonts[b]=c},this.fonts={},this.fonts.mo=V,this.nc?a(this.a.Mw):a(this.a.Nw));this.B=K.e.B;this.na=K.n.na[this.B];this.lm=!1;this.km=this.Qp=this.$h=0;this.Rp=this.Hs;this.Xa=0;this.ij=0<this.B;this.hj=this.B<K.n.na.length-1;for(b=this.Up=this.Sl=this.J=0;b<K.n.na.length;b++)for(a=0;a<K.n.na[b];a++)c=Ig(void 0,a,b),this.Up+=3,"object"===typeof c&&null!==c&&(this.J+=void 0!==c.stars?c.stars:
0,this.Sl+=void 0!==c.highScore?c.highScore:0);K.k.qw&&(this.Sl=K.k.qw());this.Sa();a=this.Fc[this.a.Rx];this.hp=new ag(K.d.g(this.a.Sx,this.canvas.width,a.r.width),K.d.g(this.a.jp,K.ha.height,a.r.height)+K.ha.top,this.depth-20,new Xb(a.r),[a.r],{ea:K.e.Sh,va:this});Eg(this);Ag(this);Hg(this);this.kd=!0};e.nb=function(){this.Af&&I(G,this.Af);this.zf&&I(G,this.zf);I(G,this.hp)};
e.Ub=function(a,b,c){if(!this.Te)for(a=0;a<this.zg.length;a++)if(cc(this.Es,this.zg[a].x-this.canvas.width,this.zg[a].y+this.wf,b,c)){this.Ag=a;break}this.Te=!1;1<K.n.na.length&&(this.lm=!0,this.$h=0,this.au=this.Rp=b,this.km=this.Qp=0)};
e.Vb=function(a,b,c){if(!this.Te&&-1!==this.Ag&&cc(this.Es,this.zg[this.Ag].x-this.canvas.width,this.zg[this.Ag].y+this.wf,b,c)&&(a=K.n.Ti||"locked",b=Bg(this.B,this.Ag,void 0,void 0),"object"===typeof b&&null!==b&&void 0!==b.state&&(a=b.state),"locked"!==a))return I(G,this),xg(K.e,this.Ag,this.B),!0;this.Ag=-1;this.lm=!1;1<K.n.na.length&&(Math.abs(this.Xa)>=this.a.uz&&(this.km>=this.a.vz||Math.abs(this.Xa)>=this.a.tz)?"previous"===this.le?this.ij&&0<=this.Xa&&this.Xa<=this.canvas.width/2?Dg(this,
this.B-1):(0>this.Xa||(this.le="next"),Dg(this,this.B)):"next"===this.le&&(this.hj&&0>=this.Xa&&this.Xa>=-this.canvas.width/2?Dg(this,this.B+1):(0<this.Xa||(this.le="previous"),Dg(this,this.B))):0<Math.abs(this.Xa)&&(this.le="next"===this.le?"previous":"next",Dg(this,this.B)));return!0};
e.Oc=function(a){if(a===K.vf||a===K.Df)this.canvas.Y=!0,this.Sa(),a===K.Df?(this.nu=K.d.g(this.a.Rd,K.ha.height,this.Ug.height)+K.ha.top,this.wf=K.d.g(this.Is,K.ha.height,this.nj.height)+K.ha.top,this.hp.y=K.d.g(this.a.jp,K.ha.height,this.hp.images[0].height)+K.ha.top,this.Af&&(this.Af.y=K.d.g(this.a.iq,K.ha.height,Rc.height)+K.ha.top),this.zf&&(this.zf.y=K.d.g(this.a.hq,K.ha.height,Qc.height)+K.ha.top),void 0===this.zf&&void 0===this.Af&&(this.wf-=this.a.Wr)):(Hg(this),Ag(this))};
e.Pe=function(a){var b=G.ia[0].x;this.lm&&(this.Qp=Math.abs(this.Rp-b),0<this.$h&&(this.km=this.Qp/(this.$h/1E3)),this.le=b>this.Rp?"previous":"next",this.$h+=a,this.Xa+=b-this.au,this.au=b,this.canvas.Y=!0);this.Te&&(b=this.zl,this.Xa=this.moveStart+this.at*hc(b-this.Al,1,-1,b,2),this.Al>=this.zl&&(this.Te=!1,this.Xa=0),this.Al+=a,this.canvas.Y=!0);if(this.Te||this.lm)"previous"===this.le&&this.Xa>=this.canvas.width/2?0<=this.B-1?(this.B-=1,this.na=K.n.na[this.B],this.ij=0<this.B,this.hj=this.B<
K.n.na.length-1,Fg(this),this.Xa-=this.canvas.width,Hg(this),Ag(this),this.canvas.Y=!0,this.moveStart-=this.canvas.width):this.Xa=Math.round(this.canvas.width/2):"next"===this.le&&this.Xa<=-this.canvas.width/2&&(this.B+1<K.n.na.length?(this.B+=1,this.na=K.n.na[this.B],this.ij=0<this.B,this.hj=this.B<K.n.na.length-1,Fg(this),this.Xa+=this.canvas.width,Hg(this),Ag(this),this.canvas.Y=!0,this.moveStart+=this.canvas.width):this.Xa=Math.round(-this.canvas.width/2))};
e.za=function(){this.Ug.o(this.Gz,this.nu);this.nj.o(Math.round(this.Hs+this.Xa),this.wf);this.kd=!1};
function Jg(a,b,c,d){this.depth=10;this.h=this.visible=!0;K.d.Ka(this,K.Hc);var f;this.type=b.failed?"failed":a;this.a=K.a.w.wa;this.Ha=this.a.type[this.type];if("landscape"===K.orientation)for(f in K.a.w.As)this.a[f]=K.a.w.As[f];for(f in K.a.R.wa)this.a[f]=K.a.R.wa[f];if(K.a.R.wa&&K.a.R.wa.type&&K.a.R.wa.type[this.type])for(f in K.a.R.wa.type[this.type])this.a[f]=K.a.R.wa.type[this.type][f];if("failed"===this.type){if(void 0!==K.a.k.wa&&K.a.k.wa.type&&void 0!==K.a.k.wa.type.failed)for(f in K.a.k.wa.type[this.type])this.Ha[f]=
K.a.k.wa.type[this.type][f]}else{if(void 0!==K.a.k.wa&&void 0!==K.a.k.wa.type)for(f in K.a.k.wa.type[this.type])this.Ha[f]=K.a.k.wa.type[this.type][f];for(f in K.a.k.wa)this.Ha[f]=K.a.k.wa[f]}this.Aa=b;this.ea=c;this.va=d;this.Yy=[Df,Ff,Gf];this.fg=[];this.Ya=new dc;this.Ya.parent=this;H(this,!1)}
function Kg(a){var b;for(b=0;b<a.J.length;b++)Lg(a.J[b]);for(b=0;b<a.Jg.length;b++)I(G,a.Jg[b]);a.Jg=[];a.Va&&Lg(a.Va);a.Va=void 0;for(b=0;b<a.buttons.length;b++)a.buttons[b].Cb=!1;a.Ya.stop();a.Ya=void 0;Mg(a)}
function Ng(a,b){var c;switch(b){case "title_level":c=K.m.N("levelEndScreenTitle_level","<LEVELENDSCREENTITLE_LEVEL>").replace("<VALUE>",a.Aa.level);break;case "title_endless":c=K.m.N("levelEndScreenTitle_endless","<LEVELENDSCREENTITLE_ENDLESS>").replace("<VALUE>",a.Aa.stage);break;case "title_difficulty":c=K.m.N("levelEndScreenTitle_difficulty","<LEVELENDSCREENTITLE_DIFFICULTY>")}void 0!==c&&a.Mc(a.a.td,c,a.a.Vg,a.a.Rd,a.a.me,a.a.Mf)}
function Og(a,b){var c;switch(b){case "subtitle_failed":c=K.m.N("levelEndScreenSubTitle_levelFailed","<LEVEL_FAILED>")}void 0!==c&&a.Mc(a.a.Wt,c,a.a.oz,a.a.pz)}
function Pg(a,b,c){var d,f,h,k,l;f=K.m.N(b.key,"<"+b.key.toUpperCase()+">");d=b.lf?b.toString(b.Kg):b.toString(b.gd);h=a.a.Kj;h.align="left";h.i="top";l=V.P();A(l,h);c?(Ma(l,"bottom"),h=a.a.Lg,h.align="left",h.i="bottom",c=V.P(),A(c,h),h=k=0,void 0!==f&&(h+=l.aa(f)+a.a.jm),void 0!==d&&(h+=c.aa(d)),h=K.d.g(a.a.Ff,a.canvas.width,h)-a.f.x,void 0!==f&&(l.o(f,h,a.Qd+l.fontSize),h+=l.aa(f)+a.a.jm,k+=l.T(f)),void 0!==d&&(b.lf?(d=c.T(d),l=a.Qd+l.fontSize-d,b.Si=new Qg(h,l,a.a.Xh,d,a.depth-100,b.Kg,c,a.a.Vh,
a.a.Wh,a.f,b.toString),k=Math.max(k,d)):(c.o(d,h,a.Qd+l.fontSize+a.a.Tt),k=Math.max(k,c.T(d)))),0<k&&(a.Qd+=k+a.a.Pd)):(void 0!==f&&(a.Mc(h,f,a.a.Ff,a.a.Mg),k=a.a.Mg,"object"===typeof k?(k.offset=void 0!==k.offset?k.offset+a.a.Pd:a.a.Pd,k.offset+=l.T(f)):"number"===typeof k&&(k+=a.a.Pd+l.T(f))),void 0!==d&&(h=a.a.Lg,h.i="top",b.lf?(c=V.P(),h.align="center",A(c,h),f=K.d.g(a.a.Ff,a.canvas.width,a.a.Xh)-a.f.x,l=k-a.f.y,b.Si=new Qg(f,l,a.a.Xh,c.T(d),a.depth-100,b.Kg,c,a.a.Vh,a.a.Wh,a.f,b.toString)):a.Mc(h,
d,a.a.Ff,k)))}
function Rg(a,b,c){var d,f,h,k,l,n;switch(b){case "totalScore":d=""+a.Aa.totalScore;f=K.m.N("levelEndScreenTotalScore","<LEVENENDSCREENTOTALSCORE>");n=0;break;case "highScore":f=K.m.N("levelEndScreenHighScore","<LEVENENDSCREENHIGHSCORE>");d=""+a.Aa.highScore;break;case "timeLeft":f=K.m.N("levelEndScreenTimeLeft","<LEVENENDSCREENTIMELEFT>");d=""+a.Aa.timeLeft;break;case "timeBonus":f=K.m.N("levelEndScreenTimeBonus","<LEVENENDSCREENTIMEBONUS>"),d=""+a.Aa.timeBonus,n=a.Aa.timeBonus}h=a.a.Kj;h.align=
"left";h.i="top";l=V.P();A(l,h);c?(Ma(l,"bottom"),h=a.a.Lg,h.align="left",h.i="bottom",c=V.P(),A(c,h),h=k=0,void 0!==f&&(h+=l.aa(f)+a.a.jm),void 0!==d&&(h+=c.aa(d)),h=K.d.g(a.a.Ff,a.canvas.width,h)-a.f.x,void 0!==f&&(l.o(f,h,a.Qd+l.fontSize),h+=l.aa(f)+a.a.jm,k+=l.T(f)),void 0!==d&&(void 0!==n?(d=c.T(d),l=a.Qd+l.fontSize-d,n=new Qg(h,l,a.a.Xh,d,a.depth-100,n,c,a.a.Vh,a.a.Wh,a.f),k=Math.max(k,d)):(c.o(d,h,a.Qd+l.fontSize+a.a.Tt),k=Math.max(k,c.T(d)))),0<k&&(a.Qd+=k+a.a.Pd)):(void 0!==f&&(a.Mc(h,f,
a.a.Ff,a.a.Mg),k=a.a.Mg,"object"===typeof k?(k.offset=void 0!==k.offset?k.offset+a.a.Pd:a.a.Pd,k.offset+=l.T(f)):"number"===typeof k&&(k+=a.a.Pd+l.T(f))),void 0!==d&&(h=a.a.Lg,h.i="top",void 0!==n?(c=V.P(),h.align="center",A(c,h),f=K.d.g(a.a.Ff,a.canvas.width,a.a.Xh)-a.f.x,l=k-a.f.y,n=new Qg(f,l,a.a.Xh,c.T(d),a.depth-100,n,c,a.a.Vh,a.a.Wh,a.f)):a.Mc(h,d,a.a.Ff,k)));n instanceof Qg&&("totalScore"===b?a.Yg=n:a.fg.push(n))}
function Sg(a,b){var c,d,f;c=K.m.N(b.key,"<"+b.key.toUpperCase()+">");d=b.lf?b.toString(b.Kg):b.toString(b.gd);void 0!==c&&a.Mc(a.a.Fn,c,a.a.Br,a.a.Gn);void 0!==d&&(b.lf?(c=V.P(),d=a.a.Wi,a.a.QA||(d.align="center"),A(c,d),d=K.d.g(a.a.Ok,a.canvas.width,a.a.Nk)-a.f.x,f=K.d.g(a.a.th,a.canvas.height,a.a.Mk)-a.f.y,b.Si=new Qg(d,f,a.a.Nk,a.a.Mk,a.depth-100,b.Kg,c,a.a.Vh,a.a.Wh,a.f,b.toString)):a.Mc(a.a.Wi,d,a.a.Ok,a.a.th))}
function Tg(a,b){var c,d,f,h;switch(b){case "totalScore":c=K.m.N("levelEndScreenTotalScore","<LEVENENDSCREENTOTALSCORE>");d=""+a.Aa.totalScore;f=0;break;case "timeLeft":c=K.m.N("levelEndScreenTimeLeft","<LEVENENDSCREENTIMELEFT>"),d=""+a.Aa.timeLeft}void 0!==c&&a.Mc(a.a.Fn,c,a.a.Br,a.a.Gn);void 0!==d&&(void 0!==f?(c=V.P(),d=a.a.Wi,d.align="center",A(c,d),d=K.d.g(a.a.Ok,a.canvas.width,a.a.Nk)-a.f.x,h=K.d.g(a.a.th,a.canvas.height,a.a.Mk)-a.f.y,f=new Qg(d,h,a.a.Nk,a.a.Mk,a.depth-100,f,c,a.a.Vh,a.a.Wh,
a.f)):a.Mc(a.a.Wi,d,a.a.Ok,a.a.th));f instanceof Qg&&("totalScore"===b?a.Yg=f:a.fg.push(f))}e=Jg.prototype;e.Mc=function(a,b,c,d,f,h){var k=V.P();A(k,a);void 0!==f&&void 0!==h&&(a=Sa(k,b,f,h,f),k.fontSize>a&&D(k,a));a=k.aa(b);h=k.T(b);k.o(b,K.d.Ca(c,this.canvas.width,a,k.align)-this.f.x,K.d.Ca(d,this.canvas.height,h,k.i)-this.f.y,f)};
function Ug(a,b){var c,d,f,h;switch(b){case "retry":c=fe;d=function(){a.of="retry";Kg(a)};break;case "exit":c=ce,d=function(){a.of="exit";Kg(a)}}void 0!==c&&(f=K.d.g(a.a.mv,a.canvas.width,c.width)-a.f.x,h=K.d.g(a.a.Pq,a.canvas.height,c.height)-a.f.y,a.buttons.push(new ag(f,h,a.depth-20,new Xb(c),[c],d,a.f)))}
function Vg(a,b){var c,d,f,h;switch(b){case "retry":c=se;d=function(){a.of="retry";Kg(a)};break;case "exit":c=qe;d=function(){a.of="exit";Kg(a)};break;case "next":c=qe,d=function(){a.of="next";Kg(a)}}void 0!==c&&(f=K.d.g(a.a.bw,a.canvas.width,c.width)-a.f.x,h=K.d.g(a.a.Or,a.canvas.height,c.height)-a.f.y,a.buttons.push(new ag(f,h,a.depth-20,new Xb(c),[c],d,a.f)))}
e.ac=function(){this.l=0;this.J=[];this.Jg=[];this.buttons=[];this.canvas.Y=!0;this.of="";this.Cd=this.Aa.failed?!0:!1;this.od=this.Ha.od&&!this.Cd;this.Rh=this.Ha.Rh&&!this.Cd&&this.Aa.ls;this.Zm=this.alpha=this.lh=0;Wg(this);var a,b,c,d,f,h,k=this;switch(this.Ha.sk){case "failed":this.b=this.a.Kl.Lw;break;case "level":this.b=this.a.Kl.Ow;break;case "difficulty":this.b=this.a.Kl.Bn;break;case "endless":this.b=this.a.Kl.Tv}this.f=new Xg(this.depth-10,this.Ua,new x(this.b.width,this.b.height));this.f.x=
K.d.g(this.a.yc,this.canvas.width,this.b.width);this.f.y=K.d.g(this.a.ec,this.canvas.height,this.b.height);y(this.f.b);this.b.o(0,0,0);!this.Cd&&this.od&&(b=K.d.g(this.a.Hp,this.canvas.width,0)-this.f.x,a=K.d.g(this.a.Ip,this.canvas.height,s_star01_fill.height)-this.f.y+Math.round(s_star01_empty.height/2),s_star01_empty.o(0,b,a),b=K.d.g(this.a.Jp,this.canvas.width,0)-this.f.x,a=K.d.g(this.a.Kp,this.canvas.height,s_star02_fill.height)-this.f.y+Math.round(s_star02_empty.height/2),s_star02_empty.o(0,
b,a),b=K.d.g(this.a.Lp,this.canvas.width,0)-this.f.x,a=K.d.g(this.a.Mp,this.canvas.height,s_star03_fill.height)-this.f.y+Math.round(s_star03_empty.height/2),s_star03_empty.o(0,b,a));void 0!==this.Ha.Pj&&Ng(this,this.Ha.Pj);void 0!==this.Ha.Xt&&Og(this,this.Ha.Xt);this.Yb={};void 0!==this.Aa.be?(c=this.Aa.be,c.visible&&Sg(this,c),this.Yb[c.id]=c):void 0!==this.Ha.Hn&&Tg(this,this.Ha.Hn);if(void 0!==this.Aa.Yb)for(a=this.Aa.Yb.length,b=V.P(),A(b,this.a.Kj),c=V.P(),A(c,this.a.Lg),b=Math.max(b.T("g"),
c.T("g"))*a+this.a.Pd*(a-1),this.Qd=K.d.g(this.a.Mg,this.canvas.height,b)-this.f.y,b=0;b<a;b++)c=this.Aa.Yb[b],c.visible&&Pg(this,this.Aa.Yb[b],1<a),this.Yb[c.id]=c;else if(void 0!==this.Ha.Gf)if("string"===typeof this.Ha.Gf)Rg(this,this.Ha.Gf,this.a.Nr);else if(this.Ha.Gf instanceof Array)for(a=this.Ha.Gf.length,b=V.P(),A(b,this.a.Kj),c=V.P(),A(c,this.a.Lg),b=Math.max(b.T("g"),c.T("g"))*a+this.a.Pd*(a-1),this.Qd=K.d.g(this.a.Mg,this.canvas.height,b)-this.f.y,b=0;b<a;b++)Rg(this,this.Ha.Gf[b],1<a||
this.a.Nr);z(this.f.b);Ug(this,this.Ha.qk);Vg(this,this.Ha.Uk);K.e.zu&&(b=K.d.g(k.a.yw,k.canvas.width,k.a.js)-this.f.x,a=K.d.g(this.a.zw,this.canvas.height,this.a.kg)-this.f.y,this.is=new vg("default_text",b,a,k.depth-20,"levelEndScreenViewHighscoreBtn",k.a.js,{ea:function(){void 0!==Yg?K.j.Jd(K.q.jl.url+"submit/"+Yg+"/"+k.Aa.totalScore):K.j.Jd(K.q.jl.url+"submit/")},vc:!0},k.f),this.buttons.push(this.is),b=function(a){a&&(k.is.bq("levelEndScreenSubmitHighscoreBtn"),k.kB=a)},Zg(this.Aa.totalScore,
b));b=K.d.g(this.a.Pi,this.canvas.width,this.a.nh)-this.f.x;a=K.d.g(this.a.oh,this.canvas.height,this.a.kg)-this.f.y;this.buttons.push(new ag(b,a,this.depth-20,new Vb(0,0,this.a.nh,this.a.kg),void 0,function(){k.of="exit";Kg(k)},this.f));for(b=0;b<this.buttons.length;b++)this.buttons[b].Cb=!1;this.f.y=-this.f.height;a=this.a.zz;this.Ya.V(a,this.hz);a+=this.a.Fi;f=0;d=this.a.Iz;this.od&&(d=Math.max(d,this.a.Jt+this.a.It*this.Aa.stars));if(this.Yg&&(this.Ya.V(a+this.a.vm,function(a,b){$g(b.parent.Yg,
b.parent.Aa.totalScore,d)}),f=a+this.a.vm+d,0<this.fg.length)){h=function(a,b){var c=b.parent,d=c.fg[c.lh];$g(c.Yg,c.Yg.value+d.value,c.a.kh);$g(d,0,c.a.kh);c.lh+=1};for(b=0;b<this.fg.length;b++)f+=this.a.Yq,this.Ya.V(f,h);f+=this.a.kh}if(void 0!==this.Yb&&(f=a,h=function(a,b){var c=b.parent,d=c.Pp[c.lh||0],f=c.Yb[d.im];void 0!==d.Pf&&(f.visible&&f.lf?$g(f.Si,d.Pf(f.Si.value),c.a.kh):f.gd=d.Pf(f.gd));d.visible&&d.lf&&$g(d.Si,d.gd,c.a.kh);c.lh+=1},this.Pp=[],void 0!==this.Aa.be&&void 0!==this.Aa.be.Pf&&
(this.Ya.V(a+this.a.vm,h),this.Pp.push(this.Aa.be),f+=this.a.vm+bonusCounterDuration),void 0!==this.Aa.Yb))for(b=0;b<this.Aa.Yb.length;b++)c=this.Aa.Yb[b],void 0!==c.Pf&&(f+=this.a.Yq,this.Ya.V(f,h),this.Pp.push(c),f+=this.a.kh);if(this.od){for(b=0;b<this.Aa.stars;b++)a+=this.a.It,this.Ya.V(a,this.jz),this.Ya.V(a,this.kz);a+=this.a.Jt}a=Math.max(a,f);this.Rh&&(a+=this.a.nx,this.Ya.V(a,this.gz),this.Ya.V(a,this.ez),this.Ya.V(a+this.a.ox,this.fz));a+=500;this.Ya.V(a,function(){K.j.Ew&&K.j.Ew()});this.Ya.V(a+
this.a.Fx,K.j.Fw);K.j.os(this.Aa);this.Ya.start();E.play(Bf)};e.Z=function(a){this.alpha=this.a.Sk*this.Zm/this.a.$b;this.Zm+=a;this.alpha>=this.a.Sk&&(this.alpha=this.a.Sk,this.h=!1);this.canvas.Y=!0};
e.hz=function(a,b){function c(){var a;for(a=0;a<d.buttons.length;a++)d.buttons[a].Cb=!0}var d=b.parent,f,h;switch(d.a.dA){case "fromLeft":h="horizontal";f=K.d.g(d.a.yc,d.canvas.width,d.f.width);d.f.x=-d.f.width;d.f.y=K.d.g(d.a.ec,d.canvas.height,d.f.height)+Math.abs(K.sa);break;case "fromRight":h="horizontal";f=K.d.g(d.a.yc,d.canvas.width,d.f.width);d.f.x=d.canvas.width;d.f.y=K.d.g(this.parent.a.ec,d.canvas.height,selft.f.height)+Math.abs(K.sa);break;case "fromBottom":h="vertical";f=K.d.g(d.a.ec,
d.canvas.height,d.f.height)+Math.abs(K.sa);d.f.x=K.d.g(d.a.yc,d.canvas.width,d.f.width);d.f.y=d.canvas.height+d.f.height;break;default:h="vertical",f=K.d.g(d.a.ec,d.canvas.height,d.f.height)+Math.abs(K.sa),d.f.x=K.d.g(d.a.yc,d.canvas.width,d.f.width),d.f.y=-d.f.height}"vertical"===h?ah(d.f,"y",f,d.a.Fi,d.a.$m,c):ah(d.f,"x",f,d.a.Fi,d.a.$m,c)};
function Mg(a){function b(){I(G,a);a.va?a.ea.call(a.va,a.of):a.ea(a.of)}var c,d;switch(a.a.eA){case "toLeft":d="horizontal";c=-a.f.width;break;case "toRight":d="horizontal";c=a.canvas.width;break;case "toBottom":d="vertical";c=a.canvas.height+a.f.height;break;default:d="vertical",c=-a.f.height}"vertical"===d?ah(a.f,"y",c,a.a.an,a.a.bn,b):ah(a.f,"x",c,a.a.an,a.a.bn,b)}
e.jz=function(a,b){var c,d=b.parent,f=Math.abs(K.sa);if(d.J.length<d.Aa.stars){switch(d.J.length+1){case 1:c=new Xg(d.depth-30,K.Oe,s_star01_fill);c.x=K.d.g(d.a.Hp,d.canvas.width,0);c.y=K.d.g(d.a.Ip,d.canvas.height,s_star01_fill.height)+f+Math.round(s_star01_empty.height/2);break;case 2:c=new Xg(d.depth-30,K.Oe,s_star02_fill);c.x=K.d.g(d.a.Jp,d.canvas.width,0);c.y=K.d.g(d.a.Kp,d.canvas.height,s_star02_fill.height)+f+Math.round(s_star02_empty.height/2);break;case 3:c=new Xg(d.depth-30,K.Oe,s_star03_fill),
c.x=K.d.g(d.a.Lp,d.canvas.width,0),c.y=K.d.g(d.a.Mp,d.canvas.height,s_star03_fill.height)+f+Math.round(s_star03_empty.height/2)}c.fb=d.a.Kt;c.ib=d.a.Kt;c.alpha=d.a.bz;ah(c,"scale",1,d.a.az,sc,function(){var a=d.J.length,b,c,n;y(d.f.b);switch(a){case 1:n=s_star01_fill;b=K.d.g(d.a.Hp,d.canvas.width,0)-d.f.x;c=K.d.g(d.a.Ip,d.canvas.height,s_star01_fill.height)-d.f.y+f+Math.round(s_star01_empty.height/2);break;case 2:n=s_star02_fill;b=K.d.g(d.a.Jp,d.canvas.width,0)-d.f.x;c=K.d.g(d.a.Kp,d.canvas.height,
s_star01_fill.height)-d.f.y+f+Math.round(s_star02_empty.height/2);break;case 3:n=s_star03_fill,b=K.d.g(d.a.Lp,d.canvas.width,0)-d.f.x,c=K.d.g(d.a.Mp,d.canvas.height,s_star01_fill.height)-d.f.y+f+Math.round(s_star03_empty.height/2)}n.o(0,b,c);z(d.f.b);d.f.kd=!0;I(G,d.J[a-1])});ah(c,"alpha",1,d.a.$y,ic);d.J.push(c);E.play(d.Yy[d.J.length-1])}};
e.kz=function(a,b){var c=b.parent,d,f;d=c.J[c.Jg.length];f=new Xg(c.depth-50,K.Oe,s_sfx_star);f.x=d.x;f.y=d.y;ah(f,"subImage",s_sfx_star.D-1,c.a.Zy,void 0,function(){I(G,f)});c.Jg.push(f)};
e.ez=function(a,b){var c=b.parent,d,f,h,k,l,n,q;d=[];h=V.P();k=K.m.N("levelEndScreenMedal","<LEVELENDSCREENMEDAL>");c.a.Zs&&A(h,c.a.Zs);f=Sa(h,k,c.a.vl,c.a.ux,!0);f<h.fontSize&&D(h,f);l=K.d.Ca(c.a.vx,Vc.width,h.aa(k,c.a.vl),h.align);n=K.d.Ca(c.a.wx,Vc.height,h.T(k,c.a.vl),h.i);for(q=0;q<Vc.D;q++)f=new x(Vc.width,Vc.height),y(f),Vc.o(q,0,0),h.o(k,l,n,c.a.vl),z(f),d.push(f);c.Va=new Xg(c.depth-120,K.Oe,d);c.Va.Kd=c.a.Ws;c.Va.Ld=c.a.Xs;c.Va.x=K.d.g({align:"center"},c.f.canvas.width,c.Va.width)-c.f.x;
c.Va.y=K.d.g(c.a.vj,c.Va.canvas.height,c.Va.height)-c.f.y+Math.abs(K.sa);l=K.d.g(c.a.Yo,c.Va.canvas.width,c.Va.width)-c.f.x;c.Va.fb=c.a.ul;c.Va.ib=c.a.ul;c.Va.parent=c.f;c.Va.alpha=0;c.Va.sA=!0;ah(c.Va,"scale",1,c.a.Hh,ic,function(){I(G,c.Eb);c.Eb=void 0});ah(c.Va,"x",l,c.a.Hh,ic);ah(c.Va,"alpha",1,0,ic);ah(c.Va,"subImage",Vc.D,c.a.sx,ic,void 0,c.a.Hh+c.a.Vs+c.a.rx,!0,c.a.tx)};
e.gz=function(a,b){var c,d=b.parent;d.Eb=new Xg(d.depth-110,K.Oe,Uc);d.Eb.y=K.d.g(d.a.vj,d.Eb.canvas.height,Uc.height)-d.f.y+d.a.qx;d.Eb.Kd=d.a.Ws;d.Eb.Ld=d.a.Xs;d.Eb.x=K.d.g(d.a.Yo,d.Eb.canvas.width,d.Eb.width)-d.f.x;c=K.d.g(d.a.vj,d.Eb.canvas.height,Uc.height)-d.f.y+Math.abs(K.sa);d.Eb.fb=d.a.ul*d.a.Ys;d.Eb.ib=d.a.ul*d.a.Ys;d.Eb.alpha=0;d.Eb.parent=d.f;ah(d.Eb,"y",c,d.a.Hh,ic);ah(d.Eb,"scale",1,d.a.Hh,ic);ah(d.Eb,"alpha",1,d.a.Hh,ic)};
e.fz=function(a,b){var c=b.parent;c.yf=new Xg(c.depth-130,K.Oe,Tc);c.yf.parent=c.f;c.yf.x=c.Va.x;c.yf.y=c.Va.y+c.a.px;ah(c.yf,"subImage",Tc.D-1,c.a.Vs,void 0,function(){I(G,c.yf);c.yf=void 0});E.play(Kf)};
e.nb=function(){var a;for(a=0;a<this.buttons.length;a++)I(G,this.buttons[a]);for(a=0;a<this.J.length;a++)I(G,this.J[a]);for(a=0;a<this.Jg.length;a++)I(G,this.Jg[a]);this.Va&&(I(G,this.Va),this.yf&&I(G,this.yf),this.Eb&&I(G,this.Eb));I(G,this.f);this.Ya&&this.Ya.stop();this.Yg&&I(G,this.Yg);for(a=0;a<this.fg.length;a++)I(G,this.fg[a]);bh()};e.za=function(){var a=p.context.globalAlpha;p.context.globalAlpha=this.alpha;sa(0,0,p.canvas.width,p.canvas.height,this.a.Gr,!1);p.context.globalAlpha=a};
function ch(a,b,c,d){this.depth=-100;this.visible=!1;this.h=!0;K.d.Ka(this,K.Hc);var f,h;this.a=c?K.a.w.et:K.a.w.options;if("landscape"===K.orientation)for(f in h=c?K.a.w.SB:K.a.w.Tx,h)this.a[f]=h[f];this.Fc=K.a.w.rc;h=c?K.a.R.et:K.a.R.options;for(f in h)this.a[f]=h[f];if(K.q.options&&K.q.options.buttons)for(f in K.q.options.buttons)this.a.buttons[f]=K.q.options.buttons[f];this.type=a;this.Mz=b;this.zd=c;this.dm=!1!==d;H(this)}e=ch.prototype;
e.Ei=function(a,b,c,d,f){var h=void 0,k=void 0,l=void 0,n=void 0,q=void 0,u=void 0;switch(a){case "music":h="music_toggle";n=this.pu;l=K.e.Eg()?"on":"off";break;case "music_big":h="music_big_toggle";n=this.pu;l=K.e.Eg()?"on":"off";break;case "sfx_big":h="sfx_big_toggle";n=this.qu;l=K.e.Rl()?"on":"off";break;case "sfx":h="sfx_toggle";n=this.qu;l=K.e.Rl()?"on":"off";break;case "language":h="language_toggle";n=this.ou;l=K.e.language();break;case "tutorial":h="default_text";k="optionsTutorial";n=this.Hj;
break;case "highScores":h="default_text";k="optionsHighScore";n=this.tt;this.on=this.Iy;break;case "moreGames":void 0!==K.q.Ex?(h="default_image",u=K.q.Ex):(h="default_text",k="optionsMoreGames");n=this.Jy;q=!0;break;case "resume":h="default_text";k="optionsResume";n=this.close;break;case "exit":h="default_text";k="optionsExit";n=K.Nh.customFunctions&&"function"===typeof K.Nh.customFunctions.exit?K.Nh.customFunctions.exit:function(){};break;case "quit":h="default_text";k="optionsQuit";n=this.ty;break;
case "restart":h="default_text";k="optionsRestart";n=this.yy;break;case "startScreen":h="default_text";k="optionsStartScreen";n=this.tt;this.on=this.Ly;break;case "about":h="default_text";k="optionsAbout";n=this.Gy;break;case "forfeitChallenge":h="default_text";k="optionsChallengeForfeit";n=this.aj;break;case "cancelChallenge":h="default_text",k="optionsChallengeCancel",n=this.Ni}void 0!==h&&void 0!==n&&("image"===this.Fc[h].type?this.buttons.push(new dh(h,b,c,this.depth-20,u,d,{ea:n,va:this,vc:q},
this.f)):"toggleText"===this.Fc[h].type?this.buttons.push(new rg(h,b,c,this.depth-20,l,d,{ea:n,va:this,vc:q},this.f)):"text"===this.Fc[h].type?this.buttons.push(new vg(h,b,c,this.depth-20,k,d,{ea:n,va:this,vc:q},this.f)):"toggle"===this.Fc[h].type&&this.buttons.push(new eh(h,b,c,this.depth-20,l,{ea:n,va:this,vc:q},this.f)),this.buttons[this.buttons.length-1].Cb=f||!1)};
e.tt=function(){var a=this;ah(a.f,"y","inGame"!==this.type?-this.f.b.height:this.canvas.height,this.a.Hl,this.a.Il,function(){I(G,a);void 0!==a.on&&a.on.call(a)});return!0};
e.Sa=function(a,b){var c,d,f,h;y(this.f.b);p.clear();this.a.backgroundImage.o(0,0,0);c=K.m.N("optionsTitle","<OPTIONS_TITLE>");d=V.P();this.a.td&&A(d,this.a.td);void 0!==this.a.me&&void 0!==this.a.Mf&&(f=Sa(d,c,this.a.me,this.a.Mf,this.a.me),d.fontSize>f&&D(d,f));f=K.d.Ca(this.a.Vg,this.canvas.width,d.aa(c),d.align)-a;h=K.d.Ca(this.a.Rd,this.canvas.height,d.T(c,d.i))-b+-1*K.sa;d.o(c,f,h);z(this.f.b)};
e.$f=function(a,b,c){var d,f,h,k,l,n,q;h=!1;var u=this.a.buttons[this.type];"inGame"===this.type&&K.a.k.pg.zx&&(u=K.a.k.pg.zx);if("function"!==typeof fh())for(d=0;d<u.length;d++){if("string"===typeof u[d]&&"moreGames"===u[d]){u.splice(d,1);break}for(f=0;f<u[d].length;f++)if("moreGames"===u[d][f]){u[d].splice(f,1);break}}if(!1===K.q.Eg||!1===K.e.oj)for(d=0;d<u.length;d++)if(u[d]instanceof Array){for(f=0;f<u[d].length;f++)if("music"===u[d][f]){K.e.pj?u[d]="sfx_big":u.splice(d,1);h=!0;break}if(h)break}else if("music_big"===
u[d]){u.splice(d,1);break}if(!K.e.pj)for(d=0;d<u.length;d++)if(u[d]instanceof Array){for(f=0;f<u[d].length;f++)if("sfx"===u[d][f]){!1!==K.q.Eg&&K.e.oj?u[d]="music_big":u.splice(d,1);h=!0;break}if(h)break}else if("sfx_big"===u[d]){u.splice(d,1);break}if(1===K.m.mw().length)for(d=0;d<u.length;d++)if("language"===u[d]){u.splice(d,1);break}h=this.Fc.default_text.r.height;k=this.a.yk;a=K.d.g(this.a.xk,this.canvas.width,k)-a;n=K.d.g(this.a.Li,this.f.b.height,h*u.length+this.a.Xd*(u.length-1))-b+-1*K.sa;
for(d=0;d<u.length;d++){l=a;q=k;if("string"===typeof u[d])this.Ei(u[d],l,n,q,c);else for(b=u[d],q=(k-(b.length-1)*this.a.Xd)/b.length,f=0;f<b.length;f++)this.Ei(b[f],l,n,q,c),l+=q+this.a.Xd;n+=h+this.a.Xd}};e.pu=function(a){var b=!0;"off"===a?(b=!1,K.Na.gb("off","options:music")):K.Na.gb("on","options:music");K.e.Eg(b);return!0};e.qu=function(a){var b=!0;"off"===a?(b=!1,K.Na.gb("off","options:sfx")):K.Na.gb("on","options:sfx");K.e.Rl(b);return!0};
e.ou=function(a){K.m.vt(a);K.Na.gb(a,"options:language");return!0};
e.Hj=function(){function a(){l.Vc+=1;l.Hj();return!0}function b(){l.Vc-=1;l.Hj();return!0}function c(){var a;l.Sa(n,q);l.jg.Cb=!0;for(a=0;a<l.buttons.length;a++)I(G,l.buttons[a]);l.buttons=[];l.$f(n,q,!0)}var d,f,h,k,l=this,n=K.d.g(l.a.yc,l.canvas.width,l.a.backgroundImage.width),q=K.d.g(l.a.ec,l.canvas.height,l.a.backgroundImage.height)+-1*K.sa;void 0===l.Vc&&(l.Vc=0);l.Rj=void 0!==K.k.ro?K.k.ro(K.e.Ab,sg()):[];K.Na.gb((10>l.Vc?"0":"")+l.Vc,"options:tutorial");for(d=0;d<l.buttons.length;d++)I(G,
l.buttons[d]);l.buttons=[];this.zd?(y(l.f.b),p.clear(),l.jg.Cb=!1):l.Sa(n,q);y(l.f.b);void 0!==l.a.Sd&&(d=K.d.g(l.a.ym,l.f.b.width,l.a.Sd.width),f=K.d.g(l.a.Of,l.f.b.height,l.a.Sd.height),l.a.Sd.o(0,d,f));k=l.Rj[l.Vc].title;void 0!==k&&""!==k&&(h=V.P(),l.a.Am&&A(h,l.a.Am),d=Sa(h,k,l.a.Bm,l.a.$p,l.a.Bm),h.fontSize>d&&D(h,d),d=K.d.Ca(l.a.xu,l.f.b.width,h.aa(k,l.a.Bm),h.align),f=K.d.Ca(l.a.aq,l.f.b.height,h.T(k,l.a.$p),h.i),h.o(k,d,f));l.Vc<l.Rj.length&&(h=l.Rj[l.Vc].b,d=K.d.g(l.a.uu,l.f.b.width,h.width),
f=K.d.g(l.a.Yp,l.f.b.height,h.height),h.o(0,d,f),k=l.Rj[l.Vc].text,h=V.P(),l.a.zm&&A(h,l.a.zm),d=Sa(h,k,l.a.ci,l.a.vu,l.a.ci),h.fontSize>d&&D(h,d),d=K.d.Ca(l.a.wu,l.f.b.width,h.aa(k,l.a.ci),h.align),f=K.d.Ca(l.a.Zp,l.f.b.height,h.T(k,l.a.ci),h.i),h.o(k,d,f,l.a.ci));z(l.f.b);h=md;d=K.d.g(l.a.tu,l.canvas.width,h.width)-l.f.x;f=K.d.g(l.a.Xp,l.canvas.height,h.height)-l.f.y-K.sa;0<=l.Vc-1?l.buttons.push(new ag(d,f,l.depth-20,new Xb(h),[h],{ea:b,va:l},l.f)):(h=kd,l.buttons.push(new ag(d,f,l.depth-20,new Xb(h),
[h],{ea:c,va:l},l.f)));h=ld;d=K.d.g(this.a.su,l.canvas.width,h.width)-l.f.x;f=K.d.g(this.a.Wp,l.canvas.height,h.height)-l.f.y-K.sa;l.Vc+1<l.Rj.length?l.buttons.push(new ag(d,f,l.depth-20,new Xb(h),[h],{ea:a,va:l},l.f)):(h=kd,l.buttons.push(new ag(d,f,l.depth-20,new Xb(h),[h],{ea:c,va:l},l.f)));return!0};
e.Gy=function(){function a(a,b,c,f,h,k){var l;l=V.P();b&&A(l,b);b=Sa(l,a,h,k,h);l.fontSize>b&&D(l,b);c=K.d.Ca(c,d.f.b.width,l.aa(a,h),l.align);f=K.d.Ca(f,d.f.b.height,l.T(a,k),l.i);l.o(a,c,f,h);return f+k}function b(a,b,c){b=K.d.g(b,d.f.b.width,a.width);c=K.d.g(c,d.f.b.height,a.height);a.o(0,b,c);return c+a.height}var c,d=this,f=K.d.g(d.a.yc,d.canvas.width,d.a.backgroundImage.width),h=K.d.g(d.a.ec,d.canvas.height,d.a.backgroundImage.height)+-1*K.sa;K.Na.gb("about","options");for(c=0;c<d.buttons.length;c++)I(G,
d.buttons[c]);d.buttons=[];this.zd?(y(d.f.b),p.clear(),d.jg.Cb=!1):d.Sa(f,h);y(d.f.b);void 0!==d.a.Sd&&b(d.a.Sd,d.a.ym,d.a.Of);var k=null;"function"===typeof K.j.Ov?k=K.j.Ov(d.a,a,b,d.f.b):(c=K.m.N("optionsAbout_header","<OPTIONSABOUT_HEADER>"),a(c,d.a.zq,d.a.Cq,d.a.Sm,d.a.Bq,d.a.Aq),b(od,d.a.Tm,d.a.lk),c=K.m.N("optionsAbout_text","<OPTIONSABOUT_TEXT>"),a(c,d.a.Dq,d.a.Um,d.a.Ci,d.a.mk,d.a.Bi));a(K.m.N("optionsAbout_version","<OPTIONSABOUT_VERSION>")+" "+gg()+("big"===K.size?"b":"s"),d.a.Vm,d.a.Gq,
d.a.Wm,d.a.Fq,d.a.Eq);z(d.f.b);if(k)for(c=0;c<k.length;++c){var l=k[c];d.buttons.push(new ag(l.x,l.y,d.depth-10,Vb(0,0,l.width,l.height),null,{ea:function(a){return function(){K.j.Jd(a)}}(l.url),vc:!0},d.f))}else void 0!==K.q.Co&&(c=K.d.g(d.a.Tm,d.f.b.width,od.width),k=K.d.g(d.a.lk,d.f.b.height,od.height),c=Math.min(c,K.d.g(d.a.Um,d.f.b.width,d.a.mk)),k=Math.min(k,K.d.g(d.a.Ci,d.f.b.height,d.a.Bi)),l=Math.max(d.a.mk,od.width),d.buttons.push(new ag(c,k,d.depth-10,Vb(0,0,l,K.d.g(d.a.Ci,d.f.b.height,
d.a.Bi)+d.a.Bi-k),null,{ea:function(){K.j.Jd(K.q.Co)},vc:!0},d.f)));d.buttons.push(new vg("default_text",K.d.g(d.a.Rm,d.f.b.width,d.a.Ai),d.a.kk,d.depth-20,"optionsAbout_backBtn",d.a.Ai,{ea:function(){var a;d.Sa(f,h);d.jg.Cb=!0;for(a=0;a<d.buttons.length;a++)I(G,d.buttons[a]);d.buttons=[];d.$f(f,h,!0);d.Ct=!1},va:d},d.f));return this.Ct=!0};
function gh(a){var b,c,d,f,h,k=K.d.g(a.a.yc,a.canvas.width,a.a.backgroundImage.width),l=K.d.g(a.a.ec,a.canvas.height,a.a.backgroundImage.height)+-1*K.sa;K.Na.gb("versions","options");for(b=0;b<a.buttons.length;b++)I(G,a.buttons[b]);a.buttons=[];a.Sa(k,l);y(a.f.b);void 0!==a.a.Sd&&a.a.Sd.o(0,K.d.g(a.a.ym,a.f.width,a.a.Sd.width),K.d.g(a.a.Of,a.f.height,a.a.Sd.height));h=V.P();A(h,a.a.Vm);La(h,"left");c=a.a.Iu;d=a.a.Ju;for(b in K.version)f=b+": "+K.version[b],h.o(f,c,d),d+=h.T(f)+a.a.Hu;c=K.d.g(a.a.Rm,
a.f.b.width,a.a.Ai);d=a.a.kk;a.buttons.push(new vg("default_text",c,d,a.depth-20,"optionsAbout_backBtn",a.a.Ai,{ea:function(){var b;a.Sa(k,l);for(b=0;b<a.buttons.length;b++)I(G,a.buttons[b]);a.buttons=[];a.$f(k,l,!0)},va:a},a.f))}e.Iy=function(){return!0};e.Jy=function(){K.Na.gb("moreGames","options");var a=fh();"function"===typeof a&&a();return!0};
e.ty=function(){var a=this;hh(this,"optionsQuitConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){K.Na.gb("confirm_yes","options:quit");I(G,a);hg(K.Na,K.e.Tg,ih(K.e),"progression:levelQuit:"+jh());K.j.ps();kh();lh(K.e);return!0})};
e.yy=function(){var a=this;hh(this,"optionsRestartConfirmationText","optionsQuitConfirmBtn_Yes","optionsQuitConfirmBtn_No",function(){K.Na.gb("confirm_yes","options:restart");I(G,a);var b=K.e;b.state="LEVEL_END";hg(K.Na,K.e.Tg,ih(K.e),"progression:levelRestart:"+jh());b=K.n.Tj?b.Ab+1:Cg(b)+1;K.e.wa=!0;K.e.zs="retry";mh(K.e,!0);b={failed:!0,level:b};K.j.Dh(b);K.se.Dh(b);return!0})};
e.aj=function(){var a,b=this;a=function(a){var d=a?"challengeForfeitMessage_success":"challengeForfeitMessage_error";nh(b,K.m.N(d,"<"+d.toUpperCase()+">"));a&&(b.jg.Cb=!1,b.dm||Wg())};hh(this,"challengeForfeitConfirmText","challengeForfeitConfirmBtn_yes","challengeForfeitConfirmBtn_no",function(){K.e.aj(a);return!0})};
e.Ni=function(){var a,b=this;a=function(a){var d=a?"challengeCancelMessage_success":"challengeCancel_error";nh(b,K.m.N(d,"<"+d.toUpperCase()+">"));a&&(b.jg.Cb=!1,b.dm||Wg())};hh(this,"challengeCancelConfirmText","challengeCancelConfirmBtn_yes","challengeCancelConfirmBtn_no",function(){K.e.Ni(a);return!0})};
function hh(a,b,c,d,f){var h,k,l,n;for(h=0;h<a.buttons.length;h++)I(G,a.buttons[h]);a.buttons=[];b=K.m.N(b,"<"+b.toUpperCase()+">");h=V.P();a.a.mr?A(h,a.a.mr):a.a.Vl&&A(h,a.a.Vl);k=Sa(h,b,a.a.Bk,a.a.wn,!0);k<h.fontSize&&D(h,k);n=h.aa(b,a.a.Bk)+10;l=h.T(b,a.a.Bk)+10;k=K.d.Ca(a.a.nr,a.f.b.width,n,h.align);l=K.d.Ca(a.a.xn,a.f.b.height,l,h.i);y(a.f.b);h.o(b,k,l,n);z(a.f.b);k=K.d.g(a.a.kr,a.canvas.width,a.a.Ri)-a.f.x;l=K.d.g(a.a.un,a.canvas.height,a.Fc.default_text.r.height)-a.f.y-K.sa;a.buttons.push(new vg("default_text",
k,l,a.depth-20,d,a.a.Ri,{ea:function(){var b,c,d;c=K.d.g(a.a.yc,a.canvas.width,a.a.backgroundImage.width);d=K.d.g(a.a.ec,a.canvas.height,a.a.backgroundImage.height)+-1*K.sa;a.Sa(c,d);for(b=0;b<a.buttons.length;b++)I(G,a.buttons[b]);a.buttons=[];a.$f(c,d,!0);return!0},va:a},a.f));k=K.d.g(a.a.lr,a.canvas.width,a.a.Ri)-a.f.x;l=K.d.g(a.a.vn,a.canvas.height,a.Fc.default_text.r.height)-a.f.y-K.sa;a.buttons.push(new vg("default_text",k,l,a.depth-20,c,a.a.Ri,{ea:function(){return"function"===typeof f?f():
!0},va:a},a.f))}function nh(a,b){var c,d,f,h;for(c=0;c<a.buttons.length;c++)I(G,a.buttons[c]);a.buttons=[];d=K.d.g(a.a.yc,a.canvas.width,a.a.backgroundImage.width);f=K.d.g(a.a.ec,a.canvas.height,a.a.backgroundImage.height)+-1*K.sa;a.Sa(d,f);c=V.P();a.a.ap&&A(c,a.a.ap);d=Sa(c,b,a.a.bp,a.a.Ax,!0);d<c.fontSize&&D(c,d);h=c.aa(b,a.a.bp)+10;f=c.T(b,a.a.bp)+10;d=K.d.Ca(a.a.Bx,a.f.b.width,h,c.align);f=K.d.Ca(a.a.Cx,a.f.b.height,f,c.i);y(a.f.b);c.o(b,d,f,h);z(a.f.b)}
e.Ly=function(){K.Na.gb("startScreen","options");lh(K.e);return!0};e.close=function(){I(G,this);return this.canvas.Y=!0};
e.ac=function(){var a,b;this.dm&&Wg(this);K.e.Zf=this;this.Kr=this.Jr=!1;a=this.a.backgroundImage;this.f=new Xg(this.depth-10,this.Ua,new x(a.width,a.height));this.f.x=K.d.g(this.a.yc,this.canvas.width,a.width);a=K.d.g(this.a.ec,this.canvas.height,a.height)+-1*K.sa;this.f.y=a;this.Sa(this.f.x,this.f.y);this.buttons=[];this.Mz?this.Hj():this.$f(this.f.x,this.f.y);this.jg=new ag(this.a.Pi,this.a.oh,this.depth-20,new Vb(0,0,this.a.nh,this.a.kg),void 0,{ea:this.close,va:this},this.f);this.ei="versions";
this.bg=new ec;K.d.Ka(this.bg,K.Hc);Ob(this.bg,this.depth-1);fc(this.bg,"keyAreaLeft",this.f.x,this.f.y+this.a.Of,this.a.gh,this.a.nk,76);fc(this.bg,"keyAreaRight",this.f.x+this.f.width-this.a.gh,this.f.y+this.a.Of,this.a.gh,this.a.nk,82);fc(this.bg,"keyAreaCentre",K.fx/2-this.a.gh/2,this.f.y+this.a.Of,this.a.gh,this.a.nk,67);b=this;this.f.y="inGame"!==this.type?this.canvas.height:-this.f.b.height;ah(this.f,"y",a,this.a.xj,this.a.yj,function(){var a;for(a=0;a<b.buttons.length;a++)b.buttons[a].Cb=
!0})};e.nb=function(){var a;this.dm&&bh();this.Jr&&na(K.vf,K.m.oo());this.Kr&&na(K.Df);for(a=0;a<this.buttons.length;a++)I(G,this.buttons[a]);this.bg.clear();I(G,this.bg);I(G,this.jg);I(G,this.f);K.e.Zf=null};e.Vb=function(){return!0};e.Ub=function(){return!0};e.wg=function(a){this.Ct&&(67===a?this.ei="":76===a?this.ei+="l":82===a&&(this.ei+="r"),"lrl"===this.ei&&gh(this))};e.Oc=function(a){a===K.vf?(this.Sa(this.f.x,this.f.y),this.Jr=!0):a===K.Df?this.Kr=!0:a===K.lv&&this.close()};
function oh(){this.depth=-200;this.h=this.visible=!0;K.d.Ka(this,K.qg);var a;this.a=K.a.w.Vk;if("landscape"===K.orientation&&K.a.w.bo)for(a in K.a.w.bo)this.a[a]=K.a.w.bo[a];this.Fc=K.a.w.rc;for(a in K.a.R.Vk)this.a[a]=K.a.R.Vk[a];H(this)}
oh.prototype.Sa=function(){var a,b,c,d;c=this.a.backgroundImage;d=(K.cx-Math.abs(K.sa))/c.ph;this.f.b=new x(d*c.Qi,d*c.ph);y(this.f.b);this.f.y=Math.abs(K.sa);a=p.context;1E-4>Math.abs(d)||1E-4>Math.abs(d)||(a.save(),a.translate(0,0),a.rotate(-0*Math.PI/180),a.scale(d,d),a.globalAlpha=1,wa(c,0,0),a.restore());c=V.P();A(c,this.a.font);d=K.m.N("gameEndScreenTitle","<GAMEENDSCREENTITLE>");a=Sa(c,d,this.a.om-(c.stroke?c.Uc:0),this.a.yz-(c.stroke?c.Uc:0),!0);a<c.fontSize&&D(c,a);a=K.d.Ca(this.a.gu,this.canvas.width,
c.aa(d),c.align);b=K.d.Ca(this.a.hu,this.canvas.height,c.T(d),c.i);c.o(d,a,b,this.a.om);z(this.f.b);this.f.canvas.Y=!0};oh.prototype.ac=function(){var a=this,b=this.a.backgroundImage,b=new x(b.width,b.height);this.f=new Xg(this.depth,K.Hc,b);this.f.x=0;this.f.y=Math.abs(K.sa);this.Sa();this.button=new vg(this.a.ar,K.d.g(this.a.xv,this.canvas.width,this.a.br),K.d.g(this.a.cr,this.canvas.height,this.Fc[this.a.ar].r.height),this.depth-10,"gameEndScreenBtnText",this.a.br,function(){I(G,a);lh(K.e)},this.f)};
oh.prototype.nb=function(){I(G,this.f);I(G,this.button)};oh.prototype.Oc=function(a){a!==K.vf&&a!==K.Df||this.Sa()};
function ag(a,b,c,d,f,h,k){function l(a,b,c){var d,f;f=K.d.no(q.canvas);a=Math.round(q.x+q.parent.x-q.Kd*q.fb);d=Math.round(q.y+q.parent.y-q.Ld*q.ib);if(q.images&&0<q.xg||0<q.Lj)q.xg=0,q.Lj=0,q.canvas.Y=!0;if(q.Dj&&q.Cb&&cc(q.ob,a,d,b-f.x,c-f.y))return q.Dj=!1,void 0!==q.va?q.Gl.call(q.va,q):q.Gl(q)}function n(a,b,c){var d,f,h;h=K.d.no(q.canvas);d=Math.round(q.x+q.parent.x-q.Kd*q.fb);f=Math.round(q.y+q.parent.y-q.Ld*q.ib);if(q.Cb&&cc(q.ob,d,f,b-h.x,c-h.y))return q.Dj=!0,q.images&&(1<q.images.length?
(q.xg=1,q.canvas.Y=!0):1<q.images[0].D&&(q.Lj=1,q.canvas.Y=!0)),void 0!==typeof Cf&&E.play(Cf),q.og=a,!0}this.depth=c;this.h=this.visible=!0;this.group="TG_Token";K.d.Ka(this,K.Hc);this.Ld=this.Kd=0;this.x=a;this.y=b;this.width=f?f[0].width:d.Oa-d.ba;this.height=f?f[0].height:d.tb-d.ua;this.alpha=this.ib=this.fb=1;this.pa=0;this.ob=d;this.images=f;this.Lj=this.xg=0;this.Dj=!1;this.Cb=!0;this.parent=void 0!==k?k:{x:0,y:0};this.$l=this.Zl=0;this.kd=!0;this.Gl=function(){};this.vc=!1;"object"===typeof h?
(this.Gl=h.ea,this.va=h.va,this.vc=h.vc):"function"===typeof h&&(this.Gl=h);var q=this;this.vc?(this.Bh=n,this.Ch=l):(this.Ub=n,this.Vb=l);H(this)}function ug(a,b,c,d,f,h){void 0===a.qa&&(a.qa=[]);a.qa.push({type:b,start:d,dd:f,lb:c,duration:h,l:0})}
function zg(a){var b,c;if(void 0!==a.qa){for(b=0;b<a.qa.length;b++)if(c=a.qa[b],c.h){switch(c.type){case "xScale":a.fb=c.start+c.dd;break;case "yScale":a.ib=c.start+c.dd;break;case "alpha":a.alpha=c.start+c.dd;break;case "angle":a.pa=c.start+c.dd;break;case "x":a.x=c.start+c.dd;break;case "y":a.y=c.start+c.dd}c.h=!1}a.canvas.Y=!0}}function Gg(a,b){a.images=b;a.canvas.Y=!0}e=ag.prototype;e.xt=function(a){this.visible=this.h=a};e.nb=function(){this.images&&(this.canvas.Y=!0)};
e.Z=function(a){var b,c;if(void 0!==this.qa){for(b=0;b<this.qa.length;b++)switch(c=this.qa[b],c.l+=a,c.type){case "xScale":var d=this.fb,f=this.Zl;this.fb=c.lb(c.l,c.start,c.dd,c.duration);this.Zl=-(this.images[0].width*this.fb-this.images[0].width*c.start)/2;if(isNaN(this.fb)||isNaN(this.Zl))this.fb=d,this.Zl=f;break;case "yScale":d=this.ib;f=this.$l;this.ib=c.lb(c.l,c.start,c.dd,c.duration);this.$l=-(this.images[0].height*this.ib-this.images[0].height*c.start)/2;if(isNaN(this.ib)||isNaN(this.$l))this.ib=
d,this.$l=f;break;case "alpha":this.alpha=c.lb(c.l,c.start,c.dd,c.duration);break;case "angle":this.pa=c.lb(c.l,c.start,c.dd,c.duration);break;case "x":d=this.x;this.x=c.lb(c.l,c.start,c.dd,c.duration);isNaN(this.x)&&(this.x=d);break;case "y":d=this.y,this.y=c.lb(c.l,c.start,c.dd,c.duration),isNaN(this.y)&&(this.y=d)}this.canvas.Y=!0}};
e.Pe=function(){var a,b,c;c=K.d.no(this.canvas);a=Math.round(this.x+this.parent.x-this.Kd*this.fb);b=Math.round(this.y+this.parent.y-this.Ld*this.ib);this.Dj&&!cc(this.ob,a,b,G.ia[this.og].x-c.x,G.ia[this.og].y-c.y)&&(this.images&&(this.Lj=this.xg=0,this.canvas.Y=!0),this.Dj=!1)};
e.za=function(){var a,b;a=Math.round(this.x+this.parent.x-this.Kd*this.fb);b=Math.round(this.y+this.parent.y-this.Ld*this.ib);this.images&&(this.images[this.xg]instanceof x?this.images[this.xg].S(a,b,this.fb,this.ib,this.pa,this.alpha):this.images[this.xg].S(this.Lj,a,b,this.fb,this.ib,this.pa,this.alpha));this.kd=!1};
function vg(a,b,c,d,f,h,k,l){this.fa=K.a.w.rc[a];a=void 0!==K.a.R.buttons?K.a.w.Ki[K.a.R.buttons[a]||K.a.R.buttons.default_color]:K.a.w.Ki[K.a.w.buttons.default_color];this.font=V.P();a.font&&A(this.font,a.font);this.fa.fontSize&&D(this.font,this.fa.fontSize);this.U=f;this.text=K.m.N(this.U,"<"+f.toUpperCase()+">");void 0!==h&&(this.width=h);this.height=this.fa.r.height;this.b={source:this.fa.r,Ea:this.fa.Ea,Gb:this.fa.Gb};f=this.Ie(this.b);h=new Vb(0,0,f[0].width,f[0].height);ag.call(this,b,c,d,
h,f,k,l)}K.d.mj(vg);e=vg.prototype;e.Xl=function(a){this.text=K.m.N(this.U,"<"+this.U.toUpperCase()+">");a&&A(this.font,a);Gg(this,this.Ie(this.b))};e.bq=function(a,b){this.U=a;this.Xl(b)};e.Sj=function(a,b,c){"string"===typeof b&&(this.text=b);c&&A(this.font,c);a instanceof r?this.b.source=a:void 0!==a.Ea&&void 0!==a.Gb&&void 0!==a.source&&(this.b=a);Gg(this,this.Ie(this.b))};
e.Ie=function(a){var b,c,d,f,h,k,l=a.Ea+a.Gb;d=this.height-(this.fa.sd||0);var n=a.source;c=this.font.aa(this.text);void 0===this.width?b=c:"number"===typeof this.width?b=this.width-l:"object"===typeof this.width&&(void 0!==this.width.width?b=this.width.width-l:(void 0!==this.width.minWidth&&(b=Math.max(this.width.minWidth-l,c)),void 0!==this.width.maxWidth&&(b=Math.min(this.width.maxWidth-l,c))));c=Sa(this.font,this.text,b,d,!0);c<this.fa.fontSize?D(this.font,c):D(this.font,this.fa.fontSize);c=a.Ea;
d=this.font.align;"center"===d?c+=Math.round(b/2):"right"===d&&(c+=b);d=Math.round(this.height/2);void 0!==this.fa.rd&&(d+=this.fa.rd);h=[];for(f=0;f<n.D;f++)k=new x(b+l,this.height),y(k),n.Da(f,0,0,a.Ea,this.height,0,0,1),n.Jk(f,a.Ea,0,n.width-l,this.height,a.Ea,0,b,this.height,1),n.Da(f,a.Ea+n.width-l,0,a.Gb,this.height,a.Ea+b,0,1),this.font.o(this.text,c,d,b),z(k),h.push(k);return h};e.Oc=function(a){a===K.vf&&this.Xl()};
function dh(a,b,c,d,f,h,k,l){this.fa=K.a.w.rc[a];void 0!==h&&(this.width=h);this.height=this.fa.r.height;this.Wd={source:this.fa.r,Ea:this.fa.Ea,Gb:this.fa.Gb};this.b=f;a=this.Ie();f=new Vb(0,0,a[0].width,a[0].height);ag.call(this,b,c,d,f,a,k,l)}K.d.mj(dh);
dh.prototype.Ie=function(){var a,b,c,d,f,h,k,l=this.Wd.Ea+this.Wd.Gb;b=this.height-(this.fa.sd||0);var n=this.Wd.source;void 0===this.width?a=this.b.width:"number"===typeof this.width?a=this.width-l:"object"===typeof this.width&&(void 0!==this.width.width?a=this.width.width-l:(void 0!==this.width.minWidth&&(a=Math.max(this.width.minWidth-l,this.b.width)),void 0!==this.width.maxWidth&&(a=Math.min(this.width.maxWidth-l,this.b.width))));k=Math.min(a/this.b.width,b/this.b.height);k=Math.min(k,1);f=Math.round(this.Wd.Ea+
(a-this.b.width*k)/2);h=Math.round((b-this.b.height*k)/2);c=[];for(b=0;b<n.D;b++){d=new x(a+l,this.height);y(d);n.Da(b,0,0,this.Wd.Ea,this.height,0,0,1);n.Jk(b,this.Wd.Ea,0,n.width-l,this.height,this.Wd.Ea,0,a,this.height,1);n.Da(b,this.Wd.Ea+n.width-l,0,this.Wd.Gb,this.height,this.Wd.Ea+a,0,1);try{p.context.drawImage(this.b,f,h,this.b.width*k,this.b.height*k)}catch(q){}z(d);c.push(d)}return c};K.d.mj(function(a,b,c,d,f,h,k){ag.call(this,a,b,c,f,d,h,k)});
function rg(a,b,c,d,f,h,k,l){var n;this.fa=K.a.w.rc[a];a=void 0!==K.a.R.buttons?K.a.w.Ki[K.a.R.buttons[a]||K.a.R.buttons.default_color]:K.a.w.Ki[K.a.w.buttons.default_color];this.font=V.P();a.font&&A(this.font,a.font);this.fa.fontSize&&D(this.font,this.fa.fontSize);void 0!==h&&(this.width=h);this.height=this.fa.r.height;this.$=this.fa.$;if(this.$.length){for(h=0;h<this.$.length;h++)if(this.$[h].id===f){this.Ra=h;break}void 0===this.Ra&&(this.Ra=0);this.text=K.m.N(this.$[this.Ra].U,"<"+this.$[this.Ra].id.toUpperCase()+
">");this.Wg=this.$[this.Ra].r;h=this.Ie();a=new Vb(0,0,h[0].width,h[0].height);n=this;"function"===typeof k?f=function(){n.Ig();return k(n.$[n.Ra].id)}:"object"===typeof k?(f={},f.vc=k.vc,f.va=this,f.ea=function(){n.Ig();return k.ea.call(k.va,n.$[n.Ra].id)}):f=function(){n.Ig()};ag.call(this,b,c,d,a,h,f,l)}}K.d.mj(rg);e=rg.prototype;
e.Ig=function(a){var b;if(void 0===a)this.Ra=(this.Ra+1)%this.$.length;else for(b=0;b<this.$.length;b++)if(this.$[b].id===a){this.Ra=b;break}this.Sj(this.$[this.Ra].r,K.m.N(this.$[this.Ra].U,"<"+this.$[this.Ra].id.toUpperCase()+">"))};e.Xl=function(a){a&&A(this.font,a);this.text=K.m.N(this.$[this.Ra].U,"<"+this.$[this.Ra].id.toUpperCase()+">");Gg(this,this.Ie())};e.Sj=function(a,b,c){this.text=b;this.Wg=a;c&&A(this.font,c);Gg(this,this.Ie())};
e.Ie=function(){var a,b,c,d,f,h,k=this.fa.Ea,l=this.fa.Gb,n=k+l;f=Math.abs(k-l);d=this.height-(this.fa.sd||0);var q=this.fa.r,u=this.font.P();b=u.aa(this.text);void 0===this.width?a=b:"number"===typeof this.width?a=this.width-n:"object"===typeof this.width&&(void 0!==this.width.width?a=this.width.width-n:(void 0!==this.width.minWidth&&(a=Math.max(this.width.minWidth-n,b)),void 0!==this.width.maxWidth&&(a=Math.min(this.width.maxWidth-n,b))));d=Sa(u,this.text,a,d,!0);d<u.fontSize&&D(u,d);b=u.aa(this.text,
a);d=k;c=u.align;"center"===c?d=a-f>=b?d+Math.round((a-f)/2):d+(this.fa.Pg+Math.round(b/2)):"left"===c?d+=this.fa.Pg:"right"===c&&(d+=a);f=Math.round(this.height/2);void 0!==this.fa.rd&&(f+=this.fa.rd);c=[];for(b=0;b<q.D;b++)h=new x(a+n,this.height),y(h),q.Da(b,0,0,k,this.height,0,0,1),q.Jk(b,k,0,q.width-n,this.height,k,0,a,this.height,1),q.Da(b,k+q.width-n,0,l,this.height,k+a,0,1),this.Wg.o(0,this.fa.ai,this.fa.bi),u.o(this.text,d,f,a),z(h),c.push(h);return c};e.Oc=function(a){a===K.vf&&this.Xl()};
function eh(a,b,c,d,f,h,k){var l;this.$=K.a.w.rc[a].$;if(this.$.length){for(a=0;a<this.$.length;a++)if(this.$[a].id===f){this.Ra=a;break}void 0===this.Ra&&(this.Ra=0);this.Wg=this.$[this.Ra].r;a=new Xb(this.Wg);l=this;f="function"===typeof h?function(){l.Ig();return h(l.$[l.Ra].id)}:"object"===typeof h?{va:this,ea:function(){l.Ig();return h.ea.call(h.va,l.$[l.Ra].id)}}:function(){l.Ig()};ag.call(this,b,c,d,a,[this.Wg],f,k)}}K.d.mj(eh);
eh.prototype.Ig=function(a){var b;if(void 0===a)this.Ra=(this.Ra+1)%this.$.length;else for(b=0;b<this.$.length;b++)if(this.$[b].id===a){this.Ra=b;break}this.Sj(this.$[this.Ra].r)};eh.prototype.Sj=function(a){this.Wg=a;Gg(this,[].concat(this.Wg))};
function ph(a,b,c,d){this.depth=10;this.visible=!1;this.h=!0;K.d.Ka(this,K.Hc);var f;this.a=K.a.w.rl;if("landscape"===K.orientation&&K.a.w.Ko)for(f in K.a.w.Ko)this.a[f]=K.a.w.Ko[f];for(f in K.a.R.rl)this.a[f]=K.a.R.rl[f];this.Bo=a;this.en=b;this.ea=c;this.va=d;this.Aj="entering";this.ru=!1;H(this,!1);Pb(this,"LevelStartDialog")}
function qh(a){var b,c,d,f,h;if("leaving"!==a.Aj){a.Aj="leaving";a.eg=0;b=function(){I(G,a);a.va?a.ea.call(a.va):a.ea&&a.ea()};if(void 0!==a.a.lp)for(c=0;c<a.a.lp.length;c++)d=a.a.lp[c],f=void 0,d.Wq&&(a.eg++,f=b),h=d.end,"x"===d.type?h=K.d.g(h,a.canvas.width,a.f.b.width):"y"===d.type&&(h=K.d.g(h,a.canvas.height,a.f.b.height)+Math.abs(K.sa)),ah(a.f,d.type,h,d.duration,d.lb,f,d.Pa,d.loop,d.Uo);0===a.eg&&b()}}e=ph.prototype;
e.ac=function(){var a,b,c,d,f,h,k=this;a=this.a.nd;b=a.width;f=a.height;this.f=new Xg(this.depth+10,this.Ua,new x(b,f));y(this.f.b);a.o(0,0,0);""!==this.en&&(c=K.d.g(this.a.Lq,b,0),d=K.d.g(this.a.Mq,f,0),a=V.P(),A(a,this.a.Kq),void 0!==this.a.Gi&&void 0!==this.a.dn&&(h=Sa(a,this.en,this.a.Gi,this.a.dn,this.a.Gi),a.fontSize>h&&D(a,h)),a.o(this.en,c,d,this.a.Gi));""!==this.Bo&&(c=K.d.g(this.a.cs,b,0),d=K.d.g(this.a.ds,f,0),a=V.P(),A(a,this.a.as),void 0!==this.a.il&&void 0!==this.a.bs&&(h=Sa(a,this.Bo,
this.a.il,this.a.bs,this.a.il),a.fontSize>h&&D(a,h)),a.o(this.Bo,c,d,this.a.il));z(this.f.b);this.f.x=K.d.g(this.a.it,this.canvas.width,b);this.f.y=K.d.g(this.a.mp,this.canvas.height,f)+Math.abs(K.sa);this.eg=0;a=function(){k.eg--;0===k.eg&&(k.Aj="paused")};if(void 0!==this.a.Jl)for(b=0;b<this.a.Jl.length;b++)f=this.a.Jl[b],c=void 0,f.Wq&&(this.eg++,c=a),d=f.end,"x"===f.type?d=K.d.g(d,this.canvas.width,this.f.b.width):"y"===f.type&&(d=K.d.g(d,this.canvas.height,this.f.b.height)+Math.abs(K.sa)),ah(this.f,
f.type,d,f.duration,f.lb,c,f.Pa,f.loop,f.Uo),void 0!==f.Xb&&E.play(f.Xb);0===this.eg&&(this.Aj="paused");this.l=0};e.nb=function(){I(G,this.f)};e.Z=function(a){"paused"!==this.state&&(this.l+=a,this.l>=this.a.jt&&qh(this))};e.Ub=function(){return this.ru=!0};e.Vb=function(){this.ru&&"paused"===this.Aj&&qh(this);return!0};
function Xg(a,b,c){this.depth=a;this.h=this.visible=!0;K.d.Ka(this,b);this.b=c;this.hc=0;this.width=c.width;this.height=c.height;this.Ld=this.Kd=this.y=this.x=0;this.ib=this.fb=1;this.pa=0;this.alpha=1;this.Ib=[];this.Jq=0;this.parent={x:0,y:0};this.kd=!0;H(this,!1)}
function ah(a,b,c,d,f,h,k,l,n){var q,u=0<k;switch(b){case "x":q=a.x;break;case "y":q=a.y;break;case "xScale":q=a.fb;break;case "yScale":q=a.ib;break;case "scale":b="xScale";q=a.fb;ah(a,"yScale",c,d,f,void 0,k,l,n);break;case "angle":q=a.pa;break;case "alpha":q=a.alpha;break;case "subImage":q=0}a.Ib.push({id:a.Jq,l:0,h:!0,Ek:u,type:b,start:q,end:c,zb:h,duration:d,lb:f,Pa:k,loop:l,Uo:n});a.Jq++}
function Lg(a){var b;for(b=a.Ib.length-1;0<=b;b--){switch(a.Ib[b].type){case "x":a.x=a.Ib[b].end;break;case "y":a.y=a.Ib[b].end;break;case "xScale":a.fb=a.Ib[b].end;break;case "yScale":a.ib=a.Ib[b].end;break;case "angle":a.pa=a.Ib[b].end;break;case "alpha":a.alpha=a.Ib[b].end;break;case "subImage":a.hc=a.Ib[b].end}"function"===typeof a.Ib[b].zb&&a.Ib[b].zb.call(a)}}
Xg.prototype.Z=function(a){var b,c,d;for(b=0;b<this.Ib.length;b++)if(c=this.Ib[b],c.h&&(c.l+=a,c.Ek&&c.l>=c.Pa&&(c.l%=c.Pa,c.Ek=!1),!c.Ek)){c.l>=c.duration?(d=c.end,c.loop?(c.Ek=!0,c.Pa=c.Uo,c.l%=c.duration):("function"===typeof c.zb&&c.zb.call(this),this.Ib[b]=void 0)):"subImage"===c.type?(d=this.b instanceof Array?this.b.length:this.b.D,d=Math.floor(c.l*d/c.duration)):d=c.lb(c.l,c.start,c.end-c.start,c.duration);switch(c.type){case "x":this.x=d;break;case "y":this.y=d;break;case "xScale":this.fb=
d;break;case "yScale":this.ib=d;break;case "angle":this.pa=d;break;case "alpha":this.alpha=d;break;case "subImage":this.hc=d}this.canvas.Y=!0}for(b=this.Ib.length-1;0<=b;b--)void 0===this.Ib[b]&&this.Ib.splice(b,1)};
Xg.prototype.za=function(){var a,b,c;b=Math.round(this.x-this.fb*this.Kd)+this.parent.x;c=Math.round(this.y-this.ib*this.Ld)+this.parent.y;a=this.b;a instanceof Array&&(a=this.b[this.hc%this.b.length]);a instanceof x?a.S(b,c,this.fb,this.ib,this.pa,this.alpha):a.S(this.hc,b,c,this.fb,this.ib,this.pa,this.alpha);this.kd=!1};
function Qg(a,b,c,d,f,h,k,l,n,q,u){this.depth=f;this.visible=!0;this.h=!1;K.d.Ka(this,K.Hc);this.x=a;this.y=b;this.Wo=l;this.Xo="object"===typeof n?n.top:n;this.gx="object"===typeof n?n.bottom:n;this.aa=c;this.T=d;this.width=this.aa+2*this.Wo;this.height=this.T+this.Xo+this.gx;this.value=h||0;this.parent=q||{x:0,y:0};this.font=k;this.toString="function"===typeof u?u:function(a){return a+""};this.alpha=1;this.gc=this.fc=this.Ld=this.Kd=0;c=new x(this.width,this.height);this.hh=new Xg(this.depth,this.Ua,
c);this.hh.x=a-this.Wo;this.hh.y=b-this.Xo;this.hh.parent=q;this.K=this.hh.b;this.Bf();H(this)}Qg.prototype.nb=function(){I(G,this.hh)};function $g(a,b,c){a.h=!0;a.cg=a.value;a.value=a.cg;a.end=b;a.duration=c;a.lb=J;a.l=0}
Qg.prototype.Bf=function(){var a,b;a=this.font.align;b=this.font.i;var c=this.Wo,d=this.Xo;this.Qq||(this.K.clear(),this.canvas.Y=!0);y(this.K);this.Qq&&this.Qq.Da(0,this.iA,this.jA,this.hA,this.gA,0,0,1);"center"===a?c+=Math.round(this.aa/2):"right"===a&&(c+=this.aa);"middle"===b?d+=Math.round(this.T/2):"bottom"===b&&(d+=this.T);b=this.toString(this.value);a=Sa(this.font,b,this.aa,this.T,!0);a<this.font.fontSize&&D(this.font,a);this.font.o(b,c,d,this.aa);z(this.K);this.hh.kd=!0};
Qg.prototype.Z=function(a){var b;b=Math.round(this.lb(this.l,this.cg,this.end-this.cg,this.duration));this.l>=this.duration?(this.value=this.end,this.h=!1,this.Bf()):b!==this.value&&(this.value=b,this.Bf());this.l+=a};function rh(a,b,c){this.depth=-100;this.visible=!1;this.h=!0;this.my=a;K.d.Ka(this,K.Hc);this.a=K.a.w.An;this.Fc=K.a.w.rc;this.dr=b;for(var d in K.a.R.An)this.a[d]=K.a.R.An[d];this.np=!1!==c;H(this)}e=rh.prototype;e.ou=function(){};
e.Ei=function(a,b,c,d,f){b=new vg("default_text",b,c,this.depth-20,a.U||"NO_TEXT_KEY_GIVEN",d,{ea:function(){a.ea&&(a.va?a.ea.call(a.va,a):a.ea(a))},va:this},this.f);this.buttons.push(b);a.text&&b.Sj(b.b,a.text);this.buttons[this.buttons.length-1].Cb=f||!1};
e.Sa=function(a,b,c){y(this.f.b);p.clear();this.a.backgroundImage.o(0,0,0);a=c?c:this.my;b=V.P();this.a.ot&&A(b,this.a.ot);c=Sa(b,a,this.a.tp,this.a.sp,!0);c<b.fontSize&&D(b,c);c=b.aa(a,this.a.tp)+10;var d=b.T(a,this.a.sp)+10;b.o(a,K.d.Ca(this.a.ry,this.f.b.width,c,b.align),K.d.Ca(this.a.sy,this.f.b.height-sh(this),d,b.i),c);z(this.f.b)};function sh(a){var b=a.dr;return K.d.g(a.a.Li,a.f.b.height,a.Fc.default_text.r.height*b.length+a.a.Xd*(b.length-1))}
e.$f=function(a,b){var c,d,f,h,k,l,n,q,u,B=[],B=this.dr;f=this.Fc.default_text.r.height;h=this.a.yk;k=K.d.g(this.a.xk,this.canvas.width,h)-a;q=sh(this);for(c=B.length-1;0<=c;c--){n=k;u=h;if("object"===typeof B[c]&&B[c].hasOwnProperty("length")&&B[c].length)for(l=B[c],u=(h-(l.length-1)*this.a.Xd)/l.length,d=0;d<l.length;d++)this.Ei(l[d],n,q,u,b),n+=u+this.a.Xd;else this.Ei(B[c],n,q,u,b);q-=f+this.a.Xd}};
e.show=function(){var a,b;for(a=0;a<this.buttons.length;a++)b=this.buttons[a],b.xt(!0);this.f.visible=!0};e.close=function(){I(G,this);return this.canvas.Y=!0};function th(a){var b=K.e.jf;b.Sa(b.f.x,b.f.y,a);for(a=0;a<b.buttons.length;a++)I(G,b.buttons[a]);b.canvas.Y=!0}
e.ac=function(){var a,b;this.np&&Wg(this);a=this.a.backgroundImage;this.f=new Xg(this.depth-10,this.Ua,new x(a.width,a.height));this.f.x=K.d.g(this.a.yc,this.canvas.width,a.width);a=K.d.g(this.a.ec,this.canvas.height,a.height)+-1*("landscape"===K.orientation?K.a.w.sn:K.a.w.Yd).xl;this.f.y=a;this.Sa(this.f.x,this.f.y);this.buttons=[];this.$f(this.f.x);b=this;this.f.y=-this.f.b.height;ah(this.f,"y",a,this.a.xj,this.a.yj,function(){var a;for(a=0;a<b.buttons.length;a++)b.buttons[a].Cb=!0})};
e.nb=function(){var a;this.np&&bh();for(a=0;a<this.buttons.length;a++)I(G,this.buttons[a]);I(G,this.f);K.e.Zf===this&&(K.e.Zf=null)};e.Vb=function(){return!0};e.Ub=function(){return!0};
function uh(a){if(null===a||"undefined"===typeof a)return"";a+="";var b="",c,d,f=0;c=d=0;for(var f=a.length,h=0;h<f;h++){var k=a.charCodeAt(h),l=null;if(128>k)d++;else if(127<k&&2048>k)l=String.fromCharCode(k>>6|192,k&63|128);else if(55296!==(k&63488))l=String.fromCharCode(k>>12|224,k>>6&63|128,k&63|128);else{if(55296!==(k&64512))throw new RangeError("Unmatched trail surrogate at "+h);l=a.charCodeAt(++h);if(56320!==(l&64512))throw new RangeError("Unmatched lead surrogate at "+(h-1));k=((k&1023)<<
10)+(l&1023)+65536;l=String.fromCharCode(k>>18|240,k>>12&63|128,k>>6&63|128,k&63|128)}null!==l&&(d>c&&(b+=a.slice(c,d)),b+=l,c=d=h+1)}d>c&&(b+=a.slice(c,f));return b}
function og(a){function b(a){var b="",c="",d;for(d=0;3>=d;d++)c=a>>>8*d&255,c="0"+c.toString(16),b+=c.substr(c.length-2,2);return b}function c(a,b,c,d,f,h,l){a=k(a,k(k(c^(b|~d),f),l));return k(a<<h|a>>>32-h,b)}function d(a,b,c,d,f,h,l){a=k(a,k(k(b^c^d,f),l));return k(a<<h|a>>>32-h,b)}function f(a,b,c,d,f,h,l){a=k(a,k(k(b&d|c&~d,f),l));return k(a<<h|a>>>32-h,b)}function h(a,b,c,d,f,h,l){a=k(a,k(k(b&c|~b&d,f),l));return k(a<<h|a>>>32-h,b)}function k(a,b){var c,d,f,h,k;f=a&2147483648;h=b&2147483648;
c=a&1073741824;d=b&1073741824;k=(a&1073741823)+(b&1073741823);return c&d?k^2147483648^f^h:c|d?k&1073741824?k^3221225472^f^h:k^1073741824^f^h:k^f^h}var l=[],n,q,u,B,C,t,s,v,w;a=uh(a);l=function(a){var b,c=a.length;b=c+8;for(var d=16*((b-b%64)/64+1),f=Array(d-1),h=0,k=0;k<c;)b=(k-k%4)/4,h=k%4*8,f[b]|=a.charCodeAt(k)<<h,k++;b=(k-k%4)/4;f[b]|=128<<k%4*8;f[d-2]=c<<3;f[d-1]=c>>>29;return f}(a);t=1732584193;s=4023233417;v=2562383102;w=271733878;a=l.length;for(n=0;n<a;n+=16)q=t,u=s,B=v,C=w,t=h(t,s,v,w,l[n+
0],7,3614090360),w=h(w,t,s,v,l[n+1],12,3905402710),v=h(v,w,t,s,l[n+2],17,606105819),s=h(s,v,w,t,l[n+3],22,3250441966),t=h(t,s,v,w,l[n+4],7,4118548399),w=h(w,t,s,v,l[n+5],12,1200080426),v=h(v,w,t,s,l[n+6],17,2821735955),s=h(s,v,w,t,l[n+7],22,4249261313),t=h(t,s,v,w,l[n+8],7,1770035416),w=h(w,t,s,v,l[n+9],12,2336552879),v=h(v,w,t,s,l[n+10],17,4294925233),s=h(s,v,w,t,l[n+11],22,2304563134),t=h(t,s,v,w,l[n+12],7,1804603682),w=h(w,t,s,v,l[n+13],12,4254626195),v=h(v,w,t,s,l[n+14],17,2792965006),s=h(s,v,
w,t,l[n+15],22,1236535329),t=f(t,s,v,w,l[n+1],5,4129170786),w=f(w,t,s,v,l[n+6],9,3225465664),v=f(v,w,t,s,l[n+11],14,643717713),s=f(s,v,w,t,l[n+0],20,3921069994),t=f(t,s,v,w,l[n+5],5,3593408605),w=f(w,t,s,v,l[n+10],9,38016083),v=f(v,w,t,s,l[n+15],14,3634488961),s=f(s,v,w,t,l[n+4],20,3889429448),t=f(t,s,v,w,l[n+9],5,568446438),w=f(w,t,s,v,l[n+14],9,3275163606),v=f(v,w,t,s,l[n+3],14,4107603335),s=f(s,v,w,t,l[n+8],20,1163531501),t=f(t,s,v,w,l[n+13],5,2850285829),w=f(w,t,s,v,l[n+2],9,4243563512),v=f(v,
w,t,s,l[n+7],14,1735328473),s=f(s,v,w,t,l[n+12],20,2368359562),t=d(t,s,v,w,l[n+5],4,4294588738),w=d(w,t,s,v,l[n+8],11,2272392833),v=d(v,w,t,s,l[n+11],16,1839030562),s=d(s,v,w,t,l[n+14],23,4259657740),t=d(t,s,v,w,l[n+1],4,2763975236),w=d(w,t,s,v,l[n+4],11,1272893353),v=d(v,w,t,s,l[n+7],16,4139469664),s=d(s,v,w,t,l[n+10],23,3200236656),t=d(t,s,v,w,l[n+13],4,681279174),w=d(w,t,s,v,l[n+0],11,3936430074),v=d(v,w,t,s,l[n+3],16,3572445317),s=d(s,v,w,t,l[n+6],23,76029189),t=d(t,s,v,w,l[n+9],4,3654602809),
w=d(w,t,s,v,l[n+12],11,3873151461),v=d(v,w,t,s,l[n+15],16,530742520),s=d(s,v,w,t,l[n+2],23,3299628645),t=c(t,s,v,w,l[n+0],6,4096336452),w=c(w,t,s,v,l[n+7],10,1126891415),v=c(v,w,t,s,l[n+14],15,2878612391),s=c(s,v,w,t,l[n+5],21,4237533241),t=c(t,s,v,w,l[n+12],6,1700485571),w=c(w,t,s,v,l[n+3],10,2399980690),v=c(v,w,t,s,l[n+10],15,4293915773),s=c(s,v,w,t,l[n+1],21,2240044497),t=c(t,s,v,w,l[n+8],6,1873313359),w=c(w,t,s,v,l[n+15],10,4264355552),v=c(v,w,t,s,l[n+6],15,2734768916),s=c(s,v,w,t,l[n+13],21,
1309151649),t=c(t,s,v,w,l[n+4],6,4149444226),w=c(w,t,s,v,l[n+11],10,3174756917),v=c(v,w,t,s,l[n+2],15,718787259),s=c(s,v,w,t,l[n+9],21,3951481745),t=k(t,q),s=k(s,u),v=k(v,B),w=k(w,C);return(b(t)+b(s)+b(v)+b(w)).toLowerCase()}var Yg;
function vh(a,b){var c=K.q.jl.url+"api";try{var d=new XMLHttpRequest;d.open("POST",c);d.setRequestHeader("Content-Type","application/x-www-form-urlencoded");d.onload=function(){"application/json"===d.getResponseHeader("Content-Type")&&b(JSON.parse(d.responseText))};d.onerror=function(a){console.log("error: "+a)};d.send(a)}catch(f){}}function wh(a){vh("call=api_is_valid",function(b){a(b.is_valid)})}
function Zg(a,b){vh("call=is_highscore&score="+a,function(a){0<=a.position?(Yg=a.code,b(void 0!==Yg)):b(!1)})}
TG_StatObjectFactory={BA:function(a){return new TG_StatObject("totalScore",a,"levelEndScreenTotalScore_"+a,0,0,!0,!0)},zA:function(a){return new TG_StatObject("highScore",a,"levelEndScreenHighScore_"+a,xh(),xh(),!0)},yA:function(a,b,c,d,f){return new TG_StatObject(a,b,c,0,d,f,!0,"max"===K.n.qh?function(a){return a+d}:function(a){return a-d})},AA:function(a,b,c,d,f){return new TG_StatObject(a,b,c,0,d,f,!0,"max"===K.n.qh?function(a){return a-d}:function(a){return a+d})}};
TG_StatObject=function(a,b,c,d,f,h,k,l,n){this.id=a;this.type=b;this.key=c;this.gd=d;this.Kg=void 0!==f?f:this.gd;this.visible=void 0!==h?h:!0;this.lf=void 0!==k?k:this.gd!==this.Kg;this.Pf=l;this.im=void 0!==n?n:"totalScore";switch(this.type){case "text":this.toString=function(a){return a};break;case "number":this.toString=function(a){return a+""};break;case "time":this.toString=function(a){return K.d.Ez(1E3*a)}}};
TG_StatObject.prototype.P=function(){return new TG_StatObject(this.id,this.type,this.key,this.gd,this.Kg,this.visible,this.lf,this.Pf,this.im)};K.version=K.version||{};K.version.tg="2.13.0";function yh(a,b,c,d,f,h,k,l){this.depth=c;this.h=this.visible=!0;this.group="Floater";this.x=a;this.y=b;this.K=d;this.Eu=f;this.Cj=h;this.$b=k;this.scale=this.state=this.l=0;this.alpha=1;this.Ay=l||sc;K.d.Ka(this,K.xh);"undefined"===typeof this.canvas&&(this.canvas=K.he);H(this)}
yh.prototype.nb=function(){this.canvas.Y=!0};yh.prototype.Z=function(a){this.l+=a;0===this.state?this.l>=this.Cj?(this.state=this.scale=1,this.l=0):(this.y+=this.Eu*a/1E3,this.scale=this.Ay(this.l,0,1,this.Cj)):(this.l>=this.$b&&I(G,this),this.y+=this.Eu*a/1E3,this.alpha=1-this.l/this.$b);this.canvas.Y=!0};yh.prototype.za=function(){this.K.S(this.x-this.K.width*this.scale/2,this.y-this.K.height*this.scale/2,this.scale,this.scale,0,this.alpha)};
function zh(a){this.depth=1E3;this.h=this.visible=!1;this.group=a;H(this)}function Ah(a,b,c,d,f,h,k,l){var n;if(l&&l.hasOwnProperty(b))return new yh(c,d,-450,l[b],f,200,h,k);n=new x(a.aa(b)+10+50,a.T(b)+50);y(n);a.align="left";a.i="top";a.o(b,30,25);z(n);l&&(l[b]=n);return new yh(c,d,-450,n,f,200,h,k)}zh.prototype.vp=function(){var a,b;a=Qb(G,function(a){return"Floater"===a.group});for(b=0;b<a.length;b+=1)I(G,a[b])};
zh.prototype.ac=function(){var a,b,c,d,f,h;this.aw=[];b=[Q,R,S,T];a=[K.m.N("Floater1","<FLOATER_1>"),K.m.N("Floater2","<FLOATER_2>"),K.m.N("Floater3","<FLOATER_3>"),K.m.N("Floater4","<FLOATER_4>")];for(c=0;c<b.length;c+=1)d=b[c],f=a[Math.min(c,a.length)],h=new x(d.aa(f)+10,d.T(f)),y(h),d.align="left",d.i="top",d.o(f,5,0),z(h),this.aw.push(h)};zh.prototype.nb=function(){this.vp()};
var X={cu:{},du:{},eu:{},fu:{},fp:{},gp:{},rz:{},Aw:{},Zu:function(){X.cu={wc:X.Dk,update:X.Le,tc:X.Je,end:X.Ke,font:Je,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.du={wc:X.Dk,update:X.Le,tc:X.Je,end:X.Ke,font:Ke,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.eu={wc:X.Dk,update:X.Le,tc:X.Je,end:X.Ke,font:Le,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.fu={wc:X.Dk,update:X.Le,tc:X.Je,end:X.Ke,font:Me,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],
[.1,.8,.1])};X.fp={wc:X.Hv,update:X.Le,tc:X.Je,end:X.Ke,$i:Ne,Zi:Oe,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.gp={wc:X.Iv,update:X.Le,tc:X.Je,end:X.Ke,$i:Ne,Zi:Oe,margin:20,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.rz={wc:X.Jv,update:X.Le,tc:X.Je,end:X.Ke,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])};X.Aw={wc:X.Gv,update:X.Le,tc:X.Je,end:X.Ke,$d:J,ae:J,Zd:uc([kc,gc,kc],[!1,!1,!0],[.1,.8,.1])}},vA:function(a){function b(a){var d,f={};for(d in a)f[d]="object"===
typeof a[d]&&null!==a[d]?b(a[d]):a[d];return f}return b(a)},WC:function(a){X.cu.font.H=a;X.du.font.H=a;X.eu.font.H=a;X.fu.font.H=a},VC:function(a){X.fp.$i.H=a;X.fp.Zi.H=a;X.gp.$i.H=a;X.gp.Zi.H=a},gi:!1,Bc:[],UC:function(a){X.gi=a},cB:function(){return X.gi},wy:function(a){var b,c;for(b=0;b<X.Bc.length;b+=1)c=X.Bc[b],void 0===c||void 0!==a&&c.kind!==a||0<c.Oh||(X.Bc[b]=void 0)},Yu:function(){X.gi=!1;X.Bc=[]},ii:function(a,b,c,d){var f,h,k;void 0===d&&(d=X.gi);if(d)for(h=0;h<X.Bc.length;h+=1)if(f=X.Bc[h],
void 0!==f&&f.uf&&f.kind===a&&f.font===b&&f.text===c)return f.Oh+=1,h;f={kind:a,font:b,text:c,Oh:1,uf:d};h=b.align;k=b.i;La(b,"center");Ma(b,"middle");d=b.aa(c)+2*a.margin;a=b.T(c)+2*a.margin;f.K=new x(d,a);y(f.K);b.o(c,d/2,a/2);z(f.K);La(b,h);Ma(b,k);for(h=0;h<X.Bc.length;h+=1)if(void 0===X.Bc[h])return X.Bc[h]=f,h;X.Bc.push(f);return X.Bc.length-1},Wu:function(a){var b=X.Bc[a];b.Oh-=1;0>=b.Oh&&!b.uf&&(X.Bc[a]=void 0)},Dk:function(a){a.buffer=X.ii(a.kind,a.kind.font,a.value,a.uf)},Hv:function(a){var b=
a.value.toString();a.buffer=0<=a.value?X.ii(a.kind,a.kind.$i,b,a.uf):X.ii(a.kind,a.kind.Zi,b,a.uf)},Iv:function(a){var b=a.value.toString();0<a.value&&(b="+"+b);a.buffer=0<=a.value?X.ii(a.kind,a.kind.$i,b,a.uf):X.ii(a.kind,a.kind.Zi,b,a.uf)},Jv:function(a){a.K=a.value},Gv:function(a){a.b=a.value;a.hc=0},Le:function(a){a.x=void 0!==a.kind.$d?a.kind.$d(a.time,a.gm,a.Cr-a.gm,a.duration):a.gm+a.time/a.duration*(a.Cr-a.gm);a.y=void 0!==a.kind.ae?a.kind.ae(a.time,a.hm,a.Dr-a.hm,a.duration):a.hm+a.time/
a.duration*(a.Dr-a.hm);void 0!==a.kind.zr&&(a.fc=a.kind.zr(a.time,0,1,a.duration));void 0!==a.kind.Ar&&(a.gc=a.kind.Ar(a.time,0,1,a.duration));void 0!==a.kind.Zd&&(a.alpha=a.kind.Zd(a.time,0,1,a.duration));void 0!==a.kind.Qv&&(a.pa=a.kind.Qv(a.time,0,360,a.duration)%360);void 0!==a.b&&(a.hc=a.time*a.b.D/a.duration)},Je:function(a){var b=p.context,c;void 0!==a.b&&null!==a.images?1===a.fc&&1===a.gc&&0===a.pa?a.b.fd(Math.floor(a.hc),a.x,a.y,a.alpha):a.b.S(Math.floor(a.hc),a.x,a.y,a.fc,a.gc,a.pa,a.alpha):
(c=void 0!==a.K&&null!==a.K?a.K:X.Bc[a.buffer].K,1===a.fc&&1===a.gc&&0===a.pa?c.fd(a.x-c.width/2,a.y-c.height/2,a.alpha):1E-4>Math.abs(a.fc)||1E-4>Math.abs(a.gc)||(b.save(),b.translate(a.x,a.y),b.rotate(-a.pa*Math.PI/180),b.scale(a.fc,a.gc),c.fd(-c.width/2,-c.height/2,a.alpha),b.restore()))},Ke:function(a){void 0!==a.buffer&&X.Wu(a.buffer)},Pe:function(a){var b,c,d=!1;for(b=0;b<X.Zb.length;b+=1)c=X.Zb[b],void 0!==c&&(0<c.Pa?(c.Pa-=a,0>c.Pa&&(c.time+=-c.Pa,c.Pa=0)):c.time+=a,0<c.Pa||(c.time>=c.duration?
(c.kind.end(c),X.Zb[b]=void 0):c.kind.update(c),d=!0));d&&(X.canvas.Y=!0)},za:function(){var a,b;for(a=0;a<X.Zb.length;a+=1)b=X.Zb[a],void 0!==b&&(0<b.Pa||b.kind.tc(b))},Zb:[],jB:function(a,b,c){X.Sv();void 0===a&&(a=K.xh);void 0===b&&(b=-1E6);void 0===c&&(c=["game"]);X.visible=!0;X.h=!0;K.d.Ka(X,a);X.depth=b;H(X);Pb(X,c);X.Yu();X.Zu()},Yz:function(a,b,c,d,f,h,k,l,n){void 0===l&&(l=void 0!==a.Pa?a.Pa:0);void 0===n&&(n=X.gi);void 0===f&&void 0!==a.Kx&&(f=c+a.Kx);void 0===h&&void 0!==a.Lx&&(h=d+a.Lx);
void 0===k&&void 0!==a.duration&&(k=a.duration);a={kind:a,value:b,gm:c,hm:d,Cr:f,Dr:h,x:c,y:d,fc:1,gc:1,alpha:1,pa:0,time:0,duration:k,Pa:l,uf:n};a.kind.wc(a);for(b=0;b<X.Zb.length;b+=1)if(void 0===X.Zb[b])return X.Zb[b]=a,b;X.Zb.push(a);return X.Zb.length-1},wC:function(a){var b;0>a||a>=X.Zb.length||(b=X.Zb[a],void 0!==b&&(b.kind.end(b),X.Zb[a]=void 0))},vp:function(){var a,b;for(a=0;a<X.Zb.length;a+=1)b=X.Zb[a],void 0!==b&&(b.kind.end(b),X.Zb[a]=void 0);X.Zb=[]},Sv:function(){X.vp();X.wy();I(G,
X)}};function Bh(a){this.depth=-99;K.d.Ka(this,K.Hc);this.h=!0;this.visible=!1;this.e=a;H(this)}Bh.prototype.vg=function(){};Bh.prototype.wg=function(){};Bh.prototype.Ub=function(a,b,c){a:{var d=this.e,f;for(f=0;f<d.Wc.length;++f)if(d.Wc[f].Ub&&d.Wc[f].Ub(a,b,c)){a=!0;break a}a=!1}return a};
Bh.prototype.Vb=function(a,b,c){var d;a:if(d=this.e,d.wb&&a===d.dq)a=d.wb.a.x,b=d.wb.a.y,d.wb.kp&&(a=d.wb.kp.x,b=d.wb.kp.y),GameUISettingsOffsets?console.log("Component:\n x: tgScale("+(a+d.wb.Zg.x-GameUISettingsOffsets.Wz)+") + GameUISettingsOffsets.X,\n y: tgScale("+(b+d.wb.Zg.y-GameUISettingsOffsets.Xz)+") + GameUISettingsOffsets.Y,"):console.log("Component:\n x: tgScale("+(a+d.wb.Zg.x)+"),\n y: tgScale("+(b+d.wb.Zg.y)+"),"),d.Au=!1,d=!0;else{for(var f=0;f<d.Wc.length;++f)if(d.Wc[f].Vb&&d.Wc[f].Vb(a,
b,c)){d=!0;break a}d=!1}return d};function Ch(){this.Ua=this.depth=0;this.Dn=this.mc=this.h=this.visible=!1;this.Wc=[];this.Pk={};this.Pk.Ve=!1;this.Er={};this.paused=this.Er.Ve=!1;this.lz=new x(0,0);this.nz=this.mz=0;this.wb=null;this.dq=this.Cu=this.Bu=-1;this.Au=!1;this.dc=this.cc=0;this.nl=null}e=Ch.prototype;e.ac=function(){this.nl=new Bh(this)};e.nb=function(){this.nl&&(I(G,this.nl),this.nl=null)};
function Dh(a,b,c){for(var d in b){var f=b[d];f.b?c[d]=new Eh(a,f):f.iu?c[d]=new Fh(a,K.m.N(f.iu,"<"+f.iu+">"),f):f.U?c[d]=new Fh(a,K.m.N(f.U,"<"+f.U+">"),f):f.text&&(c[d]=new Fh(a,f.text,f))}}function Gh(a,b){a.Ve&&(a.l+=b,a.l>=a.duration&&(a.Ve=!1,a.zb&&a.zb()))}
e.Z=function(a){Gh(this.Pk,a);Gh(this.Er,a);for(var b=0;b<this.Wc.length;++b)this.Wc[b].Z(a);if(this.wb&&this.Au){a=G.ia[this.dq].x;b=G.ia[this.dq].y;this.canvas===K.d.ug(K.rg)&&this.wb.dl(this.cc+K.sg,this.dc+K.rf);var c=a-this.Bu,d=b-this.Cu;this.wb.x+=c;this.wb.y+=d;this.wb.Zg.x+=c;this.wb.Zg.y+=d;this.Bu=a;this.Cu=b;this.mc=!0}};e.Pe=function(){if(this.mc){var a=K.d.ug(K.rg);this.canvas!==a?this.canvas.Y=this.mc:(p.ja(a),this.za())}};
e.Lk=function(a,b){for(var c=K.d.ug(K.rg)===this.canvas,d=0;d<this.Wc.length;++d){var f=this.Wc[d];f.visible&&(c&&f.dl(a,b),f.za(a,b))}};e.za=function(){var a=0,b=0;K.d.ug(K.al)!==this.canvas&&(a=K.sg,b=K.rf);this.paused?this.lz.o(this.mz+this.cc+a,this.nz+this.dc+b):this.Lk(this.cc+a,this.dc+b);this.mc=!1};function Hh(){this.gs=[];this.Fr=[];this.yt=null;this.gn=void 0;this.$n=!0}
function Ih(a){function b(a,b){if(!b)return!1;var f=0;if("string"===typeof a){if(d(a))return!1}else for(f=0;f<a.length;++f)if(d(a[f]))return!1;if(b.IA){if("string"===typeof a){if(c(a))return!0}else for(f=0;f<a.length;++f)if(c(a[f]))return!0;return!1}return!0}function c(a){for(var b in k)if(b===a||k[b]===a)return!0;return!1}function d(a){for(var b in h)if(b===a||h[b]===a)return!0;return!1}var f;if(a instanceof Hh){if(1!==arguments.length)throw"When using GameUIOptions as argument to GameUIController constructor you should not use extraComponents of gameUiSettings as parameters anymore.";
f=a}else f=new Hh,f.gs=arguments[0],f.Fr=arguments[1],f.yt=arguments[2];var h=null,k=null,l=null,h=f.gs,k=f.Fr,l=f.yt;this.Ph=f;void 0===this.Ph.gn&&(this.Ph.gn=!qg(K.e));Ch.apply(this,arguments);H(this);this.h=this.visible=!0;k=k||[];h=h||[];this.lu=2;this.vk=!1;this.p=l||Jh;this.sr=K.al;void 0!==this.p.Ua&&(this.sr=this.p.Ua);K.d.Ka(this,this.sr);this.bk=this.ak=0;this.p.background.Cw&&(this.ak=this.p.background.Cw);this.p.background.Dw&&(this.bk=this.p.background.Dw);this.p.background.elements||
(this.ud=this.p.background.b);this.p.background.fA?(Dh(this,this.p.background.elements,{}),this.ud=this.p.background.b):(f=this.p.background.b,l=new Ch,Dh(l,this.p.background.elements,[]),f||this.Ua!==K.rg?(this.ud=new x(f.width,f.height),y(this.ud),f.o(0,0,0),l.Lk(-this.ak,-this.bk),z(this.ud)):(p.ja(K.d.ug(this.Ua)),l.za()));this.ss=0;b("score",this.p.st)?(this.am=new Kh(this,this.p.st,"SCORE",0,!0),this.p.By&&new Eh(this,this.p.By)):this.am=new Lh(0,0);this.jj=b("highScore",this.p.hs)?new Kh(this,
this.p.hs,"HIGHSCORE",0,!1):new Lh(0,0);b("highScore",this.p.ks)&&new Eh(this,this.p.ks);this.Uh=b(["stage","level"],this.p.Ht)?new Kh(this,this.p.Ht,"STAGE",0,!1):new Lh(0,0);b("lives",this.p.Ns)&&new Kh(this,this.p.Ns,"LIVES",0,!1);this.rm=b("time",this.p.time)?new Kh(this,this.p.time,"TIME",0,!1,function(a){var b=Math.floor(a%6E4/1E3);return Math.floor(a/6E4)+(10>b?":0":":")+b}):new Lh(0,0);this.rm.Ef(36E4);if(this.p.Fb&&this.p.rp)throw"Don't define both progress and progressFill in your game_ui settings";
this.Fj=b("progress",this.p.Fb)?this.p.Fb.round?new Mh(this,this.p.Fb):new Nh(this,this.p.Fb):b("progress",this.p.rp)?new Nh(this,this.p.rp):new Lh(0,0);b("lives",this.p.es)&&new Eh(this,this.p.es);b("difficulty",this.p.Bn)?new Fh(this,Oh().toUpperCase(),this.p.Bn):Oh();b("difficulty",this.p.Vi)&&(f=s_ui_smiley_medium,f=(this.p.Vi.images?this.p.Vi.images:[s_ui_smiley_easy,s_ui_smiley_medium,s_ui_smiley_hard])[sg()],this.p.Vi.b||(this.p.Vi.b=f),this.Mv=new Eh(this,this.p.Vi),this.Mv.ut(f));this.p.tf&&
!this.p.tf.length&&(this.p.tf=[this.p.tf]);this.p.ge&&!this.p.ge.length&&(this.p.ge=[this.p.ge]);this.vs=[];this.ws=[];this.vs[0]=b(["item","item0"],this.p.tf)?new Eh(this,this.p.tf[0]):new Lh(0,"");this.ws[0]=b(["item","item0"],this.p.ge)?new Fh(this,"",this.p.ge[0]):new Lh(0,"");if(this.p.tf&&this.p.ge)for(f=1;f<this.p.ge.length;++f)b("item"+f,this.p.ge[f])&&(this.ws[f]=new Fh(this,"0 / 0",this.p.ge[f]),this.vs[f]=new Eh(this,this.p.tf[f]));for(var n in this.p)f=this.p[n],f.U&&new Fh(this,K.m.N(f.U,
"<"+f.U+">")+(f.separator?f.separator:""),f);this.Ls=this.mu=0;this.buttons={};for(n in this.p.buttons)f=Ph(this,this.p.buttons[n]),this.buttons[n]=f;this.p.Yx&&(f=Ph(this,this.p.Yx),this.buttons.pauseButton=f);this.zn={};for(n in this.p.zn)f=this.p.zn[n],f=new Qh[f.wA](this,f),this.zn[n]=f;this.dc=this.cc=0}Wf(Ch,Ih);var Qh={};function Ph(a,b){var c=new Rh(a,b,b.fa);a.Wc.push(c);c.aB=b;return c}e=Ih.prototype;e.Cp=function(a,b){this.buttons[b||"pauseButton"].Cp(a)};
e.Hg=function(a){this.Fj.Hg(a);return this};e.Ah=function(){return this.Fj.Ah()};e.setTime=function(a){this.rm.Ef(a);return this};e.getTime=function(){return this.rm.O()};function Sh(a){var b=Y.uc;b.jj.Ef(a);b.ss=a}function Th(a,b){a.Uh.Ef(b);1<b&&a.Fj&&a.Fj.Zr&&a.Fj.Zr()}e.Ym=function(a){a=this.am.O()+a;this.am.Ef(a);this.Ph.gn&&(this.jj.O()<a?this.jj.Ef(a):a<this.jj.O()&&this.jj.Ef(Math.max(a,this.ss)));return this};
e.nb=function(){Ch.prototype.nb.apply(this,arguments);p.ja(this.canvas);p.clear();for(var a in this.buttons)I(G,this.buttons[a])};
e.Z=function(a){1===this.lu&&this.setTime(this.getTime()+a);if(2===this.lu){if(this.mu&&1E3*this.mu>=this.getTime()){var b=Math.floor(this.getTime()/1E3),c=Math.floor(Math.max(this.getTime()-a,0)/1E3);b!==c&&(b=this.rm,b.Pc.l=0,b.Pc.Op=!0,b.font.setFillColor(b.Pc.color),b.Bf(),"undefined"!==typeof a_gameui_timewarning_second&&E.play(a_gameui_timewarning_second))}this.setTime(Math.max(this.getTime()-a,0))}Ch.prototype.Z.apply(this,arguments);this.Ls+=a};
e.Lk=function(a,b){this.ud&&(this.ud instanceof r?this.ud.fd(0,a+this.ak,b+this.bk,1):this.ud.fd(a+this.ak,b+this.bk,1));Ch.prototype.Lk.apply(this,arguments);this.Dn&&this.ud&&sa(a,b,this.ud.width,this.ud.height,"blue",!0)};
function Uh(a,b,c,d,f,h){this.e=a;this.width=f;this.height=h;this.K=null;this.x=c;this.y=d;this.visible=!0;this.a=b;this.alpha=void 0!==b.alpha?b.alpha:1;this.scale=void 0!==b.scale?b.scale:1;this.M={};this.M.cc=0;this.M.dc=0;this.M.scale=this.scale;this.M.alpha=this.alpha;this.M.pa=0;this.A={};this.A.Ve=!1;this.A.origin={};this.A.target={};this.A.l=0;this.a.Pk&&(Vh(this,this.a.Pk),this.A.Ve=!1);this.e.Wc.push(this);Wh||(Wh={wc:function(a){a.value instanceof x?a.K=a.value:(a.b=a.value,a.hc=0)},update:X.Le,
tc:X.Je,end:X.Ke,$d:J,ae:J,Zd:function(a,b,c,d){return 1-kc(a,b,c,d)},zr:function(a,b,c,d){return 1*kc(a,b,c,d)+1},Ar:function(a,b,c,d){return 1*kc(a,b,c,d)+1}})}var Wh;
function Vh(a,b){a.A.origin.x=void 0===b.x?a.x:b.x;a.A.origin.y=void 0===b.y?a.y:b.y;a.A.origin.alpha=void 0!==b.alpha?b.alpha:1;a.A.origin.scale=void 0!==b.scale?b.scale:1;a.A.target.x=a.x;a.A.target.y=a.y;a.A.target.alpha=a.alpha;a.A.target.scale=a.scale;a.A.duration=b.duration;a.A.Ve=!0;a.A.pf=b.pf||kc;a.A.l=0;a.A.Pa=b.Pa||0;Xh(a)}
function Xh(a){a.A.l>=a.A.duration&&(a.A.l=a.A.duration,a.A.Ve=!1);var b=a.A.pf(a.A.l,a.A.origin.x,a.A.target.x-a.A.origin.x,a.A.duration),c=a.A.pf(a.A.l,a.A.origin.y,a.A.target.y-a.A.origin.y,a.A.duration);a.M.cc=b-a.x;a.M.dc=c-a.y;a.M.alpha=a.A.pf(a.A.l,a.A.origin.alpha,a.A.target.alpha-a.A.origin.alpha,a.A.duration);a.M.scale=a.A.pf(a.A.l,a.A.origin.scale,a.A.target.scale-a.A.origin.scale,a.A.duration);a.e.mc=!0}e=Uh.prototype;
e.za=function(a,b){this.K&&this.K.S(this.x+this.M.cc+a,this.y+this.M.dc+b,this.M.scale,this.M.scale,0,this.M.alpha)};e.dl=function(a,b){Yh(this.x+this.M.cc+a,this.y+this.M.dc+b,this.width*this.M.scale,this.height*this.M.scale)};e.pl=function(a,b){return a>this.x+this.M.cc&&a<this.x+this.M.cc+this.width*this.M.scale&&b>this.y+this.M.dc&&b<this.y+this.M.dc+this.height*this.M.scale};e.xt=function(a){this.visible!==a&&(this.visible=a,this.e.mc=!0)};
e.Z=function(a){this.A.Ve&&(0<this.A.Pa?this.A.Pa-=a:(this.A.l+=-this.A.Pa,this.A.Pa=0,this.A.l+=a,Xh(this)))};function Lh(a,b){this.Fb=this.value=this.ml=b}e=Lh.prototype;e.Ef=function(a){this.value=a};e.O=function(){return this.value};e.Hg=function(a){0>a&&(a=0);100<a&&(a=100);this.Fb=a};e.Ah=function(){return this.Fb};e.ut=function(){};
function Eh(a,b){this.kp=b;this.a={};for(var c in b)this.a[c]=b[c];this.b=this.a.b;this.D=0;this.ig=this.a.ig;this.a.nD&&(this.a.x+=this.b.eb,this.a.y+=this.b.Za);Uh.call(this,a,this.a,this.a.x,this.a.y,this.b?this.b.width:1,this.b?this.b.height:1)}Wf(Uh,Eh);Qh.GameUIImage=Eh;function Zh(a,b){a.D!==b&&(a.D=b,a.e.mc=!0)}e=Eh.prototype;
e.za=function(a,b){this.b&&(this.ig&&(a+=-Math.floor(this.b.width/2),b+=-Math.floor(this.b.height/2)),this.b instanceof r?this.b.S(this.D,this.x+a+this.M.cc,this.y+b+this.M.dc,this.M.scale,this.M.scale,0,this.M.alpha):this.b.S(this.x+a+this.M.cc,this.y+b+this.M.dc,this.M.scale,this.M.scale,0,this.M.alpha),this.e.Dn&&sa(this.x+a-this.b.eb+1,this.y+b-this.b.Za+1,this.b.width-2,this.b.height-2,"black",!0))};
e.pl=function(a,b){if(!this.b)return!1;var c=0,d=0;this.ig&&(c+=-Math.floor(this.b.width/2),d+=-Math.floor(this.b.height/2));c-=this.b.eb;d-=this.b.Za;return a>c+this.x+this.M.cc&&a<c+this.x+this.M.cc+this.width*this.M.scale&&b>d+this.y+this.M.dc&&b<d+this.y+this.M.dc+this.height*this.M.scale};e.dl=function(a,b){this.b&&(this.ig&&(a+=-Math.floor(this.b.width/2),b+=-Math.floor(this.b.height/2)),a-=this.b.eb,b-=this.b.Za,Yh(this.x+this.M.cc+a,this.y+this.M.dc+b,this.width*this.M.scale,this.height*this.M.scale))};
e.po=function(a){a||(a=new m(0,0));a.x=this.x+K.sg+this.e.cc;a.y=this.y+K.rf+this.e.dc;return a};e.ut=function(a){a!==this.b&&(this.b=a,this.e.mc=!0,this.b&&(this.width=this.b.width,this.height=this.b.height))};
function Fh(a,b,c){"object"===typeof b&&(c=b,b=c.U?K.m.N(c.U,"<"+c.U+">"):c.text||"");this.text=b;this.font=c.font.P();c.vh&&A(this.font,c.vh);this.gt=c.x;this.ht=c.y;this.ft=c.zc;this.Ux=this.font.fillColor;this.Lf=void 0===c.Lf?.2:c.Lf;Uh.call(this,a,c,Math.floor(c.x-.1*c.zc),Math.floor(c.y-.1*c.Ic),Math.floor(1.2*c.zc),Math.floor(1.2*c.Ic));this.K=new x(this.width,this.height);switch(this.font.align){case "left":this.Qg=Math.floor(.1*c.zc);break;case "right":this.Qg=Math.floor(1.1*c.zc);break;
case "center":this.Qg=Math.floor(.6*c.zc);break;default:throw"Unknown alignment: "+this.font.align;}a=Math.floor(this.Lf*this.font.fontSize);switch(this.font.i){case "top":this.Rg=Math.floor(.1*c.Ic);break;case "bottom":this.Rg=Math.floor(1.1*c.Ic)+a;break;case "middle":this.Rg=Math.floor(.6*c.Ic)+a;break;default:throw"Unknown baseline: "+this.font.i;}this.Pc={};this.Pc.color="red";this.Pc.duration=200;this.Pc.l=0;this.Pc.Op=!1;this.Bf()}Wf(Uh,Fh);Qh.GameUIText=Fh;
Fh.prototype.Z=function(a){Uh.prototype.Z.apply(this,arguments);this.Pc.Op&&(this.Pc.l+=a,this.Pc.duration<=this.Pc.l&&(this.Pc.Op=!1,this.font.setFillColor(this.Ux),this.Bf()))};
Fh.prototype.Bf=function(){this.K.clear();y(this.K);var a=this.font.aa(this.text),b=1;a>this.ft&&(b=this.ft/a);this.font.S(this.text,this.Qg,this.Rg,b,b,0,1);this.e.Dn&&(sa(0,0,this.K.width,this.K.height,"black",!0),sa(this.gt-this.x,this.ht-this.y,this.K.width-2*(this.gt-this.x),this.K.height-2*(this.ht-this.y),"red",!0),ta(this.Qg-5,this.Rg,this.Qg+5,this.Rg),ta(this.Qg,this.Rg-5,this.Qg,this.Rg+5));this.e.mc=!0;z(this.K)};function $h(a){return""+a}function ai(a,b,c){return b+c}
function Kh(a,b,c,d,f,h){this.value=this.ml=d||0;this.Dm=-1;this.Gu=c;this.a=b;this.Fu=-99999;this.qm=b.qm||0;this.Tk=b.Tk?b.Tk:h||$h;c=ai;f&&0!==this.a.yr&&(c=lc);this.Ga=new Xf(this.ml,void 0===this.a.yr?500:this.a.yr,c);b.sh&&(this.sh="game_ui_"+b.sh);this.text=bi(this)+this.Tk(this.ml);Fh.call(this,a,this.text,b)}Wf(Fh,Kh);Qh.GameUIValue=Kh;Kh.prototype.Ef=function(a){this.value=a;Zf(this.Ga,this.value)};Kh.prototype.O=function(){return this.value};
Kh.prototype.bq=function(a){var b=this.Dm;if(a||G.zh-this.Fu>this.qm)b=this.Tk(Math.floor(this.Ga.O()));this.Dm!==b&&(this.Fu=G.zh,this.Dm=b,this.text=bi(this)+b,this.Bf())};Kh.prototype.Z=function(a){Fh.prototype.Z.apply(this,arguments);Yf(this.Ga,a);Math.floor(this.Ga.O())!==this.Dm&&this.bq()};function bi(a){var b="";a.a.Cm&&(b=a.sh?K.m.N(a.sh,"<"+a.sh.toUpperCase()+">"):K.m.N("game_ui_"+a.Gu,"<"+a.Gu+">"));return b+(a.a.separator?a.a.separator:"")}
function Nh(a,b){this.gg=this.Fb=0;this.a=b;this.Ej=this.Gg=0;this.b=b.b;this.De=b.De||b.b;this.Do=b.Do||null;this.a.Ll=this.a.Ll||0;this.a.Ml=this.a.Ml||0;this.fn=!0;this.Ul=b.Ul||0;this.J=[];this.vk=!1;this.Ga=new Xf(0,200,sc);this.Dc=new Xf(0,200,sc);Uh.call(this,a,b,b.x,b.y,this.b.width,this.b.height)}Wf(Uh,Nh);Qh.GameUIProgress=Nh;Nh.prototype.Hg=function(a){0>a&&(a=0);100<a&&(a=100);this.vk?(this.gg=a-this.Fb,Zf(this.Dc,this.gg)):(Zf(this.Ga,a),this.Fb=a)};Nh.prototype.Ah=function(){return this.Fb};
Nh.prototype.Z=function(a){Yf(this.Ga,a);var b=this.Ga.O();b!==this.Gg&&(this.e.mc=!0,this.Gg=b);Yf(this.Dc,a);a=this.Dc.O();a!==this.Ej&&(this.e.mc=!0,this.Ej=a);b+=a;if(this.fn)for(a=0;a<this.J.length;++a){var c=b>=this.J[a].position&&this.Fb+this.gg>=this.J[a].position;this.J[a].complete!==c&&(this.a.J&&(this.e.mc=!0,this.Gg=b),this.J[a].complete=c)}};
Nh.prototype.za=function(a,b){var c,d,f;if(0===this.Ul&&(0<this.Dc.O()&&this.De.Da(0,this.width*this.Ga.O()/100,0,this.De.width*this.Dc.O()/100,this.De.height,a+this.x+this.width*this.Ga.O()/100,b+this.y),this.b.Da(0,0,0,this.width*this.Ga.O()/100,this.height,a+this.x,b+this.y),this.a.J))for(c=0;c<this.J.length;++c)d=this.J[c],f=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,f.o(0,a+this.x+this.width/100*d.position,b+this.y+this.a.J.y);if(1===this.Ul&&(0<this.Dc.O()&&this.De.Da(0,0,this.height-
this.height*this.Ga.O()/100,this.width,this.height,a+this.x,b+this.y+(this.height-this.height*this.Ga.O()/100)),this.b.Da(0,0,this.height-this.height*this.Ga.O()/100,this.width,this.height,a+this.x,b+this.y+(this.height-this.height*this.Ga.O()/100)),this.a.J))for(c=0;c<this.J.length;++c)d=this.J[c],f=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,f.o(0,a+this.x+this.a.J.x,b+this.y+this.height-this.height/100*d.position);if(2===this.Ul&&(0<this.Dc.O()&&this.De.Da(0,0,this.height*this.Ga.O()/
100,this.De.width,this.De.height*this.Dc.O()/100,a+this.x+this.width*this.Ga.O()/100,b+this.y),this.b.Da(0,0,0,this.width,this.height*this.Ga.O()/100,a+this.x,b+this.y),this.a.J))for(c=0;c<this.J.length;++c)d=this.J[c],f=d.complete?s_ui_level_star_fill:s_ui_level_star_empty,f.o(0,a+this.x+this.a.J.x,b+this.y+this.height/100*d.position);this.Do&&this.Do.o(0,a+this.x+this.a.Ll,b+this.y+this.a.Ml)};function Rh(a,b,c){this.wm=!1;this.Qj=-1;this.e=a;this.a=b;this.h=!0;this.Cp(c);Eh.call(this,a,b)}
Wf(Eh,Rh);Qh.GameUIButton=Rh;Rh.prototype.Cp=function(a){var b=null,c=null,d=this.e,f=this.a;void 0===a&&(a=f.fa?f.fa:0);switch(a){case 0:b=d.Ph.$n?de:ee;c=function(){qg(K.e)?K.e.Sh(!1,!0,d.Ph.$n):K.e.Sh();return!0};break;case 1:b=fe;c=function(){K.e.Sh();return!0};break;case 2:b=s_btn_small_quit;c=function(){ci(d.Ph.$n);return!0};break;case 3:b=f.b}this.zb=c;this.a.b=b};Rh.prototype.Ub=function(a,b,c){if(this.h)return this.pl(b-K.sg,c-K.rf)?(this.wm=!0,this.Qj=a,Zh(this,1),!0):!1};
Rh.prototype.Z=function(a){Eh.prototype.Z.apply(this,arguments);this.wm&&(this.pl(G.ia[this.Qj].x-K.sg,G.ia[this.Qj].y-K.rf)?Zh(this,1):Zh(this,0))};Rh.prototype.Vb=function(a,b,c){return this.wm&&a===this.Qj?(Zh(this,0),this.pl(b-K.sg,c-K.rf)&&this.zb&&this.zb(),this.wm=!1,this.Qj=-1,!0):!1};
function Mh(a,b){this.gg=this.Fb=0;this.a=b;this.Ej=this.Gg=0;this.fn=!0;this.J=[];this.color=b.color||"#00AEEF";this.Xq=b.Xq||"#FF0F64";this.Uq=b.Uq||"#FFED93";this.Vq=void 0===b.blink||b.blink;this.nd=b.nd;this.jh=this.vk=!1;this.dg=0;this.tk=1E3;this.uk=0;this.Ga=new Xf(0,200,sc);this.Dc=new Xf(0,200,sc);Uh.call(this,a,b,b.x,b.y,1,1)}Wf(Uh,Mh);Qh.GameUIRoundProgress=Mh;function di(a){a.Vq&&(a.jh?a.dg-=a.tk:(a.jh=!0,a.dg=0,a.uk=0,Zf(a.Ga,100)))}e=Mh.prototype;
e.Hg=function(a){0>a&&(a=0);100<a&&(a=100);this.vk?(this.gg=a-this.Fb,Zf(this.Dc,this.gg)):(this.jh||(100===a&&this.Vq?di(this):Zf(this.Ga,a)),this.Fb=a)};e.Ah=function(){return this.Fb};e.Zr=function(){di(this)};
e.Z=function(a){Yf(this.Ga,a);var b=this.Ga.O();b!==this.Gg&&(this.e.mc=!0,this.Gg=b);Yf(this.Dc,a);var c=this.Dc.O();c!==this.Ej&&(this.e.mc=!0,this.Ej=c);this.jh&&(this.dg+=a,this.dg>=this.tk?100===this.Fb?(this.jh=!1,di(this)):(this.jh=!1,this.uk=0,this.Ga.wh=0,this.Ga.tm=0,Zf(this.Ga,this.Fb)):this.uk=(-Math.cos(this.dg/this.tk*5*Math.PI*2)+1)/2,this.e.mc=!0);b+=c;if(this.fn)for(a=0;a<this.J.length;++a)c=b>=this.J[a].position&&this.Fb+this.gg>=this.J[a].position,this.J[a].complete!==c&&(this.a.J&&
(this.e.mc=!0,this.Gg=b),this.J[a].complete=c)};e.dl=function(a,b){this.nd&&Yh(this.x+this.M.cc+a-this.nd.eb,this.y+this.M.dc+b-this.nd.Za,this.nd.width*this.M.scale,this.nd.height*this.M.scale)};
e.za=function(a,b){var c,d;if(this.nd){d=this.Ga.O()/100;d=Math.max(d,0);d=Math.min(d,1);var f=p.context,h=this.nd.width/2-L(4),k=f.fillStyle;if(0<this.Dc.O()){var l=this.Dc.O()/100;f.beginPath();f.arc(this.x+a,this.y+b,h,.5*-Math.PI+2*d*Math.PI,2*(d+l)*Math.PI-.5*Math.PI,!1);f.lineTo(this.x+a,this.y+b);f.fillStyle=this.Xq;f.fill()}f.beginPath();f.arc(this.x+a,this.y+b,h,.5*-Math.PI,2*d*Math.PI-.5*Math.PI,!1);f.lineTo(this.x+a,this.y+b);f.fillStyle=this.color;f.fill();this.tk&&(l=f.globalAlpha,f.globalAlpha*=
this.uk,f.beginPath(),f.arc(this.x+a,this.y+b,h,.5*-Math.PI,2*d*Math.PI-.5*Math.PI,!1),f.lineTo(this.x+a,this.y+b),f.fillStyle=this.Uq,f.fill(),f.globalAlpha=l);if(this.a.J){var l=f.strokeStyle,n=f.lineWidth;f.strokeStyle="white";f.lineWidth=L(2);for(d=0;d<this.J.length;++d){c=this.J[d];c=c.position/100*Math.PI*2;var q=Math.cos(-.5*Math.PI+c)*h;c=Math.sin(-.5*Math.PI+c)*h;f.beginPath();f.moveTo(Math.round(a+this.x),Math.round(b+this.y));f.lineTo(Math.round(a+this.x+q),Math.round(b+this.y+c));f.stroke()}f.strokeStyle=
l;f.lineWidth=n}this.nd.o(0,a+this.x,b+this.y);if(this.a.J)for(d=0;d<this.J.length;++d)c=this.J[d],h=c.complete?s_star_filled:s_star_empty,c=c.position/100*Math.PI*2,h.o(0,Math.round(a+this.x+Math.cos(-.5*Math.PI+c)*this.a.J.rb*.5),Math.round(b+this.y+Math.sin(-.5*Math.PI+c)*this.a.J.rb*.5));f.fillStyle=k}};K.version=K.version||{};K.version.game_ui="2.1.0";
var Jh={background:{b:ud},rp:{b:td,De:vd,x:L(116),y:L(90)},buttons:{pauseButton:{x:L(530),y:L(12),fa:0}},st:{x:L(120),y:L(12),zc:L(400),Ic:L(46),Lf:.2,qm:50,Cm:!1,separator:"",font:Re,vh:{fillColor:"#172348",fontSize:L(42)}},Ht:{x:L(18),y:L(18),zc:L(86),Ic:L(50),Lf:.2,Cm:!0,separator:"\n",sh:"STAGE",font:Qe,vh:{fillColor:"#799EC5"}},hs:{x:L(254),y:L(64),zc:L(270),Ic:L(20),Lf:.2,qm:50,Cm:!0,separator:": ",font:Pe,vh:{fillColor:"#5E83B0",fontSize:L(16),align:"left",i:"bottom"}},ks:{x:L(232),y:L(74),
b:xd,ig:!0},es:{x:L(36),y:L(86),b:wd,ig:!0},Ns:{x:L(56),y:L(76),zc:L(50),Ic:L(24),Lf:.2,Cm:!1,separator:"x ",font:Qe,vh:{align:"left",i:"middle",fillColor:"#5782AE"}},tf:{x:L(36),y:L(86),b:null,ig:!0},ge:{x:L(56),y:L(76),zc:L(50),Ic:L(24),Lf:.2,font:Qe,vh:{align:"left",i:"middle",fillColor:"#5782AE"}}};
function ei(a,b,c,d,f){var h=0;this.visible=this.h=!1;this.group=0;this.node=a;this.attributes=b;this.duration=c;this.zb=f;this.Rv=d;this.Fk=0;this.cg={};for(h in this.attributes)this.cg[h]=a[h];this.tr={};for(h in this.attributes)this.tr[h]=this.attributes[h]-this.cg[h];H(this)}ei.prototype.finish=function(){this.h=!1;I(G,this);for(i in this.attributes)this.node[i]=this.attributes[i];"undefined"!==typeof this.zb&&this.zb()};
ei.prototype.Z=function(a){var b=0,c,d,f;this.Fk+=a;if(this.Fk<this.duration)for(b in this.attributes)a=this.tr[b],c=this.Fk,d=this.cg[b],f=this.duration,this.node[b]=this.Rv(c,d,a,f);else this.finish()};ei.prototype.start=function(){this.h=!0};ei.prototype.pause=function(){this.h=!1};function fi(){return function(a,b,c,d){return 4*mc(a,b,c,d)}}function gi(a,b,c,d,f){this.gf(a,b,c,d,f)}function hi(a,b,c){a.$c=b;a.pd=.5;a.Lc=c;a.uy=a.$c+a.pd+a.Lc}
gi.prototype.gf=function(a,b,c,d,f,h){this.depth=100;this.h=this.visible=!0;this.group="gameObject";this.x=c;this.y=d;this.K=null;this.state=0;this.alpha=1;this.font=b.P();this.vb=0;this.text=a;this.Xb=f;ii(this,h);this.duration=500;hi(this,.25,.06);this.Xb&&E.play(this.Xb);this.gc=this.fc=1;K.d.Ka(this,K.xh);H(this);Pb(this,"game")};var ji={};
function ii(a,b){ji.hasOwnProperty(a.font.H)||(ji[a.font.H]={});var c=""+a.font.fontSize;ji[a.font.H].hasOwnProperty(c)||(ji[a.font.H][c]={});ji[a.font.H][c].hasOwnProperty(a.font.fillColor)||(ji[a.font.H][c][a.font.fillColor]={});ji[a.font.H][c][a.font.fillColor].hasOwnProperty(a.font.strokeColor)||(ji[a.font.H][c][a.font.fillColor][a.font.strokeColor]={});if(ji[a.font.H][c][a.font.fillColor][a.font.strokeColor].hasOwnProperty(a.text))a.K=ji[a.font.H][c][a.font.fillColor][a.font.strokeColor][a.text];
else{a.K=new x(Math.floor(1.2*a.font.aa(a.text)),Math.floor(1.2*a.font.T(a.text))+L(10));b||(ji[a.font.H][c][a.font.fillColor][a.font.strokeColor][a.text]=a.K);c=a.K;y(c);try{Ma(a.font,"middle"),La(a.font,"center"),a.font.o(a.text,c.width/2,c.height/2)}finally{z(c)}}}gi.prototype.nb=function(){this.canvas.Y=!0};gi.prototype.Z=function(a){this.vb+=a;this.vb>this.duration&&I(G,this);this.canvas.Y=!0;this.dk(a)};gi.prototype.dk=function(){};
gi.prototype.za=function(){this.K.S(this.x-this.K.width*this.fc/2,this.y-this.K.height*this.gc/2,this.fc,this.gc,0,this.alpha)};function ki(a,b,c,d,f,h){this.gf(a,b,c,d,f,h);this.duration=500;hi(this,.25,.06);a=uc([qc,gc,fi()],[!1,!1,!1],[this.$c,this.pd,this.Lc]);this.Nd=new Xf(0,this.duration,a);Zf(this.Nd,2);a=uc([qc,gc,kc],[!1,!1,!0],[this.$c,this.pd,this.Lc]);this.Od=new Xf(0,this.duration,a);Zf(this.Od,1)}Wf(gi,ki);
ki.prototype.dk=function(a){Yf(this.Nd,a);Yf(this.Od,a);this.fc=this.Nd.O();this.gc=this.Od.O();this.vb>this.duration*(1-this.Lc/this.uy)&&(this.font.setFillColor("white"),this.font.setStrokeColor("white"),ii(this))};
function li(a,b,c,d,f,h,k,l,n){this.gf(a,b,K.Fd+K.ld/2,K.Gd+K.cj/2+(n||0),f,l);this.font.setFillColor("white");this.font.setStrokeColor("white");a=Ka(this.font);a.color="white";Ja(this.font,a);this.depth=-20;this.duration=2E3;hi(this,.1,.3);k=k?mc:qc;a=uc([k,gc],[!1,!1],[this.$c,this.pd+this.Lc]);this.Nd=new Xf(0,this.duration,a);Zf(this.Nd,1);k=uc([k,gc],[!1,!1],[this.$c,this.pd+this.Lc]);this.Od=new Xf(0,this.duration,k);Zf(this.Od,1);k=uc([gc,mc],[!1,!1,!0],[this.$c+this.pd,this.Lc]);this.ag=new Xf(1,
this.duration,k);Zf(this.ag,0);k=uc([gc,pc],[!1,!1],[this.$c+this.pd,this.Lc]);this.Fg=new Xf(this.y,this.duration,k);Zf(this.Fg,this.y);var q=uc([gc,mc],[!1,!1,!0],[this.$c+this.pd-.2,this.Lc+.2]),u=this;h=h||.75;new mi(c,u.duration,ni(u.x-u.K.width/2,u.y-u.K.height/8,u.K.width,u.K.height/4),L(50),d,function(a){return q(a,h,-h,u.duration)})}Wf(gi,li);
li.prototype.dk=function(a){Yf(this.Nd,a);Yf(this.Od,a);Yf(this.ag,a);Yf(this.Fg,a);this.fc=this.Nd.O();this.gc=this.Od.O();this.alpha=this.ag.O();this.y=this.Fg.O()};li.prototype.za=function(){this.K.S(this.x-this.K.width*this.fc/2,this.y-this.K.height*this.gc/2,this.fc,this.gc,0,this.alpha)};
function oi(a,b,c,d,f,h){this.gf(a,b,K.Fd+K.ld/2,K.Gd+K.cj/2,f,h);this.font.setFillColor("white");this.font.setStrokeColor("white");a=Ka(this.font);a.color="white";Ja(this.font,a);this.depth=-20;this.duration=2E3;hi(this,.5,.3);a=uc([mc,gc],[!1,!1],[this.$c,this.pd+this.Lc]);this.Nd=new Xf(0,this.duration,a);Zf(this.Nd,1);a=uc([mc,gc],[!1,!1],[this.$c,this.pd+this.Lc]);this.Od=new Xf(0,this.duration,a);Zf(this.Od,1);a=uc([gc,mc],[!1,!1,!0],[this.$c+this.pd,this.Lc]);this.ag=new Xf(1,this.duration,
a);Zf(this.ag,0);a=uc([gc,pc],[!1,!1],[this.$c+this.pd,this.Lc]);this.Fg=new Xf(this.y,this.duration,a);Zf(this.Fg,this.y)}Wf(gi,oi);oi.prototype.dk=function(a){Yf(this.Nd,a);Yf(this.Od,a);Yf(this.ag,a);Yf(this.Fg,a);this.fc=this.Nd.O();this.gc=this.Od.O();this.alpha=this.ag.O();this.y=this.Fg.O()};oi.prototype.za=function(){this.K.S(this.x-this.K.width*this.fc/2,this.y-this.K.height*this.gc/2,this.fc,this.gc,0,this.alpha)};
function ni(a,b,c,d){var f=2*c+2*d,h=c/f,k=d/f;return function(f){if(f<h)return new m(a+1/h*c*f,b);if(f<h+k)return new m(a+c,b+1/k*(f-h)*d);if(f<h+k+h)return new m(a+c-1/h*(f-h-k)*c,b+d);if(1>=f)return new m(a,b+d-1/k*(f-h-k-h)*d)}}function pi(){this.Mh=new m(0,0);this.Uj=new m(0,0);this.rt=this.pa=this.pr=this.wk=this.Ms=0}pi.prototype.Fo=function(a){return this.wk<a&&this.wk+this.Ms>a};
function mi(a,b,c,d,f,h){this.b=a;this.visible=this.h=!0;this.hv=h||function(){return 1};this.depth=0;this.group="gameObject";this.scale=25/a.width;this.Xx=f;this.Ih=[];this.Ck=b;this.qr=1;this.Dz=10;this.Sy=d;this.vb=0;this.shape=c;K.d.Ka(this,K.xh);this.Fe=new m(0,0);for(a=0;a<f;++a)b=c(a/f),this.Fe.x+=b.x,this.Fe.y+=b.y;this.Fe=this.Fe.scale(1/f);for(a=0;a<f;++a)this.Ih.push(new pi),qi(this,a);uc([J,J],[!1,!0],[1,1]);H(this);Pb(this,"game")}var ri=new fa(0);
function qi(a,b){var c=a.Ih[b],d=b/a.Xx;c.Ms=a.Ck;d=a.shape(d);d=d.add(da(ri.random(360),ri.random(a.Sy)));c.rt=360;c.Uj=d.ic(a.Fe).scale(1/(a.Ck/1E3*.04));c.wk=a.vb+ri.random(a.Dz);c.Bw=ha(ri,a.b.D-1);c.Mh=a.Fe}
mi.prototype.Z=function(a){this.vb+=a;for(var b=new m(0,180),c=0;c<this.Ih.length;++c){var d=this.Ih[c],f=Math.floor((this.vb-d.wk)/this.Ck);f>d.pr&&f<this.qr-1&&(qi(this,c),d.pr=f);d.Fo(this.vb)&&(f=d.Uj.scale(-4),f=b.add(f),d.Uj=d.Uj.add(f.scale(a/1E3)),d.Mh=d.Mh.add(d.Uj.scale(a/1E3)),d.pa+=d.rt*a/1E3,d.scale=2*Math.log(d.Mh.ic(this.Fe).length()/100)*this.scale)}this.vb>this.Ck*this.qr&&I(G,this);this.canvas.Y=!0};
mi.prototype.za=function(){for(var a=0;a<this.Ih.length;++a){var b=this.Ih[a];b.Fo(this.vb)&&this.b.S(b.Bw,b.Mh.x,b.Mh.y,b.scale,b.scale,b.pa,.9*this.hv(this.vb))}};function si(a,b){this.x=a;this.y=b}e=si.prototype;e.add=function(a){this.x+=a.x;this.y+=a.y};e.ic=function(a){this.x-=a.x;this.y-=a.y};e.scale=function(a){this.x*=a;this.y*=a};e.rotate=function(a){var b=Math.sin(a*Math.PI/180);a=Math.cos(a*Math.PI/180);this.x=a*this.x+b*this.y;this.y=-b*this.x+a*this.y};
e.ng=function(a){return this.x*a.x+this.y*a.y};e.normalize=function(){var a=Math.sqrt(this.x*this.x+this.y*this.y);0===a?this.y=this.x=0:(this.x/=a,this.y/=a)};e.tc=function(a,b,c){var d=Math.min(8,this.length()/4),f=this.ic(this.normalize().scale(2*d)),h=f.add(ea(this).scale(d)),d=f.add(ea(this).scale(-d)),k=p.context;k.strokeStyle=c;k.beginPath();k.moveTo(a,b);k.lineTo(a+f.x,b+f.y);k.lineTo(a+h.x,b+h.y);k.lineTo(a+this.x,b+this.y);k.lineTo(a+d.x,b+d.y);k.lineTo(a+f.x,b+f.y);k.stroke()};
function ti(a,b){return"object"===typeof a?new m(a.x+K.Fd,a.y+K.Gd):new m(a+K.Fd,b+K.Gd)}function ui(a,b){return K.m.N(a,b||"<"+a+">")}function vi(){dc.call(this);this.group="gameObject";this.re=[];Pb(this,"game")}Wf(dc,vi);function wi(a){this.ct=a;this.El=[];this.expansion=1}wi.prototype.create=function(){0>=this.El.length&&(this.expansion=Math.round(1.2*this.expansion)+1,this.expand(this.expansion));var a=this.El.pop();this.ct.apply(a,arguments);return a};wi.prototype.release=function(a){this.El.push(a)};
wi.prototype.expand=function(a){for(var b=0;b<a;b++)this.El.push(new this.ct)};var xi=new wi(si);K.version=K.version||{};K.version.game="1.2";var Y={};function yi(){this.depth=11;this.h=this.visible=!0;K.d.Ka(this,K.qf);this.a=K.a.k.k;this.scrollTo=0;H(this);Pb(this,"game");Y={e:this};Y.VA=new zh("gameObject");Y.Zq=new zi;Y.xC=[];this.zv={};this.Fp={};Y.sb=0;Ai(this);this.Cc=0}e=yi.prototype;
e.Ym=function(a){Y.uc.Ym(a);this.Lh+=a;if(this.qb&&(Y.uc.Hg(100*this.Lh/Y.s.s.Md),100<=Y.uc.Ah())){K.j.At&&K.j.At();this.qb=!1;var b=this;Bi(this,ui("bs_stage","Stage")+" "+(Y.uc.Uh.O()+1),Bf);(new ei(null,[],300,J,function(){b.Lh-=Y.s.s.Md;var a,d=Y.uc;"undefined"===typeof a&&(a=1);Th(d,d.Uh.O()+a);Ci(Y.uc.Uh.O());Zf(b.mn,Di());Y.uc.Hg(0);Y.uc.Hg(100*b.Lh/Y.s.s.Md);b.qb=!0})).start()}};
function Ei(a){a>=K.a.k.Xe.bubbles.length&&(a=K.a.k.Xe.bubbles.length-1);for(1>a&&(a=1);1<=a;--a)if(null!==K.a.k.Xe.bubbles[a])return K.a.k.Xe.bubbles[a]}
function Fi(a,b,c,d,f,h,k,l,n,q,u){var B=ti(f,h),C=750;d&&(C*=4);a.V(b,function(){D(c,k);d?new ki("+"+n,c,B.x,B.y,kf,q):Ah(c,(d?"+":"")+n,B.x,B.y,-L(20),C+10*n,void 0,q);D(c,l)});b+=700;1<u&&(a.V(b,function(){D(c,1*k);new ki("x"+u,c,B.x,B.y,zf);D(c,l)}),b+=700,a.V(b,function(){D(c,1*k);E.play(lf);"undefined"!==typeof Yd?new Gi(f,h,3,Yd,500,1,0):(new Gi(f,h,3,Nd,400,3,0),new Gi(f+L(20),h,3,Nd,400,3,22.5),new Gi(f+L(20),h,3,Nd,400,3,45));Ah(c,"+"+n*u,B.x,B.y,-L(20),C+10*n,qc,q);D(c,l)}),b+=300);return b}
function Hi(a,b,c,d,f,h,k){for(var l=0,n=0;n<d;++n)l+=Ei(f-n);k="undefined"===typeof k?0:k;f=1;h&&(f=K.a.k.Xe.Kw);Y.e.Ym(l*f);if(0<l||0<k){var n=Ve,q=a.zv;h&&(n=Xe);var u=n.fontSize,B=Math.floor(h?n.fontSize+Math.min((l-10)/10,2*n.fontSize):u),C=new vi,t=1;n===Xe&&(a.Fp.hasOwnProperty(""+B)||(a.Fp[""+B]={}),q=a.Fp[""+B]);0<l&&(t=Fi(C,t,n,h,b,c,B,u,l,q,f));b=l*f+k;a.Mr&&I(G,a.Mr);K.a.k.xz.My&&(a.Mr=Ah(n,"["+b+"]",50,50,-L(20),5E3,qc,q));(h||0===d)&&b>=K.a.k.Xe.Bt&&(b>=K.a.k.Xe.Ny?(C.V(t+a.Cc,function(){new li(ui("bs_awesome"),
af,Id,50,mf)}),a.Cc+=t+2E3):b>=K.a.k.Xe.Oy?(C.V(t+a.Cc,function(){new li(ui("bs_great"),$e,Id,50,mf)}),a.Cc+=t+2E3):b>=K.a.k.Xe.Bt&&(C.V(t+a.Cc,function(){new li(ui("bs_nice"),Ze,Id,20,mf)}),a.Cc+=t+2E3));C.start()}return l*f}function Ii(a,b,c,d,f){if(0>=f)return b;if("object"===typeof a&&null!==a&&null!==b){var h;h="undefined"!==typeof a.length?[]:{};for(var k in a)h[k]=Ii(a[k],b[k],c,d,f-1);return h}return"number"===typeof a?a*c+b*d:b}
function Ci(a){for(var b=null,c=0;c<K.a.k.Mo.length;++c){var d=K.a.k.Mo[c];if(d.s.Tc>=a){b&&d.s.Tc!==a?(a=(a-b.s.Tc)/(d.s.Tc-b.s.Tc),Y.s=Ii(b,d,1-a,a,3),Y.s.s.border=d.s.border):Y.s=d;break}else b=d}}e.nb=function(){this.qb=!1;this.xy=!0;this.canvas.Y=!0;Tb(function(a){return"gameObject"===a.group});I(G,Y.uc);Y=null};
function Ai(a){a.qb=!1;Y.uc=new Ih({lives:!0});Th(Y.uc,1);var b=xh();b||(b=0);Sh(b);Ci(1);Ji(ui("bs_start","Bubbleshooter!"),ui("bs_shootallbubbles","Shoot all the bubbles...!"),function(){this.qb=!0},a);Y.Fa=K.ld/11/2;Y.bb=Y.Fa/(ye.width/2);Y.background=new Ki;Y.da=new Li;Mi(Y.da,K.a.k.da.Gw);Y.Gc=new Ni;Y.Gc.Di();Y.Gc.Xm=!0;Y.Gc.yB=K.a.k.k.cb;a.mn=new Xf(Di(),1E3,sc);a.Lh=0}e.ro=function(){};e.ac=function(){};e.Z=function(a){this.canvas.Y=!0;Yf(this.mn,a);this.Cc=Math.max(0,this.Cc-a)};e.Ub=function(){};
e.Vb=function(){};e.vg=function(){};e.wg=function(){};e.cl=function(a){"LEVELFINISHED"===a&&Oi()};e.Oc=function(){};e.Pe=function(){};function Bi(a,b,c){var d=new vi;d.V(a.Cc+1,function(){new li(b,Ue,Id,0,c)});a.Cc+=2E3;d.start()}function Di(){return 2*Y.Fa+(Y.s.s.border-1)*Y.da.No+L(2)}e.za=function(){ze.o(0,0,this.mn.O())};
function Ni(){this.depth=10;this.h=this.visible=!0;this.group="gameObject";K.d.Ka(this,K.qf);this.a=K.a.k.Gc;this.x=this.a.x;this.y=this.a.y;this.b=Gd;this.Xm=!1;this.alpha=1;this.cb=Y.s.s.cb;this.nm=this.bu=0;this.Oi=1;this.sm=0;this.Nj=We.fillColor;this.Kf=new x(Math.floor(1.2*We.aa("88")),Math.floor(1.2*We.T("88")));this.Ho=-1;var a=L(20);this.ob=Vb(-Hd.eb-a,-Hd.Za-a,Hd.width+2*a,Hd.height+2*a);this.mm=new x(Ad.width,Ad.height);Pi(this);this.W=[];this.random=new fa;H(this);Pb(this,"game")}
function Pi(a){y(a.mm);a.mm.clear();try{Ad.o(0,0+Ad.eb,0+Ad.Za);var b=ui("bs_tap_to_switch_bubbles"),c=Sa(Ye,b,L(180),L(20),!1),d=Ye.fontSize;Ye.fontSize>c&&D(Ye,c);Ye.o(ui("bs_tap_to_switch_bubbles"),L(40),L(16),L(180));D(Ye,d)}finally{z(a.mm)}}e=Ni.prototype;
e.Di=function(){var a,b,c,d,f;f=this.a.scale;for(b=0;b<this.W.length;b++)a=this.W[b],c=this.a.W[b].x*f+this.x,d=this.a.W[b].y*f+this.y,a.moveTo(c,d,this.a.W[b].scale);for(b=0;this.a.W.length!==this.W.length;b++)c=this.a.W[this.W.length].x*f+this.x,d=this.a.W[this.W.length].y*f+this.y,a=Qi(c,d),a.scale=this.a.W[this.W.length].scale,this.W.push(a)};e.ac=function(){this.fe=new Ri(this.x,this.y)};e.nb=function(){for(this.fe&&I(G,this.fe);0!==this.W.length;){var a=this.W.pop();I(G,a)}this.Xm=!1};
function Si(a,b,c){b-=K.Fd;c-=K.Gd;c>a.y-a.b.Za&&(c=a.y-a.b.Za);b-=a.x;c-=a.y+Y.sb;c=xi.create(b,c);c.normalize();a.rotation=Math.min(180*Math.acos(0*c.x+-1*c.y)/Math.PI,a.a.hx)*(0<b?-1:1);xi.release(c)}
e.Z=function(a){var b,c;b=G.ia[0].x;c=G.ia[0].y;Si(this,b,c);this.y=this.a.y-Y.sb;for(var d=0;d<this.W.length;++d){var f=this.W[d];f.$a=this.a.W[d].x+this.x;f.Ma=this.a.W[d].y+this.y;f.position.x=this.a.W[d].x+this.x;f.position.y=this.a.W[d].y+this.y;f.scale=this.a.W[d].scale}if(this.fe){var d=this.fe,h=this.rotation,f=-Math.sin(Math.PI*h/180),h=-Math.cos(Math.PI*h/180);d.Dl.x=f;d.Dl.y=h;this.fe.Zc.x=this.x;this.fe.Zc.y=this.y}1>=this.cb?(this.sm+=a,150<this.sm&&(this.Nj="red"===this.Nj?We.fillColor:
"red",this.Ho=-1,this.sm=0)):this.Nj=We.fillColor;b-=K.Fd;c-=K.Gd;c+=Y.sb;c=cc(this.ob,this.x,this.y,b,c);this.fe.visible=!0;this.nm=c||G.ia[0].Bb?Math.min(1,this.nm+.003*a):Math.max(0,this.nm-.003*a);c?(this.Oi=Math.min(1,this.Oi+.003*a),this.fe.visible=!1):this.Oi=Math.max(0,this.Oi-.003*a)};
function Ti(a,b){var c,d,f,h;c=a.W.indexOf(b);if(-1!==c)for(E.play(yf),++a.bu,a.W[0]=a.W.splice(c,1,a.W[0])[0],"function"===typeof a.W[0].op&&a.W[0].op(),c=0;c<a.W.length;c++)b=a.W[c],d=a.a.W[c].x+a.x,f=a.a.W[c].y+a.y,h=a.a.W[c].scale,b.moveTo(d,f,h)}e.vg=function(a){32===a&&Ti(this,this.W[1])};
e.Vb=function(a,b,c){if(0===a&&!0===Y.e.qb){a=!0;var d="object"===typeof b?new m(b.x-K.Fd,b.y-K.Gd):new m(b-K.Fd,c-K.Gd);d.y+=Y.sb;cc(this.ob,this.x,this.y,d.x,d.y)&&(a=!1);if(!0===a&&!0===this.Xm){Si(this,b,c);b=this.W.shift();b.zt(this.rotation);b.sz=!0;c=Y.Zq;for(var f in c.jb)c.jb[f]=Math.max(0,c.jb[f]-1);this.nt=b;Y.Gc.Di()}else Ti(this,this.W[1])}};function Ui(){var a=Y.Gc;a.cb--;0>=a.cb&&(a.cb=Y.s.s.cb,Y.da.Eh++)}e.Oc=function(a){a===K.vf&&Pi(this)};
e.za=function(){Hd.S(0,this.x,this.y+Y.sb,1*Y.bb,1*Y.bb,0,this.alpha);this.b.S(0,this.x,this.y+Y.sb,1*Y.bb,1*Y.bb,this.rotation,this.alpha*(1-this.Oi));var a=this.a.yv;if(this.Ho!==this.cb){y(this.Kf);try{1!==this.cb&&(this.Nj=We.fillColor);this.Kf.clear();var b=We.fillColor;We.setFillColor(this.Nj);We.o(""+this.cb,this.Kf.width/2,this.Kf.height/2);We.setFillColor(b);this.Ho=this.cb}finally{z(this.Kf)}}this.Kf.o(a.x+this.x-this.Kf.width/2,a.y+this.y-this.Kf.height/2);10>=this.bu&&this.mm.S(this.x+
L(35,"floor")-Ad.eb,this.y+L(24,"floor")+Y.sb-Ad.Za,1,1,0,this.nm)};function Vi(a,b,c){Wi(this,a,b,c)}Vi.ob=new Wb(0,0,ye.width/2);function Wi(a,b,c,d){a.depth=4;a.visible=!0;a.h=!1;a.group="gameObject";K.d.Ka(a,K.qf);a.position=new m(b,c);a.$a=a.position.x;a.Ma=a.position.y;a.alpha=1;a.speed=0;a.scale=1;a.b=ye;a.size=ye.width/2;a.type=d;a.ob=Vi.ob;a.Wb=!1;a.sz=!0;a.direction=new m(0,-1);a.re=["bubble"];a.yl=0;H(a);Pb(a,"game")}e=Vi.prototype;e.nb=function(){};
function Xi(a){var b;a.ja("game");b=new ei(a,{scale:1.1},300,J,function(){b=new ei(a,{scale:1},300,J,function(){a.ja("background")});b.group="gameObject";b.start()});b.group="gameObject";b.start()}function Yi(a,b){a.direction.x=-Math.sin(Math.PI*b/180);a.direction.y=-Math.cos(Math.PI*b/180)}e.Lm=function(){this.speed=Y.bb*Y.s.ca.speed};e.zt=function(a){E.play(xf);Yi(this,a);this.Lm();this.h=!0};e.ja=function(){};e.fl=function(){Y.da.Di(this);this.speed=0;this.h=!1;return!0};
function Zi(a,b,c){var d;c="undefined"!==typeof c?c:!0;a.ja("game");b*=a.speed;for(var f=0;f<b;){f+=1;a.position.x+=1*a.direction.x;a.position.y+=1*a.direction.y;a.$a=a.position.x;a.Ma=a.position.y;var h=[];c&&a.position.x<a.size?h.push(new m(-a.direction.x,a.direction.y)):c&&a.position.x>K.ld-a.size&&h.push(new m(-a.direction.x,a.direction.y));if(a.position.y>K.cj+a.size-Y.sb){a.remove();break}if(0<h.length){var k=new m(0,0);for(d=0;d<h.length;++d)k=k.add(h[d]);0===k.length()&&console.log("bounceDirectionAverage is 0");
k=k.normalize();a.direction=k}if(d=!a.Wb)d=Y.da,h=void 0,a.position.y<Y.Fa?d=!0:(h=$i(d,a.position.x,a.position.y),d=!1!==aj(d,h.Ia,h.position)?!0:!1),d=!0===d;if(d&&a.fl())break}}e.Z=function(a){Zi(this,a)};
function bj(a,b,c){var d;!1===a.Wb&&("undefined"!==typeof a.ma&&I(G,a.ma),a.ja("game"),d=K.a.k.qa.vv,c=(new m(b,c)).ic(new m(a.position.x,a.position.y)).normalize().scale(d),b=a.position.x-c.x,c=a.position.y-c.y,a.ma=new ei(a,{$a:b,Ma:c},K.a.k.qa.$q/2,sc,function(){a.ma=new ei(a,{$a:a.position.x,Ma:a.position.y},K.a.k.qa.$q/2,sc,function(){!1===a.Wb&&a.ja("background")});a.ma.group="gameObject";a.ma.start()}),a.ma.group="gameObject",a.ma.start())}
function cj(a,b){!1===a.Wb&&("undefined"!==typeof a.ma&&I(G,a.ma),a.ja("game"),a.$a=a.position.x,a.Ma=a.position.y,a.position.y+=b,a.ma=new ei(a,{Ma:a.position.y,$a:a.position.x},K.a.k.qa.Hx,sc,function(){!1===a.Wb&&a.ja("background");dj(a)}),a.ma.group="gameObject",a.ma.start())}
function dj(a){if(a.position.y+Y.Fa>Di()){var b=Y.e;if(b.qb){var c=Y.e;if(c.qb){c.qb=!1;var d=G,f=1,h=d.jc.length,k;void 0===f&&(f=1);void 0===c&&(c=null);for(k=0;k<d.jc.length;k+=1)"LEVELFINISHED"===d.jc[k].id&&d.jc[k].Nf===c&&(h=k);if(h===d.jc.length)for(k=0;k<d.jc.length;k+=1)void 0===d.jc[k].id&&(h=k);d.jc[h]={id:"LEVELFINISHED",time:3E3,yC:f,Nf:c,Sg:3E3,Yl:f-1,paused:0}}Bi(b,ui("bs_gameover","Game over!"))}a.yl||(a.yl=G.zh)}}
e.moveTo=function(a,b,c){var d;!1===this.Wb&&("undefined"!==typeof this.ma&&I(G,this.ma),this.ja("game"),this.position.x=a,this.position.y=b,a="undefined"!==typeof c?c:this.scale,d=this,this.ma=new ei(this,{$a:this.position.x,Ma:this.position.y,scale:a},K.a.k.qa.Bl,J,function(){!1===d.Wb&&d.ja("background")}),this.ma.group="gameObject",this.ma.start())};
function ej(a,b){var c,d,f;!1===a.Wb&&(c=$i(Y.da,a.position.x,a.position.y),"undefined"!==typeof Y.da.G[c.Ia][c.position]&&(a.ja("game"),a.Wb=!0,Ob(a,0),d=new Vi(a.position.x,a.position.y,b),Xi(d),f=new ei(a,{alpha:0},600,J),f.group="gameObject",f.start(),f=new ei(a,{scale:1.1},300,J,function(){f=new ei(a,{scale:1},300,J,function(){a.remove()});f.group="gameObject";f.start()}),f.group="gameObject",f.start(),Y.da.G[c.Ia][c.position]=d))}
e.pop=function(){var a,b;!1===this.Wb&&(this.ja("game"),Ob(this,3),this.Wb=!0,"undefined"!==typeof this.ma&&I(G,this.ma),a=new ei(this,{$a:this.position.x,Ma:this.position.y},K.a.k.qa.Bl,J),a.group="gameObject",a.start(),b=this,a=new ei(this,{scale:K.a.k.qa.ky},K.a.k.qa.jy,oc,function(){I(G,b);new Gi(b.position.x,b.position.y,b.depth,Nd,K.a.k.qa.Cj,1)}),a.group="gameObject",a.start())};
e.Xi=function(){if(!1===this.Wb){var a,b;this.ja("game");Ob(this,3+Dd.D);this.Wb=!0;"undefined"!==typeof this.ma&&I(G,this.ma);a=new ei(this,{$a:this.position.x,Ma:this.position.y},K.a.k.qa.Bl,J);a.group="gameObject";a.start();b=this;a=new ei(this,{scale:K.a.k.qa.Ln},K.a.k.qa.Rk,oc,function(){I(G,b);new Gi(b.position.x,b.position.y,b.depth,Jd,K.a.k.qa.Qk,1)});a.group="gameObject";a.start()}};
e.Kh=function(){switch(this.type){case 0:E.play(rf);break;case 1:E.play(sf);break;case 2:E.play(tf);break;case 3:E.play(uf);break;case 4:E.play(vf);break;case 5:E.play(wf)}};
function fj(a){var b;!1===a.Wb&&(a.ja("game"),Ob(a,3),a.Wb=!0,"undefined"!==typeof a.ma&&I(G,a.ma),b=K.a.k.qa.Zv,a.position.x+=Math.random()*b-b/2,a.position.y+=K.cj,b=new ei(a,{Ma:a.position.y},K.a.k.qa.Ir,rc,function(){I(G,a)}),b.group="gameObject",b.start(),b=new ei(a,{$a:a.position.x},K.a.k.qa.Ir,J),b.group="gameObject",b.start())}e.remove=function(){this.ja("game");I(G,this);this.Wb=!0};
function gj(a){0<a.yl&&Md.S(0,a.position.x,a.position.y+Y.sb,a.scale*Y.bb,a.scale*Y.bb,0,(Math.sin((G.zh-a.yl)/1E3*Math.PI*2)+1)/2)}e.dh=function(a,b){gj(this);this.b.S(this.type,a,b+Y.sb,this.scale*Y.bb,this.scale*Y.bb,0,this.alpha)};e.za=function(){0!==this.speed||this.h||this.$a!==this.position.x||this.Ma!==this.position.y||(this.$a=this.position.x,this.Ma=this.position.y);this.dh(this.$a,this.Ma)};
function Ki(){this.depth=-9E3;this.h=this.visible=!1;this.group="gameObject";var a=ti(0,0);this.x=a.x-L(6);this.y=a.y;this.ln=[];K.d.Ka(this,K.rg);H(this);Pb(this,"game")}Ki.prototype.Z=function(){};Ki.prototype.ac=function(){p.ja(this.canvas)};Ki.prototype.Di=function(a){this.ln.push(a);p.ja(this.canvas);a.za()};Ki.prototype.Cf=function(a){a=this.ln.indexOf(a);-1!==a&&this.ln.splice(a,1);this.h=!0};function hj(a,b,c){this.Ia=a;this.position=b;c&&(this.ca=c)}
function Li(){this.depth=9E3;this.visible=!0;this.h=!1;this.group="gameObject";this.G=[];this.ie=1;this.Eh=this.kf=0;this.random=new fa;K.d.Ka(this,K.rg);this.No=Math.sqrt(Math.pow(2*Y.Fa,2)-Math.pow(Y.Fa,2));this.Zn=[];H(this);Pb(this,"game")}e=Li.prototype;e.ac=function(){};e.nb=function(){};e.za=function(){Yh(K.Fd,K.Gd,K.ld,K.cj);for(var a=0;a<this.G.length;++a)for(var b=this.G[a],c=0;c<b.length;++c){var d=b[c];d&&d.JA&&d.dh(d.$a+K.Fd,d.Ma+K.Gd)}};
function ij(a){for(var b=[0,0,0,0,0,0],c=0;c<a.G.length;++c)for(var d=a.G[c],f=0;f<d.length;++f){var h=d[f];h&&5>=h.type&&0<=h.type&&b[h.type]++}return b}
function jj(a,b){b=b||2;var c;c=Y.Gc;c=0<c.W.length?c.W[0].type:void 0;for(var d=Y.Gc.nt?Y.Gc.nt.type:null,f=a.G.length;0<=f;--f)for(var h=a.G[f],k=Math.floor(K.ld/(2*Y.Fa))-(f%2===a.ie?0:1),l=0;l<k;++l){var n=Math.floor((k-1)/2)+Math.ceil(l/2)*(1-(l+1)%2*2);if(!h||!h[n]){for(var q=new hj(f,n,null),q=kj(a,q.Ia,q.position,[q.ca]),u=[],B=0,C=-1,t=0;t<q.length;++t){var s=q[t].ca;s&&5>=s.type&&0<=s.type&&s.type!==c&&s.type!==d&&("undefined"===typeof u[s.type]&&(u[s.type]=lj(a,f,n,s.type,[],!0)),u[s.type]>=
B&&(C=s.type,B=u[s.type]))}if(B>=b)return C}}return 1<b?jj(a,1):mj(new nj)}function $i(a,b,c){c=Math.round((c-Y.Fa)/a.No);c=Math.max(c,0);c%2===a.ie?(a=Math.round((b-Y.Fa)/(2*Y.Fa)),a=Math.max(Math.min(a,Math.floor(K.ld/(2*Y.Fa))-1),0)):(a=Math.round((b-2*Y.Fa)/(2*Y.Fa)),a=Math.max(Math.min(a,Math.floor(K.ld/(2*Y.Fa))-2),0));return new hj(c,a)}function oj(a,b,c){return{x:c*Y.Fa*2+Y.Fa*(b%2===a.ie?1:2),y:b*a.No+Y.Fa}}
function pj(a){var b,c,d;for(b=0;b<a.G.length;b++){c=a.G[b];d=!0;for(var f=0;f<c.length;f++)"undefined"!==typeof c[f]&&(d=!1);if(!0===d)return b}return a.G.length}function qj(a){var b,c,d,f,h;f=[];for(b=0;b<a.G.length;b++)for(d=a.G[b],c=0;c<d.length;c++)h=d[c],"undefined"!==typeof h&&f.push({ca:h,Ia:b,position:c});return f}function aj(a,b,c){return"undefined"!==typeof a.G[b]&&"undefined"!==typeof a.G[b][c]?a.G[b][c]:!1}
function Mi(a,b){var c,d,f,h,k,l,n,q;d=Math.sqrt(Math.pow(2*Y.Fa,2)-Math.pow(Y.Fa,2));var u=new nj;for(h=1;h<=b;h++){a.ie=(a.ie+1)%2;c=Math.floor(K.ld/(2*Y.Fa))-a.ie;f=[];n=-d*h+Y.Fa;for(k=0;k<c;k++){l=0===a.ie%2?k*Y.Fa*2+Y.Fa:k*Y.Fa*2+2*Y.Fa;a:{q=u;for(var B=n,C=Y.da.random.random(q.um),t=0,s=0;s<q.yd.length;++s)if(t+=q.yd[s],t>C){if(5>=s){q=new Vi(l,B,-1);break a}if(6===s){q=new rj(l,B);break a}}q=void 0}f.push(q)}a.G.splice(0,0,f);for(k=0;k<c;++k)if(q=a.G[0][k],-1===q.type)a:for(f=u,n=k,l=(s=10*
Y.s.s.Ge>Y.da.random.random(1E3))?1:Y.s.s.Re,B=[],C=0,t=[],q.Jw=s;;){for(var v=Y.da.random.random(f.Xg),w=0,s=0;5>=s;++s)if(w+=f.yd[s],w>v)if("undefined"===typeof B[s]&&(B[s]=lj(Y.da,0,n,s)),B[s]>=l){t[s]||(t[s]=!0,C++);break}else{q.type=s;break a}if(C>=f.Rz)for(t=[],s=0;s<B.length;++s)B[s]--}}c=qj(a);for(k=0;k<c.length;k++)q=c[k].ca,cj(q,d*b)}
function lj(a,b,c,d,f,h){var k=0;h=h||!1;b=[new hj(b,c)];for(f=f||[];1<=b.length;){c=b[0];f.push(c.ca);c=kj(a,c.Ia,c.position,f);for(var l=0;l<c.length;l++){var n=c[l];f.push(n.ca);d===n.ca.type&&(n.ca.Jw&&(h||(k+=999999)),b.push(n),++k)}b.splice(0,1)}return k}
function sj(a,b){var c,d,f,h=null,k=null,l,n;l=[];for(c=0;c<a.G.length;c++)for(d=a.G[c],f=c,n=Math.floor(K.ld/(2*Y.Fa))-(f%2===a.ie?0:1),f=0;f<n;f++)tj(a,c,f)||"undefined"===typeof d[f]&&l.push(new hj(c,f));f=a.G.length;n=Math.floor(K.ld/(2*Y.Fa))-(f%2===a.ie?0:1);for(c=0;c<n;c++)tj(a,a.G.length,c)||l.push(new hj(a.G.length,c));for(c=0;c<l.length;c++)if(d=l[c],0===d.Ia||0<kj(a,d.Ia,d.position).length)if(f=oj(a,d.Ia,d.position),f=b.position.ic(new m(f.x,f.y)).length(),f<h||null===h)h=f,k=d;f=oj(a,
k.Ia,k.position);"undefined"===typeof a.G[k.Ia]&&(a.G[k.Ia]=[]);a.G[k.Ia][k.position]=b;b.moveTo(f.x,f.y);return k}
e.Di=function(a){var b=0,c,d,f,h,k,l,n,q,u;n=this;this.kf++;u=!0;l=new vi;l.group="gameObject";d=0;c=sj(this,a);var B=0;h=uj(this,c.Ia,c.position);if(3<=h.length){u=!1;for(f=q=0;f<h.length;f++)this.Cf(h[f].Ia,h[f].position),++b,++q,d+=K.a.k.qa.hy*Math.pow(f+1,K.a.k.qa.iy),l.V(d,function(a,b){return function(){a.pop();B+=Hi(Y.e,a.position.x,a.position.y,1,b,!1)}}(h[f].ca,q));10<h.length&&E.play(ff);6<h.length?E.play(jf):6<h.length?E.play(kf):5<h.length?E.play(lf):4<h.length?E.play(mf):a.Kh();var C=
new m(0,0);k=vj(this);for(f=0;f<k.length;f++)this.Cf(k[f].Ia,k[f].position),++b,d+=K.a.k.qa.Hr,l.V(d,function(a){return function(){fj(a)}}(k[f].ca)),C=C.add(k[f].ca.position);0<k.length?(C=C.scale(1/k.length),l.V(d,function(){Hi(Y.e,C.x,C.y,k.length,k.length,!0,B)})):l.V(d,function(){Hi(Y.e,a.x,a.y,0,0,!1,B)})}else E.play(qf);c=kj(this,c.Ia,c.position);for(f=0;f<c.length;f++)h=c[f].ca,q=c[f].Ia,"bomb"===h.type?(h.Kh(),h.Xi()):q!==this.maxLength-1&&u&&bj(h,a.position.x,a.position.y);l.V(d,function(){n.kf--;
0===n.kf&&wj(n)});0===b&&(dj(a),Ui());l.start()};e.Cf=function(a,b){!1!==aj(this,a,b)&&(this.G[a][b]=void 0)};
function kj(a,b,c,d){var f,h,k,l;h=b%2===a.ie?[new hj(b-1,c-1),new hj(b-1,c),new hj(b,c+1),new hj(b+1,c),new hj(b+1,c-1),new hj(b,c-1)]:[new hj(b-1,c),new hj(b-1,c+1),new hj(b,c+1),new hj(b+1,c+1),new hj(b+1,c),new hj(b,c-1)];f=[];for(k=0;k<h.length;k++)b=h[k].Ia,c=h[k].position,"undefined"!==typeof a.G[b]&&"undefined"!==typeof a.G[b][c]&&(l=a.G[b][c],("undefined"!==typeof d?-1===d.indexOf(l):1)&&f.push({ca:l,Ia:b,position:c}));return f}
function uj(a,b,c){var d,f,h,k,l;h=a.G[b][c];f=[new hj(b,c,h)];d=d||[];for(b=[new hj(b,c,h)];1<=f.length;){c=f[0];d.push(c.ca);k=kj(a,c.Ia,c.position,d);for(c=0;c<k.length;c++)l=k[c],d.push(l.ca),h.type===l.ca.type&&(f.push(l),b.push(l));f.splice(0,1)}return b}
function vj(a){var b,c,d,f,h,k;if("undefined"===typeof a.G[0])return qj(a);c=[];b=b||[];f=!0;for(d=0;d<a.G[0].length;d++)h=a.G[0][d],"undefined"===typeof h?f=!0:!0===f&&(f=!1,c.push({ca:h,Ia:0,position:d}));for(;1<=c.length;){d=c[0];b.push(d.ca);h=kj(a,d.Ia,d.position,b);for(d=0;d<h.length;d++)f=h[d],-1===b.indexOf(f.ca)&&(c.push(f),b.push(f.ca));c.splice(0,1)}f=[];for(d=0;d<a.G.length;d++)for(k=a.G[d],c=0;c<k.length;c++)h=k[c],-1===b.indexOf(h)&&"undefined"!==typeof h&&f.push({ca:h,Ia:d,position:c});
return f}function xj(a){var b,c,d,f,h;h=c=0;f=new vi;f.group="gameObject";b=vj(a);for(d=0;d<b.length;d++)a.Cf(b[d].Ia,b[d].position),c+=K.a.k.qa.Hr,h++,f.V(c,function(a){return function(){fj(a)}}(b[d].ca));f.start();return h}function wj(a){if(!0===Y.e.qb){var b=Math.round(Y.s.da.Se/Y.bb),c=pj(a);a.Eh=Math.max(b-c,a.Eh);0<a.Eh&&(Mi(a,a.Eh),a.Eh=0,0<b-c&&(Y.Gc.cb=Y.s.s.cb))}}
function yj(a,b,c){var d=Y.da,f,h,k,l,n,q;d.kf++;l=Y.s.kb.rb;n=K.a.k.kb.Mn;k=new vi;k.group="gameObject";k.Ud=n;h=new m(a,b);a=qj(d);for(b=0;b<a.length;b++)f=a[b].ca,q=h.ic(f.position).length(),q<l&&"bomb"!==f.type&&"blocker"!==f.type&&k.V(q,function(a){return function(){ej(a,c)}}(f));k.V(l+K.a.k.qa.Cj*n,function(){d.kf--});k.start()}
function zj(a,b){var c=Y.da,d,f,h,k,l,n,q,u,B,C,t;c.kf++;u=Y.s.Ba.rb;B=K.a.k.Ba.Mn;C=0;q=new vi;q.group="gameObject";q.Ud=B;n=new m(a,b);d=qj(c);for(f=0;f<d.length;f++)h=d[f].ca,k=d[f].Ia,l=d[f].position,t=n.ic(h.position).length(),0===t&&c.Cf(k,l),t<u&&(c.Cf(k,l),C++,q.V(t,function(a){return function(){a.Xi()}}(h)));C+=xj(c);q.V(u+(K.a.k.qa.Qk+K.a.k.qa.Rk)*B,function(){c.kf--;0===c.kf&&wj(c)});q.start();Hi(Y.e,a,b,C,C,!0)}
function tj(a,b,c){"undefined"===typeof a.Zn[b]&&(a.Zn[b]=[]);return!0===a.Zn[b][c]}function Gi(a,b,c,d,f,h,k){this.depth=c;this.h=this.visible=!0;this.group="gameObject";K.d.Ka(this,K.xh);this.x=a;this.y=b;this.b=d;this.duration=f;this.scale=h;this.pa=0;this.rotation=k||0;H(this);Pb(this,"game");this.l=0}Gi.prototype.Z=function(a){this.l+=a;this.pa=this.rotation;this.l>=this.duration&&I(G,this)};
Gi.prototype.za=function(){var a=ti(this.x,this.y);this.b.S(Math.floor(this.l*this.b.D/this.duration),a.x,a.y+Y.sb,this.scale*Y.bb,this.scale*Y.bb,this.pa,1)};function Aj(){this.Ua=this.depth=0;this.h=this.visible=!0;H(this);Pb(this,"game")}Aj.prototype.ro=function(){var a,b,c,d;a=[];b=[Od,Qd,Rd,Sd,Td,Vd,Wd,Xd];for(c=0;c<b.length;c+=1)d=b[c],a.push({b:d,text:K.m.N("TutorialText_"+c,"<TutorialText_"+c+">"),title:K.m.N("TutorialTitle_"+c,"<TutorialHeader_"+c+">")});return a};
function Ri(a,b){this.depth=11;this.h=this.visible=!0;this.group="gameObject";K.d.Ka(this,K.qf);this.Zc=new m(a,b);this.Dl=new m(0,-1);this.alpha=0;this.a=K.a.k.fe;this.G=[];H(this);Pb(this,"game")}
function Bj(a,b){var c,d,f,h,k=null,l;l=Y.Fa;c=qj(Y.da);for(d=0;d<c.length;d++)f=c[d].ca,h=new m(f.$a,f.Ma),h=a.ic(h).ic(b.scale(a.ic(h).ng(b))).length(),h<=l&&(null===k||f.Ma>k.Ma?k=f:f.Ma===k.Ma&&Math.abs(f.$a-a.x)<Math.abs(k.$a-a.x)&&(k=f));k?(h=a.ic(new m(k.$a,k.Ma)),c=2*h.ng(b),l=h.ng(h)-Math.pow(l,2),h=Math.pow(c,2)-4*l,l=(-c+Math.sqrt(h))/2,h=(-c-Math.sqrt(h))/2):(l=Math.abs(a.x/b.x),h=Math.abs(a.y/b.y));l=Math.min(l,h);return[b.scale(l).add(a)]}
Ri.prototype.Z=function(){this.G=0!==this.alpha&&1===this.a.fs?[this.Zc].concat(Bj(this.Zc,this.Dl)):[]};Ri.prototype.Ub=function(){this.ma&&I(G,this.ma);this.ma=new ei(this,{alpha:1},400,J);this.ma.group="gameObject";this.ma.start()};Ri.prototype.Vb=function(){this.ma&&I(G,this.ma);this.ma=new ei(this,{alpha:0},400,J);this.ma.group="gameObject";this.ma.start()};
Ri.prototype.za=function(){var a,b,c,d,f,h;switch(this.a.fs){case 1:d=p.context;d.lineWidth=this.a.lineWidth;d.strokeStyle="rgba(255, 255, 255, "+.2*this.alpha+")";c=this.a.Nv;h=0;for(f=1;f<this.G.length;f++){d.beginPath();d.moveTo(this.G[f-1].x,this.G[f-1].y+Y.sb);d.lineTo(this.G[f].x,this.G[f].y+Y.sb);for(var k=this.G[f].ic(this.G[f-1]).normalize(),l=this.G[f].ic(this.G[f-1]).length(),n=this.G[f-1];h<l;h+=2*c)d.beginPath(),a=k.scale(h).add(n),b=k.scale(Math.min(l,h+c)).add(n),d.moveTo(a.x,a.y+Y.sb),
d.lineTo(b.x,b.y+Y.sb),d.stroke();h-=l}2<=this.G.length&&Ld.fd(0,this.G[this.G.length-1].x,this.G[this.G.length-1].y+Y.sb,this.alpha);break;case 2:Kd.S(0,this.Zc.x,this.Zc.y+Y.sb,1,1,this.Dl.direction()-90,this.alpha)}};function Cj(a,b){Wi(this,a,b,0);this.h=!0;this.hr=mj(new nj);this.b=Ed;this.type="blank";this.K=new x(this.b.width,this.b.height);y(this.K);ye.o(this.hr,this.b.eb,this.b.Za);this.b.o(0,this.b.eb,this.b.Za);z(this.K)}Wf(Vi,Cj);Cj.prototype.op=function(){E.play(pf)};
Cj.prototype.fl=function(){sj(Y.da,this);yj(this.position.x,this.position.y,this.hr);this.h=!1;this.Kh();return!0};Cj.prototype.Kh=function(){E.play(hf)};Cj.prototype.dh=function(){this.K.S(this.$a-this.b.eb*this.scale*Y.bb,this.Ma+Y.sb-this.b.Za*this.scale*Y.bb,this.scale*Y.bb,this.scale*Y.bb,0,this.alpha)};function Dj(a,b){Wi(this,a,b,0);this.b=Bd;this.type="bomb";this.Kn=!1}Wf(Vi,Dj);e=Dj.prototype;e.fl=function(){sj(Y.da,this);this.Xi();return!0};
e.Xi=function(){!1===this.Kn&&(this.Kh(),this.h=!1,this.Kn=!0,zj(this.position.x,this.position.y),this.pop())};
e.pop=function(){var a,b;!1===this.Wb&&(this.Wb=!0,"undefined"!==typeof this.ma&&this.ma.finish(),this.ja("game"),Ob(this,3),a=new ei(this,{$a:this.position.x,Ma:this.position.y},K.a.k.qa.Bl,J),a.group="gameObject",a.start(),b=this,a=new ei(this,{scale:K.a.k.Ba.Ln},K.a.k.Ba.Rk,oc,function(){I(G,b);new Gi(b.position.x,b.position.y,b.depth,Jd,K.a.k.Ba.Qk,K.a.k.Ba.Yv)}),a.group="gameObject",a.start())};e.Kh=function(){E.play(gf)};
e.dh=function(){this.b.S(0,this.$a,this.Ma+Y.sb,this.scale*Y.bb,this.scale*Y.bb,0,this.alpha)};function Ej(a,b){Wi(this,a,b,"fire");K.d.Ka(this,K.qf);this.depth=1;this.h=!0;this.cn=this.l=0;this.b=Cd;this.kj=0;this.Te=!1;null===Fj&&(Fj=new Wb(0,0,this.size*K.a.k.jd.Dv));this.ob=Fj}Wf(Vi,Ej);var Fj=null;e=Ej.prototype;e.op=function(){E.play(nf)};e.Lm=function(){this.speed=Y.bb*Y.s.ca.speed*K.a.k.jd.Qy};
e.nb=function(){var a,b;a=this;Y.e.xy||(b=new vi,b.group="gameObject",b.V(K.a.k.jd.Pz,function(){a.kj+=xj(Y.da);wj(Y.da)}),b.start(),Hi(Y.e,this.position.x,this.position.y+L(80),this.kj,this.kj,!0));Y.background.Cf(this)};e.zt=function(a){E.play(of);var b=new vi;b.group="gameObject";b.V(100,function(){E.play(of)});b.start();Yi(this,a);this.Lm();this.On=new Gj(this.position.x,this.position.y);this.h=this.Te=!0};e.fl=function(){return!1};
e.Z=function(a){this.cn+=a;if(!0===this.Te){Zi(this,a,K.a.k.jd.wv);(0>this.position.y+L(0)+this.size||0>this.position.x||this.position.x>K.ld)&&I(G,this);for(var b=0;b<a;++b)this.l+=1,this.l>=K.a.k.jd.Vp/Dd.D&&(this.On=new Gj(this.position.x,this.position.y),this.l-=K.a.k.jd.Vp/Dd.D);this.On.x=this.position.x;this.On.y=this.position.y;a=Y.da;var c,d,f,h,k;k=!1;b=qj(a);for(c=0;c<b.length;c++)d=b[c].ca,f=b[c].Ia,h=b[c].position,!0===$b(d.ob,d.$a,d.Ma,this.ob,this.position.x,this.position.y)&&(d.Xi(),
a.Cf(f,h),k=!0);!0===k&&this.kj++}this.canvas.Y=!0};e.dh=function(){var a=new m(this.$a,this.Ma),b=new m(0,0);this.b.S(Math.floor(this.cn/80)%this.b.D,a.x+b.x,a.y+Y.sb+b.y,this.scale*Y.bb,this.scale*Y.bb,0,this.alpha)};function Gj(a,b){this.depth=2;this.h=this.visible=!0;this.group="gameObject";K.d.Ka(this,K.qf);this.pa=0;this.zy=-.2+(new fa).random(.4);this.x=a;this.y=b;this.l=this.index=0;this.scale=K.a.k.jd.scale;this.b=Dd;H(this);Pb(this,"game")}
Gj.prototype.Z=function(a){this.l+=a;this.pa+=this.zy*a;this.l>=K.a.k.jd.Vp/this.b.D&&(this.index+=1,this.l=0,Ob(this,this.depth+1));this.index===this.b.D&&I(G,this)};Gj.prototype.za=function(){var a=new m(this.x,this.y);this.b.S(this.index,a.x,a.y,this.scale,this.scale,this.pa,1)};function nj(){this.yd=Hj(Y.s.Ee);this.um=Ij(this.yd,!1);this.Xg=Ij(this.yd,!0);for(var a=0,b=0;5>=b;++b)0<this.yd[b]&&a++;this.Rz=a}
function Jj(a,b){switch(b){case 0:return a.Jb;case 1:return a.Kb;case 2:return a.Lb;case 3:return a.Mb;case 4:return a.Nb;case 5:return a.Ob;case 6:return a.Pb;case 7:return a.Qb;case 8:return a.Rb;case 9:return a.Sb}}function Hj(a){var b=[0,0,0,0,0,0],c;for(c=Math.floor(Y.uc.Ah()/10);0<=c&&!(b=Jj(a,c));--c);return b}function Ij(a,b){var c,d=0;for(c=0;c<(b?6:a.length);++c)a[c]&&(d+=a[c]);return d}function mj(a){for(var b=Y.da.random.random(a.Xg),c=0,d=0;5>=d;++d)if(c+=a.yd[d],c>b)return d}
function rj(a,b){Wi(this,a,b,"blocker");this.b=Fd;this.type="blocker";this.Kn=!1}Wf(Vi,rj);rj.prototype.dh=function(){gj(this);this.b.S(0,this.$a,this.Ma+Y.sb,this.scale*Y.bb,this.scale*Y.bb,0,this.alpha)};function zi(){this.jb={Ba:0,tn:0,jd:0,all:0}}
function Kj(a,b){var c=5*(Y.s.s.border-pj(Y.da))+Y.Gc.cb;!b&&10>=c?(1===c?a.lc=Y.s.ub.ue:2===c?a.lc=Y.s.ub.ve:3===c?a.lc=Y.s.ub.we:4===c?a.lc=Y.s.ub.xe:5===c?a.lc=Y.s.ub.ye:6===c?a.lc=Y.s.ub.ze:7===c?a.lc=Y.s.ub.Ae:8===c?a.lc=Y.s.ub.Be:9===c?a.lc=Y.s.ub.Ce:10===c&&(a.lc=Y.s.ub.te),a.lc||(a.lc=Hj(Y.s.ub))):a.lc=Hj(Y.s.ub);a.um=Ij(a.lc);Y.uc.Uh.O()}
function Qi(a,b){var c=Y.Zq;Kj(c);for(var d=0;;){for(var f=Y.Gc.random.random(c.um),h=0,k=0;k<c.lc.length;++k)if(h+=c.lc[k],h>=f){if(0===k){c=a;d=b;f=void 0;if(!f){f=void 0;h=Y.da;f=f||ij(h);h=[];for(k=0;k<f.length;++k)0<f[k]&&h.push(k);0===h.length&&h.push(mj(new nj));f=h}f=+f[0+ha(Y.Gc.random,f.length-1-0)];return new Vi(c,d,f)}if(1===k){for(var c=a,d=b,f=new nj,h=ij(Y.da),l=0,k=void 0,k=0;6>k;++k)l=Math.max(h[k],l);for(k=0;6>k;++k)0!==h[k]?(h[k]=l-h[k],h[k]*=h[k]):h[k]=0;l=Ij(h,!0);0===l&&mj(f);
for(var n=[0,0,0,0,0,0],k=0;6>k;++k)n[k]=h[k]/l*f.yd[k];f.yd=n;f.Xg=Ij(f.yd,!0);0===f.Xg&&(f.yd=h,f.Xg=l);0===f.Xg&&(f.Xg=10);f=mj(f);return new Vi(c,d,f)}if(2===k){if(0<c.jb.Ba||0<c.jb.all)break;c.jb.Ba+=Y.s.Ec.Ba;c.jb.all+=Y.s.Ec.all;return new Dj(a,b)}if(3===k){if(0<c.jb.tn||0<c.jb.all)break;c.jb.tn+=Y.s.Ec.kb;c.jb.all+=Y.s.Ec.all;return new Cj(a,b)}if(4===k){if(0<c.jb.jd||0<c.jb.all)break;c.jb.jd+=Y.s.Ec.Ne;c.jb.all+=Y.s.Ec.all;return new Ej(a,b)}if(5===k)return new Vi(a,b,jj(Y.da))}++d;100===
d&&Kj(c,!0);200===d&&(c.lc=[1],c.um=1)}throw"generateBubbleOrSpecialBubble";}K.version=K.version||{};K.version.theme="1.0.1";K.a.w.Ki={christmasGreen:{font:{align:"center",i:"middle",fillColor:"#004e00",I:{h:!0,color:"#75e83d",offsetX:0,offsetY:2,blur:0}}},christmasRed:{font:{align:"center",i:"middle",fillColor:"#770000",I:{h:!0,color:"#f65e73",offsetX:0,offsetY:2,blur:0}}}};
function Lj(a,b){if(void 0===a)console.log("ANALYTICS WARNING: No ID passed");else{var c;c=[];for(var d="[levelnumber];[amount of stars];[tutorialnumber];[number of day];[rewardname];[booster name];[gate number];[stagenumber]".split(";"),f=a,h=0;h<d.length;h++)a.ms(d[h])&&c.push(d[h]);if("[object Array]"===Object.prototype.toString.call(b)&&b.length===c.length)for(h=0;h<c.length;h++)f=f.replace(c[h],b[h].toString());else void 0!==b&&"[object Array]"!==Object.prototype.toString.call(b)&&1===c.length?
f=a.replace(c[0],b.toString()):void 0===b&&0===c.length||console.log("ANALYTICS WARNING: Some arguments are not correct!");c=f;console.log("ID SEND TO ANALYTICS: "+c);try{analytics.customEvent(c)}catch(k){console.log("error calling analytics.menu: "+k)}}}function Mj(){String.prototype.ms||(String.prototype.ms=function(a,b){"number"!==typeof b&&(b=0);return b+a.length>this.length?!1:-1!==this.indexOf(a,b)})}
var $=new function(){this.X={Vz:"Initialize-loading",Qu:"Initialize-finished",Pu:"Game-loading",Ou:"Game-finished",Rw:"level-[levelnumber]-start",Sw:"level-[levelnumber]-won-[amount of stars]",Pw:"level-[levelnumber]-lost",Lo:"level-[levelnumber]-completeonce",Qw:"level-[levelnumber]-restart",Pn:"firsttime-initialize",Rn:"firsttime-menu",Sn:"firsttime-play",Qn:"firsttime-level-[levelnumber]-start",UA:"firsttime-tutorial[tutorialnumber]-step[step number]",$v:"firsttime-level-[levelnumber]-won-[amount of stars]",
Vy:"stage-[stagenumber]-start",Wy:"stage-[stagenumber]-won",Ty:"stage-[stagenumber]-lost",Gp:"stage-[stagenumber]-completeonce",Uy:"stage-[stagenumber]-restart",Un:"firsttime-stage-[stagenumber]-start",Vn:"firsttime-stage-[stagenumber]-won",Tn:"firsttime-stage-[stagenumber]-lost",GA:"dailyspin_counter reset_day[number of day]",HA:"dailyspin_day[number of day]  ",AC:"reward_[rewardname]",BC:"reward_no reward",CC:"reward_spin again",fC:"premiumspin_day[number of day]",eC:"premiumreward_[rewardname]",
hC:"purchase_booster_[booster name]_[levelnumber]",sD:"use_booster_[booster name]_[levelnumber]",iC:"purchase_extramoves_[levelnumber]",jC:"purchase_gate unlock_[gate number]",gC:"purchase_adremoval"};Mj()};K.j=K.j||{};var Nj=window.publisher,Oj=!1,Pj=-1;K.j.el=function(){document.title=Nj.gameName;K.j.He($.X.Pn)||(Lj($.X.Pn),K.j.We($.X.Pn));Lj($.X.Qu);Lj($.X.Pu);Nj.geoLocking?Qj(this.or):this.or()};
K.j.or=function(){K.orientation&&(K.orientation=0<=ba.indexOf("landscape")?"landscape":"portrait");new vc(Nj,K.orientation,K.e.Hd,K.e.Tb,K.e.Bd,this);var a=window.navigator.userAgent,b=!1,c=/Chrome/.test(window.navigator.userAgent)&&/Google Inc/.test(window.navigator.vendor),d=/SHL24|SHL23|SHL22|SHL25|SHL21/i.test(a)&&!c,a=/SH-01F/i.test(a)&&!c;Nj.removeMoreGamesButton&&(this.pt("startScreen","moreGames"),this.pt("levelMapScreen","moreGames"),this.pt("inGame","moreGames"));if(window.ActiveXObject||
"ActiveXObject"in window)b=!0;if(d||a)K.e.oj=!1;if(b||a||d)K.e.pj=!1;Nj.moreGames||(K.j.gl=void 0)};K.j.rs=function(){K.j.He($.X.Rn)||(Lj($.X.Rn),K.j.We($.X.Rn));Lj($.X.Ou);try{analytics.customEvent("menu")}catch(a){console.log("error calling analytics.menu: "+a)}};
K.j.qs=function(a,b){var c=this;Nj.enableAds&&!Oj&&(setTimeout(function(){c.Yr()},1E3*Nj.firstAd),setTimeout(function(){c.Xy()},1E3*Nj.firstAd),Oj=!0);Pj=b?b:-1;K.j.He($.X.Sn)||(Lj($.X.Sn),K.j.We($.X.Sn));K.j.He($.X.Qn+"_"+Pj)||(Lj($.X.Qn,Pj),K.j.We($.X.Qn+"_"+Pj));Lj($.X.Rw,Pj)};K.j.Xy=function(){var a=this;setInterval(function(){a.Yr()},1E3*Nj.adFreq)};K.j.Yr=function(){K.q.ee=!0};
K.j.At=function(){if(K.q.ee)try{K.e.Hd(),adSense.showAdvertising({callback:K.e.Tb}),K.q.ee=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),K.e.Tb()}};K.j.XC=function(a){try{K.e.Hd(),adSense.showAdvertising({callback:function(){K.e.Tb();a&&a()}})}catch(b){console.log("error calling adSense.showAdvertising: "+b),K.e.Tb()}};
K.j.os=function(a){try{var b=a.totalScore||Rj();a.timeBonus&&(b+=a.timeBonus);community.submitScore({score:b,callback:function(){if(K.q.ee)try{K.e.Hd(),adSense.showAdvertising({callback:K.e.Tb}),K.q.ee=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),K.e.Tb()}}});analytics.customEvent("score"+b)}catch(c){console.log("error submitting highscore: "+b+", "+c)}};
K.j.Dh=function(a){var b=-1;a.level&&(b=a.level);if(a.failed){Lj($.X.Pw,b);try{analytics.customEvent("levelFailed"+b)}catch(c){console.log("error calling analytics.levelFailed: "+c)}}else{void 0===a.stars&&(a.stars="undefined stars");Lj($.X.Sw,[b,a.stars]);K.j.He($.X.Lo+"_"+b)||(Lj($.X.Lo,b),Lj($.X.$v,[b,a.stars]),K.j.We($.X.Lo+"_"+b));try{analytics.customEvent("level"+b)}catch(d){console.log("error calling analytics.level: "+d)}}if(K.q.ee)try{K.e.Hd(),adSense.showAdvertising({callback:function(){K.e.Tb();
K.e.Bd()}}),K.q.ee=!1}catch(f){console.log("error calling adSense.showAdvertising: "+f),K.e.Tb(),K.e.Bd()}else K.e.Bd()};K.j.hB=function(a){try{community.submitScore({score:a,callback:function(){if(K.q.ee&&!Nj.disableEndScreenAds)try{K.e.Hd(),adSense.showAdvertising({callback:K.e.Tb}),K.q.ee=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),K.e.Tb()}}}),analytics.customEvent("score"+a)}catch(b){console.log("error submitting highscore: "+a+", "+b)}};K.j.ns=function(){Lj($.X.Qw,Pj)};
K.j.ps=function(){if(K.q.ee)try{K.e.Hd(),adSense.showAdvertising({callback:function(){K.e.Tb()}}),K.q.ee=!1}catch(a){console.log("error calling adSense.showAdvertising: "+a),K.e.Tb()}};K.j.gl=function(){if(Nj.moreGamesUrl&&""!==Nj.moreGamesUrl)K.j.Jd(Nj.moreGamesURL);else try{moregames.redirect()}catch(a){console.log("error calling moregames.redirect: "+a)}};K.j.gj=function(){return Nj.stripBranding?[]:[{b:qd,url:K.q.Co,zb:this.gl}]};K.j.$B=function(a,b,c,d,f){freemium.purchase(a,b,c,d,f)};
K.j.aD=function(a,b){K.e.Hd();try{Sj.$x(function(){a&&a();K.e.Tb()},this)}catch(c){b&&b(),K.e.Tb()}};K.j.He=function(a){if(void 0!==dg(a,void 0,"game"))return!0;!1};K.j.We=function(a){fg(a,1,"game")};
K.j.bD=function(a,b){switch(a){case "start":Lj($.X.Vy,b);K.j.He($.X.Un+" "+b)||(Lj($.X.Un,b),K.j.We($.X.Un+" "+b));break;case "won":Lj($.X.Wy,b);K.j.He($.X.Vn+" "+b)||(Lj($.X.Vn,b),K.j.We($.X.Vn+" "+b));break;case "lost":Lj($.X.Ty,b);K.j.He($.X.Tn+" "+b)||(Lj($.X.Tn,b),K.j.We($.X.Tn+" "+b));break;case "complete":K.j.He($.X.Gp+" "+b)||(Lj($.X.Gp,b),K.j.We($.X.Gp+" "+b));break;case "restart":Lj($.X.Uy,b)}};K.version=K.version||{};K.version.configuration_boostermedia="2.6";"use strict";
function Tj(){this.jk=Nj;this.$j=new XMLHttpRequest;this.cv="http://geoip.api.boostermedia.com/"}
function Qj(a){var b=new Tj;b.$j.onload=function(){var c=JSON.parse(this.responseText),d=b.jk.allowedCountries&&-1!==b.jk.allowedCountries.indexOf(c.country_code);if(b.jk.allowedIPs&&-1!==b.jk.allowedIPs.indexOf(c.ip)||d)a(0);else if(console.error("GeoLocking: Accessing from wrong location: "+c.country_code),c=document.getElementById("geolocking"))c.style.display="block"};b.$j.onerror=function(){a(0);console.warn("GeoLocking: Couldn't access location service due to error: "+error)};b.$j.open("GET",
b.cv);b.$j.send(null)}"use strict";
var Sj=new (function(){function a(){window.addEventListener("message",function(a){this.vy(a)}.bind(this),!1)}a.prototype.Xu=function(){return g.ce.cp||g.ce.Sp||g.ce.Jz?{Pr:"adFrameMobile",Hq:"adtechMobile",width:320,height:250,Mu:publisher.mobileRewardId}:{Pr:"adFrame",Hq:"adtech",width:640,height:480,Mu:publisher.desktopRewardId}};a.prototype.$x=function(a,c){this.dv=a;this.ev=c;var d=this.Xu(),f=Math.floor(1E9*Math.random());this.wd=document.createElement("div");this.wd.className="adOverlay";var h=
document.createElement("div");h.className="adBg";var k=document.createElement("div");k.className=d.Pr;this.Tf=document.createElement("iframe");this.Tf.src="http://media.oadts.com/www/delivery/afv.php?zoneid="+d.Mu+"&cb="+f;this.Tf.WA="0";this.Tf.scrolling="no";this.Tf.width=d.width;this.Tf.height=d.height;this.Tf.className=d.Hq;this.wd.appendChild(h);this.wd.appendChild(k);this.wd.appendChild(this.Tf);document.body.appendChild(this.wd)};a.prototype.jr=function(){this.wd&&(document.body.removeChild(this.wd),
this.wd=null);this.dv.call(this.ev,!0)};a.prototype.vy=function(a){if("http://media.oadts.com"===a.origin&&this.wd)switch(console.log(a),a.data){case "noVideo":case "NoVideo":document.body.removeChild(this.wd);this.wd=null;this.jr();break;case "videoEnds":case "videoComplete":this.jr()}};return a}());
function Uj(){this.depth=-1E6;this.h=this.visible=!0;this.Ua=K.Oe;this.end=this.wa=this.Jo=this.Io=this.load=this.wc=!1;this.Wn=0;this.fq=this.Wj=!1;this.state="GAME_INIT";this.screen=null;this.ep=this.Ab=this.B=0;this.Xn=!1;this.oj=this.pj=!0;this.Nx=1;this.zd=!1;this.qd={};this.ra={difficulty:1,playMusic:!0,playSFX:!0,language:K.m.oo()};window.addEventListener("gameSetPause",this.Hd,!1);window.addEventListener("gameResume",this.Tb,!1);document.addEventListener("visibilitychange",this.xw,!1);this.Tg=
"timedLevelEvent"}e=Uj.prototype;e.Hd=function(){E.pause("master");G.pause()};e.Tb=function(){E.Gj("master");zb(G);Eb(G);Ib(G);G.Gj()};e.xw=function(){document.hidden?K.e.Hd():K.e.Tb()};
e.gf=function(){var a,b=this;void 0!==K.a.R.background&&void 0!==K.a.R.background.color&&(document.body.style.background=K.a.R.background.color);K.Na=new bg;K.q.jl&&K.q.jl.h&&(b.zu=wh(function(a){b.zu=a}));K.n=K.a.k.pg||{};K.n.de=K.n.de||"level";K.n.Qh=void 0!==K.n.Qh?K.n.Qh:"level"===K.n.de;K.n.na=void 0!==K.n.na?K.n.na instanceof Array?K.n.na:[K.n.na]:[20];K.n.Ti=void 0!==K.n.Ti?K.n.Ti:"locked";K.n.em=void 0!==K.n.em?K.n.em:"difficulty"===K.n.de;K.n.Tj=void 0!==K.n.Tj?K.n.Tj:!1;K.n.Ep=void 0!==
K.n.Ep?K.n.Ep:"level"===K.n.de;K.n.qh=void 0!==K.n.qh?K.n.qh:"max";K.n.Bp=void 0!==K.n.Bp?K.n.Bp:"number";K.j.ow(function(a){var d,f,h;a&&(b.qd=a);b.ra=dg("preferences",{});b.ra.difficulty=void 0!==b.ra.difficulty?b.ra.difficulty:1;void 0!==K.n.$t&&0>K.n.$t.indexOf(sg())&&(b.ra.difficulty=K.n.$t[0]);b.ra.playMusic=void 0!==b.ra.playMusic?b.ra.playMusic:!0;b.Eg(b.ra.playMusic);b.ra.playSFX=void 0!==b.ra.playSFX?b.ra.playSFX:!0;b.Rl(b.ra.playSFX);b.ra.language=void 0!==b.ra.language&&K.m.Iw(b.ra.language)?
b.ra.language:K.m.oo();K.m.vt(b.ra.language);void 0===Bg(b.B,0,"state",void 0)&&Vj(b.B,0,"state","unlocked");if(K.n.Qh)if("locked"===K.n.Ti)for(h=!1,d=0;d<K.n.na.length;d++){for(a=0;a<K.n.na[d];a++)if(f=Bg(d,a,"state","locked"),"locked"===f){b.B=0<=a-1?d:0<=d-1?d-1:0;h=!0;break}if(h)break}else void 0!==b.ra.lastPlayed&&(b.B=b.ra.lastPlayed.world||0)});b.di=Wj();void 0!==b.di.authToken&&void 0!==b.di.challengeId&&(b.zd=!0);K.q.rD&&(this.kc=this.oD?new TestBackendServiceProvider:new BackendServiceProvider,
this.kc.ts(function(a){a&&K.e.kc.oB(b.di.authToken)}));a=parseFloat(g.t.version);E.hb&&(g.ab.gq&&g.t.Cl||g.t.Yh&&a&&4.4>a)&&(E.hk=1);this.wc=!0;this.kl=0};function Wj(){var a,b,c,d,f;b={};if(a=window.location.search.substring(1))for(a=a.split("&"),d=0,f=a.length;d<f;d++)c=a[d].split("="),b[c[0]]=c[1];return b}function Xj(a){a.state="GAME_LOAD";a.screen=new mg(function(){K.e.load=!0;mh(K.e,!0);K.se.uo();K.j.uo()},function(){},K.q.$C)}function mh(a,b){a.Wj=b||!1;a.fq=!0;a.Wn++}
function Yj(){var a=K.e;a.Wn--;switch(a.state){case "GAME_INIT":a.wc&&!a.uD&&(a.zd&&a.kc&&a.kc.dD(a.di.challengeId,function(b){!b&&a.screen&&"function"===typeof a.screen.Dp&&a.screen.Dp("challengeLoadingError_notValid")}),Xj(a));break;case "GAME_LOAD":if(a.load){if(a.zd&&a.kc)if(a.kc.Hw())qg(a),tg(a.Td.mode);else{a.screen.Dp("challengeLoadingError_notStarted");break}I(G,a.screen);"function"===typeof Aj&&(K.k=new Aj);void 0!==K.q.sv&&!1!==K.q.sv.show&&K.d.gv();lh(a)}break;case "LEVEL_INIT":a.Io&&ak(a);
break;case "LEVEL_LOAD":a.Jo&&bk(a);break;case "LEVEL_END":if(a.wa)switch(kh(),K.e.Io=!1,K.e.Jo=!1,K.s=void 0,K.d.ug(K.qf).Y=!0,K.d.ug(K.al).Y=!0,K.e.zs){case "retry":xg(K.e,K.e.Ab);break;case "next":K.n.Qh?K.e.Ab+1<K.n.na[K.e.B]?xg(K.e,K.e.Ab+1):K.e.B+1<K.n.na.length?xg(K.e,0,K.e.B+1):K.n.Ep?(K.e.state="GAME_END",K.e.end=!0,mh(K.e,!1),K.j.tw()):K.e.screen=new wg:xg(K.e,0);break;case "exit":K.n.Qh?K.e.screen=new wg:lh(K.e)}break;case "GAME_END":a.end&&(a.end=!1,K.e.screen=null,K.e.screen=new oh)}}
e.Bd=function(){K.e.fq=!1};function fh(){var a;if(void 0!==K.e.di.more_games)try{return a=decodeURIComponent(K.e.di.more_games),function(){K.j.Jd(a)}}catch(b){}if("string"===typeof K.Nh.moreGamesUrl&&""!==K.Nh.moreGamesUrl)return function(){K.j.Jd(K.Nh.moreGamesUrl)};if(void 0!==K.q.Gx)return function(){K.j.Jd(K.q.Gx)};if("function"===typeof K.j.gl)return K.j.gl}function qg(a){if(a.zd&&void 0!==a.kc)return void 0===a.Td&&(a.Td=a.kc.dB()),a.Td}e.aj=function(a){K.e.zd&&K.e.kc&&K.e.kc.aj(a)};
e.Ni=function(a){K.e.zd&&K.e.kc&&K.e.kc.Ni(a)};function sg(){return K.e.ra.difficulty}function jh(){switch(sg()){case 0:return"easy";case 1:return"medium";case 2:return"hard";default:throw"Unknown difficulty: "+sg();}}function Oh(){var a="optionsDifficulty_"+jh();return K.m.N(a,"<"+a+">")}function tg(a){K.e.ra.difficulty=a;fg("preferences",K.e.ra)}e.Eg=function(a){void 0!==a&&(K.e.ra.playMusic=a,fg("preferences",K.e.ra),a?pb("music"):ob("music"));return K.e.ra.playMusic};
e.Rl=function(a){void 0!==a&&(K.e.ra.playSFX=a,fg("preferences",K.e.ra),a?(pb("game"),pb("sfx")):(ob("game"),ob("sfx")));return K.e.ra.playSFX};e.language=function(a){void 0!==a&&(K.e.ra.language=a,fg("preferences",K.e.ra));return K.e.ra.language};function Vj(a,b,c,d){var f="game";"game"!==f&&(f="tg");void 0===K.e.qd["level_"+a+"_"+b]&&(K.e.qd["level_"+a+"_"+b]={tg:{},game:{}});void 0===c?K.e.qd["level_"+a+"_"+b][f]=d:K.e.qd["level_"+a+"_"+b][f][c]=d;K.j.yu()}
function Bg(a,b,c,d){var f="game";"game"!==f&&(f="tg");a=K.e.qd["level_"+a+"_"+b];return void 0!==a&&(a=void 0===c?a[f]:a[f][c],void 0!==a)?a:d}function dg(a,b,c){var d;"game"!==c&&(c="tg");d=K.e.qd.game;return void 0!==d&&(d=void 0===a?d[c]:d[c][a],void 0!==d)?d:b}function fg(a,b,c){"game"!==c&&(c="tg");void 0===K.e.qd.game&&(K.e.qd.game={tg:{},game:{}});void 0===a?K.e.qd.game[c]=b:K.e.qd.game[c][a]=b;K.j.yu()}
function Ig(a,b,c){var d=K.e;void 0===b&&(b=d.Ab);void 0===c&&(c=d.B);return void 0===a?Bg(c,b,"stats",{}):Bg(c,b,"stats",{})[a]}function xh(){var a=Ig("highScore",void 0,void 0);return"number"!==typeof a?0:a}function Rj(){var a,b,c,d=0;for(a=0;a<K.n.na.length;a++)for(b=0;b<K.n.na[a];b++)c=Ig(void 0,b,a),"object"===typeof c&&null!==c&&(d+=void 0!==c.highScore?c.highScore:0);return d}function lh(a){a.screen&&I(G,a.screen);a.screen=new pg;a.Ab=-1;K.j.rs()}
function Yh(a,b,c,d){var f;f=void 0!==K.a.R.lj&&void 0!==K.a.R.lj.backgroundImage?K.a.R.lj.backgroundImage:void 0!==K.a.w.lj?K.a.w.lj.backgroundImage:void 0;K.d.ja(K.qg);a=a||0;b=b||0;c=c||p.width;d=d||p.height;if(f)if(c=Math.min(Math.min(c,p.width),f.Qi),d=Math.min(Math.min(d,p.height),f.ph),void 0!==f){var h=a,k=b-K.Rq,l,n,q;for(l=0;l<f.D;l+=1)n=l%f.Jh*f.width,q=f.height*Math.floor(l/f.Jh),n>h+c||n+f.width<h||q>k+d||q+f.height<k||f.Da(l,h-n,k-q,c,d,a,b,1)}else sa(a,b,c,d,"white",!1)}
function xg(a,b,c){a.state="LEVEL_INIT";void 0===c||(a.B=c);a.Ab=b;a.Io=!0;mh(a,!1);K.j.uw()}function ak(a){a.state="LEVEL_LOAD";a.Jo=!0;mh(a,!1);K.j.vw()}
function bk(a){var b;if(a.B<K.n.na.length&&a.Ab<K.n.na[a.B]){a.state="LEVEL_PLAY";a.ep+=1;a.wa=!1;a.screen=null;Yh(0,K.Rq);b=K.Na;var c=ih(a,3),d="progression:levelStarted:"+jh(),f=a.Tg,h;for(h=0;h<b.la.length;h++)if(!b.la[h].h){b.la[h].l=0;b.la[h].paused=0;b.la[h].h=!0;b.la[h].Wv=c;b.la[h].Wx=d;b.la[h].tag=f;break}h===b.la.length&&b.la.push({h:!0,l:0,paused:0,Wv:c,Wx:d,tag:f});b.gb(c,d,void 0,K.oa.Jc.oq);b.gb("Start:","progression:levelStart:"+c,void 0,K.oa.Jc.Yj);for(b=0;b<a.B;b++);K.j.qs(a.B,a.Ab);
a.ra.lastPlayed={world:a.B,level:a.Ab};K.s=new yi}}function Cg(a,b,c){var d=0;void 0===b&&(b=a.B);void 0===c&&(c=a.Ab);for(a=0;a<b;a++)d+=K.n.na[a];return d+c}function Ji(a,b,c,d){new ph(a,b,c,d)}function ih(a,b){var c,d=a.Ab+"",f=b-d.length;if("number"===typeof b&&1<b)for(c=0;c<f;c++)d="0"+d;return d}
function Oi(){function a(a,b){return"number"!==typeof a?!1:"number"!==typeof b||"max"===K.n.qh&&a>b||"min"===K.n.qh&&a<b?!0:!1}var b=K.e,c={totalScore:Y.uc.am.O(),stage:Y.uc.Uh.O()};b.state="LEVEL_END";var d,f,h,k,l,n,q={},u=ih(b,3),c=c||{};c.level=K.n.Tj?b.Ab+1:Cg(b)+1;c.ls=!1;f=(d=Bg(b.B,b.Ab,"stats",void 0))||{};if(void 0!==c.be||void 0!==c.Yb){void 0!==c.be&&(q[c.be.id]=c.be.P(),"highScore"===c.be.id&&(n=c.be));if(void 0!==c.Yb)for(k=0;k<c.Yb.length;k++)q[c.Yb[k].id]=c.Yb[k].P(),"highScore"===
c.Yb[k].id&&(n=c.Yb[k]);for(k in q)l=q[k],void 0!==l.Pf&&(q[l.im].gd=l.Pf(q[l.im].gd));void 0!==q.totalScore&&(h=q.totalScore.gd)}else h=c.totalScore,void 0!==h&&void 0!==c.timeBonus&&(h+=c.timeBonus);k="";if(!0!==c.failed){k="Complete:";if(void 0!==h){K.Na.gb(k,"level:"+u,h,K.oa.Jc.Yj);if(void 0===d||a(h,d.highScore))f.highScore=h,c.ls=!0,K.Na.gb("highScore",":score:"+jh()+":"+u,h,K.oa.Jc.Gm);void 0!==n&&(n.gd=f.highScore);c.highScore=f.highScore}void 0!==c.stars&&(f.stars=c.stars,K.Na.gb("stars",
":score:"+jh()+":"+u,c.stars,K.oa.Jc.Gm));b.Ab+1<K.n.na[b.B]?"locked"===Bg(b.B,b.Ab+1,"state","locked")&&Vj(b.B,b.Ab+1,"state","unlocked"):b.B+1<K.n.na.length&&"locked"===Bg(b.B+1,0,"state","locked")&&Vj(b.B+1,0,"state","unlocked");Vj(b.B,b.Ab,void 0,{stats:f,state:"played"});void 0!==b.kc&&(d=K.k&&K.k.pw?K.k.pw():Rj(),void 0!==d&&b.kc.mD(d,K.n.Bp));hg(K.Na,b.Tg,u,"progression:levelCompleted:"+jh())}else K.Na.gb("Fail:","level:"+u,h,K.oa.Jc.Yj),hg(K.Na,b.Tg,u,"progression:levelFailed:"+jh());var B=
{totalScore:h,level:c.level,highScore:c.highScore,failed:!0===c.failed,stars:c.stars,stage:c.stage};K.j.In&&K.j.In();new Jg(K.n.de,c,function(a){K.e.wa=!0;K.e.zs=a;mh(K.e,!0);K.j.Dh(B);K.se.Dh(B)})}e.Hj=function(){K.e.Sh(!0)};e.Sh=function(a,b,c){var d="inGame";K.e.screen instanceof pg?d="startScreen":K.e.screen instanceof wg?d="levelMapScreen":b&&(d=K.e.Td.Ev===K.e.Td.gr?"inGame_challenger":"inGame_challengee");K.e.Zf||(K.e.Zf=new ch(d,!0===a,b,c))};
function ci(a){var b=[],c,d,f,h,k;K.e.Zf||K.e.jf||(K.e.Td.Ev===K.e.Td.gr?(c=K.m.N("challengeCancelConfirmText","<CHALLENGECANCELCONFIRMTEXT>"),d="challengeCancelConfirmBtn_yes",f="challengeCancelConfirmBtn_no",k=function(a){var b=a?"challengeCancelMessage_success":"challengeCancelMessage_error",b=K.m.N(b,"<"+b.toUpperCase()+"<");K.e.jf&&th(b);a&&Wg()},h=function(){K.e.Ni(k);return!0}):(c=K.m.N("challengeForfeitConfirmText","<CHALLENGEFORFEITCONFIRMTEXT>"),d="challengeForfeitConfirmBtn_yes",f="challengeForfeitConfirmBtn_no",
k=function(a){var b=a?"challengeForfeitMessage_success":"challengeForfeitMessage_error",b=K.m.N(b,"<"+b.toUpperCase()+"<");if(K.e.jf&&(th(b),a)){var b=K.m.N("challengeForfeitMessage_winnings",""),b=b.replace("<NAME>",K.e.Td.bC[K.e.Td.gr]),b=b.replace("<AMOUNT>",K.e.Td.tD),c=K.e.jf,d,f,h,k;d=V.P();c.a.Vt&&A(d,c.a.Vt);f=Sa(d,b,c.a.oy,c.a.ny,!0);f<d.fontSize&&D(d,f);f=d.aa(b,c.a.tp)+10;h=d.T(b,c.a.sp)+10;k=K.d.Ca(c.a.py,c.f.b.width,f,d.align);h=K.d.Ca(c.a.qy,c.f.b.height-sh(c),h,d.i);y(c.f.b);d.o(b,
k,h,f);z(c.f.b)}a&&Wg()},h=function(){K.e.aj(k);return!0}),b.push({U:d,ea:h,va:K.e}),b.push({U:f,ea:function(){K.e.jf.close();K.e.jf=null;return!0}}),K.e.jf=new rh(c,b,a),K.e.Zf=K.e.jf)}e.np=function(){var a,b;b=Qb(G,"game");for(a=0;a<b.length;a++)"function"===typeof b[a].Ao&&b[a].Ao();ig();Rb("game");Jb()};function Wg(a){var b,c;c=Qb(G);for(b=0;b<c.length;b++)"function"===typeof c[b].Ao&&c[b].Ao();Rb();Jb();ig();a&&(a.L=Math.max(0,a.L-1));Sb("system")}
function bh(){var a,b;b=Qb(G);for(a=0;a<b.length;a++)"function"===typeof b[a].ww&&b[a].ww();Sb();a=G;for(b=0;b<a.jc.length;b+=1)a.jc[b].paused=Math.max(0,a.jc[b].paused-1);a=K.Na;b=K.e.Tg;var c;for(c=0;c<a.la.length;c++)void 0!==a.la[c]&&a.la[c].tag===b&&(a.la[c].paused-=1,a.la[c].paused=Math.max(a.la[c].paused,0))}function kh(){var a;K.s&&I(G,K.s);for(a=Qb(G,"LevelStartDialog");0<a.length;)I(G,a.pop())}
function gg(){var a="";K.version.builder&&(a=K.version.builder);K.version.tg&&(a+="-"+K.version.tg);K.version.game&&(a+="-"+K.version.game);K.version.config&&(a+="-"+K.version.config);return a}e.ac=function(){this.wc||(this.gf(),mh(K.e,!0),K.se.el(),K.j.el())};
e.Z=function(a){"function"===typeof this.Qr&&(this.Qr(),this.Qr||K.e.Bd());0<this.Wn&&(this.Wj||this.fq||Yj());700>this.kl&&(this.kl+=a,700<=this.kl&&(K.q.Kz&&void 0!==K.q.bj&&K.q.bj.Xk&&K.q.bj.cm&&K.Na.start([K.q.bj.Xk,K.q.bj.cm]),void 0===Bg(this.B,0,"state",void 0)&&Vj(this.B,0,"state","unlocked")))};e.Oc=function(a,b){"languageSet"===a&&K.e.language(b)};e.Pe=function(){var a,b;for(a=0;a<K.Yd.length;a++)b=K.Yd[a],b.Y&&(p.ja(b),p.clear())};
e.za=function(){var a;for(a=0;a<K.Yd.length;a++)K.Yd[a].Y=!1};K.dz=function(){K.e=new Uj;H(K.e);Pb(K.e,"system")};(void 0===K.kv||K.kv)&&K.dz();
}());
